# -*- encoding: utf-8 -*-
"""
This large list of real cars (uk models) might be useful to teachers for
projects and classes, or perhaps scientists to test data modelling software.
Each car in the collection has a model name, a make class - which includes
the manufacturer's name and a badge - and are grouped into types
(e.g. hatchback, saloon).

**Usage:**

::

    from liar.iamaliar import IAmALiar
    number_records = 10
    maker = IAmALiar(number_records)

    # Use:
    from liar.model.raw import car_raw

    # Or from scratch:
    car_raw = {
        'name': 'car_raw',
        'class': 'igetraw',
        'data': 'car',
    }

    data_set = maker.get_data([car_raw])

    for row in data_set:
        data = Model()
        data.make = row['car_raw']['make']
        data.model = row['car_raw']['model']
        data.shape = row['car_raw']['shape']
        data.save()

"""

car = [
    {"make": "citroen", "model": "xantia sx 1905cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus ghia 2.0 4dr", "shape": "saloon"},
    {"make": "peugeot", "model": "106 xn 1124cc", "shape": "hatchback"},
    {
        "make": "subaru",
        "model": "legacy classic gl 1994cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo gh.x 2.0td", "shape": "saloon"},
    {"make": "vauxhall", "model": "tigra 1.6 coupe", "shape": "sportscoupe"},
    {"make": "volkswagen", "model": "golf gl 1781cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 lx 1905cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "omega gls 1998cc", "shape": "saloon"},
    {
        "make": "volkswagen",
        "model": "passat sport 20v turbo 1781cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "saab", "model": "9000 cse ecopower 2290cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec ghia 1388cc", "shape": "hatchback"},
    {"make": "ford", "model": "cougar 16v 2.0 3dr", "shape": "sportscoupe"},
    {"make": "bmw", "model": "3 series 328i 2793cc", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "shogun sport elegance 2972cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "clio rn 1.2 3dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zet 1.4 3dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy ghia 2295cc",
        "shape": "multipurposevehicle",
    },
    {"make": "rover", "model": "25 il 1.6 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa gls 1.2 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "zafira club 1796cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "puma rac 1.7 3dr", "shape": "sportscoupe"},
    {"make": "nissan", "model": "primera si 1597", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra envoy 1598", "shape": "hatchback"},
    {"make": "saab", "model": "900 turbo 8v 1985cc", "shape": "saloon"},
    {
        "make": "skoda",
        "model": "octavia elegance 1781cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "75 connoisseur se 2497cc", "shape": "saloon"},
    {
        "make": "honda",
        "model": "accord vtec se executive 1850cc",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "scenic dynamique 1598cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta lx 1.25", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 lx 1998cc", "shape": "saloon"},
    {"make": "rover", "model": "200 216 si 1589", "shape": "hatchback"},
    {
        "make": "rover",
        "model": "400 416 s 16v ltd edn 1589cc",
        "shape": "saloon",
    },
    {
        "make": "vauxhall",
        "model": "agila [no trim] 1199cc",
        "shape": "hatchback",
    },
    {
        "make": "tvr",
        "model": "chimaera 3950cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "astra sxi 1.6 3dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra club 1686cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 416 il 1589cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "megane scenic 1.6-petrolinjection",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "zx sx 1.9 5dr", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon 2.4 jtd veloce diesel",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "peugeot",
        "model": "306 meridian ltd edn 1997cc",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "civic blank 1396", "shape": "hatchback"},
    {"make": "tvr", "model": "cerbera 4185cc", "shape": "sportscoupe"},
    {
        "make": "ford",
        "model": "mondeo st24 2544cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "saab", "model": "03-sep se 1985cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra 16v cd 1799cc", "shape": "hatchback"},
    {
        "make": "porsche",
        "model": "boxster tiptronic s 2480cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "corsa club 1199cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega sport 2198cc", "shape": "saloon"},
    {
        "make": "ford",
        "model": "explorer the north face ltd edn 4008cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "clio rt 1390cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery td5 gs7 2.5",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "escort lx 1796", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "shogun gls 3200cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "civic vti 1797cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "megane scenic scenic 1.6",
        "shape": "estateoffroadvehicle",
    },
    {"make": "peugeot", "model": "406 glx 2.0 4dr", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra bertone edition 2198cc",
        "shape": "sportscoupe",
    },
    {"make": "ford", "model": "mondeo zetec 1988cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 416 is 1589cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta zetec 1242cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 il 1.6 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comf e/t 3dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander td4 gs 1951cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "corsa 16v 5dr", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "gtv 16v t. spark lusso black",
        "shape": "sportscoupe",
    },
    {
        "make": "ford",
        "model": "galaxy glx 2.3 est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "lexus", "model": "is 200 sport 1988", "shape": "saloon"},
    {"make": "rover", "model": "25 il 1396cc", "shape": "hatchback"},
    {"make": "volvo", "model": "s40 t se 1948cc", "shape": "saloon"},
    {
        "make": "fiat",
        "model": "doblo cargo sx 1910cc diesel panel van in white",
        "shape": "commercialvehicle",
    },
    {"make": "peugeot", "model": "206 lx 1124cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "transit 600d lx 1868cc",
        "shape": "commercialvehicle",
    },
    {
        "make": "vauxhall",
        "model": "vx220 vx220 2.2 16v convertible",
        "shape": "sportscoupe",
    },
    {
        "make": "volkswagen",
        "model": "polo s tdi pd 1422cc",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "corsa breeze ltd edn 1199cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra ls 1998", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra 1.6ls 16v 5d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra sri 1998cc", "shape": "hatchback"},
    {"make": "smart car", "model": "smart passion 600cc", "shape": "hatchback"},
    {"make": "honda", "model": "civic is 1.6 5dr", "shape": "hatchback"},
    {"make": "citroen", "model": "saxo desire 1360cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "tigra chequers ltd edn 1389",
        "shape": "sportscoupe",
    },
    {
        "make": "mitsubishi",
        "model": "carisma equippe 1834cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "focus zetec 1796cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra gls 1995cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xi",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "fiesta freestyle 1242cc", "shape": "hatchback"},
    {
        "make": "volkswagen",
        "model": "passat se 20v turbo 1781cc",
        "shape": "saloon",
    },
    {"make": "peugeot", "model": "406 glx", "shape": "estateoffroadvehicle"},
    {"make": "ford", "model": "mondeo ztc 2.0 4dr", "shape": "saloon"},
    {"make": "citroen", "model": "c5 sx 2179cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sxi 1796cc", "shape": "hatchback"},
    {
        "make": "volkswagen",
        "model": "passat sport tdi 1896cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "fiat", "model": "brava sx 1370cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander td4gs",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "fiesta free 1.25 5d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 8v1.6 5dr", "shape": "hatchback"},
    {"make": "rover", "model": "400 416 sli 1590", "shape": "hatchback"},
    {"make": "citroen", "model": "zx avantage 1360cc", "shape": "hatchback"},
    {"make": "mazda", "model": "323 glx 1489cc", "shape": "saloon"},
    {"make": "bmw", "model": "3 series 328i se 2793cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra club 1.6 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1.7d 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "escort si 1.8 5dr", "shape": "hatchback"},
    {"make": "fiat", "model": "seicento s 899cc", "shape": "hatchback"},
    {
        "make": "tvr",
        "model": "griffith 500 4988cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "alfa romeo",
        "model": "spider v6 24v 2959cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "renault",
        "model": "megane roadster 1598cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "astra cd 1598cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "megane scenic rxe 1998",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "escort flight 5dr", "shape": "hatchback"},
    {
        "make": "rover",
        "model": "400 414 le ltd edn 1396cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "306 l 1360", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xei 1796cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "civic se 1396cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1994cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus zetec 1988cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "ranger double cab 2499cc turbo diesel",
        "shape": "commercialvehicle",
    },
    {"make": "citroen", "model": "xantia sx 1761cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa trip ltd edn 973cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "ka 1299", "shape": "hatchback"},
    {"make": "mercedes-benz", "model": "220 e 16v 2199cc", "shape": "saloon"},
    {
        "make": "mercedes-benz",
        "model": "c-class c220 elegance 2199",
        "shape": "saloon",
    },
    {"make": "rover", "model": "200 214 1396", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "zafira comfort 1598cc",
        "shape": "multipurposevehicle",
    },
    {"make": "volkswagen", "model": "polo l 1.6 4dr", "shape": "hatchback"},
    {"make": "peugeot", "model": "405 quasar 1761cc", "shape": "saloon"},
    {
        "make": "tvr",
        "model": "chimaera 4556cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "lexus", "model": "is 200 sport 1988cc", "shape": "saloon"},
    {
        "make": "lotus",
        "model": "elise 111s 1796cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "honda", "model": "hr-v 1.6 3dr", "shape": "estateoffroadvehicle"},
    {"make": "vauxhall", "model": "vectra sri 140 1998cc", "shape": "saloon"},
    {
        "make": "audi",
        "model": "a4 avant tdi se",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo ghia x 1999cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo zetec 1999cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "agila 973cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xantia lx 1905cc", "shape": "hatchback"},
    {
        "make": "porsche",
        "model": "911 carrera 4 3387cc",
        "shape": "sportscoupe",
    },
    {"make": "vauxhall", "model": "vectra ls 1998cc", "shape": "hatchback"},
    {"make": "honda", "model": "accord type-r 2157cc", "shape": "saloon"},
    {
        "make": "land rover",
        "model": "freelander gs 1796cc",
        "shape": "sportscoupe",
    },
    {"make": "ford", "model": "ka 1 1.3 3dr", "shape": "hatchback"},
    {"make": "peugeot", "model": "306 lx 1587cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vx220 roadster 2.2", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "space wagon gl gdi 2351cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "fiesta lx 1297cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "laguna dynamique 1783cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra cdx 1796cc", "shape": "saloon"},
    {"make": "rover", "model": "400 sli 2.0 4dr", "shape": "saloon"},
    {"make": "ford", "model": "mondeo lx 1.8 5dr", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "sz zagato 2959cc", "shape": "sportscoupe"},
    {
        "make": "volkswagen",
        "model": "passat se tdi 110 1896cc",
        "shape": "saloon",
    },
    {"make": "vauxhall", "model": "corsa sxi 1199cc", "shape": "hatchback"},
    {"make": "nissan", "model": "almera si 1392", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1.4i 16v", "shape": "hatchback"},
    {
        "make": "saab",
        "model": "900 turbo se 1985cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "corsa gls 16v 1.2", "shape": "hatchback"},
    {"make": "peugeot", "model": "206 lx 1360", "shape": "hatchback"},
    {"make": "citroen", "model": "xantia lx 1761cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf s 1595", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 2.0 t.spark veloce",
        "shape": "saloon",
    },
    {"make": "vauxhall", "model": "vectra cdx 2198cc", "shape": "hatchback"},
    {
        "make": "mercedes-benz",
        "model": "500 sl 4973cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "fiat", "model": "brava sx 1581", "shape": "hatchback"},
    {"make": "ford", "model": "ka 1299cc", "shape": "hatchback"},
    {"make": "honda", "model": "accord vtec se 1997cc", "shape": "saloon"},
    {
        "make": "land rover",
        "model": "range rover vogue se 3947cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "mazda", "model": "626 blank 1840", "shape": "hatchback"},
    {"make": "honda", "model": "accord vtec sport 1850cc", "shape": "saloon"},
    {
        "make": "citroen",
        "model": "ax elation ltd edn 954cc",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "civic vtec sport 1493cc", "shape": "hatchback"},
    {"make": "citroen", "model": "zx avantage 1905cc", "shape": "hatchback"},
    {
        "make": "volvo",
        "model": "850 se 2435cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "focus zetec 1596cc", "shape": "hatchback"},
    {"make": "citroen", "model": "c5 exclusive 2179cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xei",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "renault",
        "model": "laguna v6 baccara 2963",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "megane scenic rt 1598cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "206 lx 1360cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa breeze ltd edn 1199cc",
        "shape": "hatchback",
    },
    {"make": "audi", "model": "a6 tdi se 2496cc", "shape": "saloon"},
    {"make": "citroen", "model": "ax spree 1.0 3d", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 zest 2 1124", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1.6 5dr", "shape": "hatchback"},
    {"make": "honda", "model": "civic se 1590cc", "shape": "hatchback"},
    {
        "make": "jeep",
        "model": "cherokee limited 3960cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "puma [no trim] 1388cc", "shape": "sportscoupe"},
    {"make": "renault", "model": "scenic rt 1598", "shape": "hatchback"},
    {"make": "peugeot", "model": "206 gti 1997cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta si 1597cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "hr-v ltd edn 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "saxo desire 1124cc", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "106 xl independence ltd edn 1124cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "omega cdx 2597cc", "shape": "saloon"},
    {
        "make": "peugeot",
        "model": "306 meridian ltd edn 1587cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra gsi 2597cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "corsa sxi 1199cc", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "galant v6 sport 2498cc",
        "shape": "saloon",
    },
    {"make": "vauxhall", "model": "astra sri 1796cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 t.spark veloce 1970cc",
        "shape": "saloon",
    },
    {"make": "vauxhall", "model": "corsa gls 16v 1199cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo 1.8 ver 5dr", "shape": "hatchback"},
    {"make": "bmw", "model": "3 series 325i sport 2494cc", "shape": "saloon"},
    {"make": "ford", "model": "mondeo lx 1798cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra club 1796cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "stream vtec se 1668cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "mondeo glx 1988", "shape": "hatchback"},
    {"make": "nissan", "model": "primera gt 1998cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1796cc", "shape": "saloon"},
    {"make": "volkswagen", "model": "golf gti 1781cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sxi 16v 1796cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio etoile 16v 1390cc",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "frontera sport 2198cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "corsa 1.4-petrolinjection",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "200 214 si 1396", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo st-200 2544cc", "shape": "hatchback"},
    {"make": "citroen", "model": "saxo sx 1124cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 sei 1.4 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta encore 1299cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus zetec 1.8 3d", "shape": "hatchback"},
    {"make": "rover", "model": "75 club se 1997cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta fus 1.2", "shape": "hatchback"},
    {"make": "suzuki", "model": "wagon r+ gl 996", "shape": "hatchback"},
    {"make": "honda", "model": "civic es 1590cc", "shape": "hatchback"},
    {"make": "skoda", "model": "octavia glxi 1595cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1598cc", "shape": "hatchback"},
    {"make": "ford", "model": "probe 24v 2497cc", "shape": "sportscoupe"},
    {"make": "citroen", "model": "xantia activa 1998cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio rt 1390", "shape": "hatchback"},
    {"make": "rover", "model": "400 420 sli 1994cc", "shape": "saloon"},
    {"make": "peugeot", "model": "106 zest 1124cc", "shape": "hatchback"},
    {"make": "rover", "model": "200 200 vi 1796cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "focus 1.8-petrolinjection",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "puma [no trim] 1679cc", "shape": "sportscoupe"},
    {"make": "volvo", "model": "940 gle 2316", "shape": "estateoffroadvehicle"},
    {"make": "toyota", "model": "corolla gs 1332cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1.7 dti", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra 1796cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "skoda", "model": "octavia slx 1984cc", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "406 lx s ltd edn 1761cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "400 420 sli 16v 1994", "shape": "saloon"},
    {
        "make": "mazda",
        "model": "mx-5 se ltd edn 1840cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "focus zet 1.8 5dr", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "806 aquamarine ltd edn 1905cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "mondeo ghia 2.0td", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra sri 2198cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta zetec s 3dr", "shape": "hatchback"},
    {"make": "rover", "model": "200 214 si 1396cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cd 1998cc", "shape": "saloon"},
    {
        "make": "land rover",
        "model": "freelander gs 1.8 4dr",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "land rover",
        "model": "freelander xedi 1994cc",
        "shape": "sportscoupe",
    },
    {
        "make": "volkswagen",
        "model": "passat 2.8-petrolinjection",
        "shape": "saloon",
    },
    {
        "make": "mitsubishi",
        "model": "shogun gls 2972cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "puma 1.7 3dr", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "galant vr-4 type-s 2498cc",
        "shape": "saloon",
    },
    {
        "make": "bmw",
        "model": "3 series 316i compact 1596cc",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "scenic expression + 1870",
        "shape": "hatchback",
    },
    {"make": "bmw", "model": "3 series se 1.8i", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra merit 1389cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy lx 1896cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "fiesta zetec lx 1242cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 gti 1587cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta free 1.25 3d", "shape": "hatchback"},
    {
        "make": "mazda",
        "model": "323 shiraz ltd edn 1324cc",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "zafira comfort 5dr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra envoy 1.6 5d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega gls 2.0 4dr", "shape": "saloon"},
    {"make": "ford", "model": "focus lx 1.8 5dr", "shape": "hatchback"},
    {"make": "suzuki", "model": "baleno gs 1590cc", "shape": "hatchback"},
    {"make": "mitsubishi", "model": "lancer glx 1468cc", "shape": "saloon"},
    {"make": "peugeot", "model": "205 gti 1580cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio grande 1149cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "espace rxe 2849cc",
        "shape": "multipurposevehicle",
    },
    {"make": "fiat", "model": "brava 80 sx 1.2 5d", "shape": "hatchback"},
    {"make": "fiat", "model": "barchetta 16v", "shape": "convertiblecabriolet"},
    {"make": "vauxhall", "model": "corsa comfort 1389cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xsara forte 1360cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra comfort 1.6", "shape": "hatchback"},
    {"make": "m.g.", "model": "mgf 1589cc", "shape": "convertiblecabriolet"},
    {"make": "rover", "model": "100 111 si 1120cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls lpg 1.4 3", "shape": "hatchback"},
    {"make": "m.g.", "model": "zs 1796cc", "shape": "saloon"},
    {"make": "fiat", "model": "punto 60 s 1242cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort tdx ltd edn 1753", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra sport 16v 1598cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta finesse 1297", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio expression + 1149cc",
        "shape": "hatchback",
    },
    {
        "make": "proton",
        "model": "persona meridian ltd edn 1299",
        "shape": "saloon",
    },
    {"make": "peugeot", "model": "206 lx 1124cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa breeze ltd edn 973cc",
        "shape": "hatchback",
    },
    {
        "make": "ford",
        "model": "focus zet 2.0 est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "bmw", "model": "3 series 320d se 1951cc", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "frontera limited 2198cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "vectra sri 130 1796cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "605 sv 2975", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "vx220 roadster 2198cc",
        "shape": "sportscoupe",
    },
    {"make": "morgan", "model": "plus 4 4-seat 1994cc", "shape": "sportscoupe"},
    {"make": "bmw", "model": "3 series 323i 2494cc", "shape": "sportscoupe"},
    {"make": "rover", "model": "75 club 1796cc", "shape": "saloon"},
    {
        "make": "mitsubishi",
        "model": "shogun pinin 1834cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "clio rt 1.6", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1.4", "shape": "hatchback"},
    {"make": "mazda", "model": "demio gsi 1498cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf gti 1984cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 lx", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra ls 1.6", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "stream vtec se sport 1998cc",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "astra ls 1700cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comf 1.2 3dr", "shape": "hatchback"},
    {"make": "renault", "model": "laguna rt 1998cc", "shape": "hatchback"},
    {
        "make": "porsche",
        "model": "boxster 2687cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "corsa club 1199cc", "shape": "hatchback"},
    {"make": "ford", "model": "cougar 2544cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "vectra cdx 2597cc", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "406 lx 1749cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "clio alize 1390cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec 1242", "shape": "hatchback"},
    {"make": "ford", "model": "focus zetec 1596", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta lx 1299cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "306 xsi 1998cc", "shape": "hatchback"},
    {"make": "honda", "model": "accord vtec s 1850cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon ts selespeed veloce 1970cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "mazda", "model": "323 executive 1840", "shape": "hatchback"},
    {"make": "peugeot", "model": "206 glx 1360cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa breeze 16v ltd edn 1199cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "406 glx 1998", "shape": "saloon"},
    {"make": "ford", "model": "granada efi ghia 1998cc", "shape": "hatchback"},
    {"make": "renault", "model": "megane rt 1598", "shape": "hatchback"},
    {"make": "honda", "model": "civic se 1590cc", "shape": "hatchback"},
    {"make": "skoda", "model": "octavia glx 1984cc", "shape": "hatchback"},
    {"make": "toyota", "model": "yaris cdx 1299cc", "shape": "hatchback"},
    {"make": "renault", "model": "laguna rti 16v 1948cc", "shape": "hatchback"},
    {
        "make": "saab",
        "model": "03-sep se t 1985",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "ford",
        "model": "focus ghia 1.8 est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "hyundai", "model": "lantra auto 4dr 2.0", "shape": "saloon"},
    {"make": "volkswagen", "model": "golf cl 1781", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa cdx 16v 1389cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio rn 1149cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon veloce 2492cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "saxo vtr 1587", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 1.8 4dr", "shape": "saloon"},
    {"make": "citroen", "model": "ax forte 1124", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra astra 1.6 sxi 16v",
        "shape": "hatchback",
    },
    {
        "make": "citroen",
        "model": "xsara picasso sx 1749cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "ford",
        "model": "explorer 4008cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra cd 16v 1796cc", "shape": "hatchback"},
    {"make": "tvr", "model": "taimar 2994cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "fiesta fin 1.3", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 16v 1389cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1686", "shape": "saloon"},
    {"make": "citroen", "model": "saxo forte 1.1 3d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa bree 1.4 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa breeze ltd edn 1686cc",
        "shape": "hatchback",
    },
    {
        "make": "mitsubishi",
        "model": "shogun pinin equippe 1997cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "focus zetec 1988cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vx220 2.2 16v coup", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "406 executive 1998cc", "shape": "saloon"},
    {"make": "citroen", "model": "xantia 16v vsx 1998", "shape": "hatchback"},
    {"make": "renault", "model": "clio rxe 1598cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra gsi 2498cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra cd 2198cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta ghia 1.6", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "colt space star equippe 1597cc",
        "shape": "hatchback",
    },
    {
        "make": "citroen",
        "model": "xantia diesel sx hatch",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "accord type-v 2254cc", "shape": "hatchback"},
    {"make": "fiat", "model": "bravo sx 1242cc", "shape": "hatchback"},
    {"make": "audi", "model": "tt t quattro", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "306 style 1905cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa gls 973cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio rxe 1598", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra club 1995cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "volkswagen", "model": "polo cl 1390cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort ghia 1753", "shape": "saloon"},
    {"make": "volvo", "model": "v40 s 1948cc", "shape": "estateoffroadvehicle"},
    {
        "make": "honda",
        "model": "civic se executive 1590cc",
        "shape": "hatchback",
    },
    {"make": "hyundai", "model": "lantra cdx 1975cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "megane liberte ltd edn 1.4",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "megane scenic scenic 1.6",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "focus ghia 1.8 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra envoy 1598cc", "shape": "hatchback"},
    {"make": "fiat", "model": "tempra s 1581cc", "shape": "saloon"},
    {"make": "honda", "model": "hr-v 1590cc", "shape": "estateoffroadvehicle"},
    {
        "make": "renault",
        "model": "clio s maxim ltd edn 1390",
        "shape": "hatchback",
    },
    {"make": "saab", "model": "03-sep s 1985", "shape": "convertiblecabriolet"},
    {"make": "rover", "model": "75 connoisseur 2497cc", "shape": "saloon"},
    {"make": "renault", "model": "clio rsi 1783cc", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "carisma mirage 1834cc",
        "shape": "hatchback",
    },
    {"make": "renault", "model": "scenic alize 1598cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "vectra sri 140 1998cc",
        "shape": "hatchback",
    },
    {
        "make": "ford",
        "model": "galaxy ztc 1.9 5dr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ferrari", "model": "365 f1 paddle shift", "shape": "sportscoupe"},
    {"make": "renault", "model": "megane alize 1.6 5d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1.6", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec 1.6 3d", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf gl 1896cc", "shape": "hatchback"},
    {
        "make": "mercedes-benz",
        "model": "e-class e240 elegance 2597cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "nissan", "model": "primera gx 1597", "shape": "saloon"},
    {"make": "volvo", "model": "440 se 1998cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort si 1796cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comfort 973cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo zet 1.8 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra club 1598cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta freestyle 1242cc", "shape": "hatchback"},
    {
        "make": "ferrari",
        "model": "f355 spider 3496cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "toyota",
        "model": "picnic gls 1998cc",
        "shape": "multipurposevehicle",
    },
    {"make": "renault", "model": "clio rsi 1783", "shape": "hatchback"},
    {"make": "honda", "model": "civic ls 1493cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "306 xr 1360cc", "shape": "hatchback"},
    {"make": "fiat", "model": "punto elx 1242cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "gtv v6 24v lusso 2959cc",
        "shape": "sportscoupe",
    },
    {
        "make": "nissan",
        "model": "micra celebration ltd edn 998cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "escort lx 1391cc", "shape": "hatchback"},
    {"make": "citroen", "model": "saxo desire 1124cc", "shape": "hatchback"},
    {"make": "rover", "model": "25 impression 1396cc", "shape": "hatchback"},
    {"make": "audi", "model": "s8 quattro 4172cc", "shape": "saloon"},
    {
        "make": "chrysler",
        "model": "grand voyager le 3301cc",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "vectra ls 1598", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta finesse 1299cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xsara lx 1360", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1995cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio mtv ltd edn 1149cc",
        "shape": "hatchback",
    },
    {"make": "nissan", "model": "primera activ 1769cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta 1.1azura 5dr", "shape": "hatchback"},
    {"make": "peugeot", "model": "206 lx 1868", "shape": "hatchback"},
    {"make": "ferrari", "model": "348 tb 3405cc", "shape": "sportscoupe"},
    {"make": "volvo", "model": "v40 t 1948cc", "shape": "estateoffroadvehicle"},
    {"make": "ford", "model": "mondeo ghia x 1988cc", "shape": "hatchback"},
    {"make": "mazda", "model": "626 gxi i.a/c 1991cc", "shape": "saloon"},
    {"make": "honda", "model": "accord es 1997cc", "shape": "sportscoupe"},
    {"make": "suzuki", "model": "vitara jx 1590cc", "shape": "sportscoupe"},
    {"make": "honda", "model": "civic vtec se 1590cc", "shape": "hatchback"},
    {"make": "volvo", "model": "s70 s70 2.5 20v se 2435cc", "shape": "saloon"},
    {"make": "ford", "model": "focus zet 1.6 3dr", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "escort cabaret ltd edn 1597cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "206 glx 1587cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy zetec 1896cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "escort flight 1597cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort finesse 1597cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort osprey 1391", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio grande ltd edn 1149cc",
        "shape": "hatchback",
    },
    {"make": "saab", "model": "900 s 1985cc", "shape": "convertiblecabriolet"},
    {
        "make": "land rover",
        "model": "freelander xei 1.8 5dr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "600 620 sli 1997cc", "shape": "saloon"},
    {
        "make": "alfa romeo",
        "model": "156 t.s selespeed 1970cc",
        "shape": "saloon",
    },
    {
        "make": "renault",
        "model": "espace rt alize 1995cc",
        "shape": "multipurposevehicle",
    },
    {"make": "honda", "model": "accord vtec se 1850cc", "shape": "hatchback"},
    {
        "make": "bmw",
        "model": "3 series 318i touring se 1796cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "nissan",
        "model": "almera tino se 1769cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "vauxhall",
        "model": "astra sport 16v 1598cc",
        "shape": "hatchback",
    },
    {"make": "bmw", "model": "3 series 318i se 1895cc", "shape": "saloon"},
    {
        "make": "alfa romeo",
        "model": "147 t.spark selespeed lusso 1970cc",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "accord vtec s 1850cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "corsa gls 1195", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "zafira club 1995cc",
        "shape": "multipurposevehicle",
    },
    {"make": "bmw", "model": "3 series 318i 1795cc", "shape": "saloon"},
    {
        "make": "volkswagen",
        "model": "passat gt 1781cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "civic sport 1396cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "laguna privilege 1783cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "mondeo zet 2.0 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sri 16v 1998cc", "shape": "hatchback"},
    {"make": "honda", "model": "hr-v 1590cc", "shape": "estateoffroadvehicle"},
    {
        "make": "ford",
        "model": "mondeo 2.0-petrolinjection",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra sri v6 2597cc", "shape": "hatchback"},
    {"make": "nissan", "model": "almera precision", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra env 2.0 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cd 2198cc", "shape": "saloon"},
    {"make": "ford", "model": "focus 1.8-dieselinjection", "shape": "saloon"},
    {
        "make": "peugeot",
        "model": "306 meridian ltd edn 1761cc",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "600 620 si 1997cc", "shape": "saloon"},
    {
        "make": "audi",
        "model": "100 avant e 1994",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "focus zetec 1.8 5d", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon ts selespeed 1970cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "peugeot", "model": "306 lx 1905", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "range rover vogue se 4.6",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "omega elite 3175cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "mitsubishi", "model": "galant 24v 1999cc", "shape": "saloon"},
    {
        "make": "mazda",
        "model": "mx-5 s 1839cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "corsa gls 973cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "vectra sri 150 2198cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "focus ghia 1753cc", "shape": "hatchback"},
    {"make": "rover", "model": "200 216 ie 1589cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra gls 1994cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 i 1.6 4dr", "shape": "saloon"},
    {
        "make": "jeep",
        "model": "grand cherokee sw orvi 2.5d es",
        "shape": "estateoffroadvehicle",
    },
    {"make": "bmw", "model": "7 series 735i 3498cc", "shape": "saloon"},
    {
        "make": "aston martin",
        "model": "db7 volante 3239cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "honda", "model": "accord ex 1955cc", "shape": "saloon"},
    {"make": "rover", "model": "400 si 1.6 5dr", "shape": "hatchback"},
    {"make": "rover", "model": "45 ixl 1994cc", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "166 super 2959cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "megane liberte ltd edn 1390cc",
        "shape": "hatchback",
    },
    {
        "make": "ford",
        "model": "galaxy glx 1998cc",
        "shape": "multipurposevehicle",
    },
    {"make": "audi", "model": "a4 tdi se 115 1896cc", "shape": "saloon"},
    {"make": "citroen", "model": "bx 19 gti 1905", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "156 t.spark 0", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra comfort 1995cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "daewoo", "model": "matiz se 1.0 5dr", "shape": "hatchback"},
    {"make": "audi", "model": "a4 se 1781cc", "shape": "saloon"},
    {
        "make": "lotus",
        "model": "elise sport 160 1796cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "saab", "model": "9000 cde 1985cc", "shape": "saloon"},
    {"make": "honda", "model": "civic 1396cc", "shape": "hatchback"},
    {
        "make": "nissan",
        "model": "micra ally ltd edn 998cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "mondeo lx 1796", "shape": "hatchback"},
    {"make": "peugeot", "model": "206 gti 2.0 3dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra sri 2597cc", "shape": "hatchback"},
    {"make": "citroen", "model": "ax 14d echo 1360cc", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "carisma sport 1834cc",
        "shape": "hatchback",
    },
    {"make": "mercedes-benz", "model": "300 se 2960", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "zafira gsi 1998cc",
        "shape": "multipurposevehicle",
    },
    {"make": "citroen", "model": "xm turbo d vsx 2088cc", "shape": "hatchback"},
    {"make": "honda", "model": "civic vtec 1493cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio expression 1149cc",
        "shape": "hatchback",
    },
    {"make": "mazda", "model": "xedos 6 v6 1995", "shape": "saloon"},
    {"make": "ford", "model": "focus zetec 1796cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 1.8", "shape": "saloon"},
    {"make": "citroen", "model": "xantia vsx 2088cc", "shape": "hatchback"},
    {"make": "subaru", "model": "impreza wrx 1994cc", "shape": "saloon"},
    {"make": "peugeot", "model": "206 lx 1868cc", "shape": "hatchback"},
    {"make": "tvr", "model": "tuscan 3996cc", "shape": "sportscoupe"},
    {"make": "bmw", "model": "3 series 330d se 2926cc", "shape": "saloon"},
    {"make": "nissan", "model": "primera se 1769cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comfort 1199cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 i 1.6 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega gls 2498cc", "shape": "saloon"},
    {
        "make": "fiat",
        "model": "cinquecento sporting 1108cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "corsa sri 1.4 5dr", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 t.spark lusso 1747",
        "shape": "saloon",
    },
    {
        "make": "vauxhall",
        "model": "astra turbo edition 2.0",
        "shape": "sportscoupe",
    },
    {"make": "toyota", "model": "camry gx 2959", "shape": "saloon"},
    {"make": "renault", "model": "5 campus 1108cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus cl 1388cc", "shape": "hatchback"},
    {"make": "renault", "model": "megane rt 1.6 5dr", "shape": "hatchback"},
    {"make": "volkswagen", "model": "passat s 1.9tdi 4dr", "shape": "saloon"},
    {"make": "vauxhall", "model": "cavalier l 1998", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra arctic ltd edn 1598",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "corsa club 1.0", "shape": "hatchback"},
    {"make": "lotus", "model": "340r lotus 340r", "shape": "sportscoupe"},
    {"make": "renault", "model": "laguna rt 1783", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "berlingo 600 1905cc",
        "shape": "commercialvehicle",
    },
    {
        "make": "land rover",
        "model": "discovery tdi gs 2495",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "astra coupe edition 1796cc",
        "shape": "sportscoupe",
    },
    {"make": "rover", "model": "200 216 sli 1589cc", "shape": "hatchback"},
    {"make": "skoda", "model": "octavia slx 1781cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa cdx 1199cc", "shape": "hatchback"},
    {"make": "porsche", "model": "911 turbo 3600cc", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "colt space star gdi glx 1834cc",
        "shape": "hatchback",
    },
    {
        "make": "chrysler",
        "model": "neon lx 1996cc",
        "shape": "commercialvehicle",
    },
    {
        "make": "land rover",
        "model": "freelander igs",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "corsa montana ltd edn 1389cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra vectra 2.0 cd", "shape": "saloon"},
    {
        "make": "nissan",
        "model": "almera ambition ltd edn 1392",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "frontera sport 2171cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "corsa sport 1598cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 t.s selespeed veloce leather",
        "shape": "saloon",
    },
    {"make": "ford", "model": "fiesta lx 1242cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 420 gsi 16v 1994", "shape": "saloon"},
    {"make": "audi", "model": "a6 quattro sport 2771cc", "shape": "saloon"},
    {
        "make": "mazda",
        "model": "premacy gsi 1840cc",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "astra club 1.6", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa club 1.0 3dr", "shape": "hatchback"},
    {
        "make": "ferrari",
        "model": "348 sp 3405cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "nissan", "model": "almera e 1497cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf se 1598cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta flight 1297cc", "shape": "hatchback"},
    {"make": "mazda", "model": "323 sport 1991cc.", "shape": "hatchback"},
    {"make": "ford", "model": "focus ghia 1796cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "cr-v ls 1973cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "escort si 1.8 3dr", "shape": "hatchback"},
    {"make": "volkswagen", "model": "polo l 999cc", "shape": "hatchback"},
    {"make": "daewoo", "model": "nubira cdx 1998cc", "shape": "saloon"},
    {
        "make": "toyota",
        "model": "mr2 g limited t bar 1997cc",
        "shape": "sportscoupe",
    },
    {"make": "renault", "model": "megane rt 1598cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy glx 2792cc",
        "shape": "multipurposevehicle",
    },
    {"make": "audi", "model": "a3 t sport 1781cc", "shape": "hatchback"},
    {"make": "chrysler", "model": "neon lx 1996", "shape": "saloon"},
    {"make": "ford", "model": "fiesta zet 1.2", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "frontera limited 3165cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "nissan", "model": "primera sri 1597", "shape": "hatchback"},
    {
        "make": "subaru",
        "model": "impreza rb5 ltd edn 1994cc",
        "shape": "saloon",
    },
    {
        "make": "vauxhall",
        "model": "omega elite 2962cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "chrysler",
        "model": "voyager le 3301",
        "shape": "multipurposevehicle",
    },
    {"make": "mazda", "model": "mx-3 v6 1845cc", "shape": "sportscoupe"},
    {
        "make": "porsche",
        "model": "911 carrera 2 tiptronic s 3596cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "bmw", "model": "3 series 316i 1596cc", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra elegance 1796cc",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "astra turbo edition 1998cc",
        "shape": "sportscoupe",
    },
    {
        "make": "mazda",
        "model": "premacy sport 1991cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "ka 1299", "shape": "hatchback"},
    {"make": "morgan", "model": "plus 4 2-seat 1995cc", "shape": "sportscoupe"},
    {"make": "renault", "model": "scenic rxe 1998cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cd 2597cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta lx 1.25", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio grande ltd edn 1149cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "corsa sprt 1.4 3dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec 1388cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo zetec 1999cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "megane alize 16v 1598cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "omega cdx 2.5 4dr", "shape": "saloon"},
    {"make": "ford", "model": "fiesta lx 1242", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "zafira comfort 2198cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "ford",
        "model": "fiesta flight ltd edn 1392cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra club1.816v 5", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "frontera sport rs 2198cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "volkswagen",
        "model": "scirocco gt 1781cc",
        "shape": "sportscoupe",
    },
    {"make": "honda", "model": "civic se 1396cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus zetec 1596cc", "shape": "hatchback"},
    {"make": "honda", "model": "cr-v es 1973", "shape": "estateoffroadvehicle"},
    {"make": "rover", "model": "25 2.0 dies 5dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "range rover 4.6 hse",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra cd 2.5 v6 5d", "shape": "hatchback"},
    {"make": "fiat", "model": "brava sx 1242cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "xm turbo exclusive 1998cc",
        "shape": "hatchback",
    },
    {
        "make": "ford",
        "model": "mondeo st200 2.5est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "fiesta flt 1.3 5dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery td5 es",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "clio rl 1149cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sri 1.8 5dr", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "shogun pinin elegance 1834cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "honda",
        "model": "hr-v vtec 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "400 sli 416", "shape": "saloon"},
    {"make": "peugeot", "model": "306 xr 1587cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "polo cl 1390", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 1988cc", "shape": "hatchback"},
    {"make": "ford", "model": "ka 1.3-petrolinjection", "shape": "hatchback"},
    {"make": "m.g.", "model": "mgf se 1796cc", "shape": "convertiblecabriolet"},
    {"make": "vauxhall", "model": "corsa gls 1199cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 1998cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "astra sport 1598cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "mondeo st-200 ltd edn 2544cc",
        "shape": "saloon",
    },
    {
        "make": "mercedes-benz",
        "model": "a-class a160 elegance 1598cc",
        "shape": "hatchback",
    },
    {"make": "toyota", "model": "celica gt 1588cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "vectra ls 1796", "shape": "hatchback"},
    {
        "make": "audi",
        "model": "tt roadster t quattro",
        "shape": "convertiblecabriolet",
    },
    {"make": "honda", "model": "accord s 1850", "shape": "saloon"},
    {"make": "audi", "model": "a6 se 2598cc", "shape": "saloon"},
    {"make": "honda", "model": "accord vtec se 1997cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "zafira elegance 1796cc",
        "shape": "multipurposevehicle",
    },
    {"make": "toyota", "model": "celica vvti 1.8 2dr", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "agila 1199cc", "shape": "hatchback"},
    {"make": "nissan", "model": "primera sport 1769cc", "shape": "hatchback"},
    {
        "make": "audi",
        "model": "a6 avant t 1781cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "zafira comfort se 1796cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "vauxhall",
        "model": "zafira elegance 2198cc",
        "shape": "multipurposevehicle",
    },
    {"make": "skoda", "model": "octavia slxi turbo", "shape": "hatchback"},
    {"make": "vauxhall", "model": "tigra 16v 1389cc", "shape": "sportscoupe"},
    {
        "make": "citroen",
        "model": "c5 exclusive se 2946cc",
        "shape": "hatchback",
    },
    {"make": "hyundai", "model": "accent lsi 1341cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo ztc 2.0 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra coupe 2.2 2d", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "306 glx 1997cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 glx 1998cc", "shape": "saloon"},
    {"make": "mazda", "model": "mx-6 gt 2497cc", "shape": "sportscoupe"},
    {
        "make": "subaru",
        "model": "forester s turbo 1994cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "xsara vtr 1761cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "mondeo ghia 2.0 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "escort cl 1391cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 1597", "shape": "saloon"},
    {"make": "jaguar", "model": "xk 8 3996cc", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "405 1.8lx 4dr", "shape": "saloon"},
    {
        "make": "rover",
        "model": "100 111 knightsbridge se 1120cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "focus ghia 1.8td", "shape": "hatchback"},
    {"make": "mazda", "model": "mx3 1.8 automatic", "shape": "sportscoupe"},
    {"make": "rover", "model": "400 414i 1396", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sri 1796cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 l 1761cc", "shape": "saloon"},
    {"make": "rover", "model": "400 1 2.0 4dr", "shape": "saloon"},
    {"make": "vauxhall", "model": "corsa sri 1389cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra club 16v 1598cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "focus cl 1.4 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa gls 1389cc", "shape": "hatchback"},
    {
        "make": "jaguar",
        "model": "xjs v12 5345",
        "shape": "convertiblecabriolet",
    },
    {"make": "rover", "model": "45 con 2.0 4dr", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra club 1796cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "megane dynamique 1598cc",
        "shape": "hatchback",
    },
    {"make": "jaguar", "model": "xj series xj6 3980", "shape": "saloon"},
    {"make": "peugeot", "model": "406 lx s ltd edn 1761", "shape": "saloon"},
    {"make": "ford", "model": "ka 1.3 3dr", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 xr 1124", "shape": "hatchback"},
    {"make": "volkswagen", "model": "beetle rhd 1984cc", "shape": "saloon"},
    {
        "make": "rover",
        "model": "200 216 cabriolet 16v 1590",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "vauxhall",
        "model": "vectra vectra club 1.8 16v",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra cd 1998cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "205 auto 1580cc", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "156 turismo 1970cc", "shape": "saloon"},
    {"make": "porsche", "model": "911 carrera 2 3.6cc", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "space wagon glx gdi 2351cc",
        "shape": "multipurposevehicle",
    },
    {"make": "renault", "model": "clio rn 1171", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "omega cd 2498cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "insight 995cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "escort lx 1597cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery tdi 2495cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "rover",
        "model": "400 416 sli tourer 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "seat", "model": "ibiza s 1390cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "306 1.9 td 5dr", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "espace rt-x 1998cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "ford",
        "model": "mondeo lx 1.8 est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra expression 1.6", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cdx 2198cc", "shape": "saloon"},
    {"make": "ford", "model": "focus ghia 1596cc", "shape": "hatchback"},
    {"make": "rover", "model": "200 220d 1994cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 416 si 1589cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "cougar [no trim] 2544cc",
        "shape": "sportscoupe",
    },
    {
        "make": "mazda",
        "model": "mx-5 sport 1839cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "mondeo glx 1796cc", "shape": "hatchback"},
    {"make": "mazda", "model": "626 gxi 1991cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra cd 16v 1.6", "shape": "hatchback"},
    {
        "make": "toyota",
        "model": "avensis gs 1975cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "omega mv6 2962cc", "shape": "saloon"},
    {"make": "ford", "model": "focus ghia 2.0 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "escort lx 1597cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra club dti 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec ghia 1242cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus zet 1.8 3dr", "shape": "hatchback"},
    {"make": "honda", "model": "civic ls 1590cc", "shape": "sportscoupe"},
    {"make": "citroen", "model": "bx 14 te 1360cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "megane sport alize 16v 1998cc",
        "shape": "sportscoupe",
    },
    {"make": "vauxhall", "model": "vectra sxi 1.8 5dr", "shape": "hatchback"},
    {"make": "rover", "model": "200 214 ie 1396cc", "shape": "hatchback"},
    {"make": "rover", "model": "75 1.8 club se", "shape": "saloon"},
    {"make": "nissan", "model": "primera slx 1998", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "147 t.spark lusso 1970cc",
        "shape": "hatchback",
    },
    {
        "make": "land rover",
        "model": "freelander td4 es 1951cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "mazda", "model": "323 lxi 1324cc", "shape": "hatchback "},
    {"make": "renault", "model": "scenic rt 1598cc", "shape": "hatchback"},
    {
        "make": "toyota",
        "model": "rav 4 gx 1998cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo lx 1796cc", "shape": "hatchback"},
    {"make": "toyota", "model": "carina e gs 1762", "shape": "hatchback"},
    {"make": "renault", "model": "clio rxe 1598cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sxi 16v 1.8", "shape": "hatchback"},
    {
        "make": "mazda",
        "model": "mx-5 s 1840cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ferrari", "model": "f355 gts 3496cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "escort finesse 1597cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic aerodeck vtec es 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra gls 2.0 5dr", "shape": "hatchback"},
    {"make": "volkswagen", "model": "passat sprt 1.8t 4d", "shape": "saloon"},
    {"make": "nissan", "model": "almera se 1497cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cd 2498cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra sri v6 2498cc", "shape": "hatchback"},
    {"make": "toyota", "model": "avensis gls 1762cc", "shape": "hatchback"},
    {"make": "m.g.", "model": "zr 1396cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 2.0 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta lx 1.3", "shape": "hatchback"},
    {"make": "rover", "model": "25 ie 1396cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "omega cdx 2498cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "c5 lx 1749cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort si 1796", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra astra 1.6 cd dualfuel",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "megane rt sport 1598cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "ka 1299cc", "shape": "hatchback"},
    {
        "make": "volkswagen",
        "model": "golf cl 1781cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "mazda", "model": "323 gxi 1489cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio alize 1390cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa envoy 973cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1389cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "xm v6 exclusive 2946cc",
        "shape": "hatchback",
    },
    {"make": "mitsubishi", "model": "carisma glx 1597cc", "shape": "hatchback"},
    {"make": "rover", "model": "618i 618 si 1850cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "megane scenic rt 1870cc",
        "shape": "hatchback",
    },
    {
        "make": "rover",
        "model": "200 216 16v coupe se ltd edn 1590",
        "shape": "sportscoupe",
    },
    {"make": "rover", "model": "200 i", "shape": "hatchback"},
    {"make": "rover", "model": "75 classic se 1951cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra 1.6 5dr", "shape": "hatchback"},
    {
        "make": "mazda",
        "model": "mx-5 s 1840cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "mercedes-benz", "model": "300 se 3199cc", "shape": "saloon"},
    {"make": "citroen", "model": "synergie sx", "shape": "multipurposevehicle"},
    {"make": "ford", "model": "mondeo lx 2.0td 5dr", "shape": "hatchback"},
    {"make": "renault", "model": "clio grande 1149cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra ls 1796cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo zetec 1798cc", "shape": "saloon"},
    {"make": "volkswagen", "model": "polo l 1390", "shape": "hatchback"},
    {"make": "nissan", "model": "micra activ 998cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "accord vtec sport 1850cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra sri 130 2172cc", "shape": "saloon"},
    {"make": "citroen", "model": "xsara lx 1360cc", "shape": "hatchback"},
    {
        "make": "mercedes-benz",
        "model": "c-class c200 classic 1998",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "400 414 i 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "tigra 1.4-petrolinjection",
        "shape": "sportscoupe",
    },
    {
        "make": "hyundai",
        "model": "lantra glsi 1599cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "megane rt 16v 1390cc", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "306 cabriolet 1998cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "land rover",
        "model": "110 defender tdi 2495cc",
        "shape": "commercialvehicle",
    },
    {
        "make": "ford",
        "model": "transit 800d lx 1868cc",
        "shape": "commercialvehicle",
    },
    {"make": "hyundai", "model": "accent 1.3 lsi", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra envoy 1598cc", "shape": "hatchback"},
    {"make": "audi", "model": "a4 avant tdi", "shape": "estateoffroadvehicle"},
    {
        "make": "vauxhall",
        "model": "zafira club 1598cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "scorpio executive 1998", "shape": "saloon"},
    {
        "make": "honda",
        "model": "civic aerodeck ls 1493cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra sxi 16v 1598cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx td 2.0 5d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 16v 1598cc", "shape": "hatchback"},
    {
        "make": "volkswagen",
        "model": "passat s tdi 90 1896cc",
        "shape": "saloon",
    },
    {"make": "peugeot", "model": "206 lx 1360cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 414 1396", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy zet 2.3 mpv",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ferrari", "model": "348 ts 3405cc", "shape": "sportscoupe"},
    {"make": "fiat", "model": "brava elx 1581cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "scenic sport alize 1598cc",
        "shape": "hatchback",
    },
    {
        "make": "alfa romeo",
        "model": "147 t.spark lusso 3 &",
        "shape": "hatchback",
    },
    {
        "make": "peugeot",
        "model": "106 xn key west ltd edn 1124cc",
        "shape": "hatchback",
    },
    {
        "make": "volvo",
        "model": "940 se 2316cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "bmw", "model": "3 series se 1.8 4dr", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "zafira club 1800cc",
        "shape": "multipurposevehicle",
    },
    {"make": "honda", "model": "prelude vti 2156cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "cavalier ls 1686cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "205 gti 1580", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 zest 2 1124cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo glx 1796", "shape": "hatchback"},
    {"make": "vauxhall", "model": "cavalier is 1.6 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sxi 1598cc", "shape": "hatchback"},
    {"make": "honda", "model": "civic lsi 1493", "shape": "sportscoupe"},
    {
        "make": "renault",
        "model": "megane sport alize 16v 1598cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "corsa comfort 973cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "frontera limited 2171cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "ford",
        "model": "ka collection ltd edn 1299cc",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "civic ls 1590cc", "shape": "hatchback"},
    {"make": "honda", "model": "integra type-r 1797cc", "shape": "sportscoupe"},
    {
        "make": "porsche",
        "model": "911 turbo tiptronic s 3600cc",
        "shape": "sportscoupe",
    },
    {
        "make": "ford",
        "model": "maverick glx lwb 2389",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "honda",
        "model": "civic tornado ltd edn 1396cc",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "400 sli 1.6a 5dr", "shape": "hatchback"},
    {"make": "subaru", "model": "impreza p1 ltd edn 1994cc", "shape": "saloon"},
    {
        "make": "renault",
        "model": "laguna dynamique 1598cc",
        "shape": "hatchback",
    },
    {
        "make": "mercedes-benz",
        "model": "380 sl 3839cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "fiesta encore 1297cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo lx 1988cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta flight 1.3 3dr", "shape": "hatchback"},
    {"make": "renault", "model": "megane 1.6 16v 5dr", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "escort 1.8 lx turbo diese escort estate 1.8 turbo diesel",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "corsa breeze ltd edn 973",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "ka [no trim] 1299cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 zest 2 1527cc", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "156 jtd 2387cc", "shape": "saloon"},
    {"make": "citroen", "model": "saxo lx 1124cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "xm turbo onyx ltd edn 1998cc",
        "shape": "hatchback",
    },
    {
        "make": "peugeot",
        "model": "405 glxdt 1905cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "land rover",
        "model": "freelander xdi 1994cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "alfa romeo", "model": "156 v6 24v 2492cc", "shape": "saloon"},
    {
        "make": "ford",
        "model": "galaxy glx 1998",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "astra sxi 1598cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf gt 1896cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort si 1796", "shape": "hatchback"},
    {"make": "renault", "model": "clio rt 1390", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega elite 2962cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra cdx 2.2", "shape": "hatchback"},
    {"make": "ford", "model": "puma 1679cc", "shape": "sportscoupe"},
    {"make": "nissan", "model": "pacific 1597cc 100nx", "shape": "sportscoupe"},
    {
        "make": "land rover",
        "model": "freelander gs 1796cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo ghia 1998cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus esp 2.0 5dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery tdi s 2495cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "citroen",
        "model": "xsara picasso sx 1997cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "renault",
        "model": "megane classic rt 16v 1598cc",
        "shape": "saloon",
    },
    {
        "make": "lotus",
        "model": "elise sport 1796cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "fiesta ghia 1596cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra gls 1998cc", "shape": "hatchback"},
    {"make": "renault", "model": "safrane rt 1995cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xsara vts 1998cc", "shape": "sportscoupe"},
    {
        "make": "renault",
        "model": "clio rl prima diesel 1870",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta lx 1297cc", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "laguna sport 16v 1783cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "vectra arc 1.8 5dr", "shape": "hatchback"},
    {"make": "toyota", "model": "celica st 1762cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "corsa mer 1.2 5dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra cd 1994cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra envoy 1686",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "400 416i 1589cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta zetec 1242cc", "shape": "hatchback"},
    {
        "make": "bmw",
        "model": "3 series 318i touring 1795cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "peugeot", "model": "106 gti 1.6 3dr", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "shogun v6 2972cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "vectra cdx 2498cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "astra env 1.7dti",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra sri 2498cc", "shape": "hatchback"},
    {"make": "ford", "model": "scorpio ultima 2295", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra ls 1.4 5dr", "shape": "hatchback"},
    {"make": "citroen", "model": "xsara x 1587cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa com 1.0 3dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery tdi 2495cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "75 connoisseur se 1796cc", "shape": "saloon"},
    {"make": "ford", "model": "fiesta classic 1753cc", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf gti 1984cc", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "space wagon glx 1755",
        "shape": "multipurposevehicle",
    },
    {"make": "renault", "model": "scenic rxe 1598cc", "shape": "hatchback"},
    {"make": "nissan", "model": "micra gx 1.3 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo verona 5dr", "shape": "saloon"},
    {"make": "volkswagen", "model": "golf gt 1896", "shape": "hatchback"},
    {"make": "renault", "model": "scenic rt 1870", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xei s/wagon",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra cd 1995cc", "shape": "hatchback"},
    {"make": "honda", "model": "civic s 1396cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xdi 1994cc",
        "shape": "sportscoupe",
    },
    {"make": "vauxhall", "model": "vectra ls 1.8 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa elegance 1199cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "106 zest 2 1527cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa elegance 1389cc",
        "shape": "hatchback",
    },
    {
        "make": "fiat",
        "model": "marea weekend elx 1998cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "renault",
        "model": "espace rt-x 2188cc",
        "shape": "multipurposevehicle",
    },
    {"make": "volkswagen", "model": "golf gti 1781", "shape": "hatchback"},
    {
        "make": "toyota",
        "model": "rav 4 vx 1998cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "citroen", "model": "saxo sx 1360cc", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "166 sportronic 2959cc", "shape": "saloon"},
    {"make": "volkswagen", "model": "golf gti 1781cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "saxo spree ltd edn 954cc",
        "shape": "hatchback",
    },
    {
        "make": "austin",
        "model": "mini paul smith ltd edn 1275cc",
        "shape": "saloon",
    },
    {"make": "peugeot", "model": "306 glx 1587cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sri 16v 1796cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xm sx 1998cc", "shape": "hatchback"},
    {"make": "toyota", "model": "corolla cdx 1587", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo tddi 2.0 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "focus lx 1.8td 5dr", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "306 306 meridian estate 2.0 auto",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "800 820 si 16v 1994cc", "shape": "saloon"},
    {"make": "saab", "model": "03-sep se 2171cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xei 1.8 3dr",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "tigra marine ltd edn 1598cc",
        "shape": "sportscoupe",
    },
    {"make": "rover", "model": "75 class se 2.0", "shape": "saloon"},
    {
        "make": "renault",
        "model": "laguna rt sport 16v 1598cc",
        "shape": "hatchback",
    },
    {
        "make": "alfa romeo",
        "model": "156 sportwagon lusso 2387cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "mitsubishi",
        "model": "carisma equippe 1597cc",
        "shape": "hatchback",
    },
    {"make": "renault", "model": "megane rt sport 1598", "shape": "hatchback"},
    {"make": "ford", "model": "ka ka 1.3 3dr", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa sport 1389cc", "shape": "hatchback"},
    {"make": "volvo", "model": "c70 t 2435", "shape": "sportscoupe"},
    {"make": "rover", "model": "800 827 sli 24v 2675cc", "shape": "saloon"},
    {"make": "rover", "model": "75 club se 2497cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra sxi 1.6 5dr", "shape": "hatchback"},
    {"make": "rover", "model": "400 414 si 101bhp -", "shape": "saloon"},
    {"make": "peugeot", "model": "306 l 1997", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery tdi es 2495cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "jeep",
        "model": "grand cherokee sw ltd 4.0a est",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "honda",
        "model": "s2000 roadster 1997cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "fiat", "model": "brava sx 1.4 5dr", "shape": "hatchback"},
    {
        "make": "porsche",
        "model": "911 carrera 4 3596cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "vectra club 1994cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander v6es",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "corsa club 973cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "106 slalom ltd edn", "shape": "hatchback"},
    {"make": "volvo", "model": "v40 1731cc", "shape": "estateoffroadvehicle"},
    {"make": "suzuki", "model": "baleno gs 1590", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "206 roland garros 1587cc",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "45 is 1.6 5dr", "shape": "hatchback"},
    {
        "make": "bmw",
        "model": "z3 roadster 1895cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "peugeot", "model": "206 xsi 1587cc", "shape": "hatchback"},
    {"make": "rover", "model": "25 ie 1119cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon t.spark lusso 1747cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "focus 1.8 zet 3dr", "shape": "hatchback"},
    {
        "make": "volvo",
        "model": "850 2.5 10v se 2435cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "volkswagen", "model": "polo cl 1390cc", "shape": "hatchback"},
    {"make": "fiat", "model": "bravo hlx 1581cc", "shape": "hatchback"},
    {"make": "honda", "model": "civic coupe 1.5l", "shape": "sportscoupe"},
    {"make": "nissan", "model": "micra gx 998cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio rxe 1600", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "xantia 16v exclusive 1998cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "306 glx 1998", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery td5 gs",
        "shape": "estateoffroadvehicle",
    },
    {"make": "volkswagen", "model": "polo cl 1390", "shape": "hatchback"},
    {"make": "nissan", "model": "almera gti 1998cc", "shape": "hatchback"},
    {"make": "mercedes-benz", "model": "190 e 2599", "shape": "saloon"},
    {"make": "ford", "model": "mondeo ghia 1988", "shape": "hatchback"},
    {"make": "ford", "model": "ka luxy 1.3 3dr", "shape": "hatchback"},
    {"make": "rover", "model": "25 ie 1119cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra gls 1799cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "freelander xi 1796cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "saab", "model": "900 s 1985cc", "shape": "hatchback"},
    {"make": "seat", "model": "cordoba sx 1595cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "focus lx 1753cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "frontera sport rs 2171cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "omega cd 2.2 4dr", "shape": "saloon"},
    {
        "make": "peugeot",
        "model": "206 coupe cabriolet s 1587cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "escort gti 1796cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega cdx 2498cc", "shape": "saloon"},
    {
        "make": "seat",
        "model": "alhambra 7 seat 1896",
        "shape": "multipurposevehicle",
    },
    {
        "make": "alfa romeo",
        "model": "147 t.spark lusso 1598cc",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "206 lx 1868cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa gsi 16v 1598", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "156 veloce 2492cc", "shape": "saloon"},
    {"make": "honda", "model": "civic type r 1998cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sxi 16v 1796cc", "shape": "hatchback"},
    {"make": "renault", "model": "clio alize 16v 1390cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "mondeo verona ltd edn 1796cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "mondeo ghia x 1753cc", "shape": "hatchback"},
    {
        "make": "mercedes-benz",
        "model": "m-class ml320 3199",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "accord es 1997cc", "shape": "saloon"},
    {
        "make": "citroen",
        "model": "saxo east coast ltd edn 954",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta ghia 1388cc", "shape": "hatchback"},
    {"make": "audi", "model": "a6 se 1984cc", "shape": "estateoffroadvehicle"},
    {
        "make": "renault",
        "model": "clio provence ltd edn 1149cc",
        "shape": "hatchback",
    },
    {"make": "mazda", "model": "mx-5 1839cc", "shape": "convertiblecabriolet"},
    {"make": "ford", "model": "mondeo ghia 1.8 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo ghia x 2544cc", "shape": "saloon"},
    {
        "make": "mitsubishi",
        "model": "shogun pajero tdr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "peugeot", "model": "306 xs 1761cc", "shape": "hatchback"},
    {"make": "seat", "model": "toledo i se 1896cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra arctic ii ltd edn 1598",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "75 connoisseur se 1997cc", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra 2198cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "bmw", "model": "z3 2.8i 193bhp", "shape": "sportscoupe"},
    {"make": "ford", "model": "mondeo ghia 2.0td", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon veloce 2387cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "honda",
        "model": "cr-v es 1973cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "ford",
        "model": "galaxy ghia 1896cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "ka ka3 1.3 3dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery mpi 1994cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "400 si 1.4 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "cougar 1988cc", "shape": "sportscoupe"},
    {
        "make": "mitsubishi",
        "model": "shogun gls 3497cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "lexus", "model": "gs 300 sport 2997cc", "shape": "saloon"},
    {
        "make": "mitsubishi",
        "model": "space wagon equippe gdi 2351cc",
        "shape": "multipurposevehicle",
    },
    {"make": "fiat", "model": "punto sporting 1242cc", "shape": "hatchback"},
    {"make": "peugeot", "model": "406 v6 2946cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "vectra cdx 1796cc", "shape": "hatchback"},
    {"make": "daewoo", "model": "espero cdxi 1998cc", "shape": "saloon"},
    {
        "make": "ford",
        "model": "escort masquerade ltd edn 1597cc",
        "shape": "saloon",
    },
    {"make": "rover", "model": "200 di 2.0 3dr", "shape": "hatchback"},
    {
        "make": "volkswagen",
        "model": "passat gl 1984cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "bmw", "model": "3 series 323i se 2494cc", "shape": "saloon"},
    {"make": "fiat", "model": "seicento sprt 1.1 3dr", "shape": "hatchback"},
    {"make": "ford", "model": "puma 1.6 3dr", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "corsa comfort 1199cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus lx 1596cc", "shape": "hatchback"},
    {"make": "bmw", "model": "7 series 730i 2986", "shape": "saloon"},
    {
        "make": "renault",
        "model": "laguna alize ltd edn 1598cc",
        "shape": "hatchback",
    },
    {"make": "renault", "model": "megane v960jlc - 6000", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "espace champs elysees ltd edn 1995cc",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "astra cdx 16v 1796cc", "shape": "hatchback"},
    {"make": "ford", "model": "probe 16v 1991cc", "shape": "sportscoupe"},
    {"make": "honda", "model": "civic 1396cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "galaxy ghia x 2295cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "alfa romeo",
        "model": "166 sportronic 3.0v6 17",
        "shape": "saloon",
    },
    {"make": "rover", "model": "400 416 is 1589cc", "shape": "hatchback"},
    {"make": "citroen", "model": "xsara lx 1587cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 2.5 v6 veloce automatic",
        "shape": "saloon",
    },
    {
        "make": "vauxhall",
        "model": "astra envoy 1.6 3d auto",
        "shape": "hatchback",
    },
    {"make": "honda", "model": "civic vtec 1668cc", "shape": "sportscoupe"},
    {"make": "honda", "model": "accord ls 1850", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra cd 1.6 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "omega gls 2498cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "lotus",
        "model": "elise convertable",
        "shape": "convertiblecabriolet",
    },
    {"make": "honda", "model": "accord ls 1850cc", "shape": "saloon"},
    {"make": "hyundai", "model": "accent mvi 1495", "shape": "sportscoupe"},
    {
        "make": "vauxhall",
        "model": "vectra premier ltd edn 1598cc",
        "shape": "saloon",
    },
    {"make": "fiat", "model": "seicento sx 1108cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "corsa vegas ltd edn 1195",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta lx 1242cc", "shape": "hatchback"},
    {"make": "porsche", "model": "911 carrera 3.0cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "corsa gls 1199cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort lx 1.6 5dr", "shape": "hatchback"},
    {"make": "peugeot", "model": "306 d turbo 1905cc", "shape": "hatchback"},
    {
        "make": "porsche",
        "model": "boxster tiptronic s 2687cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "vectra ls 2198cc", "shape": "hatchback"},
    {"make": "audi", "model": "a4 se 125bhp", "shape": "saloon"},
    {
        "make": "vauxhall",
        "model": "astra colour edition 1799",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "nissan",
        "model": "almera tino s 1769cc",
        "shape": "multipurposevehicle",
    },
    {"make": "peugeot", "model": "306 style 1360cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic marlin ltd edn 1343",
        "shape": "hatchback",
    },
    {"make": "austin", "model": "mini city e 998cc", "shape": "saloon"},
    {"make": "volkswagen", "model": "golf e 1390cc", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "range rover dse 2497cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "porsche", "model": "911 carrera 3600cc", "shape": "sportscoupe"},
    {"make": "ford", "model": "mondeo zetec 1796cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comfort 1389cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic aerodeck ls 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "laguna rt sport 1783", "shape": "hatchback"},
    {
        "make": "tvr",
        "model": "tuscan speed six 4.0 litre 3179cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "renault", "model": "clio rn 1598", "shape": "hatchback"},
    {"make": "porsche", "model": "928 gt 4957cc", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "vectra gls 1796cc", "shape": "hatchback"},
    {
        "make": "rover",
        "model": "75 tourer club se 1951cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "peugeot",
        "model": "106 roland garros 1360",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "astra ls 8v 1.6 5d", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio liberte ltd edn 1870cc",
        "shape": "hatchback",
    },
    {
        "make": "toyota",
        "model": "avensis gls 1998",
        "shape": "estateoffroadvehicle",
    },
    {"make": "skoda", "model": "fabia comfort 1390cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus ghia 1.6 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo glx 1988cc", "shape": "hatchback"},
    {
        "make": "m.g.",
        "model": "mgf 1796cc steptronic",
        "shape": "convertiblecabriolet",
    },
    {"make": "peugeot", "model": "306 lx 1905", "shape": "saloon"},
    {"make": "citroen", "model": "saxo x 1124cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra cd 16v 1598cc", "shape": "hatchback"},
    {"make": "ford", "model": "transit 190 1993", "shape": "commercialvehicle"},
    {"make": "chrysler", "model": "neon lx 2.0a", "shape": "saloon"},
    {"make": "m.g.", "model": "mgf 1796cc", "shape": "convertiblecabriolet"},
    {
        "make": "vauxhall",
        "model": "zafira comfort 1796cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "land rover",
        "model": "freelander i 1.8 5dr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "corsa envoy 973cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "saxo east coast ltd edn 1124cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "ka 1299cc", "shape": "hatchback"},
    {
        "make": "tvr",
        "model": "chimaera blank 4546",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "vauxhall",
        "model": "vectra cd 1796cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "corsa sxi 16v 1199cc", "shape": "hatchback"},
    {"make": "ford", "model": "focus ghia 1596cc", "shape": "saloon"},
    {"make": "peugeot", "model": "106 106 1.1xn", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra sri v6 2498cc", "shape": "saloon"},
    {"make": "citroen", "model": "xm turbo d vsx 2445cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort cl 1391", "shape": "hatchback"},
    {"make": "volkswagen", "model": "golf gti t 1781", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta encore 1297cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "saxo west coast ltd edn 1360",
        "shape": "hatchback",
    },
    {"make": "volkswagen", "model": "lupo e 999cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic aerodeck vtec se 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra ls 1.6", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra club 1.8", "shape": "hatchback"},
    {"make": "porsche", "model": "911 3387cc", "shape": "convertiblecabriolet"},
    {"make": "volkswagen", "model": "passat se 1781", "shape": "saloon"},
    {
        "make": "saab",
        "model": "900 turbo 16v se 1985cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "citroen",
        "model": "xsara picasso lx 1587cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "vauxhall",
        "model": "astra astra 1.6 club 8v",
        "shape": "hatchback",
    },
    {"make": "volvo", "model": "s70 2.4 170 bhp se 2435cc", "shape": "saloon"},
    {"make": "rover", "model": "400 416 sli 1590cc", "shape": "saloon"},
    {
        "make": "land rover",
        "model": "discovery td5 xs",
        "shape": "estateoffroadvehicle",
    },
    {"make": "rover", "model": "45 connoisseur 1994cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra ls 1.4 3dr", "shape": "hatchback"},
    {"make": "citroen", "model": "zx aura 1360cc", "shape": "hatchback"},
    {"make": "suzuki", "model": "baleno glx 1590", "shape": "saloon"},
    {"make": "lotus", "model": "elise 1796cc", "shape": "convertiblecabriolet"},
    {"make": "toyota", "model": "avensis gs 1.8 4dr", "shape": "hatchback"},
    {"make": "daewoo", "model": "leganza cdx 1998cc", "shape": "saloon"},
    {"make": "proton", "model": "persona 1834cc", "shape": "sportscoupe"},
    {"make": "fiat", "model": "brava sx 1370", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "90 defender tdi 2495cc",
        "shape": "commercialvehicle",
    },
    {
        "make": "rover",
        "model": "400 414 s 16v ltd edn 1396",
        "shape": "hatchback",
    },
    {"make": "peugeot", "model": "306 xldt 1905cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1598cc", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic aerodeck es 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra sxi 1.8 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "cougar coupe 2.5 3d", "shape": "sportscoupe"},
    {
        "make": "porsche",
        "model": "924 2.0-petrolmulti-point injection",
        "shape": "sportscoupe",
    },
    {
        "make": "renault",
        "model": "espace rn family ltd edn 1995cc",
        "shape": "multipurposevehicle",
    },
    {"make": "volvo", "model": "s80 2.4se automatic", "shape": "saloon"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon veloce 2.5 v6",
        "shape": "estateoffroadvehicle",
    },
    {"make": "smart car", "model": "smart 30968", "shape": "hatchback"},
    {"make": "volkswagen", "model": "bora s 1896", "shape": "saloon"},
    {
        "make": "mitsubishi",
        "model": "shogun pinin elegance 1997cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "fiesta finesse 1299cc", "shape": "hatchback"},
    {"make": "ford", "model": "puma blank 1388", "shape": "sportscoupe"},
    {"make": "vauxhall", "model": "astra ls 8v 1.6est", "shape": "hatchback"},
    {"make": "citroen", "model": "xm turbo vsx 1998cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra ls 1686cc", "shape": "saloon"},
    {"make": "ford", "model": "focus ghia 1989cc", "shape": "saloon"},
    {"make": "peugeot", "model": "306 meridian 1360cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo zetec-s 1988cc", "shape": "hatchback"},
    {
        "make": "fiat",
        "model": "ulysse el 1998cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "ford",
        "model": "mondeo zetec-s 2544cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "vectra club 2.0 dti", "shape": "hatchback"},
    {"make": "ford", "model": "escort lx 1391", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "omega elite 3.0",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "mitsubishi",
        "model": "space wagon classic 1997cc",
        "shape": "multipurposevehicle",
    },
    {
        "make": "mitsubishi",
        "model": "shogun sport equippe 2477cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "crx vti 1595", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "406 ls 1761", "shape": "saloon"},
    {"make": "ford", "model": "focus ghia 1989cc", "shape": "hatchback"},
    {"make": "ford", "model": "escort ghia 1391cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "xantia exclusive 2946cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "focus lx 1.6 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta ghia 1299cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa 1.2 club 3dr", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "306 meridian ltd edn 1905cc",
        "shape": "hatchback",
    },
    {
        "make": "mitsubishi",
        "model": "shogun equippe 3200cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "corsa new corsa sri 16v 1389cc",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "600 623 sli 2259", "shape": "saloon"},
    {"make": "vauxhall", "model": "astra sxi 1796cc", "shape": "hatchback"},
    {"make": "rover", "model": "200 200 vi 1796cc", "shape": "hatchback"},
    {
        "make": "jeep",
        "model": "cherokee limited 2499",
        "shape": "estateoffroadvehicle",
    },
    {"make": "nissan", "model": "almera sport 1769cc", "shape": "hatchback"},
    {"make": "honda", "model": "prelude blank 1997", "shape": "sportscoupe"},
    {
        "make": "peugeot",
        "model": "206 grand tourisme ltd edn 1997cc",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "600 618i 1850cc", "shape": "saloon"},
    {"make": "lexus", "model": "ls 400 3969cc", "shape": "saloon"},
    {
        "make": "porsche",
        "model": "boxster 2480cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "ford",
        "model": "galaxy zetec 2295cc",
        "shape": "multipurposevehicle",
    },
    {"make": "peugeot", "model": "405 grdt 1905cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra ls 2.0 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "focus zet 1.6 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "puma coup 1.7 2dr", "shape": "sportscoupe"},
    {"make": "renault", "model": "clio rt 1149", "shape": "hatchback"},
    {"make": "vauxhall", "model": "omega elite 2498cc", "shape": "saloon"},
    {
        "make": "audi",
        "model": "cabriolet 2771cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "vauxhall",
        "model": "vectra sri 2198cc 150 5dr",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "25 impression s 1396cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "1.7 ls tds 5 door", "shape": "hatchback"},
    {"make": "bmw", "model": "3 series 316i se 1596cc", "shape": "saloon"},
    {"make": "rover", "model": "400 414 1396cc", "shape": "hatchback"},
    {
        "make": "mazda",
        "model": "tribute gsi 1989cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "citroen",
        "model": "xsara picasso sx 1587cc",
        "shape": "multipurposevehicle",
    },
    {"make": "ford", "model": "escort lx 1597", "shape": "hatchback"},
    {"make": "rover", "model": "200 216 si 1589", "shape": "hatchback"},
    {"make": "alfa romeo", "model": "156 2.5 v6 veloce", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra club 1796", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "laguna expression 1598cc",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "omega cdx 2198cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "porsche",
        "model": "911 carrera 2 3596cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "nissan", "model": "micra s 998cc", "shape": "hatchback"},
    {
        "make": "nissan",
        "model": "terrano ii tdi se 2664cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "audi", "model": "a3 1595cc", "shape": "hatchback"},
    {"make": "mazda", "model": "626 lxi 1991cc", "shape": "saloon"},
    {"make": "vauxhall", "model": "vectra sri 140 5dr", "shape": "hatchback"},
    {"make": "toyota", "model": "starlet sportif 1332", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "megane sport 16v 1598cc",
        "shape": "hatchback",
    },
    {"make": "toyota", "model": "avensis cdx 1998", "shape": "saloon"},
    {
        "make": "rover",
        "model": "200 216 cabriolet 16v 1590cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "peugeot",
        "model": "406 rapier 2.0 e",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "tigra 16v 1598cc", "shape": "sportscoupe"},
    {"make": "peugeot", "model": "106 xl 1124cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra ls 1686cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "astra sri 16v 2198cc", "shape": "hatchback"},
    {"make": "ford", "model": "puma 16v 1.7 3dr", "shape": "sportscoupe"},
    {"make": "renault", "model": "clio rt 1794", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "156 sportwagon t.spark veloce 1970cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo lx 1597cc", "shape": "hatchback"},
    {
        "make": "peugeot",
        "model": "306 miami ltd edn 1360cc",
        "shape": "hatchback",
    },
    {
        "make": "renault",
        "model": "laguna expression 1783cc",
        "shape": "hatchback",
    },
    {
        "make": "porsche",
        "model": "911 carrera 2 3600cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "ford", "model": "ka 1.3 3dr", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "laguna 1.9td-dieseldirect injection",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "vectra sxi 16v 1796cc",
        "shape": "hatchback",
    },
    {"make": "volkswagen", "model": "passat se 1781cc", "shape": "saloon"},
    {"make": "ford", "model": "mondeo ghia 1988cc", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "astra sport 16v 1796cc",
        "shape": "hatchback",
    },
    {
        "make": "mitsubishi",
        "model": "carisma elegance 1834cc",
        "shape": "hatchback",
    },
    {
        "make": "land rover",
        "model": "freelander xdi 2.0 5dr",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "ka 1.3 3dr", "shape": "hatchback"},
    {
        "make": "land rover",
        "model": "discovery td5 s",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "mercedes-benz",
        "model": "c-class c220 diesel elegance 2155cc",
        "shape": "saloon",
    },
    {
        "make": "mitsubishi",
        "model": "shogun elegance 3497cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "mondeo ghia x 2544cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 418 sld turbo 1769", "shape": "saloon"},
    {"make": "citroen", "model": "saxo first 1124cc", "shape": "hatchback"},
    {"make": "rover", "model": "200 216 sli 16v 1590cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta finesse 1.3", "shape": "hatchback"},
    {
        "make": "mercedes-benz",
        "model": "c-class c250 turbodiesel elegance 2497",
        "shape": "saloon",
    },
    {
        "make": "land rover",
        "model": "freelander v6gs 2.5 5dr",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "alfa romeo",
        "model": "gtv 16v t. spark 1970cc",
        "shape": "sportscoupe",
    },
    {"make": "peugeot", "model": "406 v6 2946cc", "shape": "saloon"},
    {
        "make": "porsche",
        "model": "boxster s 3179cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "renault", "model": "clio rt 1390cc", "shape": "hatchback"},
    {"make": "mercedes-benz", "model": "a class 1.4 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "escort fin 1.6 5dr", "shape": "hatchback"},
    {
        "make": "vauxhall",
        "model": "omega cd 2597cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "toyota",
        "model": "avensis gls 1998cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "vauxhall", "model": "omega cd 1998", "shape": "saloon"},
    {
        "make": "ford",
        "model": "focus lx 1.8 est",
        "shape": "estateoffroadvehicle",
    },
    {"make": "ford", "model": "fiesta zet 1.25", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta f.sty 1.25 3", "shape": "hatchback"},
    {"make": "mercedes-benz", "model": "300 e 2960cc", "shape": "saloon"},
    {"make": "peugeot", "model": "607 se 2230cc", "shape": "saloon"},
    {"make": "toyota", "model": "corolla 1332cc", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta ghia 1242cc", "shape": "hatchback"},
    {"make": "nissan", "model": "almera slx 1597cc", "shape": "hatchback"},
    {
        "make": "suzuki",
        "model": "vitara jlx se 1590cc",
        "shape": "estateoffroadvehicle",
    },
    {
        "make": "vauxhall",
        "model": "astra colour edition 1598cc",
        "shape": "convertiblecabriolet",
    },
    {"make": "vauxhall", "model": "vectra ls 1799cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 414 si 16v 1396cc", "shape": "hatchback"},
    {"make": "rover", "model": "400 416 sli 16v 1590cc", "shape": "saloon"},
    {
        "make": "land rover",
        "model": "freelander gs 2497cc",
        "shape": "sportscoupe",
    },
    {
        "make": "volkswagen",
        "model": "golf 1.4-petrolinjection",
        "shape": "hatchback",
    },
    {"make": "rover", "model": "100 sli 1.4 3dr", "shape": "hatchback"},
    {
        "make": "honda",
        "model": "civic vtec se executive 1590cc",
        "shape": "hatchback",
    },
    {"make": "skoda", "model": "felicia classic 1289cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "vectra sri 2597cc", "shape": "saloon"},
    {
        "make": "m.g.",
        "model": "mgf vvc 1796cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "renault",
        "model": "clio biarritz ltd edn 1149cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "escort finesse 5dr", "shape": "hatchback"},
    {
        "make": "renault",
        "model": "clio dynamique + 1390cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "fiesta zetec-s 1596cc", "shape": "hatchback"},
    {"make": "honda", "model": "accord es 1997cc", "shape": "saloon"},
    {"make": "peugeot", "model": "106 zest 3 1527cc", "shape": "hatchback"},
    {
        "make": "ford",
        "model": "mondeo lx 1753cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "honda", "model": "civic vei 1493", "shape": "hatchback"},
    {"make": "citroen", "model": "xantia sx 1997cc", "shape": "hatchback"},
    {"make": "ford", "model": "mondeo verona 1796cc", "shape": "hatchback"},
    {"make": "hyundai", "model": "lantra si 1795", "shape": "saloon"},
    {"make": "honda", "model": "civic s 1590cc", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "spider 16v t. spark 1970cc",
        "shape": "convertiblecabriolet",
    },
    {
        "make": "vauxhall",
        "model": "cavalier concept ltd edn 1598",
        "shape": "hatchback",
    },
    {
        "make": "vauxhall",
        "model": "zafira comfort 1995cc",
        "shape": "multipurposevehicle",
    },
    {"make": "vauxhall", "model": "vectra ls 16v 1.8 5", "shape": "hatchback"},
    {"make": "ford", "model": "focus zetec 1753cc", "shape": "hatchback"},
    {"make": "porsche", "model": "911 carrera 3387cc", "shape": "sportscoupe"},
    {
        "make": "volkswagen",
        "model": "golf cl tdi 1896cc",
        "shape": "estateoffroadvehicle",
    },
    {"make": "renault", "model": "laguna rt 2.0a 5dr", "shape": "hatchback"},
    {"make": "ford", "model": "fiesta 1.2 free 3dr", "shape": "hatchback"},
    {
        "make": "alfa romeo",
        "model": "gtv v6 24v 2959cc",
        "shape": "sportscoupe",
    },
    {"make": "citroen", "model": "saxo sx 1527", "shape": "hatchback"},
    {"make": "vauxhall", "model": "astra sport 1.8 3d", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa gls 1.7d", "shape": "hatchback"},
    {"make": "honda", "model": "accord vtec se 1850cc", "shape": "saloon"},
    {"make": "fiat", "model": "punto 60 sx 1242cc", "shape": "hatchback"},
    {"make": "vauxhall", "model": "corsa comf 1.0 3dr", "shape": "hatchback"},
    {
        "make": "mitsubishi",
        "model": "colt space star glx 1299cc",
        "shape": "hatchback",
    },
    {"make": "vauxhall", "model": "corsa ls 1195cc", "shape": "hatchback"},
    {
        "make": "citroen",
        "model": "ax 14 gt 500 ltd edn 1360cc",
        "shape": "hatchback",
    },
    {"make": "ford", "model": "mondeo zetec 1798cc", "shape": "hatchback"},
    {
        "make": "ferrari",
        "model": "f355 f1 paddle shift",
        "shape": "sportscoupe",
    },
    {"make": "volkswagen", "model": "golf l 1390", "shape": "hatchback"},
    {"make": "ford", "model": "ka luxury ltd edn 1299cc", "shape": "hatchback"},
]
