# -*- encoding: utf-8 -*-
"""
Simply a list of Danish words, without meanings. Because of the common use of
accented characters, this makes the data useful to developers looking to
rigidly test their applications. The data can also be used to create the names
of far-out products, or even fictional character names.

**Usage:**

::

    from liar.iamaliar import IAmALiar
    number_records = 10
    maker = IAmALiar(number_records)

    # Use:
    from liar.model.raw import danish_raw

    # Or from scratch:
    danish_raw = {
        'name': 'danish_raw',
        'class': 'igetraw',
        'data': 'danish',
    }

    data_set = maker.get_data([danish_raw])

    for row in data_set:
        data = Model()
        data.danish_word = row['danish_raw']
        data.save()

Blurb:

::

    danish_title = {
        'name': 'danish_title',
        'class': 'iblurb',
        'language': 'danish',
        'method': 'plaintext_title',
        'min': 5,
        'max': 8,
    }

    data_set = maker.get_data([danish_title])

    for row in data_set:
        data = Model()
        data.danish_title = row['danish_title']
        data.save()

"""

danish = [
    "er",
    "jeg",
    "det",
    "du",
    "ikke",
    "at",
    "en",
    "og",
    "har",
    "vi",
    "til",
    "på",
    "hvad",
    "mig",
    "med",
    "de",
    "den",
    "for",
    "der",
    "så",
    "dig",
    "han",
    "kan",
    "af",
    "vil",
    "var",
    "her",
    "et",
    "skal",
    "ved",
    "men",
    "om",
    "nu",
    "som",
    "ja",
    "min",
    "nej",
    "noget",
    "ham",
    "hun",
    "være",
    "bare",
    "kom",
    "din",
    "hvor",
    "os",
    "dem",
    "hvis",
    "ud",
    "må",
    "fra",
    "se",
    "godt",
    "have",
    "ville",
    "gør",
    "lige",
    "okay",
    "alle",
    "op",
    "lad",
    "hvorfor",
    "tror",
    "sig",
    "tak",
    "hvordan",
    "kommer",
    "få",
    "kunne",
    "gøre",
    "meget",
    "eller",
    "hende",
    "ingen",
    "tilbage",
    "hvem",
    "gå",
    "bliver",
    "havde",
    "efter",
    "nok",
    "man",
    "da",
    "går",
    "alt",
    "sagde",
    "mit",
    "når",
    "ind",
    "vores",
    "over",
    "aldrig",
    "nogen",
    "måske",
    "hans",
    "skulle",
    "mand",
    "selv",
    "to",
    "mere",
    "jo",
    "jer",
    "siger",
    "også",
    "lidt",
    "dit",
    "kun",
    "deres",
    "far",
    "ser",
    "blev",
    "får",
    "hej",
    "sådan",
    "dette",
    "igen",
    "sammen",
    "denne",
    "hele",
    "hold",
    "mine",
    "tager",
    "ned",
    "komme",
    "dag",
    "undskyld",
    "tage",
    "blive",
    "mor",
    "væk",
    "end",
    "åh",
    "sige",
    "været",
    "tid",
    "fordi",
    "helt",
    "sted",
    "før",
    "gjorde",
    "god",
    "gang",
    "år",
    "tag",
    "laver",
    "mange",
    "nogle",
    "dine",
    "fik",
    "mener",
    "ting",
    "lille",
    "siden",
    "altid",
    "mr",
    "brug",
    "folk",
    "virkelig",
    "vent",
    "finde",
    "anden",
    "stadig",
    "hjem",
    "gud",
    "liv",
    "vej",
    "kender",
    "andre",
    "klar",
    "tale",
    "mod",
    "uden",
    "elsker",
    "set",
    "tre",
    "hør",
    "ret",
    "gerne",
    "hr",
    "giv",
    "sir",
    "sidste",
    "tog",
    "fanden",
    "intet",
    "død",
    "fint",
    "vel",
    "nå",
    "jeres",
    "lide",
    "troede",
    "hendes",
    "hen",
    "blevet",
    "vide",
    "gjort",
    "sker",
    "bedre",
    "ven",
    "første",
    "hjælpe",
    "vær",
    "aften",
    "samme",
    "andet",
    "hjælp",
    "gik",
    "vidste",
    "forstår",
    "arbejde",
    "under",
    "navn",
    "sin",
    "give",
    "skat",
    "eneste",
    "høre",
    "penge",
    "morgen",
    "endnu",
    "giver",
    "burde",
    "bedste",
    "bruge",
    "holde",
    "hey",
    "synes",
    "sikker",
    "tro",
    "fortælle",
    "venner",
    "står",
    "stop",
    "sikkert",
    "nødt",
    "længe",
    "ok",
    "verden",
    "engang",
    "taler",
    "stor",
    "døde",
    "hver",
    "måde",
    "fyr",
    "ude",
    "hedder",
    "finder",
    "par",
    "store",
    "fandt",
    "selvfølgelig",
    "fået",
    "bange",
    "skete",
    "først",
    "snart",
    "næste",
    "disse",
    "holder",
    "øjeblik",
    "faktisk",
    "mænd",
    "ihjel",
    "behøver",
    "betyder",
    "pige",
    "hos",
    "ellers",
    "flere",
    "lort",
    "gamle",
    "tiden",
    "ked",
    "søn",
    "gode",
    "hallo",
    "prøver",
    "ligesom",
    "stille",
    "mennesker",
    "rigtigt",
    "dø",
    "jack",
    "nye",
    "børn",
    "vist",
    "lave",
    "minutter",
    "lade",
    "slå",
    "gav",
    "fem",
    "huske",
    "galt",
    "derfor",
    "orden",
    "rigtig",
    "gange",
    "pas",
    "helvede",
    "dage",
    "kone",
    "fundet",
    "alene",
    "farvel",
    "møde",
    "taget",
    "allerede",
    "bliv",
    "hurtigt",
    "én",
    "herfra",
    "ønsker",
    "ses",
    "grund",
    "slags",
    "kommet",
    "rolig",
    "hvilken",
    "altså",
    "bil",
    "skyld",
    "familie",
    "sagt",
    "kvinde",
    "hørt",
    "fire",
    "venter",
    "side",
    "klare",
    "hører",
    "vejen",
    "dræbe",
    "dreng",
    "hvornår",
    "rundt",
    "fortæl",
    "imod",
    "arbejder",
    "dør",
    "hellere",
    "frem",
    "senere",
    "langt",
    "del",
    "hørte",
    "begge",
    "håber",
    "længere",
    "pis",
    "fejl",
    "bilen",
    "inden",
    "nogensinde",
    "haft",
    "dr",
    "glad",
    "livet",
    "sæt",
    "kører",
    "heller",
    "sket",
    "sandt",
    "hinanden",
    "næsten",
    "ny",
    "inde",
    "virker",
    "leder",
    "hus",
    "kæft",
    "ord",
    "ingenting",
    "politiet",
    "gået",
    "spørgsmål",
    "lang",
    "pa",
    "timer",
    "snakke",
    "lyder",
    "bag",
    "john",
    "bror",
    "byen",
    "prøve",
    "kaptajn",
    "problem",
    "indtil",
    "dog",
    "tænkte",
    "videre",
    "sent",
    "ben",
    "sød",
    "løb",
    "egen",
    "ondt",
    "barn",
    "velkommen",
    "vise",
    "fat",
    "mens",
    "omkring",
    "igennem",
    "fortalte",
    "sit",
    "problemer",
    "hva",
    "slap",
    "forbi",
    "gennem",
    "kalder",
    "job",
    "tænker",
    "ti",
    "ha",
    "fri",
    "gammel",
    "ringer",
    "sjovt",
    "færdig",
    "fast",
    "snakker",
    "våben",
    "klarer",
    "chance",
    "køre",
    "drenge",
    "ligner",
    "bad",
    "slår",
    "lader",
    "al",
    "stedet",
    "sidder",
    "ligger",
    "sa",
    "hånd",
    "stå",
    "mad",
    "stoppe",
    "hjemme",
    "ad",
    "ske",
    "hader",
    "tænk",
    "mest",
    "seks",
    "døren",
    "sgu",
    "lavet",
    "historie",
    "the",
    "vente",
    "tænke",
    "tii",
    "nummer",
    "flot",
    "plads",
    "hovedet",
    "resten",
    "datter",
    "svært",
    "føler",
    "beklager",
    "fantastisk",
    "ring",
    "bor",
    "slet",
    "nat",
    "prøv",
    "helst",
    "pengene",
    "hvilket",
    "fortæller",
    "leve",
    "mellem",
    "glem",
    "ringe",
    "live",
    "nyt",
    "redde",
    "tæt",
    "kvinder",
    "blod",
    "jorden",
    "skide",
    "stort",
    "spise",
    "herre",
    "dræbt",
    "uge",
    "new",
    "vand",
    "tur",
    "dollars",
    "kort",
    "sagen",
    "passer",
    "luk",
    "øjne",
    "beder",
    "lære",
    "time",
    "afsted",
    "sine",
    "spille",
    "dræbte",
    "bruger",
    "piger",
    "gift",
    "husker",
    "søster",
    "små",
    "mindre",
    "begynder",
    "forstået",
    "fuld",
    "hjerte",
    "holdt",
    "måtte",
    "huset",
    "præcis",
    "bør",
    "land",
    "by",
    "røven",
    "øje",
    "lov",
    "skynd",
    "slut",
    "fred",
    "læg",
    "smuk",
    "sandheden",
    "klokken",
    "spørge",
    "fedt",
    "værsgo",
    "spiller",
    "kære",
    "slog",
    "held",
    "kæreste",
    "lkke",
    "unge",
    "miss",
    "lever",
    "jamen",
    "knægt",
    "rigtige",
    "alligevel",
    "nede",
    "herrer",
    "besked",
    "slip",
    "roligt",
    "valg",
    "tænkt",
    "vis",
    "findes",
    "oppe",
    "lavede",
    "seng",
    "kærlighed",
    "fyre",
    "handler",
    "måneder",
    "svin",
    "forstå",
    "masse",
    "find",
    "dagen",
    "sætte",
    "perfekt",
    "tom",
    "hoved",
    "kl",
    "foran",
    "idé",
    "fortalt",
    "udenfor",
    "muligt",
    "ansigt",
    "agent",
    "forkert",
    "rejse",
    "elskede",
    "røv",
    "lyst",
    "frank",
    "stykke",
    "manden",
    "krig",
    "mrs",
    "ej",
    "hvert",
    "prøvede",
    "husk",
    "foregår",
    "vigtigt",
    "aftale",
    "venstre",
    "endelig",
    "idiot",
    "goddag",
    "sam",
    "svar",
    "spil",
    "ønske",
    "plan",
    "hårdt",
    "sætter",
    "dræber",
    "oh",
    "sjov",
    "kamp",
    "viser",
    "sikkerhed",
    "millioner",
    "sag",
    "chef",
    "skyde",
    "højre",
    "sender",
    "steder",
    "arbejdet",
    "lykke",
    "mening",
    "damer",
    "værelse",
    "hjælper",
    "kør",
    "godmorgen",
    "derude",
    "betale",
    "uger",
    "træk",
    "klart",
    "bede",
    "hænder",
    "godnat",
    "givet",
    "kæmpe",
    "blot",
    "fly",
    "ligeglad",
    "skyd",
    "film",
    "talte",
    "ringede",
    "lover",
    "natten",
    "charlie",
    "hente",
    "syv",
    "pistol",
    "værd",
    "sikke",
    "forældre",
    "gutter",
    "peter",
    "rart",
    "let",
    "york",
    "tja",
    "vinder",
    "fandens",
    "aner",
    "sidst",
    "tøj",
    "værre",
    "harry",
    "talt",
    "fald",
    "dårligt",
    "general",
    "dum",
    "sove",
    "hvide",
    "træt",
    "tidligere",
    "spørger",
    "derinde",
    "stod",
    "straks",
    "købe",
    "skrive",
    "javel",
    "følge",
    "største",
    "mindste",
    "kendte",
    "person",
    "begyndte",
    "mærke",
    "baby",
    "tillykke",
    "gider",
    "skyder",
    "lys",
    "sekunder",
    "henter",
    "hund",
    "desværre",
    "søde",
    "nød",
    "sidde",
    "skudt",
    "utroligt",
    "tjeneste",
    "bog",
    "ende",
    "tal",
    "indenfor",
    "øjnene",
    "tv",
    "james",
    "mente",
    "smule",
    "menneske",
    "dårlig",
    "mødes",
    "skød",
    "sendt",
    "doktor",
    "mangler",
    "læse",
    "michael",
    "vejret",
    "makker",
    "kaffe",
    "følger",
    "enhver",
    "otte",
    "onkel",
    "hår",
    "større",
    "præsident",
    "løbe",
    "beskytte",
    "kigger",
    "øh",
    "fortsæt",
    "fru",
    "vild",
    "åbne",
    "dyr",
    "skade",
    "billede",
    "eget",
    "syg",
    "fyren",
    "sort",
    "bord",
    "betaler",
    "højt",
    "slået",
    "dumme",
    "fest",
    "george",
    "vinde",
    "sende",
    "kig",
    "mike",
    "lod",
    "følg",
    "lig",
    "spiser",
    "mistet",
    "røvhul",
    "sex",
    "sid",
    "pigen",
    "hertil",
    "ære",
    "dame",
    "fængsel",
    "smukt",
    "lede",
    "sat",
    "anderledes",
    "mester",
    "kontor",
    "vii",
    "døden",
    "sendte",
    "yeah",
    "hent",
    "sorte",
    "drikke",
    "travlt",
    "david",
    "dejligt",
    "glemt",
    "spor",
    "tingene",
    "ung",
    "skole",
    "passe",
    "rør",
    "rette",
    "begynde",
    "betjent",
    "forklare",
    "ide",
    "fader",
    "landet",
    "skai",
    "hænderne",
    "umuligt",
    "herinde",
    "drøm",
    "kalde",
    "åben",
    "alting",
    "ene",
    "meter",
    "venlig",
    "vandet",
    "luften",
    "tør",
    "fanget",
    "fange",
    "overhovedet",
    "forhold",
    "råd",
    "frue",
    "jimmy",
    "smukke",
    "uanset",
    "stole",
    "godeste",
    "født",
    "forsigtig",
    "faldt",
    "send",
    "spurgte",
    "netop",
    "syntes",
    "bekymret",
    "skolen",
    "elske",
    "familien",
    "falder",
    "stil",
    "føles",
    "egne",
    "fare",
    "brugte",
    "sover",
    "vende",
    "guds",
    "forlade",
    "nar",
    "dele",
    "løber",
    "tidspunkt",
    "advokat",
    "halv",
    "oberst",
    "max",
    "kendt",
    "mødt",
    "bo",
    "fører",
    "kende",
    "slippe",
    "lærer",
    "slås",
    "stolt",
    "stopper",
    "læge",
    "mund",
    "kigge",
    "drink",
    "direkte",
    "fbi",
    "bedst",
    "mord",
    "ændre",
    "nemlig",
    "telefon",
    "angreb",
    "rejser",
    "ordre",
    "sikre",
    "normalt",
    "smid",
    "konge",
    "ægte",
    "flyve",
    "ordne",
    "skylder",
    "skriver",
    "ni",
    "rent",
    "ødelægge",
    "skib",
    "satan",
    "joe",
    "fart",
    "vender",
    "brugt",
    "prøvet",
    "telefonen",
    "vore",
    "børnene",
    "krigen",
    "kontakt",
    "gave",
    "skør",
    "mødte",
    "skrev",
    "ærligt",
    "bestemt",
    "ild",
    "middag",
    "ryger",
    "satans",
    "naturligvis",
    "kørte",
    "stemme",
    "slemt",
    "bob",
    "stand",
    "ah",
    "lyset",
    "problemet",
    "paul",
    "lukket",
    "skid",
    "hav",
    "føle",
    "forsøger",
    "aftes",
    "fars",
    "jesus",
    "blå",
    "krop",
    "flyt",
    "historien",
    "forkerte",
    "glemme",
    "pænt",
    "pris",
    "mistede",
    "ma",
    "alex",
    "dér",
    "glemte",
    "forsvind",
    "stærk",
    "billeder",
    "hurtigere",
    "starte",
    "nær",
    "taber",
    "undskylde",
    "frøken",
    "reddede",
    "bill",
    "levende",
    "bryder",
    "fleste",
    "derovre",
    "løgn",
    "lært",
    "skrevet",
    "magt",
    "ro",
    "underligt",
    "venligst",
    "paris",
    "løs",
    "an",
    "dræb",
    "selvom",
    "enkelt",
    "sang",
    "vred",
    "øl",
    "stykker",
    "rum",
    "lyver",
    "sulten",
    "tredje",
    "musik",
    "parat",
    "masser",
    "løjtnant",
    "interessant",
    "midt",
    "starter",
    "miste",
    "slipper",
    "ender",
    "vildt",
    "kammerat",
    "kampen",
    "opgave",
    "verdens",
    "professor",
    "onde",
    "hospitalet",
    "flytte",
    "bed",
    "tide",
    "red",
    "lægge",
    "snak",
    "beviser",
    "mister",
    "heldig",
    "sur",
    "sad",
    "stjal",
    "skibet",
    "trække",
    "all",
    "færdige",
    "forbandede",
    "skam",
    "kraft",
    "skud",
    "tidligt",
    "savner",
    "styrke",
    "egentlig",
    "danse",
    "pludselig",
    "wow",
    "fjols",
    "lege",
    "fremtiden",
    "tusind",
    "li",
    "klarede",
    "kaldte",
    "stol",
    "sã",
    "hær",
    "ren",
    "læst",
    "drengen",
    "skaffe",
    "hel",
    "form",
    "mål",
    "nyheder",
    "ramt",
    "lejlighed",
    "kræver",
    "sko",
    "skønt",
    "respekt",
    "nemt",
    "både",
    "sov",
    "ejer",
    "værste",
    "tegn",
    "kontrol",
    "gaden",
    "overalt",
    "lærte",
    "mon",
    "ganske",
    "spørg",
    "himlen",
    "viste",
    "ønskede",
    "skrid",
    "sværger",
    "sjæl",
    "fin",
    "fucking",
    "høj",
    "stoler",
    "plejede",
    "spillet",
    "skæbne",
    "mary",
    "forelsket",
    "lav",
    "præsidenten",
    "brød",
    "ray",
    "kys",
    "km",
    "flyver",
    "følelser",
    "særlig",
    "fortsætte",
    "tony",
    "ødelagt",
    "hul",
    "fisk",
    "håb",
    "johnny",
    "arbejdede",
    "ét",
    "flyet",
    "løbet",
    "trækker",
    "ringet",
    "bringe",
    "skidt",
    "vor",
    "hånden",
    "begyndt",
    "frygt",
    "søger",
    "sten",
    "området",
    "meningen",
    "vend",
    "right",
    "alvorligt",
    "drømme",
    "frodo",
    "tjek",
    "måned",
    "røre",
    "evigt",
    "hvilke",
    "interesseret",
    "bekymre",
    "medmindre",
    "bobby",
    "mulighed",
    "ventet",
    "satte",
    "danny",
    "lovede",
    "jul",
    "adgang",
    "dernede",
    "la",
    "skål",
    "bond",
    "fornøjelse",
    "forsøgte",
    "hjerne",
    "ligge",
    "virkede",
    "vågn",
    "udmærket",
    "amerikanske",
    "pistolen",
    "lægger",
    "hård",
    "falde",
    "ens",
    "møder",
    "bringer",
    "ekstra",
    "pã",
    "røde",
    "ærlig",
    "usa",
    "såret",
    "tjener",
    "pokker",
    "retten",
    "derfra",
    "personligt",
    "henry",
    "endda",
    "sælge",
    "is",
    "forlader",
    "stakkels",
    "sødt",
    "dens",
    "minder",
    "dejlig",
    "kongen",
    "forlod",
    "ringen",
    "smart",
    "hest",
    "enten",
    "tanker",
    "lngen",
    "dybt",
    "fod",
    "nervøs",
    "farligt",
    "lukke",
    "tænder",
    "hov",
    "jake",
    "hurtig",
    "hop",
    "sarah",
    "føre",
    "deroppe",
    "drikker",
    "bære",
    "vandt",
    "tabt",
    "richard",
    "klaret",
    "lå",
    "billy",
    "lagde",
    "hjalp",
    "fanger",
    "nødvendigt",
    "enig",
    "start",
    "mark",
    "dumt",
    "amerika",
    "køber",
    "kald",
    "san",
    "søvn",
    "navnet",
    "bogen",
    "fortjener",
    "mindst",
    "morder",
    "bagefter",
    "hvid",
    "område",
    "tilfælde",
    "vælge",
    "læser",
    "rejs",
    "hverken",
    "eddie",
    "london",
    "dave",
    "barnet",
    "båd",
    "sindssyg",
    "minut",
    "festen",
    "engelsk",
    "sælger",
    "frokost",
    "love",
    "varmt",
    "styr",
    "glæde",
    "soldater",
    "gulvet",
    "te",
    "forskellige",
    "ryggen",
    "ikk",
    "planen",
    "ordner",
    "lytter",
    "stemmer",
    "derhen",
    "and",
    "jim",
    "overleve",
    "stjålet",
    "fuldstændig",
    "will",
    "fyldt",
    "forsvandt",
    "besøg",
    "hotel",
    "stjæle",
    "luft",
    "fed",
    "åbner",
    "fremtid",
    "derind",
    "brænder",
    "takke",
    "kæmper",
    "vagt",
    "henne",
    "højere",
    "planer",
    "fatter",
    "gruppe",
    "solen",
    "bar",
    "vilje",
    "kate",
    "chris",
    "fyret",
    "dengang",
    "smutte",
    "lagt",
    "ventede",
    "bevise",
    "ovre",
    "glemmer",
    "fortsætter",
    "washington",
    "bortset",
    "korrekt",
    "derefter",
    "gal",
    "nærheden",
    "fandeme",
    "situation",
    "forsøg",
    "lukker",
    "sergent",
    "chancen",
    "smerte",
    "bygningen",
    "valgte",
    "lækker",
    "mors",
    "fede",
    "overstået",
    "blandt",
    "klog",
    "glas",
    "tilladelse",
    "købte",
    "fjern",
    "floden",
    "regler",
    "styre",
    "smutter",
    "rummet",
    "nick",
    "politi",
    "forventer",
    "bestemmer",
    "absolut",
    "drejer",
    "overfor",
    "sluk",
    "dollar",
    "myrdet",
    "selvmord",
    "lykkelig",
    "jord",
    "brev",
    "betalt",
    "modtaget",
    "dårlige",
    "bank",
    "jobbet",
    "varm",
    "ovenpå",
    "tit",
    "position",
    "kælling",
    "forestille",
    "kræfter",
    "stikker",
    "gravid",
    "hed",
    "ordrer",
    "skifter",
    "kød",
    "vigtig",
    "morges",
    "røg",
    "lyt",
    "stoffer",
    "million",
    "arm",
    "overraskelse",
    "fremad",
    "træ",
    "william",
    "beslutning",
    "ramte",
    "tjene",
    "nøglen",
    "mørke",
    "mission",
    "dommer",
    "skabe",
    "især",
    "maske",
    "uheld",
    "soldat",
    "allesammen",
    "giftes",
    "vinduet",
    "walter",
    "års",
    "åbenbart",
    "fa",
    "flytter",
    "herover",
    "slag",
    "målet",
    "hænger",
    "hjertet",
    "skatter",
    "broen",
    "halvt",
    "dæk",
    "klasse",
    "seriøst",
    "gratis",
    "selskab",
    "bryde",
    "arthur",
    "tvivl",
    "folkens",
    "navne",
    "knap",
    "tilhører",
    "frihed",
    "åbn",
    "hemmelighed",
    "fødselsdag",
    "sørg",
    "rige",
    "jones",
    "virkeligt",
    "munden",
    "guld",
    "gifte",
    "medicin",
    "øen",
    "løj",
    "ændret",
    "herind",
    "biler",
    "svaret",
    "ældre",
    "sengen",
    "grin",
    "kontoret",
    "rend",
    "undgå",
    "rører",
    "vegne",
    "efterlod",
    "havet",
    "bærer",
    "reglerne",
    "major",
    "rom",
    "svare",
    "rød",
    "optaget",
    "flygte",
    "bedt",
    "glæder",
    "spændende",
    "oplysninger",
    "ødelægger",
    "sværd",
    "virke",
    "kørt",
    "forsvinder",
    "herude",
    "forskel",
    "låne",
    "snakkede",
    "tabte",
    "særligt",
    "pik",
    "frisk",
    "fjerne",
    "totalt",
    "leo",
    "skridt",
    "godaften",
    "nærmere",
    "købt",
    "kop",
    "koster",
    "anna",
    "spillede",
    "stik",
    "langsomt",
    "hyggeligt",
    "regel",
    "halvdelen",
    "vælger",
    "robert",
    "specielt",
    "dan",
    "charles",
    "gemmer",
    "koldt",
    "følte",
    "luder",
    "rod",
    "beholde",
    "startede",
    "ofte",
    "ferie",
    "drik",
    "loven",
    "sejt",
    "savnet",
    "mærkeligt",
    "dét",
    "angrebet",
    "sager",
    "dygtig",
    "låst",
    "bøger",
    "pigerne",
    "systemet",
    "forsvundet",
    "ansvar",
    "morsomt",
    "skabt",
    "pakke",
    "bordet",
    "varme",
    "smide",
    "lugter",
    "brødre",
    "street",
    "lyve",
    "nr",
    "toilettet",
    "stikke",
    "træner",
    "date",
    "alder",
    "vaere",
    "fængslet",
    "cia",
    "båden",
    "big",
    "synge",
    "stak",
    "plejer",
    "stands",
    "toget",
    "nærmer",
    "larry",
    "kors",
    "kilometer",
    "lytte",
    "forbindelse",
    "smil",
    "led",
    "trænger",
    "pokkers",
    "los",
    "england",
    "styrer",
    "of",
    "eksempel",
    "tommy",
    "høje",
    "gælder",
    "van",
    "imellem",
    "stiller",
    "skoven",
    "nord",
    "vidne",
    "claire",
    "herren",
    "ond",
    "læste",
    "glade",
    "liste",
    "thomas",
    "smed",
    "partner",
    "sørge",
    "trods",
    "hævn",
    "pause",
    "majestæt",
    "hæren",
    "hmm",
    "valgt",
    "gemme",
    "vilde",
    "herovre",
    "show",
    "vin",
    "dobbelt",
    "skriv",
    "computer",
    "go",
    "lee",
    "ofre",
    "desuden",
    "gangen",
    "glip",
    "morgenmad",
    "hundrede",
    "mødtes",
    "tider",
    "forretning",
    "bånd",
    "forpulede",
    "martin",
    "kiggede",
    "bevæger",
    "jane",
    "bombe",
    "besøge",
    "ifølge",
    "række",
    "nåde",
    "ballade",
    "lægen",
    "overlever",
    "svarer",
    "rene",
    "magi",
    "regne",
    "herhen",
    "utrolig",
    "vrede",
    "av",
    "toppen",
    "joey",
    "nul",
    "fungerer",
    "billedet",
    "fødder",
    "mareridt",
    "idag",
    "bort",
    "filmen",
    "træd",
    "type",
    "super",
    "rapport",
    "tidlig",
    "fjenden",
    "vidst",
    "farlig",
    "spist",
    "banken",
    "tøs",
    "vundet",
    "tosset",
    "davs",
    "smut",
    "grunden",
    "holdet",
    "regner",
    "mands",
    "heldige",
    "reddet",
    "bud",
    "hvile",
    "syd",
    "hunde",
    "klap",
    "forbandet",
    "halsen",
    "ordentligt",
    "hernede",
    "rig",
    "ulykke",
    "andy",
    "planet",
    "city",
    "rachel",
    "fjender",
    "muligvis",
    "doc",
    "tiders",
    "lord",
    "forsvinde",
    "samlet",
    "program",
    "efterlade",
    "tjekke",
    "ik",
    "visse",
    "maria",
    "opmærksomhed",
    "spis",
    "kjole",
    "vidt",
    "dans",
    "maden",
    "æg",
    "steve",
    "læs",
    "ed",
    "bolden",
    "kvinden",
    "ar",
    "tryk",
    "lokale",
    "jah",
    "fortræd",
    "bevis",
    "lyd",
    "bygge",
    "tilgiv",
    "regeringen",
    "bussen",
    "boede",
    "løfte",
    "bryllup",
    "anholdt",
    "check",
    "brian",
    "taske",
    "præsentere",
    "tabe",
    "senator",
    "kysse",
    "ordet",
    "nåede",
    "dronning",
    "sprog",
    "brænde",
    "energi",
    "tante",
    "pete",
    "jerry",
    "tæller",
    "perfekte",
    "aftenen",
    "signal",
    "fremmede",
    "bedstemor",
    "fætter",
    "lucy",
    "hat",
    "bedstefar",
    "forsøge",
    "flok",
    "nået",
    "bygget",
    "fulde",
    "kaptajnen",
    "støtte",
    "mexico",
    "situationen",
    "hotellet",
    "samtale",
    "kurs",
    "liget",
    "lange",
    "kode",
    "hvabehar",
    "smith",
    "derhjemme",
    "ansigtet",
    "fælde",
    "ændrer",
    "skilt",
    "lugte",
    "evner",
    "fulgte",
    "procent",
    "sand",
    "fjende",
    "lækkert",
    "opkald",
    "hellige",
    "kevin",
    "system",
    "drengene",
    "ægteskab",
    "bukserne",
    "dukker",
    "uskyldig",
    "ødelagde",
    "grader",
    "vigtigste",
    "banen",
    "stjerne",
    "lande",
    "chefen",
    "broder",
    "glædelig",
    "slappe",
    "fis",
    "gøres",
    "løse",
    "undersøge",
    "ledte",
    "smider",
    "kortet",
    "vegas",
    "planlagt",
    "point",
    "fredag",
    "næppe",
    "forfærdeligt",
    "retning",
    "tanke",
    "bagved",
    "viiie",
    "firma",
    "samle",
    "gas",
    "operation",
    "historier",
    "knæ",
    "hejsa",
    "prinsesse",
    "rammer",
    "skaber",
    "frygter",
    "danser",
    "blomster",
    "stærke",
    "håbede",
    "minde",
    "kaldes",
    "leger",
    "ga",
    "kat",
    "skøre",
    "ugen",
    "ombord",
    "tilbud",
    "ramme",
    "tættere",
    "bragt",
    "carter",
    "kaste",
    "kirken",
    "phoebe",
    "stoppede",
    "dække",
    "kamera",
    "vidunderligt",
    "sind",
    "blind",
    "deler",
    "forladt",
    "gæster",
    "sal",
    "drop",
    "skyldig",
    "bekymrer",
    "offer",
    "kong",
    "faldet",
    "louis",
    "gæt",
    "behold",
    "synd",
    "dna",
    "unger",
    "radio",
    "kylling",
    "muligheder",
    "nægter",
    "enden",
    "betjente",
    "kugle",
    "afdeling",
    "stranden",
    "skifte",
    "ryan",
    "abe",
    "afstand",
    "mistænkte",
    "sinde",
    "lørdag",
    "spørgsmålet",
    "don",
    "vågen",
    "angående",
    "kast",
    "karriere",
    "marty",
    "hænge",
    "gemt",
    "stærkt",
    "slem",
    "stinker",
    "smager",
    "ram",
    "fremragende",
    "fugl",
    "st",
    "bøsse",
    "virkeligheden",
    "data",
    "smag",
    "jason",
    "angeles",
    "besluttet",
    "kniv",
    "personer",
    "jep",
    "listen",
    "skære",
    "ryg",
    "folket",
    "cool",
    "mød",
    "sherif",
    "grænsen",
    "mørket",
    "drage",
    "bukser",
    "savne",
    "begyndelsen",
    "privat",
    "ur",
    "prisen",
    "pres",
    "simon",
    "flyttet",
    "roger",
    "ted",
    "betyde",
    "frankrig",
    "cirka",
    "beskytter",
    "daniel",
    "amerikansk",
    "gid",
    "mændene",
    "bytte",
    "trist",
    "stationen",
    "skjule",
    "chuck",
    "angriber",
    "gar",
    "uh",
    "næ",
    "vest",
    "fine",
    "falsk",
    "succes",
    "omgang",
    "eftermiddag",
    "heste",
    "nyder",
    "køkkenet",
    "eksisterer",
    "vågner",
    "flyttede",
    "prins",
    "sekund",
    "forslag",
    "størrelse",
    "bygning",
    "stærkere",
    "skylden",
    "ordnet",
    "kaldt",
    "undskyldning",
    "aiie",
    "derover",
    "information",
    "alan",
    "lisa",
    "smidt",
    "tillid",
    "lukkede",
    "papirer",
    "spiste",
    "bruges",
    "ryge",
    "rejste",
    "nedenunder",
    "matt",
    "imponerende",
    "varer",
    "voksen",
    "seneste",
    "græde",
    "barry",
    "fuldt",
    "leg",
    "tyve",
    "herned",
    "eric",
    "alarm",
    "syge",
    "morderen",
    "meste",
    "forstod",
    "skiderik",
    "alice",
    "forbudt",
    "nyde",
    "årevis",
    "sande",
    "you",
    "rar",
    "syn",
    "edward",
    "hjernen",
    "grace",
    "begynd",
    "snakket",
    "agenter",
    "foretrækker",
    "porten",
    "hud",
    "lyde",
    "rolle",
    "radioen",
    "boss",
    "king",
    "vædde",
    "opfører",
    "college",
    "blodet",
    "gudskelov",
    "adresse",
    "gentager",
    "veninde",
    "bid",
    "væggen",
    "tab",
    "tim",
    "scott",
    "ledt",
    "beskidte",
    "fløj",
    "sørger",
    "farten",
    "opdagede",
    "please",
    "adam",
    "næse",
    "forvirret",
    "troet",
    "hemmelige",
    "vendt",
    "jakke",
    "vanvittig",
    "overrasket",
    "tjekker",
    "kold",
    "kameraet",
    "griner",
    "bring",
    "øre",
    "vagter",
    "arme",
    "jøsses",
    "lufthavnen",
    "maskine",
    "mandag",
    "kaster",
    "enige",
    "grønne",
    "udstyr",
    "forsøgt",
    "regnede",
    "nyd",
    "sider",
    "inviteret",
    "foreslår",
    "bekendt",
    "vogn",
    "eventyr",
    "bruce",
    "gandalf",
    "samarbejde",
    "herregud",
    "panik",
    "yderst",
    "skynde",
    "kroppen",
    "kirke",
    "lignende",
    "drej",
    "firmaet",
    "bande",
    "bragte",
    "turen",
    "sej",
    "herop",
    "året",
    "oversat",
    "papir",
    "fejltagelse",
    "vare",
    "betalte",
    "personlige",
    "carl",
    "kvarter",
    "kilo",
    "temmelig",
    "californien",
    "igang",
    "fair",
    "fransk",
    "forklaring",
    "rock",
    "heroppe",
    "normal",
    "kelly",
    "dækker",
    "mørkt",
    "speciel",
    "sovet",
    "nøglerne",
    "vover",
    "hemmeligt",
    "fortjent",
    "lykkedes",
    "skaf",
    "test",
    "top",
    "plus",
    "vort",
    "advarsel",
    "stjæler",
    "båndet",
    "efterlader",
    "redder",
    "sara",
    "håbe",
    "tunge",
    "knægten",
    "vigtige",
    "standse",
    "victor",
    "lød",
    "tvivler",
    "morgenen",
    "øst",
    "acceptere",
    "tanken",
    "solgt",
    "derop",
    "amy",
    "hjørnet",
    "gor",
    "tilstand",
    "skræmmer",
    "hustru",
    "undtagen",
    "in",
    "hunden",
    "forretninger",
    "glimrende",
    "kugler",
    "frit",
    "samler",
    "tilfreds",
    "spurgt",
    "bomben",
    "behøvede",
    "levede",
    "kæmpede",
    "gammelt",
    "livs",
    "sporet",
    "skader",
    "forsvare",
    "marcus",
    "iige",
    "gem",
    "ta",
    "trussel",
    "benene",
    "opdaget",
    "overlevede",
    "starten",
    "ca",
    "skræmmende",
    "rask",
    "spøg",
    "solgte",
    "kim",
    "flaske",
    "service",
    "rose",
    "bravo",
    "farve",
    "ron",
    "gi",
    "fortiden",
    "trak",
    "idioter",
    "almindelig",
    "scenen",
    "roy",
    "derned",
    "underlig",
    "banker",
    "kage",
    "park",
    "vold",
    "synger",
    "tydeligt",
    "whoa",
    "fingre",
    "cole",
    "bane",
    "grav",
    "fremme",
    "takket",
    "højhed",
    "træning",
    "team",
    "europa",
    "virkelige",
    "fingeraftryk",
    "hitler",
    "myrdede",
    "assistent",
    "amen",
    "lewis",
    "springer",
    "monster",
    "kneppe",
    "hårde",
    "endte",
    "involveret",
    "angribe",
    "jackson",
    "anelse",
    "sejr",
    "russerne",
    "chicago",
    "lift",
    "ånd",
    "vendte",
    "slemme",
    "gæst",
    "bjergene",
    "star",
    "gad",
    "præcist",
    "ku",
    "lås",
    "nøgle",
    "begravet",
    "lettere",
    "skabte",
    "latterligt",
    "sprang",
    "forsvar",
    "diskutere",
    "hils",
    "månen",
    "sexet",
    "regering",
    "pligt",
    "etage",
    "handel",
    "weekend",
    "post",
    "connor",
    "dækket",
    "herligt",
    "regnet",
    "gætte",
    "takker",
    "dom",
    "brudt",
    "formoder",
    "heks",
    "elizabeth",
    "howard",
    "løgner",
    "kopi",
    "grim",
    "sydney",
    "næsen",
    "piper",
    "miles",
    "præst",
    "susan",
    "dukke",
    "engel",
    "fantastiske",
    "piller",
    "berlin",
    "lady",
    "hoppe",
    "projekt",
    "bekræftet",
    "afslutte",
    "vinden",
    "fremmed",
    "geni",
    "hopper",
    "avisen",
    "uskadt",
    "dukkede",
    "myrde",
    "kyle",
    "besluttede",
    "skæbnen",
    "medlem",
    "halløj",
    "røvhuller",
    "aftalen",
    "borte",
    "dets",
    "fælles",
    "svømme",
    "spring",
    "folks",
    "sygdom",
    "søndag",
    "modig",
    "nævnte",
    "jagt",
    "tyler",
    "hemmeligheder",
    "dertil",
    "ansvarlig",
    "gãr",
    "fortid",
    "gæld",
    "viden",
    "svag",
    "lovet",
    "dagens",
    "græder",
    "baren",
    "krav",
    "johnson",
    "enhed",
    "emily",
    "kunst",
    "fjerde",
    "frk",
    "jenny",
    "high",
    "shit",
    "pr",
    "elsket",
    "drømmer",
    "phil",
    "moder",
    "helikopter",
    "ensom",
    "sandhed",
    "beholder",
    "nøgen",
    "mordet",
    "førte",
    "opdager",
    "derud",
    "maggie",
    "forklarer",
    "handle",
    "biiver",
    "tændt",
    "klient",
    "vognen",
    "slutte",
    "hollywood",
    "tilgive",
    "el",
    "bunden",
    "siges",
    "chokolade",
    "mave",
    "maven",
    "pund",
    "via",
    "vidner",
    "vidunderlig",
    "løsning",
    "dick",
    "rejst",
    "indrømme",
    "officer",
    "køb",
    "dømt",
    "pæn",
    "ross",
    "sadan",
    "voksede",
    "frygtelig",
    "fang",
    "tøjet",
    "dæmon",
    "guder",
    "afgang",
    "løn",
    "uskyldige",
    "indeni",
    "svær",
    "byde",
    "ogsa",
    "årig",
    "mødet",
    "slutter",
    "forhindre",
    "stan",
    "brand",
    "grunde",
    "hjæip",
    "strømmen",
    "køn",
    "spilde",
    "formål",
    "stadigvæk",
    "hjæipe",
    "interesse",
    "behov",
    "musikken",
    "pressen",
    "imens",
    "politik",
    "begik",
    "jaså",
    "sikken",
    "følelse",
    "kassen",
    "texas",
    "skærer",
    "fan",
    "parker",
    "stoppet",
    "springe",
    "skræmme",
    "mirakel",
    "nyhederne",
    "skaffer",
    "hensyn",
    "indre",
    "spilder",
    "terry",
    "sårede",
    "fordel",
    "forfærdelig",
    "rykker",
    "eiier",
    "kommandør",
    "ønsket",
    "mobil",
    "sår",
    "fangede",
    "talent",
    "skjult",
    "forresten",
    "overlevende",
    "modtager",
    "sommer",
    "højeste",
    "skørt",
    "straf",
    "nyhed",
    "hvorhen",
    "monsieur",
    "mælk",
    "skibe",
    "wayne",
    "jeff",
    "falske",
    "harold",
    "banke",
    "flotte",
    "forsinket",
    "kontakte",
    "øjet",
    "hospital",
    "teori",
    "vokser",
    "laura",
    "black",
    "ligefrem",
    "måder",
    "træffe",
    "duer",
    "abby",
    "kærligheden",
    "sært",
    "bryster",
    "brændte",
    "ligne",
    "amerikanere",
    "tekster",
    "guderne",
    "champagne",
    "programmet",
    "yo",
    "besat",
    "tyv",
    "erfaring",
    "overveje",
    "brændt",
    "niveau",
    "tirsdag",
    "alvorlig",
    "urolig",
    "slukke",
    "græd",
    "familier",
    "teknisk",
    "dronningen",
    "midten",
    "rager",
    "driver",
    "joke",
    "milde",
    "mennesket",
    "drak",
    "vagterne",
    "fejre",
    "pizza",
    "smage",
    "frygteligt",
    "dækning",
    "sludder",
    "staten",
    "potter",
    "fryser",
    "risiko",
    "knust",
    "kilde",
    "ladet",
    "anede",
    "rede",
    "whisky",
    "nøgler",
    "julie",
    "slik",
    "station",
    "døende",
    "ride",
    "butikken",
    "tvunget",
    "lincoln",
    "inspektør",
    "hemmelig",
    "lykkes",
    "publikum",
    "finger",
    "vanvid",
    "byggede",
    "flink",
    "tilbyde",
    "russiske",
    "blik",
    "billetter",
    "forstyrrer",
    "beskyttelse",
    "skønne",
    "kraften",
    "koden",
    "harvey",
    "universitetet",
    "værelset",
    "ryk",
    "kælderen",
    "ført",
    "skøn",
    "nosser",
    "kolde",
    "spion",
    "fantasi",
    "forbrydelse",
    "midnat",
    "søen",
    "begå",
    "vant",
    "byens",
    "passende",
    "torsdag",
    "betød",
    "brud",
    "udvej",
    "tænd",
    "uret",
    "stilling",
    "mærker",
    "udføre",
    "spore",
    "forleden",
    "drømte",
    "gaver",
    "ulovligt",
    "skræmte",
    "bus",
    "weekenden",
    "højst",
    "tillade",
    "skændes",
    "grave",
    "muren",
    "bundet",
    "olie",
    "hals",
    "scene",
    "bygger",
    "on",
    "hilse",
    "ondskab",
    "bevæge",
    "konstant",
    "jean",
    "ligeså",
    "punkt",
    "linje",
    "advare",
    "enheder",
    "kasse",
    "afsløre",
    "nærmest",
    "herud",
    "sammy",
    "skuespiller",
    "glor",
    "fjernet",
    "åbent",
    "begået",
    "biev",
    "fingrene",
    "hank",
    "vågne",
    "planeten",
    "ankommer",
    "tjekket",
    "berømt",
    "jomfru",
    "restaurant",
    "magten",
    "brown",
    "kontrollere",
    "angår",
    "flugt",
    "tyskland",
    "kina",
    "legetøj",
    "skuffet",
    "fodbold",
    "kilden",
    "id",
    "mm",
    "narre",
    "forfra",
    "mene",
    "skønhed",
    "annie",
    "stiger",
    "celle",
    "opgaven",
    "katie",
    "slutningen",
    "veje",
    "gordon",
    "simpelthen",
    "ører",
    "sally",
    "øjeblikket",
    "heldigvis",
    "pga",
    "betydning",
    "forestil",
    "franske",
    "simpelt",
    "billederne",
    "amerikaner",
    "tydeligvis",
    "luke",
    "pisse",
    "rådet",
    "stået",
    "sikkerheds",
    "humør",
    "lider",
    "professionel",
    "missionen",
    "frankie",
    "miami",
    "maskinen",
    "miller",
    "ligegyldigt",
    "bauer",
    "berømte",
    "tyske",
    "morgan",
    "breve",
    "briller",
    "åbnede",
    "ansatte",
    "opførsel",
    "indblandet",
    "showet",
    "taylor",
    "derek",
    "invitere",
    "udenom",
    "grad",
    "lejligheden",
    "spild",
    "forandret",
    "greg",
    "jaloux",
    "video",
    "penny",
    "retfærdighed",
    "ilden",
    "signalet",
    "sandelig",
    "aflevere",
    "sjove",
    "helte",
    "boston",
    "patient",
    "jesse",
    "brækket",
    "erne",
    "benzin",
    "gemte",
    "tingest",
    "model",
    "jackie",
    "søstre",
    "kriger",
    "smadre",
    "marshall",
    "west",
    "kontrakt",
    "strålende",
    "imorgen",
    "ændrede",
    "angela",
    "håbet",
    "status",
    "vãre",
    "race",
    "regn",
    "tilbyder",
    "melder",
    "kontakter",
    "journalist",
    "vrøvl",
    "færdigt",
    "menneskelige",
    "taxi",
    "skift",
    "træne",
    "kunnet",
    "typisk",
    "jage",
    "smadrer",
    "eks",
    "oven",
    "karl",
    "skygge",
    "bløder",
    "brylluppet",
    "fornemmelse",
    "my",
    "normale",
    "søge",
    "amok",
    "undskylder",
    "bang",
    "politimand",
    "klogt",
    "patrick",
    "flåden",
    "iidt",
    "eftersom",
    "århundrede",
    "grøn",
    "linda",
    "efterladt",
    "nigger",
    "robot",
    "gengæld",
    "ost",
    "drive",
    "vaske",
    "kommissær",
    "arresteret",
    "nummeret",
    "vågnede",
    "damen",
    "levet",
    "udover",
    "ansat",
    "pilot",
    "sprænge",
    "april",
    "forskellen",
    "konen",
    "dyb",
    "trænet",
    "tiibage",
    "junior",
    "skar",
    "trick",
    "sean",
    "ejendom",
    "håret",
    "harjeg",
    "basen",
    "romantisk",
    "timen",
    "sorg",
    "storm",
    "forsigtigt",
    "sandy",
    "rider",
    "boksen",
    "vampyr",
    "træer",
    "ræk",
    "grine",
    "subtitle",
    "elever",
    "farlige",
    "tank",
    "teknologi",
    "tusinde",
    "behandling",
    "vindue",
    "bold",
    "sænk",
    "væsen",
    "velsigne",
    "sukker",
    "lou",
    "lortet",
    "forberedt",
    "lær",
    "stolte",
    "villig",
    "skær",
    "las",
    "fandme",
    "årh",
    "behandler",
    "frie",
    "forlad",
    "garanteret",
    "lejr",
    "chancer",
    "røveri",
    "wilson",
    "emma",
    "farmand",
    "hullet",
    "forstyrre",
    "natur",
    "føreren",
    "huh",
    "forbundet",
    "paige",
    "forlovede",
    "vanvittigt",
    "spark",
    "begravelse",
    "jordens",
    "æren",
    "kunder",
    "le",
    "detaljer",
    "angel",
    "rotte",
    "fejler",
    "drukket",
    "bestemme",
    "undskyldt",
    "tomme",
    "white",
    "grimme",
    "lander",
    "nylig",
    "seiv",
    "billet",
    "ansvaret",
    "kaos",
    "gale",
    "jakkesæt",
    "baseret",
    "tropper",
    "more",
    "tillader",
    "vincent",
    "trukket",
    "sandsynligvis",
    "taxa",
    "skub",
    "beskidt",
    "armen",
    "private",
    "befinder",
    "fungere",
    "vampyrer",
    "afdelingen",
    "nettet",
    "francisco",
    "lignede",
    "sejle",
    "spøgelse",
    "rob",
    "femte",
    "træder",
    "dørene",
    "hadede",
    "ambulance",
    "pointen",
    "boet",
    "vind",
    "strøm",
    "gore",
    "dav",
    "beskeden",
    "indsats",
    "erjeg",
    "stanley",
    "tilsyneladende",
    "charmerende",
    "fysisk",
    "ait",
    "sønnike",
    "træde",
    "lette",
    "træet",
    "art",
    "laboratoriet",
    "inviterede",
    "sejler",
    "våbnet",
    "smadret",
    "numre",
    "babyen",
    "fjerner",
    "nakken",
    "hukommelse",
    "had",
    "nemmere",
    "untranslated",
    "kommandoen",
    "so",
    "blade",
    "råbe",
    "russisk",
    "anklager",
    "elevatoren",
    "generer",
    "skuiie",
    "verdenen",
    "times",
    "turner",
    "folkene",
    "indse",
    "merlin",
    "overvejer",
    "kinesisk",
    "kompliceret",
    "afhænger",
    "formue",
    "drømt",
    "begår",
    "ukendt",
    "computeren",
    "jedi",
    "neo",
    "bevare",
    "byder",
    "åbnet",
    "strisser",
    "tasken",
    "vigtigere",
    "menneskeheden",
    "døre",
    "kejseren",
    "uniform",
    "dejlige",
    "one",
    "skab",
    "stig",
    "clark",
    "rettigheder",
    "skjuler",
    "hvorfra",
    "moderne",
    "lækre",
    "nysgerrig",
    "sædvanlige",
    "bønner",
    "gætter",
    "charlotte",
    "officielt",
    "universet",
    "langs",
    "shh",
    "betty",
    "middagen",
    "affære",
    "sindssyge",
    "doug",
    "genkender",
    "ørkenen",
    "borgmester",
    "indså",
    "saml",
    "up",
    "rødt",
    "helen",
    "undersøger",
    "sønner",
    "ekspert",
    "kaldet",
    "skrider",
    "fugle",
    "derhenne",
    "total",
    "butik",
    "trappen",
    "fulgt",
    "rimelig",
    "rørte",
    "skatten",
    "hæng",
    "voksne",
    "salt",
    "lyden",
    "tvang",
    "kastede",
    "stukket",
    "sommetider",
    "mordere",
    "kedeligt",
    "helvedes",
    "nærmeste",
    "æde",
    "aidrig",
    "bevæbnet",
    "mã",
    "rick",
    "ungerne",
    "samtidig",
    "ridder",
    "cody",
    "ankom",
    "vokse",
    "slange",
    "brækkede",
    "svære",
    "collins",
    "giftede",
    "grib",
    "milliarder",
    "droppe",
    "river",
    "hade",
    "vietnam",
    "andrew",
    "kontrollen",
    "smerten",
    "kanon",
    "sagtens",
    "dæmoner",
    "overtage",
    "undersøgt",
    "sigte",
    "alvor",
    "knuse",
    "genkende",
    "wade",
    "dommeren",
    "sku",
    "flyvende",
    "tolv",
    "hit",
    "afgjort",
    "klædt",
    "trin",
    "evighed",
    "vælg",
    "klæder",
    "nancy",
    "ordentlig",
    "brad",
    "fjolser",
    "lykkelige",
    "be",
    "grønt",
    "anakin",
    "omstændigheder",
    "gyldne",
    "kollega",
    "grant",
    "venskab",
    "ansigter",
    "katastrofe",
    "opføre",
    "kampe",
    "løgne",
    "risikere",
    "rende",
    "oversættelse",
    "afrika",
    "todd",
    "halve",
    "deltage",
    "gifter",
    "benet",
    "evne",
    "måden",
    "kraftedeme",
    "eva",
    "rusland",
    "lillebror",
    "bryst",
    "ho",
    "drager",
    "flygter",
    "læger",
    "støtter",
    "nåh",
    "profil",
    "rørt",
    "siddet",
    "sikret",
    "virus",
    "dansk",
    "tisse",
    "svinet",
    "nævne",
    "jersey",
    "fu",
    "yderligere",
    "kvinderne",
    "løst",
    "ideer",
    "uhyre",
    "stolthed",
    "vække",
    "sving",
    "samling",
    "opnå",
    "imponeret",
    "josh",
    "godkendt",
    "bevægelse",
    "fjernsynet",
    "detektiv",
    "bekæmpe",
    "røvfuld",
    "løft",
    "jager",
    "svarede",
    "ammunition",
    "højde",
    "green",
    "rydde",
    "artikel",
    "såre",
    "cowboy",
    "ankommet",
    "mia",
    "tilbringe",
    "trykke",
    "koste",
    "snyde",
    "favorit",
    "håndtere",
    "desperat",
    "direktør",
    "indeholder",
    "forventede",
    "stede",
    "rygter",
    "julemanden",
    "fisse",
    "hoid",
    "skabet",
    "informationer",
    "magiske",
    "spændt",
    "kung",
    "forskning",
    "rækker",
    "taknemmelig",
    "kunde",
    "megen",
    "æder",
    "teddy",
    "kanal",
    "pinligt",
    "ms",
    "tilgiver",
    "heldigt",
    "blande",
    "startet",
    "sjæle",
    "hesten",
    "knibe",
    "kyssede",
    "varmen",
    "handlede",
    "karen",
    "nøjagtig",
    "sans",
    "bider",
    "mistænkt",
    "benjamin",
    "jill",
    "mac",
    "fbl",
    "kontanter",
    "medlemmer",
    "skjorte",
    "forfatter",
    "bomber",
    "kæmpet",
    "senatet",
    "tysk",
    "klubben",
    "monica",
    "hoveder",
    "yngre",
    "kriminelle",
    "slaver",
    "flygtede",
    "melde",
    "fortabt",
    "stammer",
    "isen",
    "selve",
    "spar",
    "befri",
    "dyrt",
    "kriminalbetjent",
    "freddy",
    "svage",
    "fortryde",
    "elev",
    "menneskelig",
    "stark",
    "stjerner",
    "modstand",
    "hjælpen",
    "svaghed",
    "civile",
    "forhandle",
    "reb",
    "bjerget",
    "årsag",
    "handlinger",
    "hermed",
    "me",
    "jennifer",
    "modtage",
    "beskeder",
    "tyskerne",
    "storartet",
    "troldmand",
    "gu",
    "anderson",
    "undersøgelse",
    "hjulpet",
    "identitet",
    "uddannelse",
    "mulige",
    "caroline",
    "pistoler",
    "skinner",
    "gade",
    "stige",
    "faktum",
    "parken",
    "repræsenterer",
    "island",
    "bro",
    "advokater",
    "ian",
    "barbara",
    "kommando",
    "tip",
    "jeps",
    "helikopteren",
    "daggry",
    "truer",
    "militæret",
    "florida",
    "badeværelset",
    "school",
    "konto",
    "sne",
    "klub",
    "stodder",
    "usædvanligt",
    "rodet",
    "skåret",
    "handling",
    "naturen",
    "faret",
    "boy",
    "åhh",
    "vejr",
    "presse",
    "sluppet",
    "sport",
    "ulækkert",
    "kujon",
    "byer",
    "villet",
    "dyrebare",
    "prue",
    "moskva",
    "diamanter",
    "påstår",
    "runde",
    "pak",
    "trykker",
    "sol",
    "behandle",
    "homer",
    "våbnene",
    "personlig",
    "pjat",
    "huse",
    "pyt",
    "narrøv",
    "sådanne",
    "forræder",
    "tøser",
    "ford",
    "per",
    "modsatte",
    "logan",
    "brevet",
    "udtryk",
    "aaron",
    "fornuft",
    "landsby",
    "narko",
    "sindssygt",
    "behandlet",
    "band",
    "niks",
    "accepterer",
    "fremskridt",
    "passede",
    "planlægger",
    "dean",
    "krone",
    "chauffør",
    "presset",
    "onsdag",
    "master",
    "no",
    "andres",
    "øverste",
    "hvidt",
    "nødig",
    "smukkeste",
    "nævnt",
    "opdage",
    "ko",
    "raymond",
    "forblive",
    "reaktion",
    "knepper",
    "jacob",
    "forbliver",
    "dømme",
    "tvinge",
    "pakket",
    "udvalgte",
    "værk",
    "tiger",
    "kæmp",
    "stof",
    "sjældent",
    "besøger",
    "fester",
    "rocky",
    "kysten",
    "konkurrence",
    "samlede",
    "røret",
    "virginia",
    "tracy",
    "tørre",
    "overbevist",
    "cigaret",
    "synder",
    "bjørn",
    "jessica",
    "lejren",
    "overfladen",
    "tælle",
    "afsluttet",
    "junglen",
    "beth",
    "marie",
    "hentede",
    "bli'r",
    "atjeg",
    "earl",
    "værdsætter",
    "bind",
    "kræft",
    "afgøre",
    "savnede",
    "chok",
    "diego",
    "råber",
    "biblioteket",
    "pladser",
    "nytter",
    "føde",
    "bestilt",
    "samfund",
    "avis",
    "bemærket",
    "cigaretter",
    "rigeligt",
    "fødselsdagen",
    "juni",
    "base",
    "øve",
    "skriger",
    "tusindvis",
    "lavt",
    "buddy",
    "ydre",
    "anne",
    "grand",
    "port",
    "gevær",
    "bløde",
    "samt",
    "bagud",
    "operationen",
    "udseende",
    "kuglen",
    "sygeplejerske",
    "skadet",
    "forventet",
    "kloge",
    "jay",
    "skyldes",
    "nuværende",
    "rapporter",
    "kristus",
    "slave",
    "patienter",
    "nakke",
    "blinde",
    "osse",
    "boller",
    "skubbe",
    "stjernerne",
    "carol",
    "engelske",
    "irriterende",
    "emne",
    "willy",
    "fylde",
    "deling",
    "fjollet",
    "forhåbentlig",
    "udsat",
    "eksamen",
    "maskiner",
    "blød",
    "bestille",
    "sæk",
    "it",
    "albert",
    "hårdere",
    "afbryde",
    "mikey",
    "menneskene",
    "motoren",
    "von",
    "pointe",
    "score",
    "indtryk",
    "politisk",
    "komplet",
    "våd",
    "bella",
    "putte",
    "mode",
    "sloane",
    "hjerter",
    "amanda",
    "gris",
    "nabo",
    "tæppe",
    "nicholas",
    "september",
    "virkelighed",
    "beundrer",
    "drinks",
    "bolle",
    "pä",
    "cooper",
    "houston",
    "katherine",
    "fort",
    "utro",
    "spejlet",
    "overtager",
    "regning",
    "generalen",
    "beskyttet",
    "heie",
    "amerikanerne",
    "ethvert",
    "loftet",
    "følgende",
    "forbandelse",
    "søgte",
    "klippe",
    "metal",
    "pakker",
    "smiler",
    "gruppen",
    "sparke",
    "olivia",
    "myndighederne",
    "forrest",
    "udstyret",
    "samvittighed",
    "brænd",
    "vægt",
    "kr",
    "hughes",
    "tjekkede",
    "andel",
    "julen",
    "tjente",
    "tomt",
    "ånder",
    "ann",
    "forvente",
    "opgive",
    "meldte",
    "skjulte",
    "løfter",
    "skrivebord",
    "styrker",
    "hot",
    "slaget",
    "snød",
    "enestående",
    "lån",
    "lastbil",
    "bridget",
    "chloe",
    "siddende",
    "skræmt",
    "hule",
    "kok",
    "elena",
    "gary",
    "reed",
    "vinger",
    "ligeglade",
    "gibbs",
    "skiftet",
    "tjent",
    "gates",
    "rasende",
    "militær",
    "grænser",
    "dale",
    "august",
    "rotter",
    "desto",
    "gaderne",
    "forvejen",
    "brystet",
    "japan",
    "oplevelse",
    "linie",
    "undrer",
    "fødderne",
    "advarede",
    "omvendt",
    "pose",
    "cm",
    "sä",
    "kysser",
    "frivilligt",
    "mulig",
    "minister",
    "gule",
    "duke",
    "dages",
    "kastet",
    "friske",
    "mars",
    "rapporten",
    "kur",
    "binde",
    "elendig",
    "psykopat",
    "afsløret",
    "nordpå",
    "fjernsyn",
    "nytte",
    "knogler",
    "oplevet",
    "bla",
    "sektor",
    "tynd",
    "tung",
    "sværere",
    "robin",
    "kostede",
    "sofaen",
    "mil",
    "shrek",
    "borgmesteren",
    "studerende",
    "austin",
    "almindelige",
    "katten",
    "sygt",
    "evig",
    "kærester",
    "boks",
    "salg",
    "manglede",
    "kilder",
    "kirk",
    "vinderen",
    "bund",
    "opleve",
    "surt",
    "oktober",
    "gården",
    "støvler",
    "foretage",
    "værdi",
    "sophie",
    "ken",
    "sværdet",
    "blæser",
    "alarmen",
    "skuffe",
    "ronnie",
    "sandwich",
    "tina",
    "je",
    "jøde",
    "stillet",
    "williams",
    "røget",
    "rykke",
    "menneskets",
    "fræk",
    "forberede",
    "tilbød",
    "lugt",
    "sky",
    "overbevise",
    "greb",
    "rådne",
    "udført",
    "hviler",
    "specielle",
    "baseball",
    "fakta",
    "prøven",
    "cykel",
    "ærgerligt",
    "mægtige",
    "tænde",
    "beviserne",
    "seje",
    "systemer",
    "jin",
    "korporal",
    "kg",
    "øvelse",
    "ethan",
    "dennis",
    "national",
    "drab",
    "søg",
    "fattige",
    "træerne",
    "ryster",
    "kørekort",
    "ordren",
    "respekterer",
    "maj",
    "kinesiske",
    "lenny",
    "videnskab",
    "afbrudt",
    "kongens",
    "golf",
    "rense",
    "matthew",
    "murphy",
    "cæsar",
    "air",
    "juli",
    "donna",
    "smadrede",
    "skrige",
    "bidt",
    "huller",
    "bakke",
    "loyalitet",
    "håndjern",
    "midler",
    "admiral",
    "fortsat",
    "klogere",
    "harris",
    "ældste",
    "professionelle",
    "skærmen",
    "kommende",
    "francis",
    "jag",
    "robinson",
    "vagten",
    "himmel",
    "karakter",
    "adressen",
    "formand",
    "ellie",
    "omringet",
    "forsvarer",
    "na",
    "omme",
    "pearl",
    "carrie",
    "tålmodighed",
    "besætningen",
    "leje",
    "kidnappet",
    "gymnasiet",
    "tilladt",
    "besøgte",
    "zone",
    "mystisk",
    "djævel",
    "lake",
    "løsladt",
    "læber",
    "mærkelig",
    "fox",
    "matrix",
    "forstanden",
    "identificere",
    "krigere",
    "risikerer",
    "hjørne",
    "smarte",
    "kameraer",
    "sekretær",
    "muligheden",
    "forlanger",
    "mus",
    "graven",
    "udkig",
    "kunstner",
    "andens",
    "carlos",
    "gina",
    "fyrene",
    "katte",
    "dallas",
    "snyder",
    "nevø",
    "tvinger",
    "landsbyen",
    "aktiveret",
    "hurtige",
    "opfør",
    "møgsvin",
    "samfundet",
    "offentligt",
    "dexter",
    "rygte",
    "mærkelige",
    "foreslå",
    "flag",
    "levere",
    "kniven",
    "michelle",
    "central",
    "lyttede",
    "harvard",
    "råbte",
    "dagbog",
    "magisk",
    "omgående",
    "orker",
    "føltes",
    "underlige",
    "hovedpine",
    "rive",
    "naturligt",
    "steg",
    "alexander",
    "forsiden",
    "anmoder",
    "sommeren",
    "templet",
    "sue",
    "skride",
    "fylder",
    "molly",
    "usa's",
    "interview",
    "offeret",
    "slottet",
    "forbryder",
    "forbindelsen",
    "gribe",
    "jonathan",
    "forræderi",
    "låse",
    "sultne",
    "hiv",
    "ricky",
    "kammerater",
    "sange",
    "mmm",
    "bingo",
    "ctu",
    "rulle",
    "ka",
    "frygte",
    "alverden",
    "fascinerende",
    "valget",
    "gã",
    "overvejet",
    "grå",
    "sure",
    "blue",
    "hjemmefra",
    "strømer",
    "pension",
    "indflydelse",
    "vokset",
    "dyre",
    "overraske",
    "sprænger",
    "flyv",
    "steven",
    "simpel",
    "nogie",
    "papirerne",
    "forenede",
    "kokain",
    "ruller",
    "fangerne",
    "affyret",
    "suppe",
    "skulder",
    "kedelig",
    "snarere",
    "www",
    "kanin",
    "irak",
    "heit",
    "lomme",
    "mordor",
    "resultatet",
    "vidunderlige",
    "udsigt",
    "trykket",
    "linjen",
    "forsæt",
    "trætte",
    "britiske",
    "beslutninger",
    "fatte",
    "studere",
    "hængt",
    "bland",
    "sigt",
    "genialt",
    "haven",
    "alles",
    "spansk",
    "døv",
    "livets",
    "besejre",
    "doktoren",
    "opfandt",
    "do",
    "blander",
    "spare",
    "aviserne",
    "bøde",
    "sebastian",
    "aragorn",
    "stående",
    "kennedy",
    "utrolige",
    "curtis",
    "danske",
    "modstå",
    "efterlad",
    "stormen",
    "tankerne",
    "gus",
    "th",
    "således",
    "cent",
    "fortryder",
    "grimt",
    "paradis",
    "spøgelser",
    "fase",
    "pung",
    "ballet",
    "nathan",
    "indrømmer",
    "sheriffen",
    "morer",
    "tværs",
    "bekymring",
    "følt",
    "serie",
    "spyt",
    "tusinder",
    "tales",
    "forbindelser",
    "vejer",
    "korte",
    "vært",
    "brændstof",
    "udfordring",
    "spænd",
    "negativ",
    "natalie",
    "smerter",
    "guldet",
    "rimeligt",
    "morpheus",
    "lederen",
    "knald",
    "november",
    "afbryder",
    "øvrigt",
    "skrig",
    "lykkeligt",
    "universitet",
    "bagi",
    "hvil",
    "agter",
    "mægtig",
    "kapitel",
    "koncentrere",
    "formentlig",
    "pille",
    "ta'r",
    "banden",
    "flyder",
    "beskrive",
    "penis",
    "kongelige",
    "lntet",
    "bestilte",
    "farfar",
    "fortæi",
    "sd",
    "pladsen",
    "opgaver",
    "værst",
    "ligemeget",
    "joseph",
    "bjerg",
    "fingeren",
    "revet",
    "oliver",
    "sparrow",
    "består",
    "mistanke",
    "sparker",
    "gader",
    "affald",
    "markedet",
    "fyrer",
    "tabere",
    "hersker",
    "måltid",
    "cindy",
    "brækker",
    "forfærdelige",
    "pæne",
    "nem",
    "udnytte",
    "tilfældigvis",
    "metoder",
    "slukket",
    "vældig",
    "seriøs",
    "selvføigelig",
    "særlige",
    "kuffert",
    "gennemgå",
    "alkohol",
    "leonard",
    "såsom",
    "skyggen",
    "tungt",
    "djævlen",
    "skille",
    "venlige",
    "tyder",
    "nordlige",
    "kram",
    "dragt",
    "insisterer",
    "danish",
    "keder",
    "reparere",
    "fãr",
    "evan",
    "fortjente",
    "frakke",
    "krydse",
    "restauranten",
    "spildt",
    "flod",
    "richie",
    "hentet",
    "gentage",
    "special",
    "tekst",
    "tosse",
    "indbrud",
    "forlovet",
    "legende",
    "undskyid",
    "lawrence",
    "bekræfte",
    "centrum",
    "mickey",
    "tyk",
    "patter",
    "palmer",
    "just",
    "udviklet",
    "aftensmad",
    "truffet",
    "blomst",
    "antal",
    "skred",
    "bart",
    "kvik",
    "søns",
    "støv",
    "pirat",
    "skrub",
    "nøje",
    "kusine",
    "walker",
    "center",
    "bishop",
    "heroin",
    "grænse",
    "avenue",
    "engle",
    "betragtning",
    "brors",
    "gut",
    "svigter",
    "vic",
    "cal",
    "vaughn",
    "audrey",
    "indien",
    "bøn",
    "venligt",
    "made",
    "landets",
    "hannah",
    "slukker",
    "jordan",
    "undergang",
    "flydende",
    "områder",
    "baker",
    "materiale",
    "angrib",
    "baggrund",
    "pragtfuldt",
    "rettet",
    "overgiver",
    "toilet",
    "kones",
    "idéer",
    "kigget",
    "ryste",
    "hilsen",
    "sikkerheden",
    "gerningsstedet",
    "hoppede",
    "skuespil",
    "zack",
    "mail",
    "mesteren",
    "hytte",
    "rebet",
    "skilsmisse",
    "advarer",
    "forklar",
    "klovn",
    "frygtelige",
    "lloyd",
    "kanten",
    "frygtede",
    "stilhed",
    "svigtet",
    "com",
    "frugt",
    "stillede",
    "honning",
    "gammeldags",
    "hundene",
    "skæg",
    "duk",
    "rute",
    "mørkets",
    "klassen",
    "himlens",
    "jagter",
    "puls",
    "bide",
    "indser",
    "flov",
    "erik",
    "stykket",
    "warren",
    "ludere",
    "anholde",
    "larm",
    "dato",
    "walt",
    "wendy",
    "beach",
    "bunke",
    "riley",
    "inviterer",
    "vækker",
    "politiske",
    "identificeret",
    "pragtfuld",
    "havnen",
    "kejser",
    "besvær",
    "australien",
    "timers",
    "underskrive",
    "wyatt",
    "sauron",
    "skamme",
    "spred",
    "ry",
    "slips",
    "forandre",
    "gonna",
    "tårer",
    "lev",
    "sydpå",
    "sprut",
    "elendige",
    "jeremy",
    "ånde",
    "forbered",
    "forbrydelser",
    "marvin",
    "holly",
    "langsom",
    "minus",
    "stephen",
    "menig",
    "hang",
    "spørgsmåi",
    "æsel",
    "malcolm",
    "nicky",
    "humor",
    "meddelelse",
    "flåde",
    "motor",
    "frygten",
    "vince",
    "truet",
    "hastighed",
    "mellemtiden",
    "mørk",
    "bak",
    "single",
    "kredsløb",
    "vaek",
    "lauren",
    "reagerer",
    "ryddet",
    "robotter",
    "syng",
    "brormand",
    "græs",
    "kryb",
    "madame",
    "bolt",
    "opringning",
    "traf",
    "hekse",
    "hill",
    "mio",
    "daisy",
    "transport",
    "gul",
    "christine",
    "football",
    "grebet",
    "dødelig",
    "gidsel",
    "borgere",
    "galning",
    "faren",
    "wallace",
    "forstand",
    "tillad",
    "lektier",
    "holdes",
    "feste",
    "forgæves",
    "jess",
    "fokusere",
    "jøder",
    "knuser",
    "blåt",
    "snydt",
    "slapper",
    "ryd",
    "flygtet",
    "kriminalitet",
    "gãre",
    "gabriel",
    "glasset",
    "vei",
    "sø",
    "ulv",
    "trænge",
    "billig",
    "halvdel",
    "terrorister",
    "milo",
    "oprør",
    "kroppe",
    "nøgne",
    "afgørende",
    "offentlig",
    "wall",
    "martha",
    "oscar",
    "stolede",
    "aber",
    "modet",
    "kreditkort",
    "fiske",
    "clay",
    "craig",
    "sméagol",
    "kontrollerer",
    "skrue",
    "bur",
    "udvalgt",
    "vodka",
    "ignorere",
    "skreg",
    "hyrede",
    "skilles",
    "kontakten",
    "rådgiver",
    "peger",
    "pastor",
    "nægtede",
    "tragedie",
    "officerer",
    "afhængig",
    "ofret",
    "knappen",
    "tilfældigt",
    "gård",
    "miranda",
    "ups",
    "regningen",
    "partnere",
    "optagelse",
    "hestene",
    "horn",
    "bekræfter",
    "eve",
    "sydlige",
    "blæse",
    "lommen",
    "risikoen",
    "årige",
    "nøjagtigt",
    "bagage",
    "armene",
    "bekymrede",
    "datters",
    "måneden",
    "adlyde",
    "kommunikation",
    "casey",
    "mobiltelefon",
    "aah",
    "hævet",
    "gentleman",
    "faderen",
    "regnen",
    "opmærksom",
    "ligene",
    "forsvaret",
    "kede",
    "flad",
    "afvist",
    "mur",
    "respektere",
    "saruman",
    "bourne",
    "stater",
    "detaljerne",
    "little",
    "iorden",
    "canada",
    "skydningen",
    "rækkevidde",
    "almindeligt",
    "biive",
    "vasker",
    "smile",
    "spanien",
    "bjerge",
    "watson",
    "uhyggeligt",
    "modtog",
    "internettet",
    "nelson",
    "kagen",
    "dreje",
    "road",
    "arrangeret",
    "soveværelset",
    "gwen",
    "moore",
    "fløjet",
    "allison",
    "colin",
    "delta",
    "landede",
    "underskrevet",
    "begrave",
    "hammer",
    "enormt",
    "gutterne",
    "fletcher",
    "lane",
    "benny",
    "møg",
    "rejsen",
    "genert",
    "enorm",
    "kørende",
    "garagen",
    "italiensk",
    "forfølger",
    "symbol",
    "house",
    "dværg",
    "bær",
    "tilstedeværelse",
    "justin",
    "kager",
    "fiona",
    "lfølge",
    "davis",
    "jern",
    "periode",
    "bi",
    "forandring",
    "motorcykel",
    "udslette",
    "personale",
    "mel",
    "vask",
    "cirkus",
    "sund",
    "ordene",
    "syne",
    "nuttet",
    "allen",
    "klæde",
    "ment",
    "forbrydere",
    "igår",
    "merry",
    "tilintetgøre",
    "feber",
    "pan",
    "nødsituation",
    "organisation",
    "sprede",
    "helbred",
    "fans",
    "sjette",
    "praktisk",
    "aviser",
    "billigt",
    "allierede",
    "lufthavn",
    "reese",
    "posen",
    "megan",
    "svigtede",
    "version",
    "koner",
    "undvære",
    "truede",
    "spillere",
    "foretager",
    "tand",
    "hong",
    "ordnede",
    "dybere",
    "præsidentens",
    "fjendens",
    "laboratorium",
    "bell",
    "stirrer",
    "djævelen",
    "teknik",
    "putter",
    "trøst",
    "blandet",
    "sejl",
    "guide",
    "spredt",
    "overfaldet",
    "pot",
    "lorte",
    "quinn",
    "hurra",
    "sy",
    "rystet",
    "brødrene",
    "farver",
    "styrtede",
    "bagagerummet",
    "brooklyn",
    "undervise",
    "dufter",
    "driller",
    "ejeren",
    "mystiske",
    "lucas",
    "ged",
    "krise",
    "antager",
    "forretningen",
    "lag",
    "dyrke",
    "long",
    "travis",
    "vaeret",
    "lokal",
    "aktivitet",
    "tykke",
    "behøves",
    "balance",
    "media",
    "male",
    "trøje",
    "lugten",
    "fjæs",
    "enterprise",
    "myrder",
    "stål",
    "orange",
    "foto",
    "beslutter",
    "tess",
    "norbit",
    "misforståelse",
    "hovedkvarter",
    "luther",
    "røve",
    "eksplosion",
    "sti",
    "skjold",
    "sølv",
    "offentlige",
    "stuen",
    "overrasker",
    "passet",
    "sprøjte",
    "frelse",
    "optager",
    "overlevet",
    "nina",
    "hale",
    "skoene",
    "beslutte",
    "online",
    "efterforskning",
    "forsyninger",
    "afbryd",
    "standard",
    "kultur",
    "hævne",
    "vækkede",
    "nogens",
    "meldt",
    "ber",
    "damon",
    "pakken",
    "koma",
    "haj",
    "spjældet",
    "hassan",
    "branche",
    "vesten",
    "laser",
    "dyrene",
    "cuba",
    "kay",
    "skider",
    "fabrikken",
    "knus",
    "missiler",
    "knuste",
    "computere",
    "alpha",
    "anklaget",
    "protest",
    "hatten",
    "køkken",
    "projektet",
    "hyret",
    "satellit",
    "laden",
    "dropper",
    "skredet",
    "aktier",
    "afleverer",
    "willie",
    "ejendele",
    "hygge",
    "out",
    "liz",
    "stolen",
    "generation",
    "agt",
    "marken",
    "bestyrelsen",
    "dodge",
    "tunnel",
    "guvernør",
    "styrken",
    "seattle",
    "udgang",
    "re",
    "troy",
    "matematik",
    "herrens",
    "tørstig",
    "skak",
    "skråt",
    "kriminel",
    "længst",
    "hemmeligheden",
    "populær",
    "dags",
    "bankede",
    "put",
    "barnebarn",
    "hal",
    "orlov",
    "dødt",
    "klager",
    "væsner",
    "resultater",
    "forbandelsen",
    "mormor",
    "nash",
    "bilbo",
    "forsikre",
    "intelligent",
    "delt",
    "vænne",
    "legede",
    "ulykkelig",
    "nødvendige",
    "rebecca",
    "kolleger",
    "nætter",
    "løjet",
    "religion",
    "anthony",
    "manhattan",
    "damerne",
    "genere",
    "south",
    "kane",
    "baglæns",
    "hawaii",
    "kke",
    "victoria",
    "christian",
    "er",
    "præsten",
    "slot",
    "mærket",
    "tilkald",
    "griber",
    "psykiater",
    "mitch",
    "overordnede",
    "lily",
    "bush",
    "farer",
    "skiftede",
    "samarbejder",
    "pil",
    "fartøj",
    "besætning",
    "franklin",
    "arrangere",
    "klatre",
    "sun",
    "lyse",
    "lastbilen",
    "undertøj",
    "lisbeth",
    "krydser",
    "overtale",
    "usynlig",
    "bilerne",
    "afslører",
    "julia",
    "shaw",
    "konkurrencen",
    "retfærdigt",
    "kenny",
    "mcclane",
    "overgive",
    "liggende",
    "japansk",
    "efterforskningen",
    "holdning",
    "fattet",
    "taie",
    "atter",
    "graver",
    "presser",
    "tæve",
    "plet",
    "stefan",
    "tåle",
    "tradition",
    "naboer",
    "interesserer",
    "lam",
    "forestilling",
    "woody",
    "aktiv",
    "trafikken",
    "hall",
    "north",
    "pam",
    "mødre",
    "øjeblikkeligt",
    "løser",
    "ilt",
    "buzz",
    "udnytter",
    "ofrene",
    "huden",
    "personen",
    "rita",
    "maskinerne",
    "erjo",
    "svømmer",
    "pisser",
    "eksploderer",
    "skammer",
    "klip",
    "sild",
    "santa",
    "norman",
    "lovligt",
    "betaling",
    "tungen",
    "beverly",
    "kursen",
    "drømmen",
    "ambassadør",
    "stu",
    "biografen",
    "tårnet",
    "morsom",
    "ivan",
    "ærlige",
    "reklame",
    "garanti",
    "samantha",
    "samtalen",
    "forstærkning",
    "nævner",
    "ærede",
    "vinkel",
    "grundigt",
    "koncentrer",
    "bevæbnede",
    "iiiie",
    "bay",
    "hor",
    "forrådte",
    "mønster",
    "edmund",
    "kortene",
    "fornemmer",
    "privatliv",
    "konger",
    "skaffet",
    "arv",
    "felix",
    "pâ",
    "obi",
    "troen",
    "bedes",
    "slutning",
    "bakken",
    "carson",
    "mangel",
    "geværet",
    "mason",
    "debbie",
    "stød",
    "soldaterne",
    "dusin",
    "billige",
    "rollen",
    "nederlag",
    "åndssvage",
    "aftenens",
    "beskyt",
    "isabel",
    "skynet",
    "voldsomt",
    "livstid",
    "sænke",
    "brændende",
    "come",
    "tårn",
    "søreme",
    "trapperne",
    "lidelse",
    "eksplosionen",
    "jamie",
    "mærk",
    "tænderne",
    "grupper",
    "aitid",
    "sejren",
    "gentlemen",
    "begivenhed",
    "motorvejen",
    "bruden",
    "ledig",
    "straffet",
    "foden",
    "branden",
    "udvikle",
    "kasser",
    "clyde",
    "tyggegummi",
    "rygtet",
    "fã",
    "voyager",
    "velsignet",
    "tricks",
    "forsikring",
    "international",
    "udtale",
    "pop",
    "stone",
    "spider",
    "genial",
    "prinsen",
    "afsnit",
    "fyld",
    "gangs",
    "oz",
    "følsom",
    "drukne",
    "flår",
    "gloria",
    "plage",
    "væg",
    "deltager",
    "bagfra",
    "rosa",
    "retssag",
    "afdøde",
    "blad",
    "phoenix",
    "sodavand",
    "distrikt",
    "lægerne",
    "skiltet",
    "kiar",
    "um",
    "elliot",
    "spreder",
    "roser",
    "forgiftet",
    "hellig",
    "omsider",
    "indstil",
    "droppede",
    "begravelsen",
    "kiste",
    "veronica",
    "overbetjent",
    "dessert",
    "manglende",
    "wan",
    "undgår",
    "ankomst",
    "enorme",
    "forrådt",
    "d'herrer",
    "kvarteret",
    "ørerne",
    "lur",
    "kontrakten",
    "undersøg",
    "overvågning",
    "kvit",
    "udvikling",
    "fjernede",
    "værdig",
    "smuttet",
    "bagdøren",
    "judy",
    "ideen",
    "navnene",
    "kræve",
    "værktøj",
    "øjeblikke",
    "mcgee",
    "randy",
    "lager",
    "brække",
    "parti",
    "klør",
    "samles",
    "rådighed",
    "hil",
    "elvis",
    "museum",
    "iaver",
    "nation",
    "døgnet",
    "alvorlige",
    "intelligens",
    "delte",
    "underviser",
    "latin",
    "føj",
    "herr",
    "satser",
    "mappe",
    "usædvanlig",
    "kriminalassistent",
    "ulykken",
    "aftrækkeren",
    "hovedkvarteret",
    "vinter",
    "haster",
    "bekymringer",
    "bevist",
    "varsel",
    "fejrer",
    "designet",
    "gondor",
    "nyeste",
    "spærret",
    "begyndelse",
    "spyd",
    "fattig",
    "ægtemand",
    "burke",
    "kaffen",
    "bevidstløs",
    "årets",
    "last",
    "diskret",
    "ralph",
    "ali",
    "aha",
    "tvillinger",
    "sluttede",
    "modstander",
    "tatovering",
    "kø",
    "årsagen",
    "fuglen",
    "døtre",
    "hut",
    "sæson",
    "synet",
    "kristen",
    "secret",
    "nicole",
    "påvirker",
    "bygninger",
    "united",
    "hyre",
    "modige",
    "kvindelige",
    "tilpas",
    "whoo",
    "sherman",
    "vane",
    "filer",
    "uventet",
    "glimt",
    "sexede",
    "vinduer",
    "politibetjent",
    "anders",
    "chip",
    "noah",
    "neil",
    "turde",
    "kongressen",
    "beskyttede",
    "sangen",
    "dygtige",
    "forfremmet",
    "udtalelse",
    "umulig",
    "ih",
    "dermed",
    "efternavn",
    "ægteskabet",
    "fil",
    "selskabet",
    "klipper",
    "hore",
    "marco",
    "herredet",
    "stress",
    "vidnet",
    "køleskabet",
    "evnen",
    "hængende",
    "sær",
    "posten",
    "værelser",
    "svor",
    "interessante",
    "almægtige",
    "huskede",
    "skjul",
    "skru",
    "toby",
    "flint",
    "forståelse",
    "kopier",
    "knalde",
    "ki",
    "japanske",
    "tegnet",
    "kjolen",
    "præsenterer",
    "vinteren",
    "panden",
    "lester",
    "paranoid",
    "pá",
    "omgivet",
    "dansede",
    "obersten",
    "lektion",
    "gir",
    "pool",
    "hector",
    "tøsedreng",
    "øhm",
    "jared",
    "knække",
    "fandtes",
]
