# -*- encoding: utf-8 -*-
"""
Simply a list of about 6000 common English words. They are each catagorized
by word type (Noun, Verb, Pronoun, etc) which helps to anticipate how the word
might work in the sample data being created, for instance as something's name,
or within a media title.

**Usage:**

::

    from liar.iamaliar import IAmALiar
    number_records = 10
    maker = IAmALiar(number_records)

    # Use:
    from liar.model.raw import english_raw

    # Or from scratch:
    english_raw = {
        'name': 'english_raw',
        'class': 'igetraw',
        'data': 'english',
    }

    data_set = maker.get_data([english_raw])

    for row in data_set:
        data = Model()
        english_word.word = row['english_raw']['word']
        english_word.classification = row['english_raw']['classification']
        data.save()

Blurb:

::

    english_title = {
        'name': 'english_title',
        'class': 'iblurb',
        'language': 'english',
        'method': 'html_bullets',
        'min': 7,
        'max': 10,
    }

    data_set = maker.get_data([english_title])

    for row in data_set:
        data = Model()
        data.english_title = row['english_title']
        data.save()


If you only need the english word, use the property option:

::

    from liar.iamaliar import IAmALiar

    from liar.model.raw import english_raw

    english_word_raw = {
        'name': 'english_word_raw',
        'class': 'igetraw',
        'data': 'english',
        'property': 'word'
    }

    from liar.model.raw import english_word_raw

    number_records = 10
    maker = IAmALiar(number_records)

    data_set = maker.get_data([english_word_raw])

    for row in data_set:
        data.english_word = row['english_word_raw']

"""

english = [
    {"classification": "Noun", "word": "abandon"},
    {"classification": "Verb", "word": "abandon"},
    {"classification": "Adjective", "word": "able"},
    {"classification": "Adjective", "word": "abnormal"},
    {"classification": "Preposition", "word": "aboard"},
    {"classification": "Adverb", "word": "aboard"},
    {"classification": "Preposition", "word": "about"},
    {"classification": "Adverb", "word": "about"},
    {"classification": "Preposition", "word": "above"},
    {"classification": "Adverb", "word": "above"},
    {"classification": "Adverb", "word": "abroad"},
    {"classification": "Noun", "word": "absence"},
    {"classification": "Adjective", "word": "absent"},
    {"classification": "Verb", "word": "absent"},
    {"classification": "Adjective", "word": "absolute"},
    {"classification": "Noun", "word": "absolute"},
    {"classification": "Adverb", "word": "absolutely"},
    {"classification": "Verb", "word": "absorb"},
    {"classification": "Adjective", "word": "abstract"},
    {"classification": "Verb", "word": "abstract"},
    {"classification": "Adjective", "word": "english"},
    {"classification": "Verb", "word": "accelerate"},
    {"classification": "Verb", "word": "accept"},
    {"classification": "Adjective", "word": "accept"},
    {"classification": "Adjective", "word": "acceptable"},
    {"classification": "Noun", "word": "access"},
    {"classification": "Verb", "word": "accompany"},
    {"classification": "Verb", "word": "accomplish"},
    {"classification": "Verb", "word": "accord"},
    {"classification": "Noun", "word": "accordance"},
    {"classification": "Adverb", "word": "according"},
    {"classification": "Adverb", "word": "accordingly"},
    {"classification": "Noun", "word": "account"},
    {"classification": "Verb", "word": "account"},
    {"classification": "Adjective", "word": "accumulate"},
    {"classification": "Verb", "word": "accumulate"},
    {"classification": "Noun", "word": "accuracy"},
    {"classification": "Adjective", "word": "accurate"},
    {"classification": "Adverb", "word": "accurately"},
    {"classification": "Verb", "word": "accuse"},
    {"classification": "Noun", "word": "accuse"},
    {"classification": "Adjective", "word": "accused"},
    {"classification": "Noun", "word": "accustom"},
    {"classification": "Verb", "word": "accustom"},
    {"classification": "Verb", "word": "ache"},
    {"classification": "Noun", "word": "ache"},
    {"classification": "Verb", "word": "achieve"},
    {"classification": "Adjective", "word": "acid"},
    {"classification": "Noun", "word": "acid"},
    {"classification": "Verb", "word": "acquire"},
    {"classification": "Preposition", "word": "across"},
    {"classification": "Noun", "word": "across"},
    {"classification": "Adverb", "word": "across"},
    {"classification": "Noun", "word": "act"},
    {"classification": "Verb", "word": "act"},
    {"classification": "Adjective", "word": "acting"},
    {"classification": "Noun", "word": "action"},
    {"classification": "Adjective", "word": "active"},
    {"classification": "Noun", "word": "actor"},
    {"classification": "Noun", "word": "actress"},
    {"classification": "Noun", "word": "actual"},
    {"classification": "Adjective", "word": "actual"},
    {"classification": "Adverb", "word": "actually"},
    {"classification": "Noun", "word": "adam"},
    {"classification": "Verb", "word": "adapt"},
    {"classification": "Adjective", "word": "adapt"},
    {"classification": "Verb", "word": "add"},
    {"classification": "Noun", "word": "addition"},
    {"classification": "Adjective", "word": "additional"},
    {"classification": "Verb", "word": "address"},
    {"classification": "Adjective", "word": "adequate"},
    {"classification": "Verb", "word": "adhere"},
    {"classification": "Adjective", "word": "adjacent"},
    {"classification": "Verb", "word": "adjective"},
    {"classification": "Verb", "word": "adjust"},
    {"classification": "Verb", "word": "administer"},
    {"classification": "Adjective", "word": "administrative"},
    {"classification": "Verb", "word": "admire"},
    {"classification": "Verb", "word": "admit"},
    {"classification": "Adjective", "word": "admitted"},
    {"classification": "Adjective", "word": "adolescent"},
    {"classification": "Verb", "word": "adopt"},
    {"classification": "Adjective", "word": "adopted"},
    {"classification": "Noun", "word": "adoption"},
    {"classification": "Noun", "word": "adult"},
    {"classification": "Adjective", "word": "adult"},
    {"classification": "Adjective", "word": "advance"},
    {"classification": "Verb", "word": "advance"},
    {"classification": "Adjective", "word": "advanced"},
    {"classification": "Verb", "word": "advantage"},
    {"classification": "Noun", "word": "advantage"},
    {"classification": "Verb", "word": "adventure"},
    {"classification": "Verb", "word": "advertise"},
    {"classification": "Noun", "word": "advice"},
    {"classification": "Verb", "word": "advise"},
    {"classification": "Adjective", "word": "advisory"},
    {"classification": "Verb", "word": "advocate"},
    {"classification": "Adjective", "word": "aesthetic"},
    {"classification": "Noun", "word": "affair"},
    {"classification": "Noun", "word": "affect"},
    {"classification": "Verb", "word": "affect"},
    {"classification": "Verb", "word": "affiliate"},
    {"classification": "Noun", "word": "affiliate"},
    {"classification": "Noun", "word": "affluence"},
    {"classification": "Verb", "word": "afford"},
    {"classification": "Noun", "word": "african"},
    {"classification": "Adjective", "word": "african"},
    {"classification": "Preposition", "word": "after"},
    {"classification": "SubordConjunction", "word": "after"},
    {"classification": "Adjective", "word": "after"},
    {"classification": "Adverb", "word": "after"},
    {"classification": "Noun", "word": "afternoon"},
    {"classification": "Preposition", "word": "again"},
    {"classification": "Adverb", "word": "again"},
    {"classification": "Preposition", "word": "against"},
    {"classification": "Verb", "word": "age"},
    {"classification": "Noun", "word": "age"},
    {"classification": "Noun", "word": "agencies"},
    {"classification": "Noun", "word": "agency"},
    {"classification": "Adjective", "word": "agent"},
    {"classification": "Noun", "word": "agent"},
    {"classification": "Verb", "word": "aggregate"},
    {"classification": "Adjective", "word": "aggregate"},
    {"classification": "Noun", "word": "aggregate"},
    {"classification": "Verb", "word": "agitate"},
    {"classification": "Adverb", "word": "agree"},
    {"classification": "Verb", "word": "agree"},
    {"classification": "Noun", "word": "agreement"},
    {"classification": "Adjective", "word": "agricultural"},
    {"classification": "Adverb", "word": "ahead"},
    {"classification": "Verb", "word": "aid"},
    {"classification": "Verb", "word": "aim"},
    {"classification": "Noun", "word": "air"},
    {"classification": "Adjective", "word": "al"},
    {"classification": "Noun", "word": "alcohol"},
    {"classification": "Adjective", "word": "alert"},
    {"classification": "Noun", "word": "alert"},
    {"classification": "Verb", "word": "align"},
    {"classification": "Adjective", "word": "alike"},
    {"classification": "Adverb", "word": "alike"},
    {"classification": "Adjective", "word": "alive"},
    {"classification": "Noun", "word": "all"},
    {"classification": "Adjective", "word": "all"},
    {"classification": "Adverb", "word": "all"},
    {"classification": "Verb", "word": "allege"},
    {"classification": "Verb", "word": "alliance"},
    {"classification": "Noun", "word": "alliance"},
    {"classification": "Adjective", "word": "allied"},
    {"classification": "Noun", "word": "allies"},
    {"classification": "Verb", "word": "allocate"},
    {"classification": "Noun", "word": "allotment"},
    {"classification": "Verb", "word": "allow"},
    {"classification": "Verb", "word": "allude"},
    {"classification": "Verb", "word": "ally"},
    {"classification": "Noun", "word": "ally"},
    {"classification": "Adverb", "word": "almost"},
    {"classification": "Adverb", "word": "alone"},
    {"classification": "Adjective", "word": "alone"},
    {"classification": "Preposition", "word": "along"},
    {"classification": "Adverb", "word": "along"},
    {"classification": "Adverb", "word": "aloud"},
    {"classification": "Adverb", "word": "already"},
    {"classification": "Verb", "word": "alter"},
    {"classification": "Adjective", "word": "alternative"},
    {"classification": "SubordConjunction", "word": "although"},
    {"classification": "Adverb", "word": "altogether"},
    {"classification": "Adverb", "word": "always"},
    {"classification": "Adjective", "word": "amateur"},
    {"classification": "Noun", "word": "amateur"},
    {"classification": "Adjective", "word": "amazing"},
    {"classification": "Noun", "word": "ambassador"},
    {"classification": "Adjective", "word": "ambiguous"},
    {"classification": "Noun", "word": "ambition"},
    {"classification": "Verb", "word": "ambition"},
    {"classification": "Adjective", "word": "ambitious"},
    {"classification": "Noun", "word": "amendment"},
    {"classification": "Noun", "word": "american"},
    {"classification": "Adjective", "word": "american"},
    {"classification": "Preposition", "word": "among"},
    {"classification": "Preposition", "word": "amongst"},
    {"classification": "Adjective", "word": "amorphous"},
    {"classification": "Noun", "word": "amount"},
    {"classification": "Verb", "word": "amount"},
    {"classification": "Verb", "word": "amuse"},
    {"classification": "Verb", "word": "analyze"},
    {"classification": "Noun", "word": "ancient"},
    {"classification": "Adjective", "word": "ancient"},
    {"classification": "CoordConjunction", "word": "and"},
    {"classification": "Noun", "word": "anger"},
    {"classification": "Verb", "word": "anger"},
    {"classification": "Noun", "word": "angle"},
    {"classification": "Verb", "word": "angle"},
    {"classification": "Adjective", "word": "anglo-saxon"},
    {"classification": "Adjective", "word": "angry"},
    {"classification": "Noun", "word": "angular"},
    {"classification": "Adjective", "word": "angular"},
    {"classification": "Adjective", "word": "animal"},
    {"classification": "Noun", "word": "animal"},
    {"classification": "Noun", "word": "ann"},
    {"classification": "Adjective", "word": "anniversary"},
    {"classification": "Noun", "word": "announcement"},
    {"classification": "Noun", "word": "annoy"},
    {"classification": "Noun", "word": "annoyance"},
    {"classification": "Adjective", "word": "annual"},
    {"classification": "Noun", "word": "annual"},
    {"classification": "Noun", "word": "anode"},
    {"classification": "Adjective", "word": "anonymous"},
    {"classification": "Verb", "word": "answer"},
    {"classification": "Noun", "word": "answer"},
    {"classification": "Noun", "word": "anticipation"},
    {"classification": "Noun", "word": "anti-semitism"},
    {"classification": "Adjective", "word": "anxious"},
    {"classification": "Adverb", "word": "any"},
    {"classification": "Pronoun", "word": "anybody"},
    {"classification": "Noun", "word": "anybody"},
    {"classification": "Adverb", "word": "anyhow"},
    {"classification": "Pronoun", "word": "anyone"},
    {"classification": "Noun", "word": "anyone"},
    {"classification": "Adverb", "word": "anything"},
    {"classification": "Noun", "word": "anything"},
    {"classification": "Adverb", "word": "anyway"},
    {"classification": "Adverb", "word": "anywhere"},
    {"classification": "Adverb", "word": "apart"},
    {"classification": "Noun", "word": "apartment"},
    {"classification": "Verb", "word": "apology"},
    {"classification": "Noun", "word": "apparatus"},
    {"classification": "Adjective", "word": "apparent"},
    {"classification": "Adverb", "word": "apparently"},
    {"classification": "Verb", "word": "appeal"},
    {"classification": "Verb", "word": "appear"},
    {"classification": "Noun", "word": "appear"},
    {"classification": "Verb", "word": "append"},
    {"classification": "Verb", "word": "applaud"},
    {"classification": "Verb", "word": "apple"},
    {"classification": "Noun", "word": "apple"},
    {"classification": "Verb", "word": "apply"},
    {"classification": "Verb", "word": "appoint"},
    {"classification": "Verb", "word": "appraise"},
    {"classification": "Verb", "word": "appreciate"},
    {"classification": "Noun", "word": "approach"},
    {"classification": "Verb", "word": "approach"},
    {"classification": "Adjective", "word": "appropriate"},
    {"classification": "Verb", "word": "appropriate"},
    {"classification": "Noun", "word": "approval"},
    {"classification": "Verb", "word": "approve"},
    {"classification": "Adjective", "word": "approximate"},
    {"classification": "Verb", "word": "approximate"},
    {"classification": "Adverb", "word": "approximately"},
    {"classification": "Noun", "word": "april"},
    {"classification": "Adjective", "word": "arbitrary"},
    {"classification": "Noun", "word": "arc"},
    {"classification": "Verb", "word": "arc"},
    {"classification": "Verb", "word": "arch"},
    {"classification": "Adjective", "word": "arch"},
    {"classification": "Noun", "word": "arch"},
    {"classification": "Noun", "word": "architect"},
    {"classification": "Noun", "word": "are"},
    {"classification": "Noun", "word": "area"},
    {"classification": "Verb", "word": "argue"},
    {"classification": "Verb", "word": "argument"},
    {"classification": "Noun", "word": "argument"},
    {"classification": "Verb", "word": "arise"},
    {"classification": "Noun", "word": "arise"},
    {"classification": "Verb", "word": "arm"},
    {"classification": "Noun", "word": "arm"},
    {"classification": "Adjective", "word": "armed"},
    {"classification": "Noun", "word": "arms"},
    {"classification": "Noun", "word": "army"},
    {"classification": "Preposition", "word": "around"},
    {"classification": "Adverb", "word": "around"},
    {"classification": "Verb", "word": "arouse"},
    {"classification": "Verb", "word": "arrange"},
    {"classification": "Noun", "word": "arrangement"},
    {"classification": "Verb", "word": "arrest"},
    {"classification": "Noun", "word": "arrival"},
    {"classification": "Verb", "word": "arrive"},
    {"classification": "Noun", "word": "arrive"},
    {"classification": "Noun", "word": "arrow"},
    {"classification": "Noun", "word": "art"},
    {"classification": "Noun", "word": "artery"},
    {"classification": "Noun", "word": "article"},
    {"classification": "Verb", "word": "article"},
    {"classification": "Adjective", "word": "artificial"},
    {"classification": "Noun", "word": "artist"},
    {"classification": "Adjective", "word": "artistic"},
    {"classification": "SubordConjunction", "word": "as"},
    {"classification": "Noun", "word": "as"},
    {"classification": "Verb", "word": "ascribe"},
    {"classification": "Noun", "word": "ash"},
    {"classification": "Verb", "word": "ash"},
    {"classification": "Adjective", "word": "ashamed"},
    {"classification": "Adverb", "word": "aside"},
    {"classification": "Noun", "word": "aside"},
    {"classification": "Verb", "word": "ask"},
    {"classification": "Noun", "word": "ask"},
    {"classification": "Noun", "word": "asking"},
    {"classification": "Noun", "word": "aspect"},
    {"classification": "Verb", "word": "assemble"},
    {"classification": "Verb", "word": "assent"},
    {"classification": "Verb", "word": "assert"},
    {"classification": "Verb", "word": "assess"},
    {"classification": "Noun", "word": "asset"},
    {"classification": "Noun", "word": "assign"},
    {"classification": "Verb", "word": "assign"},
    {"classification": "Verb", "word": "assimilate"},
    {"classification": "Verb", "word": "assist"},
    {"classification": "Noun", "word": "assistance"},
    {"classification": "Adjective", "word": "assistant"},
    {"classification": "Verb", "word": "associate"},
    {"classification": "Adjective", "word": "associate"},
    {"classification": "Adjective", "word": "associated"},
    {"classification": "Verb", "word": "assume"},
    {"classification": "Adjective", "word": "assumed"},
    {"classification": "Verb", "word": "assure"},
    {"classification": "Noun", "word": "assured"},
    {"classification": "Adjective", "word": "assured"},
    {"classification": "Verb", "word": "astonish"},
    {"classification": "Preposition", "word": "at"},
    {"classification": "Noun", "word": "atlanta"},
    {"classification": "Adjective", "word": "atlantic"},
    {"classification": "Noun", "word": "atmosphere"},
    {"classification": "Noun", "word": "atom"},
    {"classification": "Verb", "word": "atom"},
    {"classification": "Adjective", "word": "atomic"},
    {"classification": "Verb", "word": "attach"},
    {"classification": "Noun", "word": "attach"},
    {"classification": "Noun", "word": "attack"},
    {"classification": "Verb", "word": "attack"},
    {"classification": "Noun", "word": "attain"},
    {"classification": "Verb", "word": "attain"},
    {"classification": "Verb", "word": "attempt"},
    {"classification": "Verb", "word": "attend"},
    {"classification": "Adjective", "word": "attentive"},
    {"classification": "Noun", "word": "attitude"},
    {"classification": "Verb", "word": "attorney"},
    {"classification": "Noun", "word": "attorney"},
    {"classification": "Verb", "word": "attract"},
    {"classification": "Noun", "word": "attract"},
    {"classification": "Adjective", "word": "attractive"},
    {"classification": "Verb", "word": "attribute"},
    {"classification": "Noun", "word": "attribute"},
    {"classification": "Adjective", "word": "audience"},
    {"classification": "Noun", "word": "aunt"},
    {"classification": "Noun", "word": "authentic"},
    {"classification": "Adjective", "word": "authentic"},
    {"classification": "Verb", "word": "author"},
    {"classification": "Noun", "word": "author"},
    {"classification": "Verb", "word": "authorize"},
    {"classification": "Adjective", "word": "authorized"},
    {"classification": "Adjective", "word": "automatic"},
    {"classification": "Adverb", "word": "automatically"},
    {"classification": "Noun", "word": "automobile"},
    {"classification": "Noun", "word": "autumn"},
    {"classification": "Verb", "word": "avail"},
    {"classification": "Noun", "word": "avail"},
    {"classification": "Adjective", "word": "available"},
    {"classification": "Noun", "word": "avenue"},
    {"classification": "Noun", "word": "average"},
    {"classification": "Verb", "word": "average"},
    {"classification": "Adjective", "word": "average"},
    {"classification": "Adjective", "word": "averse"},
    {"classification": "Verb", "word": "avoid"},
    {"classification": "Adjective", "word": "avoid"},
    {"classification": "Noun", "word": "avoidance"},
    {"classification": "Verb", "word": "awake"},
    {"classification": "Adjective", "word": "awake"},
    {"classification": "Verb", "word": "award"},
    {"classification": "Adjective", "word": "aware"},
    {"classification": "Adverb", "word": "away"},
    {"classification": "Noun", "word": "awe"},
    {"classification": "Verb", "word": "awe"},
    {"classification": "Adjective", "word": "awkward"},
    {"classification": "Noun", "word": "axe"},
    {"classification": "Noun", "word": "axis"},
    {"classification": "Verb", "word": "baby"},
    {"classification": "Adjective", "word": "baby"},
    {"classification": "Noun", "word": "baby"},
    {"classification": "Adverb", "word": "back"},
    {"classification": "Adjective", "word": "back"},
    {"classification": "Verb", "word": "back"},
    {"classification": "Noun", "word": "back"},
    {"classification": "Noun", "word": "background"},
    {"classification": "Noun", "word": "backward"},
    {"classification": "Verb", "word": "backward"},
    {"classification": "Adjective", "word": "backward"},
    {"classification": "Adverb", "word": "backward"},
    {"classification": "Adjective", "word": "bad"},
    {"classification": "Verb", "word": "bad"},
    {"classification": "Adverb", "word": "badly"},
    {"classification": "Noun", "word": "bag"},
    {"classification": "Verb", "word": "bag"},
    {"classification": "Noun", "word": "baggage"},
    {"classification": "Noun", "word": "bake"},
    {"classification": "Verb", "word": "bake"},
    {"classification": "Verb", "word": "baker"},
    {"classification": "Verb", "word": "balance"},
    {"classification": "Noun", "word": "balance"},
    {"classification": "Verb", "word": "ball"},
    {"classification": "Noun", "word": "ball"},
    {"classification": "Noun", "word": "ballet"},
    {"classification": "Verb", "word": "band"},
    {"classification": "Verb", "word": "bank"},
    {"classification": "Noun", "word": "bank"},
    {"classification": "Noun", "word": "bar"},
    {"classification": "Verb", "word": "barber"},
    {"classification": "Noun", "word": "barber"},
    {"classification": "Adjective", "word": "bare"},
    {"classification": "Noun", "word": "bare"},
    {"classification": "Adverb", "word": "barely"},
    {"classification": "Noun", "word": "bargain"},
    {"classification": "Verb", "word": "bargain"},
    {"classification": "Noun", "word": "barn"},
    {"classification": "Verb", "word": "barn"},
    {"classification": "Verb", "word": "barrel"},
    {"classification": "Noun", "word": "barrel"},
    {"classification": "Noun", "word": "barton"},
    {"classification": "Adjective", "word": "base"},
    {"classification": "Noun", "word": "base"},
    {"classification": "Noun", "word": "baseball"},
    {"classification": "Noun", "word": "based"},
    {"classification": "Adjective", "word": "based"},
    {"classification": "Adjective", "word": "basement"},
    {"classification": "Noun", "word": "bases"},
    {"classification": "Adjective", "word": "basic"},
    {"classification": "Noun", "word": "basin"},
    {"classification": "Noun", "word": "basis"},
    {"classification": "Verb", "word": "basket"},
    {"classification": "Noun", "word": "basket"},
    {"classification": "Noun", "word": "bath"},
    {"classification": "Verb", "word": "bathe"},
    {"classification": "Noun", "word": "bathe"},
    {"classification": "Verb", "word": "battery"},
    {"classification": "Adjective", "word": "battle"},
    {"classification": "Noun", "word": "battle"},
    {"classification": "Verb", "word": "battle"},
    {"classification": "Noun", "word": "bay"},
    {"classification": "Verb", "word": "bay"},
    {"classification": "Adjective", "word": "bay"},
    {"classification": "Verb", "word": "be"},
    {"classification": "Verb", "word": "beach"},
    {"classification": "Noun", "word": "beach"},
    {"classification": "Noun", "word": "beak"},
    {"classification": "Verb", "word": "beam"},
    {"classification": "Noun", "word": "beam"},
    {"classification": "Noun", "word": "bean"},
    {"classification": "Noun", "word": "bear"},
    {"classification": "Verb", "word": "bear"},
    {"classification": "Verb", "word": "beard"},
    {"classification": "Noun", "word": "beard"},
    {"classification": "Noun", "word": "bearing"},
    {"classification": "Noun", "word": "beast"},
    {"classification": "Adjective", "word": "beat"},
    {"classification": "Verb", "word": "beat"},
    {"classification": "Noun", "word": "beat"},
    {"classification": "Adjective", "word": "beautiful"},
    {"classification": "Noun", "word": "beauty"},
    {"classification": "Verb", "word": "became"},
    {"classification": "SubordConjunction", "word": "because"},
    {"classification": "Verb", "word": "become"},
    {"classification": "Verb", "word": "bed"},
    {"classification": "Noun", "word": "bed"},
    {"classification": "Noun", "word": "bedroom"},
    {"classification": "Adjective", "word": "beef"},
    {"classification": "Noun", "word": "beef"},
    {"classification": "Noun", "word": "beer"},
    {"classification": "SubordConjunction", "word": "before"},
    {"classification": "Preposition", "word": "before"},
    {"classification": "Adverb", "word": "before"},
    {"classification": "Verb", "word": "beg"},
    {"classification": "Noun", "word": "beg"},
    {"classification": "Noun", "word": "begin"},
    {"classification": "Verb", "word": "begin"},
    {"classification": "Noun", "word": "behalf"},
    {"classification": "Verb", "word": "behave"},
    {"classification": "Noun", "word": "behavior"},
    {"classification": "Preposition", "word": "behind"},
    {"classification": "Adverb", "word": "behind"},
    {"classification": "Adjective", "word": "behind"},
    {"classification": "Noun", "word": "behind"},
    {"classification": "Adverb", "word": "being"},
    {"classification": "Noun", "word": "being"},
    {"classification": "Noun", "word": "belief"},
    {"classification": "Noun", "word": "believe"},
    {"classification": "Verb", "word": "believe"},
    {"classification": "Noun", "word": "bell"},
    {"classification": "Verb", "word": "bell"},
    {"classification": "Verb", "word": "belly"},
    {"classification": "Noun", "word": "belly"},
    {"classification": "Verb", "word": "belong"},
    {"classification": "Preposition", "word": "below"},
    {"classification": "Adverb", "word": "below"},
    {"classification": "Noun", "word": "belt"},
    {"classification": "Verb", "word": "belt"},
    {"classification": "Noun", "word": "ben"},
    {"classification": "Adverb", "word": "ben"},
    {"classification": "Noun", "word": "bench"},
    {"classification": "Verb", "word": "bench"},
    {"classification": "Verb", "word": "bend"},
    {"classification": "Noun", "word": "bend"},
    {"classification": "Preposition", "word": "beneath"},
    {"classification": "Adverb", "word": "beneath"},
    {"classification": "Verb", "word": "benefit"},
    {"classification": "Noun", "word": "bent"},
    {"classification": "Verb", "word": "bent"},
    {"classification": "Noun", "word": "berlin"},
    {"classification": "Noun", "word": "berry"},
    {"classification": "Verb", "word": "berry"},
    {"classification": "Preposition", "word": "beside"},
    {"classification": "Noun", "word": "beside"},
    {"classification": "Adverb", "word": "beside"},
    {"classification": "Preposition", "word": "besides"},
    {"classification": "Adverb", "word": "besides"},
    {"classification": "Verb", "word": "best"},
    {"classification": "Adjective", "word": "best"},
    {"classification": "Noun", "word": "best"},
    {"classification": "Verb", "word": "bet"},
    {"classification": "Noun", "word": "bet"},
    {"classification": "Verb", "word": "better"},
    {"classification": "Noun", "word": "better"},
    {"classification": "Adjective", "word": "better"},
    {"classification": "Preposition", "word": "between"},
    {"classification": "Noun", "word": "between"},
    {"classification": "Preposition", "word": "beyond"},
    {"classification": "Adverb", "word": "beyond"},
    {"classification": "Noun", "word": "bible"},
    {"classification": "Noun", "word": "bicycle"},
    {"classification": "Verb", "word": "bid"},
    {"classification": "Noun", "word": "bid"},
    {"classification": "Adjective", "word": "big"},
    {"classification": "Verb", "word": "big"},
    {"classification": "Noun", "word": "big"},
    {"classification": "Adjective", "word": "bigger"},
    {"classification": "Adjective", "word": "biggest"},
    {"classification": "Noun", "word": "bill"},
    {"classification": "Verb", "word": "bill"},
    {"classification": "Noun", "word": "billion"},
    {"classification": "Noun", "word": "billy"},
    {"classification": "Verb", "word": "bind"},
    {"classification": "Noun", "word": "bind"},
    {"classification": "Adjective", "word": "binding"},
    {"classification": "Noun", "word": "binding"},
    {"classification": "Noun", "word": "binomial"},
    {"classification": "Adjective", "word": "binomial"},
    {"classification": "Adjective", "word": "biological"},
    {"classification": "Noun", "word": "bird"},
    {"classification": "Verb", "word": "bird"},
    {"classification": "Noun", "word": "birth"},
    {"classification": "Verb", "word": "bit"},
    {"classification": "Noun", "word": "bit"},
    {"classification": "Verb", "word": "bite"},
    {"classification": "Verb", "word": "bitter"},
    {"classification": "Noun", "word": "bitter"},
    {"classification": "Adverb", "word": "black"},
    {"classification": "Adjective", "word": "black"},
    {"classification": "Noun", "word": "black"},
    {"classification": "Verb", "word": "blade"},
    {"classification": "Noun", "word": "blade"},
    {"classification": "Verb", "word": "blame"},
    {"classification": "Adjective", "word": "blanket"},
    {"classification": "Verb", "word": "blanket"},
    {"classification": "Verb", "word": "bleed"},
    {"classification": "Verb", "word": "bless"},
    {"classification": "Verb", "word": "blind"},
    {"classification": "Adjective", "word": "blind"},
    {"classification": "Noun", "word": "blind"},
    {"classification": "Noun", "word": "block"},
    {"classification": "Verb", "word": "block"},
    {"classification": "Noun", "word": "blonde"},
    {"classification": "Verb", "word": "blonde"},
    {"classification": "Noun", "word": "blood"},
    {"classification": "Verb", "word": "blood"},
    {"classification": "Noun", "word": "blow"},
    {"classification": "Verb", "word": "blow"},
    {"classification": "Verb", "word": "blue"},
    {"classification": "Adjective", "word": "blue"},
    {"classification": "Noun", "word": "blue"},
    {"classification": "Verb", "word": "board"},
    {"classification": "Noun", "word": "board"},
    {"classification": "Verb", "word": "boast"},
    {"classification": "Noun", "word": "boast"},
    {"classification": "Verb", "word": "boat"},
    {"classification": "Noun", "word": "boat"},
    {"classification": "Noun", "word": "boating"},
    {"classification": "Noun", "word": "bob"},
    {"classification": "Verb", "word": "bob"},
    {"classification": "Noun", "word": "bobby"},
    {"classification": "Noun", "word": "bodies"},
    {"classification": "Verb", "word": "body"},
    {"classification": "Noun", "word": "body"},
    {"classification": "Noun", "word": "boil"},
    {"classification": "Verb", "word": "boil"},
    {"classification": "Noun", "word": "bold"},
    {"classification": "Verb", "word": "bold"},
    {"classification": "Verb", "word": "bomb"},
    {"classification": "Noun", "word": "bomb"},
    {"classification": "Verb", "word": "bond"},
    {"classification": "Noun", "word": "bond"},
    {"classification": "Adjective", "word": "bond"},
    {"classification": "Verb", "word": "bone"},
    {"classification": "Noun", "word": "bone"},
    {"classification": "Verb", "word": "book"},
    {"classification": "Noun", "word": "book"},
    {"classification": "Noun", "word": "boots"},
    {"classification": "Noun", "word": "border"},
    {"classification": "Verb", "word": "border"},
    {"classification": "Verb", "word": "bore"},
    {"classification": "Noun", "word": "bore"},
    {"classification": "Verb", "word": "born"},
    {"classification": "Verb", "word": "borrow"},
    {"classification": "Noun", "word": "borrow"},
    {"classification": "Noun", "word": "boss"},
    {"classification": "Verb", "word": "boss"},
    {"classification": "Noun", "word": "boston"},
    {"classification": "Pronoun", "word": "both"},
    {"classification": "Verb", "word": "bother"},
    {"classification": "Noun", "word": "bother"},
    {"classification": "Verb", "word": "bottle"},
    {"classification": "Noun", "word": "bottle"},
    {"classification": "Adjective", "word": "bottom"},
    {"classification": "Verb", "word": "bottom"},
    {"classification": "Noun", "word": "bottom"},
    {"classification": "Noun", "word": "bought"},
    {"classification": "Noun", "word": "bound"},
    {"classification": "Verb", "word": "bound"},
    {"classification": "Verb", "word": "bow"},
    {"classification": "Noun", "word": "bow"},
    {"classification": "Verb", "word": "bowl"},
    {"classification": "Noun", "word": "bowl"},
    {"classification": "Noun", "word": "box"},
    {"classification": "Verb", "word": "box"},
    {"classification": "Noun", "word": "boy"},
    {"classification": "Verb", "word": "boy"},
    {"classification": "Noun", "word": "brain"},
    {"classification": "Verb", "word": "brain"},
    {"classification": "Verb", "word": "branch"},
    {"classification": "Noun", "word": "branch"},
    {"classification": "Adjective", "word": "branch"},
    {"classification": "Noun", "word": "brass"},
    {"classification": "Verb", "word": "brave"},
    {"classification": "Adjective", "word": "brave"},
    {"classification": "Noun", "word": "brave"},
    {"classification": "Noun", "word": "bravery"},
    {"classification": "Verb", "word": "bread"},
    {"classification": "Adjective", "word": "bread"},
    {"classification": "Noun", "word": "bread"},
    {"classification": "Adjective", "word": "breadth"},
    {"classification": "Verb", "word": "break"},
    {"classification": "Noun", "word": "break"},
    {"classification": "Verb", "word": "breakfast"},
    {"classification": "Noun", "word": "breakfast"},
    {"classification": "Noun", "word": "breath"},
    {"classification": "Verb", "word": "breathe"},
    {"classification": "Noun", "word": "breed"},
    {"classification": "Verb", "word": "breed"},
    {"classification": "Noun", "word": "bribe"},
    {"classification": "Verb", "word": "bribe"},
    {"classification": "Noun", "word": "brick"},
    {"classification": "Verb", "word": "brick"},
    {"classification": "Noun", "word": "bride"},
    {"classification": "Verb", "word": "bride"},
    {"classification": "Noun", "word": "bridge"},
    {"classification": "Verb", "word": "bridge"},
    {"classification": "Noun", "word": "brief"},
    {"classification": "Verb", "word": "brief"},
    {"classification": "Adverb", "word": "brief"},
    {"classification": "Adjective", "word": "brief"},
    {"classification": "Adverb", "word": "briefly"},
    {"classification": "Noun", "word": "bright"},
    {"classification": "Adjective", "word": "bright"},
    {"classification": "Adverb", "word": "bright"},
    {"classification": "Verb", "word": "bright"},
    {"classification": "Adjective", "word": "brighten"},
    {"classification": "Verb", "word": "brighten"},
    {"classification": "Adjective", "word": "brilliant"},
    {"classification": "Verb", "word": "bring"},
    {"classification": "Noun", "word": "british"},
    {"classification": "Adjective", "word": "british"},
    {"classification": "Noun", "word": "broad"},
    {"classification": "Adjective", "word": "broad"},
    {"classification": "Noun", "word": "broadcast"},
    {"classification": "Adjective", "word": "broadcast"},
    {"classification": "Adverb", "word": "broadcast"},
    {"classification": "Verb", "word": "broke"},
    {"classification": "Verb", "word": "broken"},
    {"classification": "Adjective", "word": "bronchial"},
    {"classification": "Verb", "word": "brother"},
    {"classification": "Noun", "word": "brown"},
    {"classification": "Adjective", "word": "brown"},
    {"classification": "Verb", "word": "brown"},
    {"classification": "Noun", "word": "brush"},
    {"classification": "Verb", "word": "brush"},
    {"classification": "Noun", "word": "bubble"},
    {"classification": "Noun", "word": "buck"},
    {"classification": "Verb", "word": "buck"},
    {"classification": "Noun", "word": "bucket"},
    {"classification": "Verb", "word": "bucket"},
    {"classification": "Noun", "word": "budget"},
    {"classification": "Noun", "word": "build"},
    {"classification": "Verb", "word": "build"},
    {"classification": "Noun", "word": "builder"},
    {"classification": "Noun", "word": "building"},
    {"classification": "Noun", "word": "built"},
    {"classification": "Adjective", "word": "built"},
    {"classification": "Noun", "word": "bulk"},
    {"classification": "Verb", "word": "bulk"},
    {"classification": "Noun", "word": "bullet"},
    {"classification": "Noun", "word": "bunch"},
    {"classification": "Verb", "word": "bunch"},
    {"classification": "Noun", "word": "bundle"},
    {"classification": "Verb", "word": "bundle"},
    {"classification": "Noun", "word": "burden"},
    {"classification": "Verb", "word": "burden"},
    {"classification": "Noun", "word": "bureau"},
    {"classification": "Noun", "word": "burn"},
    {"classification": "Verb", "word": "burn"},
    {"classification": "Noun", "word": "burning"},
    {"classification": "Adjective", "word": "burning"},
    {"classification": "Noun", "word": "burst"},
    {"classification": "Verb", "word": "burst"},
    {"classification": "Noun", "word": "bury"},
    {"classification": "Verb", "word": "bury"},
    {"classification": "Noun", "word": "bus"},
    {"classification": "Verb", "word": "bush"},
    {"classification": "Noun", "word": "bush"},
    {"classification": "Noun", "word": "business"},
    {"classification": "Adjective", "word": "businesslike"},
    {"classification": "Adjective", "word": "busy"},
    {"classification": "Verb", "word": "busy"},
    {"classification": "CoordConjunction", "word": "but"},
    {"classification": "Noun", "word": "but"},
    {"classification": "Verb", "word": "but"},
    {"classification": "Noun", "word": "butter"},
    {"classification": "Verb", "word": "butter"},
    {"classification": "Noun", "word": "button"},
    {"classification": "Verb", "word": "button"},
    {"classification": "Verb", "word": "buy"},
    {"classification": "Preposition", "word": "by"},
    {"classification": "Adjective", "word": "by"},
    {"classification": "Adverb", "word": "by"},
    {"classification": "Noun", "word": "cabin"},
    {"classification": "Verb", "word": "cabin"},
    {"classification": "Noun", "word": "cady"},
    {"classification": "Noun", "word": "cafe"},
    {"classification": "Verb", "word": "cage"},
    {"classification": "Noun", "word": "cage"},
    {"classification": "Noun", "word": "cake"},
    {"classification": "Verb", "word": "cake"},
    {"classification": "Verb", "word": "calculate"},
    {"classification": "Noun", "word": "calendar"},
    {"classification": "Verb", "word": "calendar"},
    {"classification": "Noun", "word": "calif"},
    {"classification": "Noun", "word": "call"},
    {"classification": "Verb", "word": "call"},
    {"classification": "Noun", "word": "calling"},
    {"classification": "Noun", "word": "calm"},
    {"classification": "Noun", "word": "came"},
    {"classification": "Verb", "word": "came"},
    {"classification": "Noun", "word": "camera"},
    {"classification": "Verb", "word": "camp"},
    {"classification": "Noun", "word": "camp"},
    {"classification": "Verb", "word": "campaign"},
    {"classification": "Noun", "word": "campaign"},
    {"classification": "Noun", "word": "campus"},
    {"classification": "Verb", "word": "can"},
    {"classification": "Noun", "word": "can"},
    {"classification": "Noun", "word": "canada"},
    {"classification": "Noun", "word": "canal"},
    {"classification": "Verb", "word": "cancel"},
    {"classification": "Noun", "word": "cancer"},
    {"classification": "Noun", "word": "cap"},
    {"classification": "Verb", "word": "cap"},
    {"classification": "Noun", "word": "capabilities"},
    {"classification": "Adjective", "word": "capable"},
    {"classification": "Verb", "word": "cape"},
    {"classification": "Noun", "word": "cape"},
    {"classification": "Adjective", "word": "capital"},
    {"classification": "Verb", "word": "captain"},
    {"classification": "Noun", "word": "captain"},
    {"classification": "Adjective", "word": "captain"},
    {"classification": "Noun", "word": "capture"},
    {"classification": "Verb", "word": "capture"},
    {"classification": "Noun", "word": "car"},
    {"classification": "Noun", "word": "carbon"},
    {"classification": "Verb", "word": "card"},
    {"classification": "Noun", "word": "card"},
    {"classification": "Noun", "word": "care"},
    {"classification": "Noun", "word": "career"},
    {"classification": "Verb", "word": "career"},
    {"classification": "Adjective", "word": "careful"},
    {"classification": "Adverb", "word": "carefully"},
    {"classification": "Noun", "word": "carl"},
    {"classification": "Noun", "word": "carriage"},
    {"classification": "Verb", "word": "carry"},
    {"classification": "Noun", "word": "carry"},
    {"classification": "Noun", "word": "carrying"},
    {"classification": "Verb", "word": "cart"},
    {"classification": "Noun", "word": "cart"},
    {"classification": "Noun", "word": "case"},
    {"classification": "Verb", "word": "case"},
    {"classification": "Noun", "word": "cash"},
    {"classification": "Verb", "word": "cash"},
    {"classification": "Noun", "word": "cast"},
    {"classification": "Verb", "word": "cast"},
    {"classification": "Noun", "word": "castle"},
    {"classification": "Verb", "word": "castle"},
    {"classification": "Adjective", "word": "casual"},
    {"classification": "Noun", "word": "casual"},
    {"classification": "Verb", "word": "cat"},
    {"classification": "Noun", "word": "cat"},
    {"classification": "Noun", "word": "catalogue"},
    {"classification": "Verb", "word": "catalogue"},
    {"classification": "Verb", "word": "catch"},
    {"classification": "Noun", "word": "catch"},
    {"classification": "Noun", "word": "categories"},
    {"classification": "Verb", "word": "cater"},
    {"classification": "Noun", "word": "cater"},
    {"classification": "Noun", "word": "catholic"},
    {"classification": "Adjective", "word": "catholic"},
    {"classification": "Noun", "word": "cattle"},
    {"classification": "Verb", "word": "cause"},
    {"classification": "Noun", "word": "cause"},
    {"classification": "Verb", "word": "caution"},
    {"classification": "Noun", "word": "caution"},
    {"classification": "Adjective", "word": "cautious"},
    {"classification": "Noun", "word": "cavalry"},
    {"classification": "Noun", "word": "cave"},
    {"classification": "Verb", "word": "cave"},
    {"classification": "Verb", "word": "cease"},
    {"classification": "Noun", "word": "cease"},
    {"classification": "Verb", "word": "ceiling"},
    {"classification": "Noun", "word": "cell"},
    {"classification": "Verb", "word": "cell"},
    {"classification": "Noun", "word": "cellar"},
    {"classification": "Noun", "word": "cent"},
    {"classification": "Verb", "word": "center"},
    {"classification": "Noun", "word": "center"},
    {"classification": "Adjective", "word": "central"},
    {"classification": "Noun", "word": "certain"},
    {"classification": "Adjective", "word": "certain"},
    {"classification": "Adverb", "word": "certain"},
    {"classification": "Adverb", "word": "certainly"},
    {"classification": "Verb", "word": "chain"},
    {"classification": "Noun", "word": "chain"},
    {"classification": "Verb", "word": "chair"},
    {"classification": "Noun", "word": "chair"},
    {"classification": "Noun", "word": "chairman"},
    {"classification": "Verb", "word": "chalk"},
    {"classification": "Noun", "word": "chalk"},
    {"classification": "Noun", "word": "challenge"},
    {"classification": "Verb", "word": "challenge"},
    {"classification": "Verb", "word": "chamber"},
    {"classification": "Noun", "word": "chamber"},
    {"classification": "Verb", "word": "champion"},
    {"classification": "Verb", "word": "chance"},
    {"classification": "Adjective", "word": "chance"},
    {"classification": "Adverb", "word": "chance"},
    {"classification": "Noun", "word": "chance"},
    {"classification": "Noun", "word": "chandler"},
    {"classification": "Verb", "word": "change"},
    {"classification": "Verb", "word": "channel"},
    {"classification": "Noun", "word": "channel"},
    {"classification": "Noun", "word": "chapel"},
    {"classification": "Verb", "word": "chapel"},
    {"classification": "Noun", "word": "chapter"},
    {"classification": "Verb", "word": "chapter"},
    {"classification": "Verb", "word": "character"},
    {"classification": "Adjective", "word": "characteristic"},
    {"classification": "Noun", "word": "charge"},
    {"classification": "Verb", "word": "charge"},
    {"classification": "Noun", "word": "charlie"},
    {"classification": "Noun", "word": "charm"},
    {"classification": "Verb", "word": "charm"},
    {"classification": "Adjective", "word": "charming"},
    {"classification": "Noun", "word": "chart"},
    {"classification": "Verb", "word": "chart"},
    {"classification": "Verb", "word": "charter"},
    {"classification": "Adverb", "word": "cheap"},
    {"classification": "Verb", "word": "cheap"},
    {"classification": "Noun", "word": "cheap"},
    {"classification": "Noun", "word": "cheat"},
    {"classification": "Verb", "word": "cheat"},
    {"classification": "Noun", "word": "check"},
    {"classification": "Verb", "word": "check"},
    {"classification": "Adjective", "word": "check"},
    {"classification": "Noun", "word": "cheek"},
    {"classification": "Verb", "word": "cheek"},
    {"classification": "Verb", "word": "cheer"},
    {"classification": "Noun", "word": "cheer"},
    {"classification": "Noun", "word": "cheese"},
    {"classification": "Adjective", "word": "chemical"},
    {"classification": "Noun", "word": "chest"},
    {"classification": "Verb", "word": "chest"},
    {"classification": "Noun", "word": "chicken"},
    {"classification": "Noun", "word": "chief"},
    {"classification": "Adjective", "word": "chief"},
    {"classification": "Adverb", "word": "chiefly"},
    {"classification": "Verb", "word": "child"},
    {"classification": "Noun", "word": "child"},
    {"classification": "Noun", "word": "childhood"},
    {"classification": "Noun", "word": "children"},
    {"classification": "Noun", "word": "chimney"},
    {"classification": "Noun", "word": "chin"},
    {"classification": "Noun", "word": "china"},
    {"classification": "Adjective", "word": "chinese"},
    {"classification": "Noun", "word": "choice"},
    {"classification": "Adjective", "word": "choice"},
    {"classification": "Verb", "word": "choose"},
    {"classification": "Noun", "word": "chose"},
    {"classification": "Verb", "word": "chose"},
    {"classification": "Noun", "word": "chosen"},
    {"classification": "Noun", "word": "christ"},
    {"classification": "Adjective", "word": "christian"},
    {"classification": "Verb", "word": "church"},
    {"classification": "Noun", "word": "church"},
    {"classification": "Noun", "word": "cigarette"},
    {"classification": "Noun", "word": "circle"},
    {"classification": "Verb", "word": "circle"},
    {"classification": "Noun", "word": "circuit"},
    {"classification": "Verb", "word": "circuit"},
    {"classification": "Adjective", "word": "circular"},
    {"classification": "Verb", "word": "circulate"},
    {"classification": "Verb", "word": "circumstance"},
    {"classification": "Noun", "word": "cities"},
    {"classification": "Noun", "word": "citizen"},
    {"classification": "Adjective", "word": "citizen"},
    {"classification": "Adjective", "word": "city"},
    {"classification": "Noun", "word": "city"},
    {"classification": "Adjective", "word": "civic"},
    {"classification": "Adjective", "word": "civil"},
    {"classification": "Noun", "word": "civilian"},
    {"classification": "Verb", "word": "civilize"},
    {"classification": "Noun", "word": "claim"},
    {"classification": "Verb", "word": "claim"},
    {"classification": "Verb", "word": "clarify"},
    {"classification": "Verb", "word": "classification"},
    {"classification": "Noun", "word": "classification"},
    {"classification": "Noun", "word": "classes"},
    {"classification": "Noun", "word": "classic"},
    {"classification": "Verb", "word": "classify"},
    {"classification": "Verb", "word": "clay"},
    {"classification": "Noun", "word": "clay"},
    {"classification": "Adjective", "word": "clean"},
    {"classification": "Adverb", "word": "clean"},
    {"classification": "Noun", "word": "cleaning"},
    {"classification": "Noun", "word": "clear"},
    {"classification": "Verb", "word": "clear"},
    {"classification": "Adjective", "word": "clear"},
    {"classification": "Adverb", "word": "clear"},
    {"classification": "Adverb", "word": "clearly"},
    {"classification": "Noun", "word": "clerk"},
    {"classification": "Adjective", "word": "clever"},
    {"classification": "Noun", "word": "client"},
    {"classification": "Noun", "word": "cliff"},
    {"classification": "Verb", "word": "climate"},
    {"classification": "Verb", "word": "climb"},
    {"classification": "Noun", "word": "climb"},
    {"classification": "Verb", "word": "clinic"},
    {"classification": "Noun", "word": "clinic"},
    {"classification": "Verb", "word": "clinical"},
    {"classification": "Noun", "word": "clock"},
    {"classification": "Verb", "word": "clock"},
    {"classification": "Adverb", "word": "close"},
    {"classification": "Noun", "word": "close"},
    {"classification": "Verb", "word": "close"},
    {"classification": "Adverb", "word": "closely"},
    {"classification": "Noun", "word": "closer"},
    {"classification": "Noun", "word": "cloth"},
    {"classification": "Verb", "word": "clothe"},
    {"classification": "Noun", "word": "clothes"},
    {"classification": "Verb", "word": "cloud"},
    {"classification": "Noun", "word": "cloud"},
    {"classification": "Noun", "word": "club"},
    {"classification": "Verb", "word": "club"},
    {"classification": "Verb", "word": "coach"},
    {"classification": "Noun", "word": "coach"},
    {"classification": "Verb", "word": "coal"},
    {"classification": "Noun", "word": "coal"},
    {"classification": "Adjective", "word": "coarse"},
    {"classification": "Verb", "word": "coast"},
    {"classification": "Noun", "word": "coast"},
    {"classification": "Noun", "word": "coat"},
    {"classification": "Verb", "word": "coat"},
    {"classification": "Noun", "word": "coating"},
    {"classification": "Noun", "word": "cocktail"},
    {"classification": "Noun", "word": "code"},
    {"classification": "Adjective", "word": "coefficient"},
    {"classification": "Noun", "word": "coffee"},
    {"classification": "Adjective", "word": "cogent"},
    {"classification": "Noun", "word": "coin"},
    {"classification": "Verb", "word": "coin"},
    {"classification": "Verb", "word": "coincide"},
    {"classification": "Noun", "word": "cold"},
    {"classification": "Verb", "word": "cold"},
    {"classification": "Noun", "word": "collapse"},
    {"classification": "Verb", "word": "collapse"},
    {"classification": "Noun", "word": "collar"},
    {"classification": "Verb", "word": "collar"},
    {"classification": "Verb", "word": "collect"},
    {"classification": "Adjective", "word": "collected"},
    {"classification": "Adjective", "word": "collective"},
    {"classification": "Verb", "word": "collide"},
    {"classification": "Adjective", "word": "colloquial"},
    {"classification": "Noun", "word": "colonel"},
    {"classification": "Adjective", "word": "colonial"},
    {"classification": "Noun", "word": "colony"},
    {"classification": "Noun", "word": "color"},
    {"classification": "Verb", "word": "color"},
    {"classification": "Adjective", "word": "colored"},
    {"classification": "Noun", "word": "column"},
    {"classification": "Noun", "word": "comb"},
    {"classification": "Verb", "word": "comb"},
    {"classification": "Noun", "word": "combat"},
    {"classification": "Verb", "word": "combat"},
    {"classification": "Noun", "word": "combination"},
    {"classification": "Verb", "word": "combine"},
    {"classification": "Adjective", "word": "combined"},
    {"classification": "Noun", "word": "come"},
    {"classification": "Verb", "word": "come"},
    {"classification": "Noun", "word": "comedy"},
    {"classification": "Noun", "word": "comes"},
    {"classification": "Noun", "word": "comfort"},
    {"classification": "Verb", "word": "comfort"},
    {"classification": "Adjective", "word": "comfortable"},
    {"classification": "Noun", "word": "coming"},
    {"classification": "Adjective", "word": "coming"},
    {"classification": "Verb", "word": "command"},
    {"classification": "Noun", "word": "command"},
    {"classification": "Verb", "word": "comment"},
    {"classification": "Verb", "word": "commerce"},
    {"classification": "Noun", "word": "commerce"},
    {"classification": "Adjective", "word": "commercial"},
    {"classification": "Verb", "word": "commission"},
    {"classification": "Verb", "word": "commit"},
    {"classification": "Verb", "word": "committee"},
    {"classification": "Noun", "word": "common"},
    {"classification": "Verb", "word": "common"},
    {"classification": "Adverb", "word": "commonly"},
    {"classification": "Verb", "word": "commune"},
    {"classification": "Verb", "word": "communicate"},
    {"classification": "Verb", "word": "companion"},
    {"classification": "Verb", "word": "company"},
    {"classification": "Adjective", "word": "comparable"},
    {"classification": "Verb", "word": "compare"},
    {"classification": "Verb", "word": "comparison"},
    {"classification": "Verb", "word": "compel"},
    {"classification": "Verb", "word": "compensate"},
    {"classification": "Verb", "word": "compete"},
    {"classification": "Noun", "word": "competence"},
    {"classification": "Adjective", "word": "competent"},
    {"classification": "Adjective", "word": "competitive"},
    {"classification": "Verb", "word": "complain"},
    {"classification": "Verb", "word": "complement"},
    {"classification": "Adjective", "word": "complete"},
    {"classification": "Verb", "word": "complete"},
    {"classification": "Adverb", "word": "completely"},
    {"classification": "Adjective", "word": "complex"},
    {"classification": "Verb", "word": "complicate"},
    {"classification": "Adjective", "word": "complicate"},
    {"classification": "Verb", "word": "comply"},
    {"classification": "Noun", "word": "component"},
    {"classification": "Verb", "word": "component"},
    {"classification": "Verb", "word": "compose"},
    {"classification": "Adjective", "word": "composed"},
    {"classification": "Noun", "word": "composer"},
    {"classification": "Noun", "word": "compound"},
    {"classification": "Verb", "word": "compound"},
    {"classification": "Verb", "word": "comprehend"},
    {"classification": "Verb", "word": "comprise"},
    {"classification": "Verb", "word": "compromise"},
    {"classification": "Noun", "word": "compulsion"},
    {"classification": "Verb", "word": "compute"},
    {"classification": "Verb", "word": "conceive"},
    {"classification": "Verb", "word": "concentrate"},
    {"classification": "Adjective", "word": "concentric"},
    {"classification": "Noun", "word": "concept"},
    {"classification": "Verb", "word": "concern"},
    {"classification": "Noun", "word": "concern"},
    {"classification": "Verb", "word": "concert"},
    {"classification": "Verb", "word": "conclude"},
    {"classification": "Verb", "word": "concrete"},
    {"classification": "Adjective", "word": "concrete"},
    {"classification": "Adjective", "word": "condemned"},
    {"classification": "Adjective", "word": "condense"},
    {"classification": "Verb", "word": "condense"},
    {"classification": "Verb", "word": "condition"},
    {"classification": "Noun", "word": "condition"},
    {"classification": "Adjective", "word": "conditioned"},
    {"classification": "Verb", "word": "conduct"},
    {"classification": "Verb", "word": "confer"},
    {"classification": "Verb", "word": "confess"},
    {"classification": "Adjective", "word": "confident"},
    {"classification": "Adjective", "word": "confidential"},
    {"classification": "Noun", "word": "configuration"},
    {"classification": "Noun", "word": "confine"},
    {"classification": "Verb", "word": "confine"},
    {"classification": "Verb", "word": "conflict"},
    {"classification": "Verb", "word": "conform"},
    {"classification": "Adjective", "word": "conform"},
    {"classification": "Verb", "word": "confront"},
    {"classification": "Verb", "word": "confuse"},
    {"classification": "Adjective", "word": "confuse"},
    {"classification": "Noun", "word": "congo"},
    {"classification": "Verb", "word": "congratulate"},
    {"classification": "Noun", "word": "congratulation"},
    {"classification": "Noun", "word": "congregation"},
    {"classification": "Adjective", "word": "congressional"},
    {"classification": "Noun", "word": "conjunction"},
    {"classification": "Verb", "word": "connect"},
    {"classification": "Noun", "word": "connection"},
    {"classification": "Verb", "word": "conquer"},
    {"classification": "Noun", "word": "conscience"},
    {"classification": "Adjective", "word": "conscious"},
    {"classification": "Verb", "word": "consent"},
    {"classification": "Noun", "word": "consequence"},
    {"classification": "Adjective", "word": "consequent"},
    {"classification": "Adverb", "word": "consequently"},
    {"classification": "Adjective", "word": "conservative"},
    {"classification": "Verb", "word": "conserve"},
    {"classification": "Verb", "word": "consider"},
    {"classification": "Adjective", "word": "considerable"},
    {"classification": "Adverb", "word": "considerably"},
    {"classification": "Verb", "word": "consist"},
    {"classification": "Adjective", "word": "consistent"},
    {"classification": "Adverb", "word": "consistently"},
    {"classification": "Verb", "word": "console"},
    {"classification": "Verb", "word": "constant"},
    {"classification": "Adverb", "word": "constantly"},
    {"classification": "Verb", "word": "constitute"},
    {"classification": "Adjective", "word": "constitutional"},
    {"classification": "Adjective", "word": "construct"},
    {"classification": "Verb", "word": "construct"},
    {"classification": "Verb", "word": "consult"},
    {"classification": "Verb", "word": "consume"},
    {"classification": "Noun", "word": "consumer"},
    {"classification": "Noun", "word": "contact"},
    {"classification": "Verb", "word": "contain"},
    {"classification": "Adjective", "word": "contaminate"},
    {"classification": "Verb", "word": "contaminate"},
    {"classification": "Verb", "word": "contemplate"},
    {"classification": "Adjective", "word": "contemporary"},
    {"classification": "Verb", "word": "contend"},
    {"classification": "Adjective", "word": "content"},
    {"classification": "Verb", "word": "contest"},
    {"classification": "Noun", "word": "context"},
    {"classification": "Adjective", "word": "context"},
    {"classification": "Verb", "word": "context"},
    {"classification": "Adjective", "word": "continent"},
    {"classification": "Adjective", "word": "continental"},
    {"classification": "Adjective", "word": "contingent"},
    {"classification": "Adverb", "word": "continually"},
    {"classification": "Verb", "word": "continue"},
    {"classification": "Adjective", "word": "continuous"},
    {"classification": "Adverb", "word": "continuously"},
    {"classification": "Adjective", "word": "contract"},
    {"classification": "Verb", "word": "contract"},
    {"classification": "Verb", "word": "contradict"},
    {"classification": "Adjective", "word": "contrary"},
    {"classification": "Verb", "word": "contrast"},
    {"classification": "Verb", "word": "contribute"},
    {"classification": "Verb", "word": "control"},
    {"classification": "Noun", "word": "control"},
    {"classification": "Verb", "word": "convene"},
    {"classification": "Verb", "word": "convenient"},
    {"classification": "Verb", "word": "convention"},
    {"classification": "Adjective", "word": "conventional"},
    {"classification": "Verb", "word": "converge"},
    {"classification": "Adjective", "word": "converse"},
    {"classification": "Verb", "word": "converse"},
    {"classification": "Verb", "word": "convert"},
    {"classification": "Verb", "word": "cook"},
    {"classification": "Noun", "word": "cook"},
    {"classification": "Noun", "word": "cool"},
    {"classification": "Verb", "word": "cool"},
    {"classification": "Adjective", "word": "cool"},
    {"classification": "Verb", "word": "cooperate"},
    {"classification": "Adjective", "word": "cooperative"},
    {"classification": "Verb", "word": "coordinate"},
    {"classification": "Adjective", "word": "coordinate"},
    {"classification": "Noun", "word": "cope"},
    {"classification": "Verb", "word": "cope"},
    {"classification": "Verb", "word": "copper"},
    {"classification": "Noun", "word": "copper"},
    {"classification": "Verb", "word": "copy"},
    {"classification": "Noun", "word": "copy"},
    {"classification": "Verb", "word": "core"},
    {"classification": "Noun", "word": "core"},
    {"classification": "Verb", "word": "cork"},
    {"classification": "Noun", "word": "cork"},
    {"classification": "Verb", "word": "corn"},
    {"classification": "Noun", "word": "corn"},
    {"classification": "Noun", "word": "corner"},
    {"classification": "Verb", "word": "corner"},
    {"classification": "Verb", "word": "corporate"},
    {"classification": "Adjective", "word": "corporate"},
    {"classification": "Noun", "word": "corps"},
    {"classification": "Adjective", "word": "correct"},
    {"classification": "Verb", "word": "correct"},
    {"classification": "Noun", "word": "correction"},
    {"classification": "Verb", "word": "correlate"},
    {"classification": "Noun", "word": "correlate"},
    {"classification": "Verb", "word": "correspond"},
    {"classification": "Noun", "word": "correspondence"},
    {"classification": "Adjective", "word": "corresponding"},
    {"classification": "Verb", "word": "cost"},
    {"classification": "Noun", "word": "cost"},
    {"classification": "Noun", "word": "cottage"},
    {"classification": "Verb", "word": "cotton"},
    {"classification": "Noun", "word": "cotton"},
    {"classification": "Verb", "word": "cough"},
    {"classification": "Verb", "word": "could"},
    {"classification": "Noun", "word": "council"},
    {"classification": "Verb", "word": "count"},
    {"classification": "Noun", "word": "count"},
    {"classification": "Verb", "word": "counter"},
    {"classification": "Adverb", "word": "counter"},
    {"classification": "Adjective", "word": "counter"},
    {"classification": "Noun", "word": "counties"},
    {"classification": "Adverb", "word": "country"},
    {"classification": "Adjective", "word": "country"},
    {"classification": "Noun", "word": "county"},
    {"classification": "Adjective", "word": "couple"},
    {"classification": "Verb", "word": "couple"},
    {"classification": "Noun", "word": "courage"},
    {"classification": "Verb", "word": "course"},
    {"classification": "Noun", "word": "course"},
    {"classification": "Verb", "word": "court"},
    {"classification": "Noun", "word": "court"},
    {"classification": "Noun", "word": "cousin"},
    {"classification": "Noun", "word": "cover"},
    {"classification": "Verb", "word": "cover"},
    {"classification": "Noun", "word": "coverage"},
    {"classification": "Adjective", "word": "covered"},
    {"classification": "Noun", "word": "covering"},
    {"classification": "Verb", "word": "cow"},
    {"classification": "Noun", "word": "cow"},
    {"classification": "Adjective", "word": "coward"},
    {"classification": "Verb", "word": "coward"},
    {"classification": "Noun", "word": "coward"},
    {"classification": "Adjective", "word": "crack"},
    {"classification": "Noun", "word": "crack"},
    {"classification": "Verb", "word": "crack"},
    {"classification": "Noun", "word": "craft"},
    {"classification": "Verb", "word": "craft"},
    {"classification": "Noun", "word": "crash"},
    {"classification": "Verb", "word": "crash"},
    {"classification": "Adjective", "word": "crazy"},
    {"classification": "Verb", "word": "cream"},
    {"classification": "Noun", "word": "cream"},
    {"classification": "Verb", "word": "create"},
    {"classification": "Adjective", "word": "create"},
    {"classification": "Adjective", "word": "creative"},
    {"classification": "Noun", "word": "creature"},
    {"classification": "Adjective", "word": "credible"},
    {"classification": "Noun", "word": "credit"},
    {"classification": "Verb", "word": "credit"},
    {"classification": "Noun", "word": "creep"},
    {"classification": "Verb", "word": "creep"},
    {"classification": "Verb", "word": "crew"},
    {"classification": "Noun", "word": "crew"},
    {"classification": "Noun", "word": "crime"},
    {"classification": "Adjective", "word": "criminal"},
    {"classification": "Noun", "word": "criminal"},
    {"classification": "Noun", "word": "crises"},
    {"classification": "Noun", "word": "crisis"},
    {"classification": "Noun", "word": "critic"},
    {"classification": "Adjective", "word": "critic"},
    {"classification": "Verb", "word": "critic"},
    {"classification": "Verb", "word": "crop"},
    {"classification": "Noun", "word": "crop"},
    {"classification": "Preposition", "word": "cross"},
    {"classification": "Adjective", "word": "cross"},
    {"classification": "Verb", "word": "cross"},
    {"classification": "Noun", "word": "cross"},
    {"classification": "Verb", "word": "crossing"},
    {"classification": "Verb", "word": "crowd"},
    {"classification": "Noun", "word": "crowd"},
    {"classification": "Noun", "word": "crown"},
    {"classification": "Adjective", "word": "crucial"},
    {"classification": "Noun", "word": "cruel"},
    {"classification": "Adjective", "word": "cruel"},
    {"classification": "Noun", "word": "crush"},
    {"classification": "Verb", "word": "crush"},
    {"classification": "Verb", "word": "cry"},
    {"classification": "Adjective", "word": "crystal"},
    {"classification": "Noun", "word": "crystal"},
    {"classification": "Noun", "word": "cuban"},
    {"classification": "Adjective", "word": "cuban"},
    {"classification": "Verb", "word": "cultivate"},
    {"classification": "Noun", "word": "cultivation"},
    {"classification": "Adjective", "word": "cultural"},
    {"classification": "Noun", "word": "culture"},
    {"classification": "Verb", "word": "culture"},
    {"classification": "Adjective", "word": "cumbersome"},
    {"classification": "Noun", "word": "cup"},
    {"classification": "Verb", "word": "cup"},
    {"classification": "Verb", "word": "cupboard"},
    {"classification": "Noun", "word": "cupboard"},
    {"classification": "Verb", "word": "cure"},
    {"classification": "Noun", "word": "cure"},
    {"classification": "Adjective", "word": "curious"},
    {"classification": "Verb", "word": "curl"},
    {"classification": "Noun", "word": "curl"},
    {"classification": "Adjective", "word": "current"},
    {"classification": "Adverb", "word": "currently"},
    {"classification": "Verb", "word": "curse"},
    {"classification": "Adjective", "word": "curt"},
    {"classification": "Verb", "word": "curtain"},
    {"classification": "Verb", "word": "curve"},
    {"classification": "Adjective", "word": "curve"},
    {"classification": "Verb", "word": "cushion"},
    {"classification": "Noun", "word": "cushion"},
    {"classification": "Verb", "word": "custom"},
    {"classification": "Noun", "word": "custom"},
    {"classification": "Adjective", "word": "customary"},
    {"classification": "Adjective", "word": "cut"},
    {"classification": "Verb", "word": "cut"},
    {"classification": "Noun", "word": "cut"},
    {"classification": "Adjective", "word": "cutting"},
    {"classification": "Noun", "word": "cutting"},
    {"classification": "Noun", "word": "cycle"},
    {"classification": "Verb", "word": "cycle"},
    {"classification": "Noun", "word": "cylinder"},
    {"classification": "Noun", "word": "daily"},
    {"classification": "Adjective", "word": "daily"},
    {"classification": "Adverb", "word": "daily"},
    {"classification": "Verb", "word": "damage"},
    {"classification": "Noun", "word": "damage"},
    {"classification": "Verb", "word": "damn"},
    {"classification": "Adjective", "word": "damp"},
    {"classification": "Noun", "word": "damp"},
    {"classification": "Noun", "word": "dan"},
    {"classification": "Verb", "word": "dance"},
    {"classification": "Noun", "word": "dancer"},
    {"classification": "Verb", "word": "danger"},
    {"classification": "Noun", "word": "danger"},
    {"classification": "Adjective", "word": "dangerous"},
    {"classification": "Verb", "word": "dare"},
    {"classification": "Noun", "word": "dare"},
    {"classification": "Adjective", "word": "dark"},
    {"classification": "Verb", "word": "dark"},
    {"classification": "Noun", "word": "dark"},
    {"classification": "Adjective", "word": "darken"},
    {"classification": "Verb", "word": "darken"},
    {"classification": "Noun", "word": "darkness"},
    {"classification": "Noun", "word": "data"},
    {"classification": "Verb", "word": "date"},
    {"classification": "Noun", "word": "date"},
    {"classification": "Noun", "word": "daughter"},
    {"classification": "Verb", "word": "dawn"},
    {"classification": "Noun", "word": "dawn"},
    {"classification": "Noun", "word": "day"},
    {"classification": "Noun", "word": "daylight"},
    {"classification": "Noun", "word": "dead"},
    {"classification": "Adjective", "word": "dead"},
    {"classification": "Adverb", "word": "dead"},
    {"classification": "Verb", "word": "dead"},
    {"classification": "Adjective", "word": "deaf"},
    {"classification": "Verb", "word": "deaf"},
    {"classification": "Verb", "word": "deafen"},
    {"classification": "Verb", "word": "deal"},
    {"classification": "Noun", "word": "deal"},
    {"classification": "Noun", "word": "dealer"},
    {"classification": "Noun", "word": "dealing"},
    {"classification": "Noun", "word": "dean"},
    {"classification": "Adverb", "word": "dear"},
    {"classification": "Noun", "word": "dear"},
    {"classification": "Verb", "word": "dear"},
    {"classification": "Adjective", "word": "dear"},
    {"classification": "Verb", "word": "death"},
    {"classification": "Verb", "word": "debate"},
    {"classification": "Noun", "word": "debt"},
    {"classification": "Noun", "word": "decade"},
    {"classification": "Verb", "word": "decay"},
    {"classification": "Noun", "word": "decay"},
    {"classification": "Noun", "word": "deceit"},
    {"classification": "Verb", "word": "deceive"},
    {"classification": "Adjective", "word": "decent"},
    {"classification": "Verb", "word": "decide"},
    {"classification": "Adjective", "word": "decided"},
    {"classification": "Adjective", "word": "decimal"},
    {"classification": "Noun", "word": "decimal"},
    {"classification": "Noun", "word": "decision"},
    {"classification": "Adjective", "word": "decisive"},
    {"classification": "Verb", "word": "deck"},
    {"classification": "Noun", "word": "deck"},
    {"classification": "Verb", "word": "declare"},
    {"classification": "Verb", "word": "decline"},
    {"classification": "Verb", "word": "decrease"},
    {"classification": "Noun", "word": "decrease"},
    {"classification": "Verb", "word": "dedicate"},
    {"classification": "Adjective", "word": "deed"},
    {"classification": "Verb", "word": "deed"},
    {"classification": "Adverb", "word": "deep"},
    {"classification": "Adjective", "word": "deep"},
    {"classification": "Noun", "word": "deep"},
    {"classification": "Verb", "word": "deepen"},
    {"classification": "Adverb", "word": "deeply"},
    {"classification": "Verb", "word": "defeat"},
    {"classification": "Verb", "word": "defect"},
    {"classification": "Noun", "word": "defect"},
    {"classification": "Verb", "word": "defend"},
    {"classification": "Adjective", "word": "defendant"},
    {"classification": "Noun", "word": "defendant"},
    {"classification": "Verb", "word": "defense"},
    {"classification": "Verb", "word": "defer"},
    {"classification": "Adjective", "word": "deficient"},
    {"classification": "Verb", "word": "define"},
    {"classification": "Adjective", "word": "definite"},
    {"classification": "Noun", "word": "definite"},
    {"classification": "Adverb", "word": "definitely"},
    {"classification": "Verb", "word": "deflect"},
    {"classification": "Adjective", "word": "degenerate"},
    {"classification": "Verb", "word": "degenerate"},
    {"classification": "Verb", "word": "degrade"},
    {"classification": "Noun", "word": "degree"},
    {"classification": "Noun", "word": "delaware"},
    {"classification": "Verb", "word": "delay"},
    {"classification": "Noun", "word": "delay"},
    {"classification": "Verb", "word": "deliberate"},
    {"classification": "Adjective", "word": "deliberate"},
    {"classification": "Adverb", "word": "deliberately"},
    {"classification": "Adjective", "word": "delicate"},
    {"classification": "Verb", "word": "delight"},
    {"classification": "Adjective", "word": "delightful"},
    {"classification": "Verb", "word": "deliver"},
    {"classification": "Verb", "word": "demand"},
    {"classification": "Adjective", "word": "democratic"},
    {"classification": "Verb", "word": "demonstrate"},
    {"classification": "Verb", "word": "denote"},
    {"classification": "Adjective", "word": "dense"},
    {"classification": "Noun", "word": "density"},
    {"classification": "Verb", "word": "deny"},
    {"classification": "Verb", "word": "department"},
    {"classification": "Verb", "word": "depend"},
    {"classification": "Adjective", "word": "dependent"},
    {"classification": "Adjective", "word": "depress"},
    {"classification": "Verb", "word": "depress"},
    {"classification": "Verb", "word": "deprive"},
    {"classification": "Noun", "word": "depth"},
    {"classification": "Verb", "word": "derive"},
    {"classification": "Verb", "word": "descend"},
    {"classification": "Adjective", "word": "descendant"},
    {"classification": "Noun", "word": "descendant"},
    {"classification": "Verb", "word": "describe"},
    {"classification": "Adjective", "word": "desert"},
    {"classification": "Verb", "word": "desert"},
    {"classification": "Noun", "word": "desert"},
    {"classification": "Verb", "word": "deserve"},
    {"classification": "Verb", "word": "design"},
    {"classification": "Noun", "word": "design"},
    {"classification": "Verb", "word": "desirable"},
    {"classification": "Verb", "word": "desire"},
    {"classification": "Verb", "word": "desk"},
    {"classification": "Noun", "word": "desk"},
    {"classification": "Verb", "word": "despair"},
    {"classification": "Noun", "word": "despair"},
    {"classification": "Adjective", "word": "desperate"},
    {"classification": "Adverb", "word": "desperately"},
    {"classification": "Preposition", "word": "despite"},
    {"classification": "Noun", "word": "despite"},
    {"classification": "Verb", "word": "destroy"},
    {"classification": "Noun", "word": "destruction"},
    {"classification": "Adjective", "word": "destructive"},
    {"classification": "Noun", "word": "detail"},
    {"classification": "Verb", "word": "detect"},
    {"classification": "Adjective", "word": "detect"},
    {"classification": "Adjective", "word": "detective"},
    {"classification": "Adjective", "word": "detergent"},
    {"classification": "Verb", "word": "determine"},
    {"classification": "Adjective", "word": "determined"},
    {"classification": "Verb", "word": "detriment"},
    {"classification": "Noun", "word": "detriment"},
    {"classification": "Verb", "word": "develop"},
    {"classification": "Verb", "word": "deviate"},
    {"classification": "Noun", "word": "device"},
    {"classification": "Verb", "word": "devil"},
    {"classification": "Noun", "word": "devil"},
    {"classification": "Verb", "word": "devise"},
    {"classification": "Noun", "word": "devise"},
    {"classification": "Adjective", "word": "devote"},
    {"classification": "Verb", "word": "devote"},
    {"classification": "Noun", "word": "devote"},
    {"classification": "Adjective", "word": "devoted"},
    {"classification": "Verb", "word": "diagram"},
    {"classification": "Noun", "word": "diagram"},
    {"classification": "Noun", "word": "diameter"},
    {"classification": "Adjective", "word": "diamond"},
    {"classification": "Noun", "word": "diamond"},
    {"classification": "Verb", "word": "dictate"},
    {"classification": "Verb", "word": "die"},
    {"classification": "Noun", "word": "die"},
    {"classification": "Verb", "word": "diet"},
    {"classification": "Noun", "word": "diet"},
    {"classification": "Verb", "word": "difference"},
    {"classification": "Noun", "word": "difference"},
    {"classification": "Adjective", "word": "different"},
    {"classification": "Adjective", "word": "difficult"},
    {"classification": "Verb", "word": "difficult"},
    {"classification": "Noun", "word": "difficulties"},
    {"classification": "Verb", "word": "diffuse"},
    {"classification": "Adjective", "word": "diffuse"},
    {"classification": "Verb", "word": "dig"},
    {"classification": "Noun", "word": "dig"},
    {"classification": "Verb", "word": "digest"},
    {"classification": "Noun", "word": "dilemma"},
    {"classification": "Noun", "word": "dimension"},
    {"classification": "Verb", "word": "dine"},
    {"classification": "Noun", "word": "dinner"},
    {"classification": "Verb", "word": "dip"},
    {"classification": "Noun", "word": "dip"},
    {"classification": "Adjective", "word": "diplomatic"},
    {"classification": "Adjective", "word": "direct"},
    {"classification": "Verb", "word": "direct"},
    {"classification": "Noun", "word": "direct"},
    {"classification": "Adverb", "word": "directly"},
    {"classification": "Verb", "word": "dirt"},
    {"classification": "Noun", "word": "dirt"},
    {"classification": "Adjective", "word": "dirty"},
    {"classification": "Verb", "word": "dirty"},
    {"classification": "Verb", "word": "disagree"},
    {"classification": "Verb", "word": "disappear"},
    {"classification": "Noun", "word": "disappearance"},
    {"classification": "Verb", "word": "disappoint"},
    {"classification": "Verb", "word": "disapprove"},
    {"classification": "Verb", "word": "disaster"},
    {"classification": "Noun", "word": "disaster"},
    {"classification": "Verb", "word": "discern"},
    {"classification": "Verb", "word": "discharge"},
    {"classification": "Noun", "word": "discharge"},
    {"classification": "Verb", "word": "discipline"},
    {"classification": "Verb", "word": "discomfort"},
    {"classification": "Adjective", "word": "discontent"},
    {"classification": "Verb", "word": "discontent"},
    {"classification": "Verb", "word": "discourse"},
    {"classification": "Verb", "word": "discover"},
    {"classification": "Adjective", "word": "discrete"},
    {"classification": "Verb", "word": "discrete"},
    {"classification": "Verb", "word": "discuss"},
    {"classification": "Verb", "word": "disease"},
    {"classification": "Noun", "word": "disease"},
    {"classification": "Verb", "word": "disgust"},
    {"classification": "Verb", "word": "dish"},
    {"classification": "Noun", "word": "dish"},
    {"classification": "Noun", "word": "disk"},
    {"classification": "Verb", "word": "dismiss"},
    {"classification": "Noun", "word": "dismiss"},
    {"classification": "Verb", "word": "dispense"},
    {"classification": "Verb", "word": "disperse"},
    {"classification": "Verb", "word": "displace"},
    {"classification": "Noun", "word": "displacement"},
    {"classification": "Verb", "word": "display"},
    {"classification": "Adjective", "word": "displayed"},
    {"classification": "Noun", "word": "disposal"},
    {"classification": "Verb", "word": "dispose"},
    {"classification": "Verb", "word": "dispute"},
    {"classification": "Verb", "word": "disregard"},
    {"classification": "Noun", "word": "disregard"},
    {"classification": "Verb", "word": "disrespect"},
    {"classification": "Noun", "word": "disrespect"},
    {"classification": "Verb", "word": "dissatisfy"},
    {"classification": "Verb", "word": "dissipate"},
    {"classification": "Verb", "word": "dissolve"},
    {"classification": "Verb", "word": "distance"},
    {"classification": "Noun", "word": "distance"},
    {"classification": "Adjective", "word": "distant"},
    {"classification": "Adjective", "word": "distinct"},
    {"classification": "Verb", "word": "distinct"},
    {"classification": "Noun", "word": "distinction"},
    {"classification": "Adjective", "word": "distinctive"},
    {"classification": "Verb", "word": "distinguish"},
    {"classification": "Adjective", "word": "distinguished"},
    {"classification": "Adjective", "word": "distort"},
    {"classification": "Verb", "word": "distort"},
    {"classification": "Verb", "word": "distribute"},
    {"classification": "Verb", "word": "district"},
    {"classification": "Adjective", "word": "district"},
    {"classification": "Verb", "word": "disturb"},
    {"classification": "Noun", "word": "disturb"},
    {"classification": "Verb", "word": "ditch"},
    {"classification": "Noun", "word": "ditch"},
    {"classification": "Verb", "word": "dive"},
    {"classification": "Noun", "word": "dive"},
    {"classification": "Verb", "word": "diverge"},
    {"classification": "Verb", "word": "diverse"},
    {"classification": "Adjective", "word": "diverse"},
    {"classification": "Adverb", "word": "diverse"},
    {"classification": "Verb", "word": "divide"},
    {"classification": "Noun", "word": "divide"},
    {"classification": "Adjective", "word": "divided"},
    {"classification": "Adjective", "word": "divine"},
    {"classification": "Verb", "word": "divine"},
    {"classification": "Noun", "word": "divorce"},
    {"classification": "Verb", "word": "do"},
    {"classification": "Noun", "word": "do"},
    {"classification": "Verb", "word": "doctor"},
    {"classification": "Noun", "word": "doctor"},
    {"classification": "Verb", "word": "dog"},
    {"classification": "Noun", "word": "dog"},
    {"classification": "Noun", "word": "doing"},
    {"classification": "Noun", "word": "dollar"},
    {"classification": "Adjective", "word": "domestic"},
    {"classification": "Noun", "word": "domestic"},
    {"classification": "Adjective", "word": "dominant"},
    {"classification": "Verb", "word": "dominate"},
    {"classification": "Verb", "word": "don"},
    {"classification": "Noun", "word": "don"},
    {"classification": "Adjective", "word": "done"},
    {"classification": "Noun", "word": "donkey"},
    {"classification": "Noun", "word": "door"},
    {"classification": "Verb", "word": "dot"},
    {"classification": "Noun", "word": "dot"},
    {"classification": "Adverb", "word": "double"},
    {"classification": "Verb", "word": "double"},
    {"classification": "Adjective", "word": "double"},
    {"classification": "Noun", "word": "double"},
    {"classification": "Verb", "word": "doubt"},
    {"classification": "Adjective", "word": "doubtful"},
    {"classification": "Preposition", "word": "down"},
    {"classification": "Verb", "word": "down"},
    {"classification": "Adjective", "word": "down"},
    {"classification": "Adverb", "word": "down"},
    {"classification": "Noun", "word": "down"},
    {"classification": "Noun", "word": "dozen"},
    {"classification": "Verb", "word": "draft"},
    {"classification": "Adjective", "word": "draft"},
    {"classification": "Verb", "word": "drag"},
    {"classification": "Noun", "word": "drag"},
    {"classification": "Verb", "word": "drain"},
    {"classification": "Noun", "word": "drain"},
    {"classification": "Noun", "word": "drama"},
    {"classification": "Adjective", "word": "dramatic"},
    {"classification": "Verb", "word": "drank"},
    {"classification": "Noun", "word": "drank"},
    {"classification": "Adjective", "word": "drastic"},
    {"classification": "Noun", "word": "drastic"},
    {"classification": "Verb", "word": "draw"},
    {"classification": "Noun", "word": "draw"},
    {"classification": "Noun", "word": "drawer"},
    {"classification": "Noun", "word": "drawing"},
    {"classification": "Verb", "word": "dream"},
    {"classification": "Noun", "word": "dream"},
    {"classification": "Verb", "word": "dress"},
    {"classification": "Noun", "word": "dress"},
    {"classification": "Verb", "word": "drew"},
    {"classification": "Verb", "word": "drill"},
    {"classification": "Noun", "word": "drill"},
    {"classification": "Verb", "word": "drink"},
    {"classification": "Noun", "word": "drink"},
    {"classification": "Noun", "word": "drinking"},
    {"classification": "Verb", "word": "drive"},
    {"classification": "Noun", "word": "drive"},
    {"classification": "Noun", "word": "driver"},
    {"classification": "Adjective", "word": "driving"},
    {"classification": "Noun", "word": "driving"},
    {"classification": "Verb", "word": "drop"},
    {"classification": "Noun", "word": "drop"},
    {"classification": "Verb", "word": "drove"},
    {"classification": "Noun", "word": "drove"},
    {"classification": "Verb", "word": "drown"},
    {"classification": "Verb", "word": "drug"},
    {"classification": "Noun", "word": "drug"},
    {"classification": "Verb", "word": "drum"},
    {"classification": "Noun", "word": "drum"},
    {"classification": "Adjective", "word": "drunk"},
    {"classification": "Noun", "word": "drunk"},
    {"classification": "Adjective", "word": "dry"},
    {"classification": "Verb", "word": "dry"},
    {"classification": "Adjective", "word": "drying"},
    {"classification": "Verb", "word": "duck"},
    {"classification": "Noun", "word": "duck"},
    {"classification": "Adverb", "word": "due"},
    {"classification": "Verb", "word": "due"},
    {"classification": "Adjective", "word": "due"},
    {"classification": "Noun", "word": "due"},
    {"classification": "Verb", "word": "dull"},
    {"classification": "Adjective", "word": "dull"},
    {"classification": "Noun", "word": "duration"},
    {"classification": "Preposition", "word": "during"},
    {"classification": "Verb", "word": "dust"},
    {"classification": "Noun", "word": "dust"},
    {"classification": "Noun", "word": "duties"},
    {"classification": "Noun", "word": "duty"},
    {"classification": "Noun", "word": "dying"},
    {"classification": "Adjective", "word": "dying"},
    {"classification": "Adjective", "word": "dynamic"},
    {"classification": "Pronoun", "word": "each"},
    {"classification": "Noun", "word": "eager"},
    {"classification": "Adjective", "word": "eager"},
    {"classification": "Noun", "word": "ear"},
    {"classification": "Verb", "word": "ear"},
    {"classification": "Adverb", "word": "early"},
    {"classification": "Verb", "word": "earn"},
    {"classification": "Noun", "word": "earn"},
    {"classification": "Noun", "word": "earnest"},
    {"classification": "Verb", "word": "earnest"},
    {"classification": "Adjective", "word": "earnest"},
    {"classification": "Verb", "word": "earth"},
    {"classification": "Noun", "word": "earth"},
    {"classification": "Noun", "word": "ease"},
    {"classification": "Adverb", "word": "easily"},
    {"classification": "Noun", "word": "east"},
    {"classification": "Verb", "word": "east"},
    {"classification": "Adverb", "word": "east"},
    {"classification": "Adjective", "word": "east"},
    {"classification": "Adjective", "word": "eastern"},
    {"classification": "Verb", "word": "easy"},
    {"classification": "Verb", "word": "eat"},
    {"classification": "Noun", "word": "eating"},
    {"classification": "Adjective", "word": "economic"},
    {"classification": "Adjective", "word": "economical"},
    {"classification": "Adjective", "word": "ecumenical"},
    {"classification": "Verb", "word": "edge"},
    {"classification": "Verb", "word": "edit"},
    {"classification": "Noun", "word": "edition"},
    {"classification": "Noun", "word": "editor"},
    {"classification": "Adjective", "word": "editorial"},
    {"classification": "Verb", "word": "educate"},
    {"classification": "Adjective", "word": "educated"},
    {"classification": "Noun", "word": "education"},
    {"classification": "Adjective", "word": "educational"},
    {"classification": "Noun", "word": "effect"},
    {"classification": "Verb", "word": "effect"},
    {"classification": "Adjective", "word": "effective"},
    {"classification": "Adverb", "word": "effectively"},
    {"classification": "Adjective", "word": "efficient"},
    {"classification": "Noun", "word": "effort"},
    {"classification": "Verb", "word": "effort"},
    {"classification": "Verb", "word": "egg"},
    {"classification": "Noun", "word": "egg"},
    {"classification": "Adjective", "word": "eight"},
    {"classification": "Noun", "word": "eight"},
    {"classification": "Adjective", "word": "eighteenth"},
    {"classification": "Noun", "word": "eighth"},
    {"classification": "Adjective", "word": "eighth"},
    {"classification": "Pronoun", "word": "either"},
    {"classification": "Verb", "word": "elaborate"},
    {"classification": "Adjective", "word": "elaborate"},
    {"classification": "Noun", "word": "elaine"},
    {"classification": "Adjective", "word": "elastic"},
    {"classification": "Noun", "word": "elastic"},
    {"classification": "Noun", "word": "elder"},
    {"classification": "Adjective", "word": "elder"},
    {"classification": "Adjective", "word": "elect"},
    {"classification": "Noun", "word": "elect"},
    {"classification": "Verb", "word": "elect"},
    {"classification": "Adjective", "word": "election"},
    {"classification": "Adjective", "word": "electric"},
    {"classification": "Adjective", "word": "electrical"},
    {"classification": "Adjective", "word": "electronic"},
    {"classification": "Noun", "word": "element"},
    {"classification": "Verb", "word": "element"},
    {"classification": "Adjective", "word": "elementary"},
    {"classification": "Adjective", "word": "elevate"},
    {"classification": "Verb", "word": "elevate"},
    {"classification": "Adjective", "word": "eleven"},
    {"classification": "Noun", "word": "eleven"},
    {"classification": "Verb", "word": "elicit"},
    {"classification": "Adjective", "word": "elicit"},
    {"classification": "Verb", "word": "eliminate"},
    {"classification": "Adjective", "word": "eloquent"},
    {"classification": "Adverb", "word": "elsewhere"},
    {"classification": "Noun", "word": "em"},
    {"classification": "Adjective", "word": "emancipate"},
    {"classification": "Verb", "word": "emancipate"},
    {"classification": "Verb", "word": "embody"},
    {"classification": "Noun", "word": "embrace"},
    {"classification": "Verb", "word": "embrace"},
    {"classification": "Verb", "word": "emerge"},
    {"classification": "Noun", "word": "emission"},
    {"classification": "Noun", "word": "emotion"},
    {"classification": "Adjective", "word": "emotional"},
    {"classification": "Verb", "word": "emphasize"},
    {"classification": "Noun", "word": "empire"},
    {"classification": "Adjective", "word": "empirical"},
    {"classification": "Verb", "word": "employ"},
    {"classification": "Noun", "word": "employ"},
    {"classification": "Adjective", "word": "empty"},
    {"classification": "Verb", "word": "empty"},
    {"classification": "Noun", "word": "empty"},
    {"classification": "Verb", "word": "enable"},
    {"classification": "Verb", "word": "enclose"},
    {"classification": "Noun", "word": "enclosure"},
    {"classification": "Adverb", "word": "encounter"},
    {"classification": "Verb", "word": "encounter"},
    {"classification": "Verb", "word": "encourage"},
    {"classification": "Adjective", "word": "encouraging"},
    {"classification": "Verb", "word": "end"},
    {"classification": "Noun", "word": "end"},
    {"classification": "Noun", "word": "ending"},
    {"classification": "Adjective", "word": "endless"},
    {"classification": "Noun", "word": "enemies"},
    {"classification": "Noun", "word": "enemy"},
    {"classification": "Adjective", "word": "enemy"},
    {"classification": "Noun", "word": "energy"},
    {"classification": "Adjective", "word": "enforced"},
    {"classification": "Adjective", "word": "engaged"},
    {"classification": "Verb", "word": "engine"},
    {"classification": "Noun", "word": "engine"},
    {"classification": "Verb", "word": "engineer"},
    {"classification": "Adjective", "word": "english"},
    {"classification": "Noun", "word": "english"},
    {"classification": "Verb", "word": "english"},
    {"classification": "Verb", "word": "enhance"},
    {"classification": "Verb", "word": "enjoy"},
    {"classification": "Noun", "word": "enjoyment"},
    {"classification": "Verb", "word": "enlighten"},
    {"classification": "Adjective", "word": "enormous"},
    {"classification": "Adverb", "word": "enough"},
    {"classification": "Noun", "word": "enough"},
    {"classification": "Adjective", "word": "enough"},
    {"classification": "Verb", "word": "enrich"},
    {"classification": "Verb", "word": "ensure"},
    {"classification": "Verb", "word": "enter"},
    {"classification": "Verb", "word": "enterprise"},
    {"classification": "Verb", "word": "entertain"},
    {"classification": "Noun", "word": "entertain"},
    {"classification": "Noun", "word": "enthusiasm"},
    {"classification": "Adjective", "word": "enthusiastic"},
    {"classification": "Adjective", "word": "entire"},
    {"classification": "Noun", "word": "entire"},
    {"classification": "Adverb", "word": "entirely"},
    {"classification": "Noun", "word": "entity"},
    {"classification": "Noun", "word": "entrance"},
    {"classification": "Verb", "word": "entrance"},
    {"classification": "Noun", "word": "entries"},
    {"classification": "Noun", "word": "entry"},
    {"classification": "Verb", "word": "enumerate"},
    {"classification": "Noun", "word": "environment"},
    {"classification": "Verb", "word": "envy"},
    {"classification": "Noun", "word": "envy"},
    {"classification": "Noun", "word": "episode"},
    {"classification": "Verb", "word": "equal"},
    {"classification": "Noun", "word": "equal"},
    {"classification": "Adjective", "word": "equal"},
    {"classification": "Adverb", "word": "equally"},
    {"classification": "Verb", "word": "equate"},
    {"classification": "Noun", "word": "equation"},
    {"classification": "Adjective", "word": "equidistant"},
    {"classification": "Noun", "word": "equipment"},
    {"classification": "Adjective", "word": "equivalent"},
    {"classification": "Verb", "word": "equivalent"},
    {"classification": "Noun", "word": "era"},
    {"classification": "Verb", "word": "err"},
    {"classification": "Noun", "word": "error"},
    {"classification": "Noun", "word": "escape"},
    {"classification": "Verb", "word": "escape"},
    {"classification": "Adverb", "word": "especially"},
    {"classification": "Noun", "word": "essence"},
    {"classification": "Verb", "word": "essence"},
    {"classification": "Adjective", "word": "essential"},
    {"classification": "Adjective", "word": "establish"},
    {"classification": "Noun", "word": "estate"},
    {"classification": "Verb", "word": "estate"},
    {"classification": "Verb", "word": "estimate"},
    {"classification": "Adjective", "word": "eternal"},
    {"classification": "Noun", "word": "eternal"},
    {"classification": "Adjective", "word": "ethical"},
    {"classification": "Noun", "word": "ethics"},
    {"classification": "Adjective", "word": "european"},
    {"classification": "Noun", "word": "european"},
    {"classification": "Verb", "word": "evaluate"},
    {"classification": "Noun", "word": "evaluation"},
    {"classification": "Verb", "word": "evaporate"},
    {"classification": "Adjective", "word": "evaporate"},
    {"classification": "Noun", "word": "eve"},
    {"classification": "Adjective", "word": "even"},
    {"classification": "Verb", "word": "even"},
    {"classification": "Noun", "word": "even"},
    {"classification": "Noun", "word": "evening"},
    {"classification": "Noun", "word": "event"},
    {"classification": "Verb", "word": "event"},
    {"classification": "Adjective", "word": "eventual"},
    {"classification": "Adverb", "word": "eventually"},
    {"classification": "Adverb", "word": "ever"},
    {"classification": "Adjective", "word": "everlasting"},
    {"classification": "Noun", "word": "everybody"},
    {"classification": "Adjective", "word": "everyday"},
    {"classification": "Pronoun", "word": "everyone"},
    {"classification": "Noun", "word": "everyone"},
    {"classification": "Noun", "word": "everything"},
    {"classification": "Adverb", "word": "everywhere"},
    {"classification": "Verb", "word": "evidence"},
    {"classification": "Noun", "word": "evidence"},
    {"classification": "Adjective", "word": "evident"},
    {"classification": "Adverb", "word": "evidently"},
    {"classification": "Noun", "word": "evil"},
    {"classification": "Adjective", "word": "evil"},
    {"classification": "Adverb", "word": "evil"},
    {"classification": "Verb", "word": "evoke"},
    {"classification": "Verb", "word": "evolve"},
    {"classification": "Verb", "word": "exact"},
    {"classification": "Adjective", "word": "exact"},
    {"classification": "Adverb", "word": "exactly"},
    {"classification": "Verb", "word": "examine"},
    {"classification": "Noun", "word": "example"},
    {"classification": "Verb", "word": "example"},
    {"classification": "Noun", "word": "excellence"},
    {"classification": "Adjective", "word": "excellent"},
    {"classification": "Adverb", "word": "excellent"},
    {"classification": "Preposition", "word": "except"},
    {"classification": "Verb", "word": "except"},
    {"classification": "Noun", "word": "exception"},
    {"classification": "Noun", "word": "excess"},
    {"classification": "Adjective", "word": "excessive"},
    {"classification": "Verb", "word": "exchange"},
    {"classification": "Noun", "word": "exchange"},
    {"classification": "Verb", "word": "excite"},
    {"classification": "Adjective", "word": "exciting"},
    {"classification": "Verb", "word": "exclude"},
    {"classification": "Adjective", "word": "exclusive"},
    {"classification": "Verb", "word": "excuse"},
    {"classification": "Verb", "word": "execute"},
    {"classification": "Adjective", "word": "executive"},
    {"classification": "Verb", "word": "exercise"},
    {"classification": "Noun", "word": "exercise"},
    {"classification": "Verb", "word": "exert"},
    {"classification": "Noun", "word": "exhaust"},
    {"classification": "Verb", "word": "exhaust"},
    {"classification": "Adjective", "word": "exhaust"},
    {"classification": "Verb", "word": "exhibit"},
    {"classification": "Noun", "word": "exhibit"},
    {"classification": "Verb", "word": "exist"},
    {"classification": "Noun", "word": "existence"},
    {"classification": "Verb", "word": "expand"},
    {"classification": "Adjective", "word": "expanding"},
    {"classification": "Verb", "word": "expect"},
    {"classification": "Noun", "word": "expect"},
    {"classification": "Verb", "word": "expel"},
    {"classification": "Noun", "word": "expense"},
    {"classification": "Adjective", "word": "expensive"},
    {"classification": "Noun", "word": "experience"},
    {"classification": "Verb", "word": "experiment"},
    {"classification": "Adjective", "word": "experimental"},
    {"classification": "Adjective", "word": "expert"},
    {"classification": "Noun", "word": "expert"},
    {"classification": "Verb", "word": "expert"},
    {"classification": "Verb", "word": "explain"},
    {"classification": "Adjective", "word": "explain"},
    {"classification": "Noun", "word": "explanation"},
    {"classification": "Adjective", "word": "explicit"},
    {"classification": "Verb", "word": "explode"},
    {"classification": "Noun", "word": "exploit"},
    {"classification": "Noun", "word": "exploration"},
    {"classification": "Verb", "word": "explore"},
    {"classification": "Noun", "word": "explosion"},
    {"classification": "Adjective", "word": "explosive"},
    {"classification": "Noun", "word": "exponent"},
    {"classification": "Verb", "word": "export"},
    {"classification": "Noun", "word": "export"},
    {"classification": "Verb", "word": "expose"},
    {"classification": "Noun", "word": "exposure"},
    {"classification": "Adjective", "word": "express"},
    {"classification": "Noun", "word": "express"},
    {"classification": "Verb", "word": "extend"},
    {"classification": "Verb", "word": "extension"},
    {"classification": "Adjective", "word": "extensive"},
    {"classification": "Noun", "word": "extent"},
    {"classification": "Adjective", "word": "extent"},
    {"classification": "Adjective", "word": "external"},
    {"classification": "Noun", "word": "extra"},
    {"classification": "Adjective", "word": "extra"},
    {"classification": "Verb", "word": "extract"},
    {"classification": "Noun", "word": "extract"},
    {"classification": "Adjective", "word": "extraordinary"},
    {"classification": "Noun", "word": "extraordinary"},
    {"classification": "Noun", "word": "extreme"},
    {"classification": "Adjective", "word": "extreme"},
    {"classification": "Adverb", "word": "extremely"},
    {"classification": "Verb", "word": "eye"},
    {"classification": "Noun", "word": "eye"},
    {"classification": "Noun", "word": "face"},
    {"classification": "Verb", "word": "face"},
    {"classification": "Adjective", "word": "faced"},
    {"classification": "Verb", "word": "facilitate"},
    {"classification": "Noun", "word": "facing"},
    {"classification": "Noun", "word": "fact"},
    {"classification": "Noun", "word": "faction"},
    {"classification": "Noun", "word": "factor"},
    {"classification": "Verb", "word": "factor"},
    {"classification": "Verb", "word": "fade"},
    {"classification": "Adjective", "word": "fade"},
    {"classification": "Verb", "word": "fail"},
    {"classification": "Noun", "word": "failure"},
    {"classification": "Noun", "word": "faint"},
    {"classification": "Adjective", "word": "faint"},
    {"classification": "Verb", "word": "faint"},
    {"classification": "Adjective", "word": "fair"},
    {"classification": "Adverb", "word": "fair"},
    {"classification": "Noun", "word": "fair"},
    {"classification": "Verb", "word": "fair"},
    {"classification": "Adverb", "word": "fairly"},
    {"classification": "Noun", "word": "faith"},
    {"classification": "Verb", "word": "fall"},
    {"classification": "Noun", "word": "fall"},
    {"classification": "Adjective", "word": "fallen"},
    {"classification": "Adjective", "word": "false"},
    {"classification": "Adverb", "word": "false"},
    {"classification": "Noun", "word": "fame"},
    {"classification": "Verb", "word": "fame"},
    {"classification": "Adjective", "word": "familiar"},
    {"classification": "Noun", "word": "familiar"},
    {"classification": "Verb", "word": "family"},
    {"classification": "Adjective", "word": "famous"},
    {"classification": "Noun", "word": "fan"},
    {"classification": "Noun", "word": "fancy"},
    {"classification": "Adjective", "word": "fancy"},
    {"classification": "Verb", "word": "fancy"},
    {"classification": "Adjective", "word": "fantastic"},
    {"classification": "Adjective", "word": "far"},
    {"classification": "Adverb", "word": "far"},
    {"classification": "Noun", "word": "far"},
    {"classification": "Verb", "word": "fare"},
    {"classification": "Noun", "word": "fare"},
    {"classification": "Verb", "word": "farm"},
    {"classification": "Noun", "word": "farmer"},
    {"classification": "Adverb", "word": "farther"},
    {"classification": "Verb", "word": "farther"},
    {"classification": "Adjective", "word": "farther"},
    {"classification": "Verb", "word": "fashion"},
    {"classification": "Noun", "word": "fashion"},
    {"classification": "Adjective", "word": "fast"},
    {"classification": "Noun", "word": "fast"},
    {"classification": "Verb", "word": "fast"},
    {"classification": "Verb", "word": "fasten"},
    {"classification": "Adjective", "word": "fasten"},
    {"classification": "Noun", "word": "fat"},
    {"classification": "Verb", "word": "fat"},
    {"classification": "Adjective", "word": "fat"},
    {"classification": "Noun", "word": "fate"},
    {"classification": "Noun", "word": "father"},
    {"classification": "Verb", "word": "father"},
    {"classification": "Verb", "word": "fatten"},
    {"classification": "Verb", "word": "fault"},
    {"classification": "Noun", "word": "fault"},
    {"classification": "Noun", "word": "favor"},
    {"classification": "Noun", "word": "favorable"},
    {"classification": "Adjective", "word": "favorite"},
    {"classification": "Noun", "word": "favorite"},
    {"classification": "Verb", "word": "fear"},
    {"classification": "Noun", "word": "fear"},
    {"classification": "Adjective", "word": "feasible"},
    {"classification": "Noun", "word": "feast"},
    {"classification": "Verb", "word": "feast"},
    {"classification": "Noun", "word": "feather"},
    {"classification": "Verb", "word": "feather"},
    {"classification": "Noun", "word": "feature"},
    {"classification": "Noun", "word": "federal"},
    {"classification": "Adjective", "word": "federal"},
    {"classification": "Verb", "word": "feed"},
    {"classification": "Noun", "word": "feed"},
    {"classification": "Noun", "word": "feeding"},
    {"classification": "Noun", "word": "feel"},
    {"classification": "Verb", "word": "feel"},
    {"classification": "Noun", "word": "feeling"},
    {"classification": "Adjective", "word": "feeling"},
    {"classification": "Noun", "word": "feet"},
    {"classification": "Noun", "word": "fell"},
    {"classification": "Adjective", "word": "fell"},
    {"classification": "Verb", "word": "fell"},
    {"classification": "Noun", "word": "fellow"},
    {"classification": "Verb", "word": "fellow"},
    {"classification": "Verb", "word": "fellowship"},
    {"classification": "Noun", "word": "felt"},
    {"classification": "Verb", "word": "felt"},
    {"classification": "Adjective", "word": "female"},
    {"classification": "Noun", "word": "female"},
    {"classification": "Verb", "word": "fence"},
    {"classification": "Noun", "word": "fence"},
    {"classification": "Adjective", "word": "fertile"},
    {"classification": "Adjective", "word": "festival"},
    {"classification": "Verb", "word": "fever"},
    {"classification": "Noun", "word": "fever"},
    {"classification": "Pronoun", "word": "few"},
    {"classification": "Adjective", "word": "few"},
    {"classification": "Noun", "word": "fiber"},
    {"classification": "Noun", "word": "fiction"},
    {"classification": "Verb", "word": "field"},
    {"classification": "Noun", "word": "field"},
    {"classification": "Adjective", "word": "fierce"},
    {"classification": "Adjective", "word": "fifteen"},
    {"classification": "Noun", "word": "fifteen"},
    {"classification": "Adjective", "word": "fifth"},
    {"classification": "Noun", "word": "fifth"},
    {"classification": "Adjective", "word": "fifty"},
    {"classification": "Noun", "word": "fifty"},
    {"classification": "Noun", "word": "fig"},
    {"classification": "Verb", "word": "fight"},
    {"classification": "Adjective", "word": "fighting"},
    {"classification": "Verb", "word": "figure"},
    {"classification": "Noun", "word": "figure"},
    {"classification": "Adjective", "word": "figured"},
    {"classification": "Verb", "word": "file"},
    {"classification": "Noun", "word": "file"},
    {"classification": "Noun", "word": "filing"},
    {"classification": "Verb", "word": "fill"},
    {"classification": "Adjective", "word": "fill"},
    {"classification": "Noun", "word": "fill"},
    {"classification": "Noun", "word": "filling"},
    {"classification": "Verb", "word": "film"},
    {"classification": "Noun", "word": "film"},
    {"classification": "Adjective", "word": "final"},
    {"classification": "Adverb", "word": "finally"},
    {"classification": "Noun", "word": "finance"},
    {"classification": "Adjective", "word": "financial"},
    {"classification": "Verb", "word": "find"},
    {"classification": "Noun", "word": "find"},
    {"classification": "Noun", "word": "finding"},
    {"classification": "Verb", "word": "fine"},
    {"classification": "Adjective", "word": "fine"},
    {"classification": "Adverb", "word": "fine"},
    {"classification": "Noun", "word": "fine"},
    {"classification": "Verb", "word": "finger"},
    {"classification": "Noun", "word": "finger"},
    {"classification": "Verb", "word": "finish"},
    {"classification": "Noun", "word": "finish"},
    {"classification": "Adjective", "word": "finished"},
    {"classification": "Adjective", "word": "finite"},
    {"classification": "Verb", "word": "fire"},
    {"classification": "Noun", "word": "fire"},
    {"classification": "Noun", "word": "firing"},
    {"classification": "Adjective", "word": "firm"},
    {"classification": "Adverb", "word": "firmly"},
    {"classification": "Adjective", "word": "firms"},
    {"classification": "Adjective", "word": "first"},
    {"classification": "Adverb", "word": "first"},
    {"classification": "Noun", "word": "first"},
    {"classification": "Adjective", "word": "fiscal"},
    {"classification": "Noun", "word": "fiscal"},
    {"classification": "Verb", "word": "fish"},
    {"classification": "Noun", "word": "fish"},
    {"classification": "Verb", "word": "fist"},
    {"classification": "Noun", "word": "fist"},
    {"classification": "Verb", "word": "fit"},
    {"classification": "Adjective", "word": "fit"},
    {"classification": "Noun", "word": "fit"},
    {"classification": "Adjective", "word": "five"},
    {"classification": "Noun", "word": "five"},
    {"classification": "Verb", "word": "fix"},
    {"classification": "Adjective", "word": "fix"},
    {"classification": "Noun", "word": "fix"},
    {"classification": "Adjective", "word": "fixed"},
    {"classification": "Verb", "word": "flag"},
    {"classification": "Noun", "word": "flag"},
    {"classification": "Verb", "word": "flame"},
    {"classification": "Noun", "word": "flame"},
    {"classification": "Adjective", "word": "flash"},
    {"classification": "Verb", "word": "flash"},
    {"classification": "Noun", "word": "flash"},
    {"classification": "Adverb", "word": "flat"},
    {"classification": "Verb", "word": "flat"},
    {"classification": "Adjective", "word": "flat"},
    {"classification": "Noun", "word": "flat"},
    {"classification": "Adjective", "word": "flatten"},
    {"classification": "Verb", "word": "flatten"},
    {"classification": "Verb", "word": "flavor"},
    {"classification": "Noun", "word": "flavor"},
    {"classification": "Verb", "word": "flesh"},
    {"classification": "Noun", "word": "flesh"},
    {"classification": "Verb", "word": "flew"},
    {"classification": "Adjective", "word": "flexible"},
    {"classification": "Noun", "word": "flight"},
    {"classification": "Verb", "word": "float"},
    {"classification": "Noun", "word": "float"},
    {"classification": "Verb", "word": "flood"},
    {"classification": "Verb", "word": "floor"},
    {"classification": "Noun", "word": "floor"},
    {"classification": "Verb", "word": "flour"},
    {"classification": "Noun", "word": "flour"},
    {"classification": "Verb", "word": "flow"},
    {"classification": "Noun", "word": "flow"},
    {"classification": "Verb", "word": "flower"},
    {"classification": "Noun", "word": "flower"},
    {"classification": "Verb", "word": "fluctuate"},
    {"classification": "Adjective", "word": "fluent"},
    {"classification": "Noun", "word": "fluent"},
    {"classification": "Adjective", "word": "fluid"},
    {"classification": "Noun", "word": "fluid"},
    {"classification": "Verb", "word": "flux"},
    {"classification": "Noun", "word": "flux"},
    {"classification": "Verb", "word": "fly"},
    {"classification": "Adjective", "word": "fly"},
    {"classification": "Noun", "word": "fly"},
    {"classification": "Verb", "word": "flying"},
    {"classification": "Verb", "word": "foam"},
    {"classification": "Noun", "word": "foam"},
    {"classification": "Verb", "word": "focus"},
    {"classification": "Noun", "word": "focus"},
    {"classification": "Verb", "word": "fog"},
    {"classification": "Noun", "word": "fog"},
    {"classification": "Verb", "word": "foil"},
    {"classification": "Noun", "word": "foil"},
    {"classification": "Verb", "word": "fold"},
    {"classification": "Noun", "word": "fold"},
    {"classification": "Verb", "word": "follow"},
    {"classification": "Noun", "word": "follow"},
    {"classification": "Adjective", "word": "following"},
    {"classification": "Adjective", "word": "fond"},
    {"classification": "Verb", "word": "fond"},
    {"classification": "Noun", "word": "fond"},
    {"classification": "Verb", "word": "food"},
    {"classification": "Noun", "word": "food"},
    {"classification": "Verb", "word": "fool"},
    {"classification": "Noun", "word": "fool"},
    {"classification": "Verb", "word": "foot"},
    {"classification": "Noun", "word": "foot"},
    {"classification": "Noun", "word": "football"},
    {"classification": "CoordConjunction", "word": "for"},
    {"classification": "Preposition", "word": "for"},
    {"classification": "Noun", "word": "for"},
    {"classification": "Verb", "word": "forbid"},
    {"classification": "Verb", "word": "force"},
    {"classification": "Noun", "word": "force"},
    {"classification": "Adjective", "word": "forced"},
    {"classification": "Verb", "word": "ford"},
    {"classification": "Adjective", "word": "foreign"},
    {"classification": "Verb", "word": "forest"},
    {"classification": "Adjective", "word": "forest"},
    {"classification": "Noun", "word": "forest"},
    {"classification": "Adverb", "word": "forever"},
    {"classification": "Verb", "word": "forget"},
    {"classification": "Verb", "word": "forgive"},
    {"classification": "Verb", "word": "forgo"},
    {"classification": "Verb", "word": "fork"},
    {"classification": "Noun", "word": "fork"},
    {"classification": "Verb", "word": "form"},
    {"classification": "Noun", "word": "form"},
    {"classification": "Adjective", "word": "formal"},
    {"classification": "Noun", "word": "formal"},
    {"classification": "Adjective", "word": "formed"},
    {"classification": "Adjective", "word": "former"},
    {"classification": "Noun", "word": "former"},
    {"classification": "Adverb", "word": "formerly"},
    {"classification": "Noun", "word": "forming"},
    {"classification": "Noun", "word": "formula"},
    {"classification": "Verb", "word": "formulate"},
    {"classification": "Noun", "word": "fort"},
    {"classification": "Adverb", "word": "forth"},
    {"classification": "Noun", "word": "forth"},
    {"classification": "Noun", "word": "fortunate"},
    {"classification": "Adverb", "word": "fortunately"},
    {"classification": "Verb", "word": "fortune"},
    {"classification": "Adjective", "word": "forty"},
    {"classification": "Noun", "word": "forty"},
    {"classification": "Adjective", "word": "forward"},
    {"classification": "Adverb", "word": "forward"},
    {"classification": "Verb", "word": "forward"},
    {"classification": "Noun", "word": "forward"},
    {"classification": "Adjective", "word": "fossil"},
    {"classification": "Noun", "word": "fossil"},
    {"classification": "Verb", "word": "found"},
    {"classification": "Noun", "word": "found"},
    {"classification": "Noun", "word": "foundation"},
    {"classification": "Adjective", "word": "four"},
    {"classification": "Noun", "word": "four"},
    {"classification": "Adjective", "word": "fourteen"},
    {"classification": "Noun", "word": "fourteen"},
    {"classification": "Adjective", "word": "fourth"},
    {"classification": "Noun", "word": "fourth"},
    {"classification": "Verb", "word": "fraction"},
    {"classification": "Noun", "word": "fraction"},
    {"classification": "Verb", "word": "fragment"},
    {"classification": "Verb", "word": "frame"},
    {"classification": "Noun", "word": "frame"},
    {"classification": "Noun", "word": "framework"},
    {"classification": "Adjective", "word": "frank"},
    {"classification": "Verb", "word": "frank"},
    {"classification": "Noun", "word": "frank"},
    {"classification": "Adjective", "word": "franklin"},
    {"classification": "Adjective", "word": "fraternal"},
    {"classification": "Noun", "word": "fraud"},
    {"classification": "Noun", "word": "fred"},
    {"classification": "Adjective", "word": "free"},
    {"classification": "Adverb", "word": "free"},
    {"classification": "Noun", "word": "freedom"},
    {"classification": "Adverb", "word": "freely"},
    {"classification": "Verb", "word": "freeze"},
    {"classification": "Noun", "word": "freeze"},
    {"classification": "Verb", "word": "freight"},
    {"classification": "Adjective", "word": "freight"},
    {"classification": "Noun", "word": "freight"},
    {"classification": "Adjective", "word": "french"},
    {"classification": "Noun", "word": "french"},
    {"classification": "Adjective", "word": "frequent"},
    {"classification": "Adverb", "word": "frequently"},
    {"classification": "Verb", "word": "fresh"},
    {"classification": "Noun", "word": "fresh"},
    {"classification": "Noun", "word": "friday"},
    {"classification": "Verb", "word": "friend"},
    {"classification": "Noun", "word": "friend"},
    {"classification": "Adverb", "word": "friendly"},
    {"classification": "Adjective", "word": "friendly"},
    {"classification": "Noun", "word": "fright"},
    {"classification": "Verb", "word": "frighten"},
    {"classification": "Verb", "word": "frightened"},
    {"classification": "Preposition", "word": "from"},
    {"classification": "Verb", "word": "front"},
    {"classification": "Adjective", "word": "front"},
    {"classification": "Noun", "word": "front"},
    {"classification": "Adjective", "word": "frontier"},
    {"classification": "Verb", "word": "frontier"},
    {"classification": "Noun", "word": "frontier"},
    {"classification": "Adjective", "word": "frozen"},
    {"classification": "Verb", "word": "fruit"},
    {"classification": "Adjective", "word": "frustrate"},
    {"classification": "Verb", "word": "frustrate"},
    {"classification": "Verb", "word": "fry"},
    {"classification": "Noun", "word": "fry"},
    {"classification": "Verb", "word": "fuel"},
    {"classification": "Noun", "word": "fuel"},
    {"classification": "Verb", "word": "fulfill"},
    {"classification": "Adverb", "word": "full"},
    {"classification": "Verb", "word": "full"},
    {"classification": "Noun", "word": "full"},
    {"classification": "Adverb", "word": "fully"},
    {"classification": "Noun", "word": "fun"},
    {"classification": "Verb", "word": "function"},
    {"classification": "Noun", "word": "function"},
    {"classification": "Adjective", "word": "functional"},
    {"classification": "Verb", "word": "fund"},
    {"classification": "Noun", "word": "fund"},
    {"classification": "Adjective", "word": "fundamental"},
    {"classification": "Noun", "word": "funeral"},
    {"classification": "Adjective", "word": "funny"},
    {"classification": "Noun", "word": "funny"},
    {"classification": "Verb", "word": "fur"},
    {"classification": "Adjective", "word": "fur"},
    {"classification": "Noun", "word": "fur"},
    {"classification": "Verb", "word": "furnish"},
    {"classification": "Noun", "word": "furnish"},
    {"classification": "Verb", "word": "furniture"},
    {"classification": "Adjective", "word": "further"},
    {"classification": "Adverb", "word": "further"},
    {"classification": "Adverb", "word": "furthermore"},
    {"classification": "Verb", "word": "fuse"},
    {"classification": "Noun", "word": "fuse"},
    {"classification": "Adjective", "word": "future"},
    {"classification": "Verb", "word": "future"},
    {"classification": "Noun", "word": "gaiety"},
    {"classification": "Adjective", "word": "gain"},
    {"classification": "Verb", "word": "gain"},
    {"classification": "Noun", "word": "gain"},
    {"classification": "Adjective", "word": "gallery"},
    {"classification": "Noun", "word": "gallon"},
    {"classification": "Adjective", "word": "game"},
    {"classification": "Verb", "word": "game"},
    {"classification": "Noun", "word": "game"},
    {"classification": "Verb", "word": "gang"},
    {"classification": "Verb", "word": "gap"},
    {"classification": "Noun", "word": "gap"},
    {"classification": "Verb", "word": "garage"},
    {"classification": "Noun", "word": "garage"},
    {"classification": "Verb", "word": "garden"},
    {"classification": "Noun", "word": "garden"},
    {"classification": "Verb", "word": "gas"},
    {"classification": "Noun", "word": "gas"},
    {"classification": "Verb", "word": "gate"},
    {"classification": "Noun", "word": "gate"},
    {"classification": "Verb", "word": "gather"},
    {"classification": "Noun", "word": "gather"},
    {"classification": "Adjective", "word": "gathering"},
    {"classification": "Verb", "word": "gave"},
    {"classification": "Adjective", "word": "gay"},
    {"classification": "Noun", "word": "gay"},
    {"classification": "Verb", "word": "gear"},
    {"classification": "Noun", "word": "gear"},
    {"classification": "Adjective", "word": "general"},
    {"classification": "Adverb", "word": "generally"},
    {"classification": "Verb", "word": "generate"},
    {"classification": "Adjective", "word": "generous"},
    {"classification": "Noun", "word": "genius"},
    {"classification": "Adjective", "word": "gentle"},
    {"classification": "Verb", "word": "gentle"},
    {"classification": "Noun", "word": "gentle"},
    {"classification": "Adverb", "word": "gently"},
    {"classification": "Adjective", "word": "genuine"},
    {"classification": "Noun", "word": "george"},
    {"classification": "Verb", "word": "germ"},
    {"classification": "Noun", "word": "germ"},
    {"classification": "Adjective", "word": "german"},
    {"classification": "Noun", "word": "german"},
    {"classification": "Verb", "word": "gesture"},
    {"classification": "Noun", "word": "gesture"},
    {"classification": "Verb", "word": "get"},
    {"classification": "Noun", "word": "get"},
    {"classification": "Noun", "word": "getting"},
    {"classification": "Adjective", "word": "giant"},
    {"classification": "Noun", "word": "giant"},
    {"classification": "Verb", "word": "gift"},
    {"classification": "Verb", "word": "gin"},
    {"classification": "Noun", "word": "gin"},
    {"classification": "Noun", "word": "girl"},
    {"classification": "Verb", "word": "give"},
    {"classification": "Noun", "word": "give"},
    {"classification": "Verb", "word": "given"},
    {"classification": "Adverb", "word": "given"},
    {"classification": "Noun", "word": "gives"},
    {"classification": "Noun", "word": "giving"},
    {"classification": "Adjective", "word": "glad"},
    {"classification": "Verb", "word": "glad"},
    {"classification": "Verb", "word": "glance"},
    {"classification": "Noun", "word": "glance"},
    {"classification": "Verb", "word": "glass"},
    {"classification": "Noun", "word": "glory"},
    {"classification": "Verb", "word": "go"},
    {"classification": "Noun", "word": "go"},
    {"classification": "Noun", "word": "goal"},
    {"classification": "Noun", "word": "goat"},
    {"classification": "Verb", "word": "god"},
    {"classification": "Noun", "word": "god"},
    {"classification": "Noun", "word": "going"},
    {"classification": "Verb", "word": "gold"},
    {"classification": "Noun", "word": "gold"},
    {"classification": "Adjective", "word": "golden"},
    {"classification": "Verb", "word": "golf"},
    {"classification": "Noun", "word": "golf"},
    {"classification": "Adjective", "word": "good"},
    {"classification": "Adverb", "word": "good"},
    {"classification": "Verb", "word": "good"},
    {"classification": "Noun", "word": "good"},
    {"classification": "Noun", "word": "goods"},
    {"classification": "Verb", "word": "got"},
    {"classification": "Verb", "word": "govern"},
    {"classification": "Adjective", "word": "governing"},
    {"classification": "Adjective", "word": "governmental"},
    {"classification": "Verb", "word": "grace"},
    {"classification": "Noun", "word": "grace"},
    {"classification": "Verb", "word": "grade"},
    {"classification": "Noun", "word": "grade"},
    {"classification": "Noun", "word": "gradual"},
    {"classification": "Adverb", "word": "gradually"},
    {"classification": "Verb", "word": "graduate"},
    {"classification": "Adjective", "word": "grain"},
    {"classification": "Verb", "word": "grain"},
    {"classification": "Noun", "word": "grain"},
    {"classification": "Noun", "word": "grains"},
    {"classification": "Verb", "word": "grammar"},
    {"classification": "Adjective", "word": "grammatical"},
    {"classification": "Adjective", "word": "grand"},
    {"classification": "Verb", "word": "grant"},
    {"classification": "Noun", "word": "graph"},
    {"classification": "Verb", "word": "grass"},
    {"classification": "Noun", "word": "grass"},
    {"classification": "Adjective", "word": "grateful"},
    {"classification": "Adjective", "word": "grave"},
    {"classification": "Verb", "word": "grave"},
    {"classification": "Noun", "word": "grave"},
    {"classification": "Adjective", "word": "gravity"},
    {"classification": "Adjective", "word": "gray"},
    {"classification": "Noun", "word": "gray"},
    {"classification": "Verb", "word": "grease"},
    {"classification": "Noun", "word": "grease"},
    {"classification": "Adjective", "word": "great"},
    {"classification": "Noun", "word": "great"},
    {"classification": "Adverb", "word": "greatly"},
    {"classification": "Noun", "word": "greed"},
    {"classification": "Adjective", "word": "greek"},
    {"classification": "Noun", "word": "greek"},
    {"classification": "Adjective", "word": "green"},
    {"classification": "Verb", "word": "green"},
    {"classification": "Noun", "word": "green"},
    {"classification": "Noun", "word": "greet"},
    {"classification": "Verb", "word": "greet"},
    {"classification": "Adjective", "word": "greet"},
    {"classification": "Verb", "word": "grew"},
    {"classification": "Verb", "word": "grind"},
    {"classification": "Noun", "word": "grind"},
    {"classification": "Verb", "word": "grip"},
    {"classification": "Noun", "word": "grip"},
    {"classification": "Adjective", "word": "gross"},
    {"classification": "Noun", "word": "ground"},
    {"classification": "Verb", "word": "ground"},
    {"classification": "Noun", "word": "group"},
    {"classification": "Verb", "word": "grow"},
    {"classification": "Noun", "word": "growth"},
    {"classification": "Verb", "word": "guard"},
    {"classification": "Noun", "word": "guard"},
    {"classification": "Noun", "word": "guards"},
    {"classification": "Verb", "word": "guess"},
    {"classification": "Noun", "word": "guess"},
    {"classification": "Verb", "word": "guest"},
    {"classification": "Noun", "word": "guest"},
    {"classification": "Noun", "word": "guidance"},
    {"classification": "Noun", "word": "guide"},
    {"classification": "Verb", "word": "guide"},
    {"classification": "Verb", "word": "guilt"},
    {"classification": "Adjective", "word": "guilty"},
    {"classification": "Noun", "word": "gulf"},
    {"classification": "Verb", "word": "gun"},
    {"classification": "Noun", "word": "gun"},
    {"classification": "Verb", "word": "guy"},
    {"classification": "Noun", "word": "guy"},
    {"classification": "Noun", "word": "habit"},
    {"classification": "Noun", "word": "hair"},
    {"classification": "Adverb", "word": "half"},
    {"classification": "Verb", "word": "half"},
    {"classification": "Adjective", "word": "half"},
    {"classification": "Noun", "word": "hall"},
    {"classification": "Noun", "word": "ham"},
    {"classification": "Noun", "word": "hammer"},
    {"classification": "Verb", "word": "hammer"},
    {"classification": "Verb", "word": "hand"},
    {"classification": "Noun", "word": "hand"},
    {"classification": "Adjective", "word": "handed"},
    {"classification": "Verb", "word": "handle"},
    {"classification": "Noun", "word": "handle"},
    {"classification": "Noun", "word": "handling"},
    {"classification": "Verb", "word": "handling"},
    {"classification": "Adjective", "word": "handsome"},
    {"classification": "Noun", "word": "handwriting"},
    {"classification": "Verb", "word": "hang"},
    {"classification": "Noun", "word": "hang"},
    {"classification": "Noun", "word": "hanging"},
    {"classification": "Adjective", "word": "hanging"},
    {"classification": "Verb", "word": "happen"},
    {"classification": "Adverb", "word": "happily"},
    {"classification": "Noun", "word": "happiness"},
    {"classification": "Adjective", "word": "happy"},
    {"classification": "Verb", "word": "harbor"},
    {"classification": "Noun", "word": "harbor"},
    {"classification": "Adverb", "word": "hard"},
    {"classification": "Verb", "word": "hard"},
    {"classification": "Adjective", "word": "hard"},
    {"classification": "Noun", "word": "hard"},
    {"classification": "Verb", "word": "harden"},
    {"classification": "Adverb", "word": "hardly"},
    {"classification": "Adjective", "word": "hardy"},
    {"classification": "Noun", "word": "hardy"},
    {"classification": "Noun", "word": "harm"},
    {"classification": "Verb", "word": "harry"},
    {"classification": "Verb", "word": "harvest"},
    {"classification": "Noun", "word": "harvest"},
    {"classification": "Noun", "word": "haste"},
    {"classification": "Verb", "word": "hasten"},
    {"classification": "Noun", "word": "hat"},
    {"classification": "Adjective", "word": "hat"},
    {"classification": "Verb", "word": "hate"},
    {"classification": "Noun", "word": "hate"},
    {"classification": "Noun", "word": "hatred"},
    {"classification": "Verb", "word": "have"},
    {"classification": "Noun", "word": "having"},
    {"classification": "Noun", "word": "hay"},
    {"classification": "Verb", "word": "hay"},
    {"classification": "Pronoun", "word": "he"},
    {"classification": "Noun", "word": "head"},
    {"classification": "Verb", "word": "head"},
    {"classification": "Adjective", "word": "head"},
    {"classification": "Noun", "word": "headache"},
    {"classification": "Noun", "word": "headdress"},
    {"classification": "Adjective", "word": "headed"},
    {"classification": "Verb", "word": "heal"},
    {"classification": "Noun", "word": "health"},
    {"classification": "Adjective", "word": "healthy"},
    {"classification": "Verb", "word": "heap"},
    {"classification": "Noun", "word": "heap"},
    {"classification": "Verb", "word": "hear"},
    {"classification": "Verb", "word": "heart"},
    {"classification": "Noun", "word": "heart"},
    {"classification": "Verb", "word": "heat"},
    {"classification": "Noun", "word": "heat"},
    {"classification": "Adjective", "word": "heating"},
    {"classification": "Verb", "word": "heaven"},
    {"classification": "Noun", "word": "heaven"},
    {"classification": "Adverb", "word": "heavenly"},
    {"classification": "Adjective", "word": "heavenly"},
    {"classification": "Adverb", "word": "heavily"},
    {"classification": "Adjective", "word": "heavy"},
    {"classification": "Verb", "word": "heavy"},
    {"classification": "Adverb", "word": "heavy"},
    {"classification": "Noun", "word": "height"},
    {"classification": "Verb", "word": "heighten"},
    {"classification": "Verb", "word": "hell"},
    {"classification": "Verb", "word": "help"},
    {"classification": "Adjective", "word": "helpful"},
    {"classification": "Adjective", "word": "helpless"},
    {"classification": "Noun", "word": "hemisphere"},
    {"classification": "Noun", "word": "hen"},
    {"classification": "Verb", "word": "hence"},
    {"classification": "Adverb", "word": "hence"},
    {"classification": "Noun", "word": "henry"},
    {"classification": "Pronoun", "word": "her"},
    {"classification": "Verb", "word": "herd"},
    {"classification": "Noun", "word": "herd"},
    {"classification": "Adjective", "word": "herd"},
    {"classification": "Adverb", "word": "here"},
    {"classification": "Noun", "word": "here"},
    {"classification": "Adjective", "word": "heritage"},
    {"classification": "Noun", "word": "hero"},
    {"classification": "Adjective", "word": "heroic"},
    {"classification": "Verb", "word": "hesitate"},
    {"classification": "Noun", "word": "hide"},
    {"classification": "Verb", "word": "hide"},
    {"classification": "Adverb", "word": "high"},
    {"classification": "Noun", "word": "high"},
    {"classification": "Adjective", "word": "high"},
    {"classification": "Verb", "word": "high"},
    {"classification": "Adverb", "word": "highly"},
    {"classification": "Noun", "word": "highway"},
    {"classification": "Verb", "word": "hill"},
    {"classification": "Noun", "word": "hill"},
    {"classification": "Pronoun", "word": "him"},
    {"classification": "Adjective", "word": "hinder"},
    {"classification": "Verb", "word": "hinder"},
    {"classification": "Verb", "word": "hindrance"},
    {"classification": "Noun", "word": "hindrance"},
    {"classification": "Noun", "word": "hire"},
    {"classification": "Pronoun", "word": "his"},
    {"classification": "Noun", "word": "historian"},
    {"classification": "Adjective", "word": "historic"},
    {"classification": "Adjective", "word": "historical"},
    {"classification": "Verb", "word": "history"},
    {"classification": "Noun", "word": "hit"},
    {"classification": "Verb", "word": "hit"},
    {"classification": "Verb", "word": "hold"},
    {"classification": "Noun", "word": "hold"},
    {"classification": "Noun", "word": "holder"},
    {"classification": "Noun", "word": "holding"},
    {"classification": "Noun", "word": "hole"},
    {"classification": "Verb", "word": "hole"},
    {"classification": "Adjective", "word": "hole"},
    {"classification": "Adjective", "word": "holiday"},
    {"classification": "Verb", "word": "hollow"},
    {"classification": "Adjective", "word": "hollow"},
    {"classification": "Noun", "word": "hollow"},
    {"classification": "Adverb", "word": "hollow"},
    {"classification": "Adjective", "word": "holy"},
    {"classification": "Adjective", "word": "home"},
    {"classification": "Adverb", "word": "home"},
    {"classification": "Noun", "word": "home"},
    {"classification": "Adjective", "word": "homemade"},
    {"classification": "Adjective", "word": "homogeneous"},
    {"classification": "Adjective", "word": "honest"},
    {"classification": "Adjective", "word": "honesty"},
    {"classification": "Verb", "word": "honey"},
    {"classification": "Noun", "word": "honey"},
    {"classification": "Noun", "word": "honor"},
    {"classification": "Noun", "word": "hook"},
    {"classification": "Verb", "word": "hook"},
    {"classification": "Verb", "word": "hope"},
    {"classification": "Noun", "word": "hope"},
    {"classification": "Noun", "word": "horizon"},
    {"classification": "Adjective", "word": "horizontal"},
    {"classification": "Verb", "word": "horn"},
    {"classification": "Noun", "word": "horn"},
    {"classification": "Noun", "word": "horror"},
    {"classification": "Adjective", "word": "horse"},
    {"classification": "Noun", "word": "horse"},
    {"classification": "Verb", "word": "horse"},
    {"classification": "Adjective", "word": "hospital"},
    {"classification": "Noun", "word": "host"},
    {"classification": "Verb", "word": "host"},
    {"classification": "Adjective", "word": "hostile"},
    {"classification": "Noun", "word": "hostile"},
    {"classification": "Adjective", "word": "hot"},
    {"classification": "Noun", "word": "hotel"},
    {"classification": "Noun", "word": "hour"},
    {"classification": "Noun", "word": "hours"},
    {"classification": "Verb", "word": "house"},
    {"classification": "Noun", "word": "house"},
    {"classification": "Noun", "word": "household"},
    {"classification": "Adjective", "word": "household"},
    {"classification": "Noun", "word": "houses"},
    {"classification": "Noun", "word": "housing"},
    {"classification": "SubordConjunction", "word": "how"},
    {"classification": "Adverb", "word": "how"},
    {"classification": "Adverb", "word": "however"},
    {"classification": "Adjective", "word": "huge"},
    {"classification": "Adjective", "word": "human"},
    {"classification": "Noun", "word": "human"},
    {"classification": "Verb", "word": "humble"},
    {"classification": "Adjective", "word": "humble"},
    {"classification": "Verb", "word": "humor"},
    {"classification": "Noun", "word": "humor"},
    {"classification": "Noun", "word": "hundred"},
    {"classification": "Adjective", "word": "hundred"},
    {"classification": "Verb", "word": "hunger"},
    {"classification": "Noun", "word": "hunger"},
    {"classification": "Adjective", "word": "hungry"},
    {"classification": "Noun", "word": "hunt"},
    {"classification": "Verb", "word": "hunt"},
    {"classification": "Noun", "word": "hunting"},
    {"classification": "Noun", "word": "hurrah"},
    {"classification": "Verb", "word": "hurrah"},
    {"classification": "Adjective", "word": "hurried"},
    {"classification": "Noun", "word": "hurry"},
    {"classification": "Verb", "word": "hurry"},
    {"classification": "Noun", "word": "hurt"},
    {"classification": "Verb", "word": "hurt"},
    {"classification": "Noun", "word": "husband"},
    {"classification": "Verb", "word": "husband"},
    {"classification": "Noun", "word": "hut"},
    {"classification": "Noun", "word": "hydrogen"},
    {"classification": "Noun", "word": "ice"},
    {"classification": "Verb", "word": "ice"},
    {"classification": "Noun", "word": "idea"},
    {"classification": "Noun", "word": "ideal"},
    {"classification": "Adjective", "word": "ideal"},
    {"classification": "Noun", "word": "ideas"},
    {"classification": "Adjective", "word": "identical"},
    {"classification": "Verb", "word": "identify"},
    {"classification": "Adjective", "word": "ideological"},
    {"classification": "Adjective", "word": "idle"},
    {"classification": "Verb", "word": "idle"},
    {"classification": "SubordConjunction", "word": "if"},
    {"classification": "Verb", "word": "ignore"},
    {"classification": "Noun", "word": "ill"},
    {"classification": "Adjective", "word": "ill"},
    {"classification": "Adverb", "word": "ill"},
    {"classification": "Noun", "word": "illness"},
    {"classification": "Verb", "word": "illuminate"},
    {"classification": "Adjective", "word": "illuminate"},
    {"classification": "Noun", "word": "illusion"},
    {"classification": "Verb", "word": "illustrate"},
    {"classification": "Adjective", "word": "illustrate"},
    {"classification": "Noun", "word": "illustration"},
    {"classification": "Verb", "word": "image"},
    {"classification": "Noun", "word": "image"},
    {"classification": "Adjective", "word": "imaginary"},
    {"classification": "Adjective", "word": "imaginative"},
    {"classification": "Verb", "word": "imagine"},
    {"classification": "Verb", "word": "imitate"},
    {"classification": "Adjective", "word": "immediate"},
    {"classification": "Adverb", "word": "immediately"},
    {"classification": "Adjective", "word": "immense"},
    {"classification": "Verb", "word": "impact"},
    {"classification": "Noun", "word": "impact"},
    {"classification": "Adjective", "word": "imperial"},
    {"classification": "Verb", "word": "implement"},
    {"classification": "Noun", "word": "implement"},
    {"classification": "Adjective", "word": "implicit"},
    {"classification": "Verb", "word": "imply"},
    {"classification": "Noun", "word": "import"},
    {"classification": "Verb", "word": "import"},
    {"classification": "Verb", "word": "important"},
    {"classification": "Verb", "word": "impose"},
    {"classification": "Noun", "word": "impose"},
    {"classification": "Adjective", "word": "impossible"},
    {"classification": "Verb", "word": "impress"},
    {"classification": "Adjective", "word": "impressive"},
    {"classification": "Verb", "word": "improve"},
    {"classification": "Noun", "word": "impulse"},
    {"classification": "Verb", "word": "impulse"},
    {"classification": "Preposition", "word": "in"},
    {"classification": "Verb", "word": "in"},
    {"classification": "Noun", "word": "in"},
    {"classification": "Adverb", "word": "in"},
    {"classification": "Adjective", "word": "inadequate"},
    {"classification": "Noun", "word": "inc"},
    {"classification": "Adjective", "word": "incentive"},
    {"classification": "Adjective", "word": "incessant"},
    {"classification": "Noun", "word": "inch"},
    {"classification": "Adjective", "word": "inch"},
    {"classification": "Verb", "word": "inch"},
    {"classification": "Adjective", "word": "incident"},
    {"classification": "Verb", "word": "incline"},
    {"classification": "Verb", "word": "include"},
    {"classification": "Adjective", "word": "included"},
    {"classification": "Adjective", "word": "inclusive"},
    {"classification": "Noun", "word": "income"},
    {"classification": "Adjective", "word": "incompatible"},
    {"classification": "Adjective", "word": "inconsistent"},
    {"classification": "Adjective", "word": "incorporate"},
    {"classification": "Verb", "word": "incorporate"},
    {"classification": "Verb", "word": "increase"},
    {"classification": "Adverb", "word": "increasingly"},
    {"classification": "Adjective", "word": "incredible"},
    {"classification": "Adverb", "word": "indeed"},
    {"classification": "Noun", "word": "independence"},
    {"classification": "Adjective", "word": "independent"},
    {"classification": "Noun", "word": "index"},
    {"classification": "Verb", "word": "index"},
    {"classification": "Noun", "word": "india"},
    {"classification": "Noun", "word": "indian"},
    {"classification": "Adjective", "word": "indian"},
    {"classification": "Verb", "word": "indicate"},
    {"classification": "Adjective", "word": "indicated"},
    {"classification": "Adjective", "word": "indigenous"},
    {"classification": "Adjective", "word": "indirect"},
    {"classification": "Noun", "word": "individual"},
    {"classification": "Adjective", "word": "individual"},
    {"classification": "Adjective", "word": "indoor"},
    {"classification": "Verb", "word": "induce"},
    {"classification": "Adjective", "word": "industrial"},
    {"classification": "Adjective", "word": "inevitable"},
    {"classification": "Adverb", "word": "inevitably"},
    {"classification": "Verb", "word": "infer"},
    {"classification": "Adjective", "word": "inferior"},
    {"classification": "Noun", "word": "influence"},
    {"classification": "Verb", "word": "influence"},
    {"classification": "Adjective", "word": "influential"},
    {"classification": "Adjective", "word": "inform"},
    {"classification": "Verb", "word": "inform"},
    {"classification": "Verb", "word": "information"},
    {"classification": "Adjective", "word": "informed"},
    {"classification": "Adjective", "word": "ingenious"},
    {"classification": "Adjective", "word": "inherent"},
    {"classification": "Verb", "word": "inhibit"},
    {"classification": "Noun", "word": "initial"},
    {"classification": "Adjective", "word": "initial"},
    {"classification": "Verb", "word": "initial"},
    {"classification": "Adjective", "word": "initiative"},
    {"classification": "Verb", "word": "injure"},
    {"classification": "Adjective", "word": "injury"},
    {"classification": "Noun", "word": "ink"},
    {"classification": "Verb", "word": "ink"},
    {"classification": "Noun", "word": "inn"},
    {"classification": "Verb", "word": "inn"},
    {"classification": "Adjective", "word": "innate"},
    {"classification": "Verb", "word": "innate"},
    {"classification": "Adjective", "word": "inner"},
    {"classification": "Noun", "word": "innocence"},
    {"classification": "Adjective", "word": "innocent"},
    {"classification": "Noun", "word": "innovation"},
    {"classification": "Verb", "word": "inquire"},
    {"classification": "Noun", "word": "insect"},
    {"classification": "Adjective", "word": "insect"},
    {"classification": "Noun", "word": "inside"},
    {"classification": "Adjective", "word": "inside"},
    {"classification": "Adverb", "word": "inside"},
    {"classification": "Noun", "word": "insight"},
    {"classification": "Verb", "word": "insist"},
    {"classification": "Verb", "word": "inspect"},
    {"classification": "Adjective", "word": "inspired"},
    {"classification": "Noun", "word": "instance"},
    {"classification": "Verb", "word": "instance"},
    {"classification": "Adjective", "word": "instant"},
    {"classification": "Adverb", "word": "instant"},
    {"classification": "Adverb", "word": "instead"},
    {"classification": "Verb", "word": "instinct"},
    {"classification": "Adjective", "word": "instinct"},
    {"classification": "Noun", "word": "institute"},
    {"classification": "Adjective", "word": "institute"},
    {"classification": "Verb", "word": "institute"},
    {"classification": "Adjective", "word": "instruct"},
    {"classification": "Verb", "word": "instruct"},
    {"classification": "Verb", "word": "instrument"},
    {"classification": "Verb", "word": "insult"},
    {"classification": "Noun", "word": "insurance"},
    {"classification": "Verb", "word": "insure"},
    {"classification": "Noun", "word": "integer"},
    {"classification": "Verb", "word": "integrate"},
    {"classification": "Noun", "word": "intellect"},
    {"classification": "Adjective", "word": "intellectual"},
    {"classification": "Adjective", "word": "intelligent"},
    {"classification": "Verb", "word": "intend"},
    {"classification": "Adjective", "word": "intended"},
    {"classification": "Adjective", "word": "intense"},
    {"classification": "Noun", "word": "interact"},
    {"classification": "Verb", "word": "interact"},
    {"classification": "Verb", "word": "interested"},
    {"classification": "Adjective", "word": "interesting"},
    {"classification": "Verb", "word": "interfere"},
    {"classification": "Adjective", "word": "interior"},
    {"classification": "Verb", "word": "interlock"},
    {"classification": "Adjective", "word": "intermediate"},
    {"classification": "Verb", "word": "intermediate"},
    {"classification": "Adjective", "word": "internal"},
    {"classification": "Adjective", "word": "international"},
    {"classification": "Verb", "word": "interpret"},
    {"classification": "Verb", "word": "interrupt"},
    {"classification": "Verb", "word": "intersect"},
    {"classification": "Noun", "word": "interval"},
    {"classification": "Verb", "word": "intervene"},
    {"classification": "Verb", "word": "interview"},
    {"classification": "Noun", "word": "player"},
    {"classification": "Verb", "word": "plead"},
    {"classification": "Adjective", "word": "pleasant"},
    {"classification": "Verb", "word": "please"},
    {"classification": "Adjective", "word": "pleased"},
    {"classification": "Noun", "word": "pleasure"},
    {"classification": "Verb", "word": "pleasure"},
    {"classification": "Adjective", "word": "plenty"},
    {"classification": "Noun", "word": "plot"},
    {"classification": "Verb", "word": "plot"},
    {"classification": "Noun", "word": "plow"},
    {"classification": "Verb", "word": "plow"},
    {"classification": "Noun", "word": "plug"},
    {"classification": "Verb", "word": "plug"},
    {"classification": "Noun", "word": "plural"},
    {"classification": "Adjective", "word": "plural"},
    {"classification": "Adjective", "word": "plus"},
    {"classification": "Noun", "word": "pocket"},
    {"classification": "Verb", "word": "pocket"},
    {"classification": "Noun", "word": "poem"},
    {"classification": "Noun", "word": "poet"},
    {"classification": "Adjective", "word": "poetic"},
    {"classification": "Noun", "word": "poetry"},
    {"classification": "Noun", "word": "point"},
    {"classification": "Verb", "word": "point"},
    {"classification": "Adjective", "word": "pointed"},
    {"classification": "Noun", "word": "pointing"},
    {"classification": "Noun", "word": "poison"},
    {"classification": "Verb", "word": "poison"},
    {"classification": "Noun", "word": "pole"},
    {"classification": "Verb", "word": "pole"},
    {"classification": "Noun", "word": "police"},
    {"classification": "Verb", "word": "police"},
    {"classification": "Noun", "word": "policies"},
    {"classification": "Noun", "word": "policy"},
    {"classification": "Verb", "word": "policy"},
    {"classification": "Noun", "word": "polish"},
    {"classification": "Adjective", "word": "polish"},
    {"classification": "Verb", "word": "polish"},
    {"classification": "Verb", "word": "polite"},
    {"classification": "Adjective", "word": "political"},
    {"classification": "Adjective", "word": "politician"},
    {"classification": "Noun", "word": "polynomial"},
    {"classification": "Adjective", "word": "polynomial"},
    {"classification": "Noun", "word": "pond"},
    {"classification": "Verb", "word": "pond"},
    {"classification": "Noun", "word": "pool"},
    {"classification": "Verb", "word": "pool"},
    {"classification": "Noun", "word": "poor"},
    {"classification": "Adjective", "word": "poor"},
    {"classification": "Noun", "word": "pope"},
    {"classification": "Adjective", "word": "popular"},
    {"classification": "Noun", "word": "porch"},
    {"classification": "Noun", "word": "port"},
    {"classification": "Verb", "word": "port"},
    {"classification": "Noun", "word": "portion"},
    {"classification": "Verb", "word": "portion"},
    {"classification": "Noun", "word": "position"},
    {"classification": "Verb", "word": "position"},
    {"classification": "Adjective", "word": "positive"},
    {"classification": "Verb", "word": "possess"},
    {"classification": "Noun", "word": "possession"},
    {"classification": "Verb", "word": "possession"},
    {"classification": "Noun", "word": "possibilities"},
    {"classification": "Adjective", "word": "possible"},
    {"classification": "Adverb", "word": "possibly"},
    {"classification": "Noun", "word": "post"},
    {"classification": "Adjective", "word": "post"},
    {"classification": "Adverb", "word": "post"},
    {"classification": "Verb", "word": "post"},
    {"classification": "Verb", "word": "postpone"},
    {"classification": "Adjective", "word": "postulate"},
    {"classification": "Verb", "word": "postulate"},
    {"classification": "Noun", "word": "pot"},
    {"classification": "Verb", "word": "pot"},
    {"classification": "Adjective", "word": "potential"},
    {"classification": "Noun", "word": "pound"},
    {"classification": "Verb", "word": "pound"},
    {"classification": "Noun", "word": "pounds"},
    {"classification": "Noun", "word": "pour"},
    {"classification": "Verb", "word": "pour"},
    {"classification": "Adjective", "word": "pour"},
    {"classification": "Noun", "word": "powder"},
    {"classification": "Verb", "word": "powder"},
    {"classification": "Noun", "word": "power"},
    {"classification": "Adjective", "word": "powerful"},
    {"classification": "Adjective", "word": "practical"},
    {"classification": "Adverb", "word": "practically"},
    {"classification": "Verb", "word": "practice"},
    {"classification": "Noun", "word": "pragmatic"},
    {"classification": "Adjective", "word": "pragmatic"},
    {"classification": "Verb", "word": "praise"},
    {"classification": "Verb", "word": "pray"},
    {"classification": "Noun", "word": "prayer"},
    {"classification": "Verb", "word": "prayer"},
    {"classification": "Verb", "word": "preach"},
    {"classification": "Verb", "word": "precede"},
    {"classification": "Adjective", "word": "preceding"},
    {"classification": "Adjective", "word": "precious"},
    {"classification": "Adjective", "word": "precipitate"},
    {"classification": "Verb", "word": "precipitate"},
    {"classification": "Adjective", "word": "precise"},
    {"classification": "Verb", "word": "predict"},
    {"classification": "Verb", "word": "prefer"},
    {"classification": "Adjective", "word": "preliminary"},
    {"classification": "Noun", "word": "premier"},
    {"classification": "Adjective", "word": "premier"},
    {"classification": "Noun", "word": "premise"},
    {"classification": "Verb", "word": "premise"},
    {"classification": "Noun", "word": "preparation"},
    {"classification": "Verb", "word": "prepare"},
    {"classification": "Adjective", "word": "prepared"},
    {"classification": "Noun", "word": "preposition"},
    {"classification": "Noun", "word": "presence"},
    {"classification": "Adjective", "word": "present"},
    {"classification": "Verb", "word": "present"},
    {"classification": "Adverb", "word": "presently"},
    {"classification": "Verb", "word": "preserve"},
    {"classification": "Adjective", "word": "president"},
    {"classification": "Adjective", "word": "presidential"},
    {"classification": "Noun", "word": "press"},
    {"classification": "Verb", "word": "press"},
    {"classification": "Adjective", "word": "pressing"},
    {"classification": "Verb", "word": "prestige"},
    {"classification": "Adverb", "word": "presumably"},
    {"classification": "Verb", "word": "presume"},
    {"classification": "Verb", "word": "pretend"},
    {"classification": "Adverb", "word": "pretty"},
    {"classification": "Adjective", "word": "pretty"},
    {"classification": "Verb", "word": "prevail"},
    {"classification": "Verb", "word": "prevent"},
    {"classification": "Adjective", "word": "previous"},
    {"classification": "Adverb", "word": "previously"},
    {"classification": "Verb", "word": "price"},
    {"classification": "Noun", "word": "pride"},
    {"classification": "Verb", "word": "pride"},
    {"classification": "Noun", "word": "priest"},
    {"classification": "Verb", "word": "priest"},
    {"classification": "Adverb", "word": "primarily"},
    {"classification": "Adjective", "word": "primary"},
    {"classification": "Noun", "word": "prime"},
    {"classification": "Adjective", "word": "prime"},
    {"classification": "Verb", "word": "prime"},
    {"classification": "Adjective", "word": "primitive"},
    {"classification": "Verb", "word": "prince"},
    {"classification": "Adjective", "word": "prince"},
    {"classification": "Noun", "word": "principal"},
    {"classification": "Adjective", "word": "principal"},
    {"classification": "Verb", "word": "principle"},
    {"classification": "Noun", "word": "print"},
    {"classification": "Verb", "word": "print"},
    {"classification": "Adjective", "word": "prior"},
    {"classification": "Adjective", "word": "priority"},
    {"classification": "Noun", "word": "prison"},
    {"classification": "Verb", "word": "prison"},
    {"classification": "Adjective", "word": "private"},
    {"classification": "Noun", "word": "prize"},
    {"classification": "Verb", "word": "prize"},
    {"classification": "Adjective", "word": "probable"},
    {"classification": "Adverb", "word": "probably"},
    {"classification": "Noun", "word": "problem"},
    {"classification": "Noun", "word": "proceed"},
    {"classification": "Verb", "word": "proceed"},
    {"classification": "Verb", "word": "procession"},
    {"classification": "Verb", "word": "proclaim"},
    {"classification": "Verb", "word": "procure"},
    {"classification": "Noun", "word": "produce"},
    {"classification": "Verb", "word": "produce"},
    {"classification": "Verb", "word": "product"},
    {"classification": "Adjective", "word": "productive"},
    {"classification": "Noun", "word": "profession"},
    {"classification": "Verb", "word": "profession"},
    {"classification": "Adjective", "word": "professional"},
    {"classification": "Noun", "word": "profit"},
    {"classification": "Verb", "word": "profit"},
    {"classification": "Noun", "word": "profound"},
    {"classification": "Adjective", "word": "profound"},
    {"classification": "Verb", "word": "profound"},
    {"classification": "Noun", "word": "program"},
    {"classification": "Noun", "word": "progress"},
    {"classification": "Verb", "word": "progress"},
    {"classification": "Verb", "word": "prohibit"},
    {"classification": "Noun", "word": "project"},
    {"classification": "Verb", "word": "project"},
    {"classification": "Adjective", "word": "prominent"},
    {"classification": "Verb", "word": "promise"},
    {"classification": "Adjective", "word": "promise"},
    {"classification": "Adjective", "word": "promising"},
    {"classification": "Verb", "word": "promote"},
    {"classification": "Noun", "word": "prompt"},
    {"classification": "Verb", "word": "prompt"},
    {"classification": "Adverb", "word": "promptly"},
    {"classification": "Verb", "word": "pronounce"},
    {"classification": "Noun", "word": "proof"},
    {"classification": "Verb", "word": "proof"},
    {"classification": "Adjective", "word": "proof"},
    {"classification": "Noun", "word": "propaganda"},
    {"classification": "Verb", "word": "propagate"},
    {"classification": "Adjective", "word": "proper"},
    {"classification": "Adverb", "word": "proper"},
    {"classification": "Adverb", "word": "properly"},
    {"classification": "Verb", "word": "property"},
    {"classification": "Adjective", "word": "property"},
    {"classification": "Noun", "word": "proportion"},
    {"classification": "Verb", "word": "proportion"},
    {"classification": "Noun", "word": "proposal"},
    {"classification": "Verb", "word": "propose"},
    {"classification": "Verb", "word": "prospect"},
    {"classification": "Verb", "word": "prosper"},
    {"classification": "Verb", "word": "protect"},
    {"classification": "Noun", "word": "protection"},
    {"classification": "Verb", "word": "protest"},
    {"classification": "Adjective", "word": "protestant"},
    {"classification": "Verb", "word": "protestant"},
    {"classification": "Adjective", "word": "proud"},
    {"classification": "Verb", "word": "prove"},
    {"classification": "Verb", "word": "provide"},
    {"classification": "Noun", "word": "providence"},
    {"classification": "Noun", "word": "province"},
    {"classification": "Noun", "word": "provision"},
    {"classification": "Verb", "word": "provision"},
    {"classification": "Verb", "word": "provoke"},
    {"classification": "Noun", "word": "prudence"},
    {"classification": "Adjective", "word": "psychological"},
    {"classification": "Noun", "word": "public"},
    {"classification": "Adjective", "word": "public"},
    {"classification": "Adverb", "word": "publicly"},
    {"classification": "Verb", "word": "publish"},
    {"classification": "Noun", "word": "pull"},
    {"classification": "Verb", "word": "pull"},
    {"classification": "Adjective", "word": "pulled"},
    {"classification": "Adjective", "word": "pulmonary"},
    {"classification": "Noun", "word": "pump"},
    {"classification": "Verb", "word": "pump"},
    {"classification": "Adjective", "word": "punctual"},
    {"classification": "Verb", "word": "punish"},
    {"classification": "Noun", "word": "pupil"},
    {"classification": "Verb", "word": "purchase"},
    {"classification": "Adjective", "word": "pure"},
    {"classification": "Adverb", "word": "purely"},
    {"classification": "Noun", "word": "purple"},
    {"classification": "Adjective", "word": "purple"},
    {"classification": "Verb", "word": "purple"},
    {"classification": "Noun", "word": "purport"},
    {"classification": "Noun", "word": "purpose"},
    {"classification": "Verb", "word": "purpose"},
    {"classification": "Adverb", "word": "pursuant"},
    {"classification": "Adjective", "word": "pursuant"},
    {"classification": "Verb", "word": "pursue"},
    {"classification": "Noun", "word": "push"},
    {"classification": "Verb", "word": "push"},
    {"classification": "Noun", "word": "put"},
    {"classification": "Verb", "word": "put"},
    {"classification": "Noun", "word": "putting"},
    {"classification": "Verb", "word": "puzzle"},
    {"classification": "Noun", "word": "qualification"},
    {"classification": "Adjective", "word": "qualified"},
    {"classification": "Verb", "word": "qualify"},
    {"classification": "Noun", "word": "qualities"},
    {"classification": "Verb", "word": "quantity"},
    {"classification": "Noun", "word": "quarrel"},
    {"classification": "Verb", "word": "quarrel"},
    {"classification": "Noun", "word": "quart"},
    {"classification": "Verb", "word": "quarter"},
    {"classification": "Noun", "word": "queen"},
    {"classification": "Verb", "word": "queen"},
    {"classification": "Noun", "word": "question"},
    {"classification": "Verb", "word": "question"},
    {"classification": "Noun", "word": "quick"},
    {"classification": "Adjective", "word": "quick"},
    {"classification": "Adverb", "word": "quick"},
    {"classification": "Adverb", "word": "quickly"},
    {"classification": "Adjective", "word": "quiet"},
    {"classification": "Verb", "word": "quiet"},
    {"classification": "Adverb", "word": "quietly"},
    {"classification": "Adverb", "word": "quite"},
    {"classification": "Adjective", "word": "quite"},
    {"classification": "Noun", "word": "quote"},
    {"classification": "Verb", "word": "quote"},
    {"classification": "Noun", "word": "rabbit"},
    {"classification": "Noun", "word": "race"},
    {"classification": "Verb", "word": "race"},
    {"classification": "Adjective", "word": "racial"},
    {"classification": "Noun", "word": "radical"},
    {"classification": "Adjective", "word": "radical"},
    {"classification": "Adjective", "word": "radio"},
    {"classification": "Noun", "word": "radius"},
    {"classification": "Noun", "word": "rail"},
    {"classification": "Verb", "word": "rail"},
    {"classification": "Noun", "word": "railroad"},
    {"classification": "Verb", "word": "railroad"},
    {"classification": "Noun", "word": "rain"},
    {"classification": "Verb", "word": "rain"},
    {"classification": "Verb", "word": "raise"},
    {"classification": "Adjective", "word": "raised"},
    {"classification": "Noun", "word": "rake"},
    {"classification": "Verb", "word": "rake"},
    {"classification": "Noun", "word": "ralph"},
    {"classification": "Noun", "word": "ran"},
    {"classification": "Verb", "word": "ran"},
    {"classification": "Noun", "word": "ranch"},
    {"classification": "Verb", "word": "ranch"},
    {"classification": "Noun", "word": "random"},
    {"classification": "Adjective", "word": "random"},
    {"classification": "Verb", "word": "rang"},
    {"classification": "Noun", "word": "range"},
    {"classification": "Verb", "word": "range"},
    {"classification": "Adjective", "word": "rank"},
    {"classification": "Adverb", "word": "rank"},
    {"classification": "Verb", "word": "rank"},
    {"classification": "Adjective", "word": "rapid"},
    {"classification": "Adverb", "word": "rapidly"},
    {"classification": "Adjective", "word": "rare"},
    {"classification": "Adverb", "word": "rarely"},
    {"classification": "Noun", "word": "rate"},
    {"classification": "Verb", "word": "rate"},
    {"classification": "Adjective", "word": "rather"},
    {"classification": "Noun", "word": "ratio"},
    {"classification": "Adjective", "word": "rational"},
    {"classification": "Noun", "word": "raw"},
    {"classification": "Adjective", "word": "raw"},
    {"classification": "Noun", "word": "ray"},
    {"classification": "Verb", "word": "ray"},
    {"classification": "Verb", "word": "razor"},
    {"classification": "Noun", "word": "reach"},
    {"classification": "Verb", "word": "reach"},
    {"classification": "Verb", "word": "react"},
    {"classification": "Noun", "word": "reaction"},
    {"classification": "Adjective", "word": "reactionary"},
    {"classification": "Noun", "word": "read"},
    {"classification": "Verb", "word": "read"},
    {"classification": "Adjective", "word": "read"},
    {"classification": "Noun", "word": "reader"},
    {"classification": "Adverb", "word": "readily"},
    {"classification": "Adjective", "word": "reading"},
    {"classification": "Noun", "word": "ready"},
    {"classification": "Adjective", "word": "ready"},
    {"classification": "Adverb", "word": "ready"},
    {"classification": "Verb", "word": "ready"},
    {"classification": "Noun", "word": "real"},
    {"classification": "Adjective", "word": "real"},
    {"classification": "Noun", "word": "realism"},
    {"classification": "Adjective", "word": "realistic"},
    {"classification": "Noun", "word": "realization"},
    {"classification": "Verb", "word": "realize"},
    {"classification": "Adverb", "word": "really"},
    {"classification": "Noun", "word": "rear"},
    {"classification": "Adjective", "word": "rear"},
    {"classification": "Verb", "word": "rear"},
    {"classification": "Adverb", "word": "rear"},
    {"classification": "Noun", "word": "reason"},
    {"classification": "Verb", "word": "reason"},
    {"classification": "Adverb", "word": "reasonable"},
    {"classification": "Adverb", "word": "reasonably"},
    {"classification": "Noun", "word": "rebel"},
    {"classification": "Verb", "word": "rebel"},
    {"classification": "Noun", "word": "recall"},
    {"classification": "Verb", "word": "recall"},
    {"classification": "Noun", "word": "receipt"},
    {"classification": "Verb", "word": "receipt"},
    {"classification": "Verb", "word": "receive"},
    {"classification": "Adjective", "word": "recent"},
    {"classification": "Adverb", "word": "recently"},
    {"classification": "Noun", "word": "recognition"},
    {"classification": "Verb", "word": "recognize"},
    {"classification": "Verb", "word": "recommend"},
    {"classification": "Verb", "word": "record"},
    {"classification": "Adjective", "word": "recording"},
    {"classification": "Noun", "word": "rectangle"},
    {"classification": "Adjective", "word": "rectangle"},
    {"classification": "Noun", "word": "rector"},
    {"classification": "Verb", "word": "recur"},
    {"classification": "Noun", "word": "red"},
    {"classification": "Adjective", "word": "red"},
    {"classification": "Verb", "word": "red"},
    {"classification": "Verb", "word": "redden"},
    {"classification": "Adjective", "word": "redden"},
    {"classification": "Noun", "word": "reduce"},
    {"classification": "Verb", "word": "reduction"},
    {"classification": "Verb", "word": "refer"},
    {"classification": "Verb", "word": "reflect"},
    {"classification": "Adjective", "word": "reflected"},
    {"classification": "Noun", "word": "reflection"},
    {"classification": "Noun", "word": "reform"},
    {"classification": "Verb", "word": "reform"},
    {"classification": "Noun", "word": "refresh"},
    {"classification": "Adjective", "word": "refresh"},
    {"classification": "Verb", "word": "refund"},
    {"classification": "Noun", "word": "refuse"},
    {"classification": "Adjective", "word": "refuse"},
    {"classification": "Verb", "word": "refuse"},
    {"classification": "Verb", "word": "refute"},
    {"classification": "Verb", "word": "regard"},
    {"classification": "Preposition", "word": "regarding"},
    {"classification": "Adjective", "word": "regardless"},
    {"classification": "Noun", "word": "regime"},
    {"classification": "Verb", "word": "regiment"},
    {"classification": "Noun", "word": "region"},
    {"classification": "Adjective", "word": "regional"},
    {"classification": "Noun", "word": "register"},
    {"classification": "Verb", "word": "register"},
    {"classification": "Verb", "word": "registration"},
    {"classification": "Verb", "word": "regret"},
    {"classification": "Adjective", "word": "regular"},
    {"classification": "Adverb", "word": "regularly"},
    {"classification": "Noun", "word": "rehabilitation"},
    {"classification": "Noun", "word": "reign"},
    {"classification": "Verb", "word": "reign"},
    {"classification": "Noun", "word": "reinforce"},
    {"classification": "Verb", "word": "reinforce"},
    {"classification": "Verb", "word": "reject"},
    {"classification": "Noun", "word": "rejoice"},
    {"classification": "Verb", "word": "rejoice"},
    {"classification": "Verb", "word": "relate"},
    {"classification": "Noun", "word": "relation"},
    {"classification": "Adjective", "word": "relative"},
    {"classification": "Adverb", "word": "relatively"},
    {"classification": "Noun", "word": "release"},
    {"classification": "Verb", "word": "release"},
    {"classification": "Noun", "word": "relevance"},
    {"classification": "Adjective", "word": "relevant"},
    {"classification": "Adjective", "word": "reliable"},
    {"classification": "Noun", "word": "relief"},
    {"classification": "Verb", "word": "relieve"},
    {"classification": "Noun", "word": "religion"},
    {"classification": "Adjective", "word": "religious"},
    {"classification": "Noun", "word": "reluctance"},
    {"classification": "Verb", "word": "rely"},
    {"classification": "Noun", "word": "remain"},
    {"classification": "Verb", "word": "remain"},
    {"classification": "Adjective", "word": "remainder"},
    {"classification": "Noun", "word": "remark"},
    {"classification": "Verb", "word": "remark"},
    {"classification": "Adjective", "word": "remarkable"},
    {"classification": "Noun", "word": "remedy"},
    {"classification": "Verb", "word": "remember"},
    {"classification": "Verb", "word": "remind"},
    {"classification": "Adjective", "word": "remote"},
    {"classification": "Noun", "word": "removal"},
    {"classification": "Noun", "word": "remove"},
    {"classification": "Verb", "word": "remove"},
    {"classification": "Adjective", "word": "removed"},
    {"classification": "Noun", "word": "renaissance"},
    {"classification": "Noun", "word": "render"},
    {"classification": "Verb", "word": "render"},
    {"classification": "Noun", "word": "rent"},
    {"classification": "Verb", "word": "rent"},
    {"classification": "Noun", "word": "reorganization"},
    {"classification": "Noun", "word": "repair"},
    {"classification": "Verb", "word": "repair"},
    {"classification": "Noun", "word": "repeat"},
    {"classification": "Verb", "word": "repeat"},
    {"classification": "Noun", "word": "repetition"},
    {"classification": "Verb", "word": "replace"},
    {"classification": "Verb", "word": "reply"},
    {"classification": "Verb", "word": "report"},
    {"classification": "Verb", "word": "represent"},
    {"classification": "Adjective", "word": "representative"},
    {"classification": "Verb", "word": "repress"},
    {"classification": "Verb", "word": "reproduce"},
    {"classification": "Adjective", "word": "republic"},
    {"classification": "Noun", "word": "republican"},
    {"classification": "Adjective", "word": "republican"},
    {"classification": "Verb", "word": "repudiate"},
    {"classification": "Verb", "word": "reputation"},
    {"classification": "Noun", "word": "request"},
    {"classification": "Verb", "word": "request"},
    {"classification": "Verb", "word": "require"},
    {"classification": "Noun", "word": "requirement"},
    {"classification": "Verb", "word": "rescue"},
    {"classification": "Noun", "word": "research"},
    {"classification": "Verb", "word": "research"},
    {"classification": "Verb", "word": "reserve"},
    {"classification": "Adjective", "word": "reserved"},
    {"classification": "Noun", "word": "residence"},
    {"classification": "Adjective", "word": "resident"},
    {"classification": "Adjective", "word": "residential"},
    {"classification": "Adjective", "word": "intimate"},
    {"classification": "Preposition", "word": "into"},
    {"classification": "Noun", "word": "intrinsic"},
    {"classification": "Adjective", "word": "intrinsic"},
    {"classification": "Verb", "word": "introduce"},
    {"classification": "Adjective", "word": "intuitive"},
    {"classification": "Verb", "word": "invade"},
    {"classification": "Verb", "word": "invent"},
    {"classification": "Verb", "word": "inventory"},
    {"classification": "Noun", "word": "inverse"},
    {"classification": "Adjective", "word": "inverse"},
    {"classification": "Verb", "word": "invest"},
    {"classification": "Verb", "word": "investigate"},
    {"classification": "Noun", "word": "investigation"},
    {"classification": "Noun", "word": "invitation"},
    {"classification": "Verb", "word": "invite"},
    {"classification": "Verb", "word": "invoke"},
    {"classification": "Verb", "word": "involve"},
    {"classification": "Adjective", "word": "involved"},
    {"classification": "Noun", "word": "inward"},
    {"classification": "Adjective", "word": "inward"},
    {"classification": "Adjective", "word": "irish"},
    {"classification": "Noun", "word": "iron"},
    {"classification": "Verb", "word": "iron"},
    {"classification": "Verb", "word": "irrigate"},
    {"classification": "Verb", "word": "is"},
    {"classification": "Noun", "word": "island"},
    {"classification": "Verb", "word": "island"},
    {"classification": "Verb", "word": "isolate"},
    {"classification": "Adjective", "word": "isolated"},
    {"classification": "Noun", "word": "issue"},
    {"classification": "Verb", "word": "issue"},
    {"classification": "Pronoun", "word": "it"},
    {"classification": "Noun", "word": "italian"},
    {"classification": "Adjective", "word": "italian"},
    {"classification": "Noun", "word": "item"},
    {"classification": "Adverb", "word": "item"},
    {"classification": "Verb", "word": "item"},
    {"classification": "Pronoun", "word": "its"},
    {"classification": "Noun", "word": "jack"},
    {"classification": "Verb", "word": "jack"},
    {"classification": "Noun", "word": "jacket"},
    {"classification": "Verb", "word": "jacket"},
    {"classification": "Noun", "word": "jail"},
    {"classification": "Verb", "word": "jail"},
    {"classification": "Noun", "word": "jane"},
    {"classification": "Noun", "word": "january"},
    {"classification": "Noun", "word": "japan"},
    {"classification": "Adjective", "word": "japan"},
    {"classification": "Verb", "word": "japan"},
    {"classification": "Adjective", "word": "japanese"},
    {"classification": "Noun", "word": "jaw"},
    {"classification": "Verb", "word": "jaw"},
    {"classification": "Adjective", "word": "jealous"},
    {"classification": "Noun", "word": "jean"},
    {"classification": "Noun", "word": "jersey"},
    {"classification": "Noun", "word": "jess"},
    {"classification": "Noun", "word": "jesus"},
    {"classification": "Noun", "word": "jet"},
    {"classification": "Verb", "word": "jet"},
    {"classification": "Noun", "word": "jew"},
    {"classification": "Noun", "word": "jewel"},
    {"classification": "Verb", "word": "jewel"},
    {"classification": "Adjective", "word": "jewish"},
    {"classification": "Noun", "word": "job"},
    {"classification": "Verb", "word": "job"},
    {"classification": "Noun", "word": "joe"},
    {"classification": "Noun", "word": "john"},
    {"classification": "Noun", "word": "johnny"},
    {"classification": "Noun", "word": "join"},
    {"classification": "Verb", "word": "join"},
    {"classification": "Noun", "word": "joint"},
    {"classification": "Verb", "word": "joint"},
    {"classification": "Adjective", "word": "joint"},
    {"classification": "Noun", "word": "joke"},
    {"classification": "Verb", "word": "joke"},
    {"classification": "Noun", "word": "joseph"},
    {"classification": "Adjective", "word": "journal"},
    {"classification": "Noun", "word": "journey"},
    {"classification": "Verb", "word": "journey"},
    {"classification": "Noun", "word": "joy"},
    {"classification": "Verb", "word": "joy"},
    {"classification": "Adjective", "word": "judge"},
    {"classification": "Verb", "word": "judge"},
    {"classification": "Noun", "word": "judgment"},
    {"classification": "Verb", "word": "judgment"},
    {"classification": "Adjective", "word": "judicial"},
    {"classification": "Noun", "word": "juice"},
    {"classification": "Verb", "word": "juice"},
    {"classification": "Noun", "word": "july"},
    {"classification": "Noun", "word": "jump"},
    {"classification": "Adjective", "word": "jump"},
    {"classification": "Adverb", "word": "jump"},
    {"classification": "Verb", "word": "jump"},
    {"classification": "Noun", "word": "june"},
    {"classification": "Noun", "word": "jungle"},
    {"classification": "Noun", "word": "junior"},
    {"classification": "Adjective", "word": "junior"},
    {"classification": "Noun", "word": "jurisdiction"},
    {"classification": "Adjective", "word": "jurisdiction"},
    {"classification": "Adjective", "word": "jury"},
    {"classification": "Noun", "word": "just"},
    {"classification": "Adjective", "word": "just"},
    {"classification": "Adverb", "word": "just"},
    {"classification": "Verb", "word": "just"},
    {"classification": "Adjective", "word": "justice"},
    {"classification": "Verb", "word": "justice"},
    {"classification": "Adjective", "word": "justify"},
    {"classification": "Verb", "word": "justify"},
    {"classification": "Noun", "word": "kansas"},
    {"classification": "Noun", "word": "kate"},
    {"classification": "Noun", "word": "keep"},
    {"classification": "Verb", "word": "keep"},
    {"classification": "Noun", "word": "keeping"},
    {"classification": "Noun", "word": "key"},
    {"classification": "Verb", "word": "key"},
    {"classification": "Noun", "word": "kick"},
    {"classification": "Verb", "word": "kick"},
    {"classification": "Noun", "word": "kid"},
    {"classification": "Verb", "word": "kid"},
    {"classification": "Noun", "word": "kill"},
    {"classification": "Verb", "word": "kill"},
    {"classification": "Noun", "word": "killer"},
    {"classification": "Adjective", "word": "killing"},
    {"classification": "Adjective", "word": "kind"},
    {"classification": "Verb", "word": "kind"},
    {"classification": "Noun", "word": "kindred"},
    {"classification": "Adjective", "word": "kindred"},
    {"classification": "Noun", "word": "king"},
    {"classification": "Verb", "word": "king"},
    {"classification": "Noun", "word": "kingdom"},
    {"classification": "Verb", "word": "kiss"},
    {"classification": "Noun", "word": "kitchen"},
    {"classification": "Verb", "word": "kitchen"},
    {"classification": "Noun", "word": "knee"},
    {"classification": "Verb", "word": "knee"},
    {"classification": "Verb", "word": "kneel"},
    {"classification": "Verb", "word": "knew"},
    {"classification": "Noun", "word": "knife"},
    {"classification": "Verb", "word": "knife"},
    {"classification": "Noun", "word": "knock"},
    {"classification": "Verb", "word": "knock"},
    {"classification": "Noun", "word": "knot"},
    {"classification": "Verb", "word": "knot"},
    {"classification": "Noun", "word": "know"},
    {"classification": "Verb", "word": "know"},
    {"classification": "Noun", "word": "knowing"},
    {"classification": "Adjective", "word": "knowing"},
    {"classification": "Verb", "word": "knowledge"},
    {"classification": "Noun", "word": "la"},
    {"classification": "Noun", "word": "label"},
    {"classification": "Verb", "word": "label"},
    {"classification": "Noun", "word": "labor"},
    {"classification": "Verb", "word": "labor"},
    {"classification": "Noun", "word": "lack"},
    {"classification": "Verb", "word": "lack"},
    {"classification": "Verb", "word": "ladder"},
    {"classification": "Noun", "word": "ladies"},
    {"classification": "Noun", "word": "lady"},
    {"classification": "Adjective", "word": "lady"},
    {"classification": "Noun", "word": "lake"},
    {"classification": "Verb", "word": "lake"},
    {"classification": "Noun", "word": "lamp"},
    {"classification": "Noun", "word": "land"},
    {"classification": "Verb", "word": "land"},
    {"classification": "Noun", "word": "landing"},
    {"classification": "Adjective", "word": "landing"},
    {"classification": "Noun", "word": "landscape"},
    {"classification": "Noun", "word": "lane"},
    {"classification": "Adjective", "word": "lane"},
    {"classification": "Noun", "word": "language"},
    {"classification": "Verb", "word": "language"},
    {"classification": "Noun", "word": "large"},
    {"classification": "Adjective", "word": "large"},
    {"classification": "Adverb", "word": "large"},
    {"classification": "Adverb", "word": "largely"},
    {"classification": "Noun", "word": "last"},
    {"classification": "Adjective", "word": "last"},
    {"classification": "Verb", "word": "last"},
    {"classification": "Adjective", "word": "late"},
    {"classification": "Verb", "word": "late"},
    {"classification": "Adverb", "word": "lately"},
    {"classification": "Noun", "word": "later"},
    {"classification": "Adjective", "word": "later"},
    {"classification": "Adverb", "word": "later"},
    {"classification": "Noun", "word": "latin"},
    {"classification": "Verb", "word": "latin"},
    {"classification": "Adjective", "word": "latin"},
    {"classification": "Adjective", "word": "latter"},
    {"classification": "Noun", "word": "laugh"},
    {"classification": "Verb", "word": "laugh"},
    {"classification": "Verb", "word": "laughter"},
    {"classification": "Noun", "word": "launch"},
    {"classification": "Verb", "word": "launch"},
    {"classification": "Noun", "word": "laura"},
    {"classification": "Noun", "word": "law"},
    {"classification": "Verb", "word": "law"},
    {"classification": "Noun", "word": "lawyer"},
    {"classification": "Noun", "word": "lay"},
    {"classification": "Verb", "word": "lay"},
    {"classification": "Adjective", "word": "lay"},
    {"classification": "Noun", "word": "layer"},
    {"classification": "Adjective", "word": "lazy"},
    {"classification": "Noun", "word": "lead"},
    {"classification": "Verb", "word": "lead"},
    {"classification": "Noun", "word": "leader"},
    {"classification": "Noun", "word": "leading"},
    {"classification": "Adjective", "word": "leading"},
    {"classification": "Noun", "word": "leaf"},
    {"classification": "Verb", "word": "leaf"},
    {"classification": "Noun", "word": "league"},
    {"classification": "Verb", "word": "league"},
    {"classification": "Noun", "word": "lean"},
    {"classification": "Verb", "word": "lean"},
    {"classification": "Verb", "word": "learn"},
    {"classification": "Adjective", "word": "learned"},
    {"classification": "Noun", "word": "learning"},
    {"classification": "Adjective", "word": "least"},
    {"classification": "Adverb", "word": "least"},
    {"classification": "Noun", "word": "leather"},
    {"classification": "Verb", "word": "leather"},
    {"classification": "Noun", "word": "leave"},
    {"classification": "Verb", "word": "leave"},
    {"classification": "Noun", "word": "leaves"},
    {"classification": "Noun", "word": "lecture"},
    {"classification": "Verb", "word": "lecture"},
    {"classification": "Noun", "word": "lee"},
    {"classification": "Verb", "word": "lee"},
    {"classification": "Adjective", "word": "lee"},
    {"classification": "Noun", "word": "left"},
    {"classification": "Adjective", "word": "left"},
    {"classification": "Noun", "word": "leg"},
    {"classification": "Verb", "word": "leg"},
    {"classification": "Adjective", "word": "legal"},
    {"classification": "Noun", "word": "legend"},
    {"classification": "Verb", "word": "legend"},
    {"classification": "Verb", "word": "legislate"},
    {"classification": "Noun", "word": "legislation"},
    {"classification": "Adjective", "word": "legislative"},
    {"classification": "Adjective", "word": "legitimate"},
    {"classification": "Verb", "word": "legitimate"},
    {"classification": "Noun", "word": "leisure"},
    {"classification": "Adjective", "word": "leisure"},
    {"classification": "Verb", "word": "lend"},
    {"classification": "Adjective", "word": "length"},
    {"classification": "Verb", "word": "length"},
    {"classification": "Verb", "word": "lengthen"},
    {"classification": "Noun", "word": "lens"},
    {"classification": "Noun", "word": "less"},
    {"classification": "Verb", "word": "less"},
    {"classification": "Adjective", "word": "less"},
    {"classification": "Adverb", "word": "less"},
    {"classification": "Adjective", "word": "lessen"},
    {"classification": "Verb", "word": "lessen"},
    {"classification": "Noun", "word": "lesson"},
    {"classification": "Verb", "word": "lesson"},
    {"classification": "Noun", "word": "let"},
    {"classification": "Verb", "word": "let"},
    {"classification": "Noun", "word": "letter"},
    {"classification": "Verb", "word": "letter"},
    {"classification": "Noun", "word": "level"},
    {"classification": "Adjective", "word": "level"},
    {"classification": "Verb", "word": "level"},
    {"classification": "Noun", "word": "lewis"},
    {"classification": "Verb", "word": "liable"},
    {"classification": "Adjective", "word": "liable"},
    {"classification": "Noun", "word": "liar"},
    {"classification": "Noun", "word": "liberal"},
    {"classification": "Adjective", "word": "liberal"},
    {"classification": "Verb", "word": "liberate"},
    {"classification": "Adjective", "word": "liberate"},
    {"classification": "Noun", "word": "librarian"},
    {"classification": "Noun", "word": "license"},
    {"classification": "Verb", "word": "license"},
    {"classification": "Noun", "word": "lid"},
    {"classification": "Noun", "word": "lie"},
    {"classification": "Verb", "word": "lie"},
    {"classification": "Noun", "word": "life"},
    {"classification": "Noun", "word": "lift"},
    {"classification": "Verb", "word": "lift"},
    {"classification": "Noun", "word": "light"},
    {"classification": "Adjective", "word": "light"},
    {"classification": "Adverb", "word": "light"},
    {"classification": "Verb", "word": "light"},
    {"classification": "Verb", "word": "lighten"},
    {"classification": "Noun", "word": "lighting"},
    {"classification": "Adverb", "word": "lightly"},
    {"classification": "Noun", "word": "lights"},
    {"classification": "Preposition", "word": "like"},
    {"classification": "Noun", "word": "like"},
    {"classification": "Adjective", "word": "like"},
    {"classification": "Verb", "word": "like"},
    {"classification": "Adverb", "word": "likely"},
    {"classification": "Adjective", "word": "likely"},
    {"classification": "Noun", "word": "limb"},
    {"classification": "Verb", "word": "limb"},
    {"classification": "Verb", "word": "limit"},
    {"classification": "Adjective", "word": "limited"},
    {"classification": "Noun", "word": "line"},
    {"classification": "Verb", "word": "line"},
    {"classification": "Adjective", "word": "linear"},
    {"classification": "Adjective", "word": "linguistic"},
    {"classification": "Noun", "word": "lip"},
    {"classification": "Verb", "word": "lip"},
    {"classification": "Noun", "word": "liquid"},
    {"classification": "Adjective", "word": "liquid"},
    {"classification": "Noun", "word": "liquor"},
    {"classification": "Verb", "word": "liquor"},
    {"classification": "Noun", "word": "list"},
    {"classification": "Verb", "word": "list"},
    {"classification": "Verb", "word": "listen"},
    {"classification": "Adverb", "word": "literally"},
    {"classification": "Adjective", "word": "literary"},
    {"classification": "Verb", "word": "litigate"},
    {"classification": "Adjective", "word": "little"},
    {"classification": "Noun", "word": "little"},
    {"classification": "Adverb", "word": "little"},
    {"classification": "Verb", "word": "live"},
    {"classification": "Adjective", "word": "live"},
    {"classification": "Noun", "word": "live"},
    {"classification": "Adjective", "word": "lived"},
    {"classification": "Adverb", "word": "lively"},
    {"classification": "Adjective", "word": "lively"},
    {"classification": "Noun", "word": "lives"},
    {"classification": "Noun", "word": "living"},
    {"classification": "Verb", "word": "load"},
    {"classification": "Noun", "word": "loaf"},
    {"classification": "Verb", "word": "loaf"},
    {"classification": "Noun", "word": "loan"},
    {"classification": "Verb", "word": "lobby"},
    {"classification": "Noun", "word": "lobby"},
    {"classification": "Noun", "word": "local"},
    {"classification": "Adjective", "word": "local"},
    {"classification": "Verb", "word": "locate"},
    {"classification": "Noun", "word": "location"},
    {"classification": "Verb", "word": "lock"},
    {"classification": "Noun", "word": "lock"},
    {"classification": "Noun", "word": "locomotion"},
    {"classification": "Verb", "word": "lodge"},
    {"classification": "Noun", "word": "lodge"},
    {"classification": "Noun", "word": "log"},
    {"classification": "Verb", "word": "log"},
    {"classification": "Noun", "word": "logic"},
    {"classification": "Adjective", "word": "logical"},
    {"classification": "Noun", "word": "london"},
    {"classification": "Adjective", "word": "lonely"},
    {"classification": "Noun", "word": "long"},
    {"classification": "Adjective", "word": "long"},
    {"classification": "Adverb", "word": "long"},
    {"classification": "Noun", "word": "longer"},
    {"classification": "Verb", "word": "look"},
    {"classification": "Noun", "word": "look"},
    {"classification": "Noun", "word": "looking"},
    {"classification": "Adjective", "word": "looking"},
    {"classification": "Noun", "word": "loop"},
    {"classification": "Verb", "word": "loop"},
    {"classification": "Verb", "word": "loose"},
    {"classification": "Noun", "word": "loose"},
    {"classification": "Adjective", "word": "loose"},
    {"classification": "Verb", "word": "loosen"},
    {"classification": "Verb", "word": "lord"},
    {"classification": "Noun", "word": "lord"},
    {"classification": "Noun", "word": "los"},
    {"classification": "Verb", "word": "lose"},
    {"classification": "Adjective", "word": "losing"},
    {"classification": "Verb", "word": "losing"},
    {"classification": "Verb", "word": "loss"},
    {"classification": "Verb", "word": "lost"},
    {"classification": "Noun", "word": "lot"},
    {"classification": "Verb", "word": "lot"},
    {"classification": "Adjective", "word": "loud"},
    {"classification": "Adverb", "word": "loud"},
    {"classification": "Noun", "word": "love"},
    {"classification": "Verb", "word": "love"},
    {"classification": "Adverb", "word": "lovely"},
    {"classification": "Adjective", "word": "lovely"},
    {"classification": "Noun", "word": "lover"},
    {"classification": "Noun", "word": "low"},
    {"classification": "Adjective", "word": "low"},
    {"classification": "Adverb", "word": "low"},
    {"classification": "Verb", "word": "low"},
    {"classification": "Noun", "word": "lower"},
    {"classification": "Adjective", "word": "lower"},
    {"classification": "Verb", "word": "lower"},
    {"classification": "Adjective", "word": "loyal"},
    {"classification": "Noun", "word": "loyalty"},
    {"classification": "Noun", "word": "luck"},
    {"classification": "Adjective", "word": "lucky"},
    {"classification": "Verb", "word": "lumber"},
    {"classification": "Noun", "word": "lumber"},
    {"classification": "Verb", "word": "lump"},
    {"classification": "Noun", "word": "lump"},
    {"classification": "Verb", "word": "lunch"},
    {"classification": "Noun", "word": "lunch"},
    {"classification": "Verb", "word": "luncheon"},
    {"classification": "Noun", "word": "luncheon"},
    {"classification": "Noun", "word": "lung"},
    {"classification": "Noun", "word": "luxury"},
    {"classification": "Noun", "word": "lying"},
    {"classification": "Noun", "word": "ma"},
    {"classification": "Verb", "word": "machine"},
    {"classification": "Verb", "word": "mad"},
    {"classification": "Noun", "word": "mad"},
    {"classification": "Adjective", "word": "mad"},
    {"classification": "Verb", "word": "madden"},
    {"classification": "Noun", "word": "made"},
    {"classification": "Adjective", "word": "made"},
    {"classification": "Noun", "word": "magazine"},
    {"classification": "Verb", "word": "magazine"},
    {"classification": "Adjective", "word": "magic"},
    {"classification": "Adjective", "word": "magnetic"},
    {"classification": "Adjective", "word": "magnificent"},
    {"classification": "Noun", "word": "magnitude"},
    {"classification": "Noun", "word": "maid"},
    {"classification": "Noun", "word": "mail"},
    {"classification": "Verb", "word": "mail"},
    {"classification": "Adjective", "word": "main"},
    {"classification": "Noun", "word": "main"},
    {"classification": "Verb", "word": "main"},
    {"classification": "Adverb", "word": "mainly"},
    {"classification": "Verb", "word": "maintain"},
    {"classification": "Noun", "word": "maintenance"},
    {"classification": "Adjective", "word": "major"},
    {"classification": "Noun", "word": "make"},
    {"classification": "Verb", "word": "make"},
    {"classification": "Noun", "word": "making"},
    {"classification": "Noun", "word": "male"},
    {"classification": "Adjective", "word": "male"},
    {"classification": "Verb", "word": "male"},
    {"classification": "Noun", "word": "mama"},
    {"classification": "Noun", "word": "man"},
    {"classification": "Verb", "word": "man"},
    {"classification": "Noun", "word": "manage"},
    {"classification": "Verb", "word": "manage"},
    {"classification": "Verb", "word": "management"},
    {"classification": "Verb", "word": "manifest"},
    {"classification": "Adjective", "word": "manifest"},
    {"classification": "Verb", "word": "manipulate"},
    {"classification": "Adjective", "word": "mankind"},
    {"classification": "Noun", "word": "mankind"},
    {"classification": "Noun", "word": "manner"},
    {"classification": "Verb", "word": "mantle"},
    {"classification": "Noun", "word": "mantle"},
    {"classification": "Verb", "word": "manufacture"},
    {"classification": "Adjective", "word": "manufacturing"},
    {"classification": "Pronoun", "word": "many"},
    {"classification": "Noun", "word": "many"},
    {"classification": "Adjective", "word": "many"},
    {"classification": "Verb", "word": "map"},
    {"classification": "Noun", "word": "map"},
    {"classification": "Noun", "word": "marble"},
    {"classification": "Adjective", "word": "marble"},
    {"classification": "Noun", "word": "march"},
    {"classification": "Verb", "word": "march"},
    {"classification": "Noun", "word": "margin"},
    {"classification": "Verb", "word": "margin"},
    {"classification": "Adjective", "word": "marginal"},
    {"classification": "Adjective", "word": "marine"},
    {"classification": "Verb", "word": "mark"},
    {"classification": "Noun", "word": "mark"},
    {"classification": "Adjective", "word": "marked"},
    {"classification": "Verb", "word": "market"},
    {"classification": "Noun", "word": "market"},
    {"classification": "Noun", "word": "marriage"},
    {"classification": "Verb", "word": "marriage"},
    {"classification": "Verb", "word": "marry"},
    {"classification": "Noun", "word": "mars"},
    {"classification": "Noun", "word": "marshal"},
    {"classification": "Verb", "word": "marshal"},
    {"classification": "Noun", "word": "martin"},
    {"classification": "Noun", "word": "mary"},
    {"classification": "Verb", "word": "mason"},
    {"classification": "Noun", "word": "mason"},
    {"classification": "Verb", "word": "mass"},
    {"classification": "Noun", "word": "mass"},
    {"classification": "Adjective", "word": "massive"},
    {"classification": "Verb", "word": "master"},
    {"classification": "Noun", "word": "master"},
    {"classification": "Noun", "word": "mat"},
    {"classification": "Verb", "word": "mat"},
    {"classification": "Adjective", "word": "mat"},
    {"classification": "Noun", "word": "match"},
    {"classification": "Verb", "word": "match"},
    {"classification": "Noun", "word": "mate"},
    {"classification": "Verb", "word": "mate"},
    {"classification": "Adjective", "word": "mate"},
    {"classification": "Adjective", "word": "material"},
    {"classification": "Verb", "word": "material"},
    {"classification": "Noun", "word": "material"},
    {"classification": "Adjective", "word": "maternal"},
    {"classification": "Adjective", "word": "mathematical"},
    {"classification": "Noun", "word": "matrix"},
    {"classification": "Verb", "word": "matter"},
    {"classification": "Noun", "word": "matter"},
    {"classification": "Verb", "word": "mature"},
    {"classification": "Adjective", "word": "mature"},
    {"classification": "Noun", "word": "maturity"},
    {"classification": "Noun", "word": "maximum"},
    {"classification": "Adjective", "word": "maximum"},
    {"classification": "Noun", "word": "may"},
    {"classification": "Verb", "word": "may"},
    {"classification": "Adjective", "word": "maybe"},
    {"classification": "Adverb", "word": "maybe"},
    {"classification": "Noun", "word": "maybe"},
    {"classification": "Noun", "word": "mayor"},
    {"classification": "Pronoun", "word": "me"},
    {"classification": "Verb", "word": "meal"},
    {"classification": "Noun", "word": "meal"},
    {"classification": "Noun", "word": "mean"},
    {"classification": "Adjective", "word": "mean"},
    {"classification": "Verb", "word": "mean"},
    {"classification": "Noun", "word": "meaning"},
    {"classification": "Noun", "word": "meantime"},
    {"classification": "Adverb", "word": "meantime"},
    {"classification": "Adverb", "word": "meanwhile"},
    {"classification": "Noun", "word": "meanwhile"},
    {"classification": "Noun", "word": "measure"},
    {"classification": "Verb", "word": "measure"},
    {"classification": "Adjective", "word": "measure"},
    {"classification": "Adjective", "word": "measured"},
    {"classification": "Adjective", "word": "measuring"},
    {"classification": "Verb", "word": "meat"},
    {"classification": "Noun", "word": "meat"},
    {"classification": "Adjective", "word": "mechanic"},
    {"classification": "Adjective", "word": "mechanical"},
    {"classification": "Noun", "word": "mechanical"},
    {"classification": "Adjective", "word": "medical"},
    {"classification": "Verb", "word": "medicine"},
    {"classification": "Noun", "word": "medicine"},
    {"classification": "Adjective", "word": "medium"},
    {"classification": "Noun", "word": "medium"},
    {"classification": "Verb", "word": "meet"},
    {"classification": "Noun", "word": "meet"},
    {"classification": "Adjective", "word": "meet"},
    {"classification": "Adverb", "word": "meet"},
    {"classification": "Noun", "word": "meeting"},
    {"classification": "Noun", "word": "melody"},
    {"classification": "Noun", "word": "melt"},
    {"classification": "Verb", "word": "melt"},
    {"classification": "Noun", "word": "melting"},
    {"classification": "Adjective", "word": "melting"},
    {"classification": "Verb", "word": "member"},
    {"classification": "Noun", "word": "member"},
    {"classification": "Adjective", "word": "memorial"},
    {"classification": "Noun", "word": "memory"},
    {"classification": "Noun", "word": "men"},
    {"classification": "Verb", "word": "mend"},
    {"classification": "Adjective", "word": "mental"},
    {"classification": "Noun", "word": "mental"},
    {"classification": "Noun", "word": "mention"},
    {"classification": "Verb", "word": "mention"},
    {"classification": "Noun", "word": "mercer"},
    {"classification": "Verb", "word": "merchant"},
    {"classification": "Adjective", "word": "merchant"},
    {"classification": "Noun", "word": "mercy"},
    {"classification": "Noun", "word": "mere"},
    {"classification": "Adjective", "word": "mere"},
    {"classification": "Verb", "word": "mere"},
    {"classification": "Adverb", "word": "merely"},
    {"classification": "Noun", "word": "merger"},
    {"classification": "Noun", "word": "merit"},
    {"classification": "Verb", "word": "merit"},
    {"classification": "Noun", "word": "merry"},
    {"classification": "Adjective", "word": "merry"},
    {"classification": "Verb", "word": "mess"},
    {"classification": "Noun", "word": "mess"},
    {"classification": "Noun", "word": "message"},
    {"classification": "Verb", "word": "message"},
    {"classification": "Noun", "word": "messenger"},
    {"classification": "Noun", "word": "metal"},
    {"classification": "Verb", "word": "metal"},
    {"classification": "Noun", "word": "metaphor"},
    {"classification": "Noun", "word": "method"},
    {"classification": "Adjective", "word": "metropolitan"},
    {"classification": "Adjective", "word": "mexican"},
    {"classification": "Noun", "word": "mexican"},
    {"classification": "Noun", "word": "microscope"},
    {"classification": "Adjective", "word": "middle"},
    {"classification": "Noun", "word": "midnight"},
    {"classification": "Adjective", "word": "midnight"},
    {"classification": "Verb", "word": "might"},
    {"classification": "Noun", "word": "mighty"},
    {"classification": "Adverb", "word": "mighty"},
    {"classification": "Verb", "word": "migrate"},
    {"classification": "Adjective", "word": "mild"},
    {"classification": "Noun", "word": "mile"},
    {"classification": "Adjective", "word": "military"},
    {"classification": "Noun", "word": "milk"},
    {"classification": "Verb", "word": "milk"},
    {"classification": "Noun", "word": "mill"},
    {"classification": "Verb", "word": "mill"},
    {"classification": "Noun", "word": "miller"},
    {"classification": "Noun", "word": "million"},
    {"classification": "Noun", "word": "mind"},
    {"classification": "Verb", "word": "mind"},
    {"classification": "Pronoun", "word": "mine"},
    {"classification": "Noun", "word": "mine"},
    {"classification": "Verb", "word": "mine"},
    {"classification": "Adjective", "word": "mineral"},
    {"classification": "Verb", "word": "mineral"},
    {"classification": "Adjective", "word": "minimal"},
    {"classification": "Noun", "word": "minimum"},
    {"classification": "Noun", "word": "minister"},
    {"classification": "Verb", "word": "minister"},
    {"classification": "Noun", "word": "minor"},
    {"classification": "Adjective", "word": "minor"},
    {"classification": "Noun", "word": "minute"},
    {"classification": "Adjective", "word": "minute"},
    {"classification": "Noun", "word": "mirror"},
    {"classification": "Verb", "word": "mirror"},
    {"classification": "Noun", "word": "miserable"},
    {"classification": "Adjective", "word": "miserable"},
    {"classification": "Noun", "word": "misery"},
    {"classification": "Noun", "word": "miss"},
    {"classification": "Verb", "word": "miss"},
    {"classification": "Noun", "word": "missile"},
    {"classification": "Adjective", "word": "missile"},
    {"classification": "Verb", "word": "missing"},
    {"classification": "Noun", "word": "mission"},
    {"classification": "Verb", "word": "mission"},
    {"classification": "Noun", "word": "mistake"},
    {"classification": "Verb", "word": "mistake"},
    {"classification": "Verb", "word": "mix"},
    {"classification": "Adjective", "word": "mixed"},
    {"classification": "Noun", "word": "mixture"},
    {"classification": "Adjective", "word": "mobile"},
    {"classification": "Noun", "word": "mode"},
    {"classification": "Noun", "word": "model"},
    {"classification": "Adjective", "word": "model"},
    {"classification": "Verb", "word": "model"},
    {"classification": "Adjective", "word": "moderate"},
    {"classification": "Verb", "word": "moderate"},
    {"classification": "Noun", "word": "modern"},
    {"classification": "Adjective", "word": "modern"},
    {"classification": "Adjective", "word": "modest"},
    {"classification": "Noun", "word": "modesty"},
    {"classification": "Verb", "word": "modify"},
    {"classification": "Adjective", "word": "moist"},
    {"classification": "Verb", "word": "moist"},
    {"classification": "Noun", "word": "mold"},
    {"classification": "Verb", "word": "mold"},
    {"classification": "Noun", "word": "moment"},
    {"classification": "Adjective", "word": "momentary"},
    {"classification": "Noun", "word": "monarch"},
    {"classification": "Adjective", "word": "monarch"},
    {"classification": "Noun", "word": "monday"},
    {"classification": "Noun", "word": "money"},
    {"classification": "Verb", "word": "money"},
    {"classification": "Noun", "word": "monkey"},
    {"classification": "Noun", "word": "month"},
    {"classification": "Adjective", "word": "monthly"},
    {"classification": "Adverb", "word": "monthly"},
    {"classification": "Noun", "word": "monument"},
    {"classification": "Noun", "word": "mood"},
    {"classification": "Noun", "word": "moon"},
    {"classification": "Verb", "word": "moon"},
    {"classification": "Noun", "word": "moonlight"},
    {"classification": "Adjective", "word": "moonlight"},
    {"classification": "Noun", "word": "moral"},
    {"classification": "Adjective", "word": "moral"},
    {"classification": "Verb", "word": "moral"},
    {"classification": "Noun", "word": "more"},
    {"classification": "Adverb", "word": "more"},
    {"classification": "Adjective", "word": "more"},
    {"classification": "Verb", "word": "more"},
    {"classification": "Adverb", "word": "moreover"},
    {"classification": "Noun", "word": "morgan"},
    {"classification": "Adjective", "word": "morning"},
    {"classification": "Noun", "word": "morris"},
    {"classification": "Noun", "word": "morse"},
    {"classification": "Adjective", "word": "most"},
    {"classification": "Adverb", "word": "mostly"},
    {"classification": "Noun", "word": "mother"},
    {"classification": "Verb", "word": "mother"},
    {"classification": "Adjective", "word": "mother"},
    {"classification": "Adverb", "word": "motherly"},
    {"classification": "Adjective", "word": "motherly"},
    {"classification": "Noun", "word": "motion"},
    {"classification": "Verb", "word": "motion"},
    {"classification": "Noun", "word": "motive"},
    {"classification": "Verb", "word": "motive"},
    {"classification": "Adjective", "word": "motive"},
    {"classification": "Noun", "word": "motor"},
    {"classification": "Noun", "word": "mount"},
    {"classification": "Verb", "word": "mount"},
    {"classification": "Noun", "word": "mountain"},
    {"classification": "Adjective", "word": "mountain"},
    {"classification": "Adjective", "word": "mounted"},
    {"classification": "Noun", "word": "mouse"},
    {"classification": "Verb", "word": "mouse"},
    {"classification": "Noun", "word": "mouth"},
    {"classification": "Verb", "word": "mouth"},
    {"classification": "Noun", "word": "move"},
    {"classification": "Verb", "word": "move"},
    {"classification": "Noun", "word": "movement"},
    {"classification": "Noun", "word": "movie"},
    {"classification": "Noun", "word": "moving"},
    {"classification": "Adjective", "word": "moving"},
    {"classification": "Noun", "word": "much"},
    {"classification": "Adjective", "word": "much"},
    {"classification": "Noun", "word": "mud"},
    {"classification": "Verb", "word": "mud"},
    {"classification": "Adjective", "word": "multiple"},
    {"classification": "Verb", "word": "multiply"},
    {"classification": "Adjective", "word": "municipal"},
    {"classification": "Noun", "word": "murder"},
    {"classification": "Noun", "word": "muscle"},
    {"classification": "Noun", "word": "museum"},
    {"classification": "Noun", "word": "music"},
    {"classification": "Noun", "word": "musical"},
    {"classification": "Adjective", "word": "musical"},
    {"classification": "Noun", "word": "musician"},
    {"classification": "Noun", "word": "must"},
    {"classification": "Noun", "word": "mustard"},
    {"classification": "Adjective", "word": "mutual"},
    {"classification": "Pronoun", "word": "my"},
    {"classification": "Adjective", "word": "my"},
    {"classification": "Adjective", "word": "mysterious"},
    {"classification": "Adjective", "word": "mystery"},
    {"classification": "Noun", "word": "myth"},
    {"classification": "Noun", "word": "nail"},
    {"classification": "Adjective", "word": "nail"},
    {"classification": "Adjective", "word": "naked"},
    {"classification": "Noun", "word": "name"},
    {"classification": "Adverb", "word": "namely"},
    {"classification": "Adjective", "word": "narrative"},
    {"classification": "Noun", "word": "narrow"},
    {"classification": "Verb", "word": "narrow"},
    {"classification": "Adjective", "word": "narrow"},
    {"classification": "Noun", "word": "nation"},
    {"classification": "Adjective", "word": "national"},
    {"classification": "Noun", "word": "native"},
    {"classification": "Adjective", "word": "native"},
    {"classification": "Noun", "word": "natural"},
    {"classification": "Adjective", "word": "natural"},
    {"classification": "Adverb", "word": "naturally"},
    {"classification": "Noun", "word": "nature"},
    {"classification": "Verb", "word": "nature"},
    {"classification": "Adjective", "word": "naval"},
    {"classification": "Noun", "word": "navy"},
    {"classification": "Preposition", "word": "near"},
    {"classification": "Adverb", "word": "near"},
    {"classification": "Verb", "word": "near"},
    {"classification": "Adverb", "word": "nearly"},
    {"classification": "Noun", "word": "neat"},
    {"classification": "Adjective", "word": "neat"},
    {"classification": "Adverb", "word": "necessarily"},
    {"classification": "Adjective", "word": "necessary"},
    {"classification": "Noun", "word": "neck"},
    {"classification": "Verb", "word": "neck"},
    {"classification": "Noun", "word": "need"},
    {"classification": "Verb", "word": "need"},
    {"classification": "Adverb", "word": "need"},
    {"classification": "Noun", "word": "needle"},
    {"classification": "Verb", "word": "needle"},
    {"classification": "Adverb", "word": "needs"},
    {"classification": "Verb", "word": "negative"},
    {"classification": "Adjective", "word": "negative"},
    {"classification": "Verb", "word": "neglect"},
    {"classification": "Adverb", "word": "neglect"},
    {"classification": "Noun", "word": "negro"},
    {"classification": "Adjective", "word": "negro"},
    {"classification": "Noun", "word": "negroes"},
    {"classification": "Noun", "word": "neighbor"},
    {"classification": "Verb", "word": "neighbor"},
    {"classification": "Adjective", "word": "neighbor"},
    {"classification": "Adjective", "word": "neighboring"},
    {"classification": "Pronoun", "word": "neither"},
    {"classification": "Adjective", "word": "neither"},
    {"classification": "Noun", "word": "nephew"},
    {"classification": "Noun", "word": "nerve"},
    {"classification": "Verb", "word": "nerve"},
    {"classification": "Adjective", "word": "nervous"},
    {"classification": "Noun", "word": "nest"},
    {"classification": "Verb", "word": "nest"},
    {"classification": "Adjective", "word": "net"},
    {"classification": "Verb", "word": "net"},
    {"classification": "Noun", "word": "network"},
    {"classification": "Noun", "word": "neutral"},
    {"classification": "Adjective", "word": "neutral"},
    {"classification": "Adverb", "word": "never"},
    {"classification": "SubordConjunction", "word": "nevertheless"},
    {"classification": "Adjective", "word": "new"},
    {"classification": "Adverb", "word": "new"},
    {"classification": "Adverb", "word": "newly"},
    {"classification": "Noun", "word": "newspaper"},
    {"classification": "Adjective", "word": "next"},
    {"classification": "Adverb", "word": "next"},
    {"classification": "Adjective", "word": "nice"},
    {"classification": "Noun", "word": "niche"},
    {"classification": "Noun", "word": "nick"},
    {"classification": "Verb", "word": "nick"},
    {"classification": "Noun", "word": "niece"},
    {"classification": "Noun", "word": "night"},
    {"classification": "Noun", "word": "nine"},
    {"classification": "Adjective", "word": "nine"},
    {"classification": "Adjective", "word": "nineteenth"},
    {"classification": "Noun", "word": "ninth"},
    {"classification": "Adjective", "word": "ninth"},
    {"classification": "Noun", "word": "no"},
    {"classification": "Adverb", "word": "no"},
    {"classification": "Adjective", "word": "no"},
    {"classification": "Noun", "word": "noble"},
    {"classification": "Adjective", "word": "noble"},
    {"classification": "Verb", "word": "noble"},
    {"classification": "Noun", "word": "nobody"},
    {"classification": "Noun", "word": "noise"},
    {"classification": "Verb", "word": "noise"},
    {"classification": "Pronoun", "word": "none"},
    {"classification": "Noun", "word": "none"},
    {"classification": "Adjective", "word": "none"},
    {"classification": "Noun", "word": "noon"},
    {"classification": "Verb", "word": "noon"},
    {"classification": "Adjective", "word": "noon"},
    {"classification": "CoordConjunction", "word": "nor"},
    {"classification": "Noun", "word": "norm"},
    {"classification": "Adjective", "word": "norm"},
    {"classification": "Adjective", "word": "normal"},
    {"classification": "Adverb", "word": "normally"},
    {"classification": "Noun", "word": "north"},
    {"classification": "Verb", "word": "north"},
    {"classification": "Adjective", "word": "north"},
    {"classification": "Adverb", "word": "north"},
    {"classification": "Adjective", "word": "northern"},
    {"classification": "Noun", "word": "northwest"},
    {"classification": "Adjective", "word": "northwest"},
    {"classification": "Adverb", "word": "northwest"},
    {"classification": "Noun", "word": "nose"},
    {"classification": "Verb", "word": "nose"},
    {"classification": "Adjective", "word": "not"},
    {"classification": "Adverb", "word": "not"},
    {"classification": "Noun", "word": "notable"},
    {"classification": "Adjective", "word": "notable"},
    {"classification": "Adjective", "word": "notate"},
    {"classification": "Noun", "word": "note"},
    {"classification": "Verb", "word": "note"},
    {"classification": "Noun", "word": "notebook"},
    {"classification": "Adjective", "word": "noted"},
    {"classification": "Noun", "word": "nothing"},
    {"classification": "Adverb", "word": "nothing"},
    {"classification": "Noun", "word": "notice"},
    {"classification": "Verb", "word": "notice"},
    {"classification": "Noun", "word": "noun"},
    {"classification": "Adjective", "word": "novel"},
    {"classification": "Noun", "word": "november"},
    {"classification": "Noun", "word": "now"},
    {"classification": "Adjective", "word": "now"},
    {"classification": "Adverb", "word": "now"},
    {"classification": "Adverb", "word": "nowadays"},
    {"classification": "Adverb", "word": "nowhere"},
    {"classification": "Adjective", "word": "nuclear"},
    {"classification": "Adjective", "word": "nude"},
    {"classification": "Noun", "word": "nuisance"},
    {"classification": "Noun", "word": "null"},
    {"classification": "Adjective", "word": "null"},
    {"classification": "Verb", "word": "null"},
    {"classification": "Noun", "word": "number"},
    {"classification": "Adjective", "word": "numerous"},
    {"classification": "Noun", "word": "nurse"},
    {"classification": "Verb", "word": "nurse"},
    {"classification": "Noun", "word": "nut"},
    {"classification": "Verb", "word": "nut"},
    {"classification": "Noun", "word": "nutrient"},
    {"classification": "Adjective", "word": "nutrient"},
    {"classification": "Noun", "word": "obedience"},
    {"classification": "Adjective", "word": "obedient"},
    {"classification": "Verb", "word": "obey"},
    {"classification": "Adjective", "word": "object"},
    {"classification": "Verb", "word": "object"},
    {"classification": "Noun", "word": "objection"},
    {"classification": "Adjective", "word": "objective"},
    {"classification": "Verb", "word": "oblige"},
    {"classification": "Verb", "word": "observe"},
    {"classification": "Adjective", "word": "obsolete"},
    {"classification": "Verb", "word": "obsolete"},
    {"classification": "Verb", "word": "obtain"},
    {"classification": "Adjective", "word": "obvious"},
    {"classification": "Noun", "word": "occasion"},
    {"classification": "Verb", "word": "occasion"},
    {"classification": "Adjective", "word": "occasional"},
    {"classification": "Adverb", "word": "occasionally"},
    {"classification": "Verb", "word": "occupy"},
    {"classification": "Verb", "word": "occur"},
    {"classification": "Noun", "word": "occurrence"},
    {"classification": "Noun", "word": "ocean"},
    {"classification": "Adjective", "word": "ocean"},
    {"classification": "Adjective", "word": "odd"},
    {"classification": "Noun", "word": "odor"},
    {"classification": "Preposition", "word": "of"},
    {"classification": "Preposition", "word": "off"},
    {"classification": "Noun", "word": "off"},
    {"classification": "Adverb", "word": "off"},
    {"classification": "Adjective", "word": "off"},
    {"classification": "Verb", "word": "offend"},
    {"classification": "Noun", "word": "offense"},
    {"classification": "Noun", "word": "offer"},
    {"classification": "Verb", "word": "offer"},
    {"classification": "Noun", "word": "offering"},
    {"classification": "Noun", "word": "office"},
    {"classification": "Verb", "word": "office"},
    {"classification": "Verb", "word": "officer"},
    {"classification": "Noun", "word": "official"},
    {"classification": "Adjective", "word": "official"},
    {"classification": "Adjective", "word": "often"},
    {"classification": "Adverb", "word": "often"},
    {"classification": "Noun", "word": "oil"},
    {"classification": "Verb", "word": "oil"},
    {"classification": "Noun", "word": "old"},
    {"classification": "Adjective", "word": "old"},
    {"classification": "Adjective", "word": "old-fashioned"},
    {"classification": "Noun", "word": "omission"},
    {"classification": "Verb", "word": "omit"},
    {"classification": "Preposition", "word": "on"},
    {"classification": "SubordConjunction", "word": "once"},
    {"classification": "Adverb", "word": "once"},
    {"classification": "Pronoun", "word": "one "},
    {"classification": "Noun", "word": "one"},
    {"classification": "Verb", "word": "one"},
    {"classification": "Adjective", "word": "one"},
    {"classification": "Adverb", "word": "ones"},
    {"classification": "Adjective", "word": "only"},
    {"classification": "Noun", "word": "onset"},
    {"classification": "Verb", "word": "onset"},
    {"classification": "Preposition", "word": "onto"},
    {"classification": "Noun", "word": "open"},
    {"classification": "Adjective", "word": "open"},
    {"classification": "Verb", "word": "open"},
    {"classification": "Noun", "word": "opening"},
    {"classification": "Adverb", "word": "openly"},
    {"classification": "Noun", "word": "opera"},
    {"classification": "Verb", "word": "operate"},
    {"classification": "Noun", "word": "operation"},
    {"classification": "Noun", "word": "opinion"},
    {"classification": "Verb", "word": "opinion"},
    {"classification": "Noun", "word": "oppose"},
    {"classification": "Verb", "word": "oppose"},
    {"classification": "Noun", "word": "opposite"},
    {"classification": "Adjective", "word": "opposite"},
    {"classification": "Noun", "word": "option"},
    {"classification": "CoordConjunction", "word": "or"},
    {"classification": "Noun", "word": "or"},
    {"classification": "Adjective", "word": "oral"},
    {"classification": "Noun", "word": "orange"},
    {"classification": "Adjective", "word": "orange"},
    {"classification": "Noun", "word": "orbit"},
    {"classification": "Noun", "word": "order"},
    {"classification": "Verb", "word": "order"},
    {"classification": "Adjective", "word": "orderly"},
    {"classification": "Adverb", "word": "orderly"},
    {"classification": "Adjective", "word": "ordinary"},
    {"classification": "Noun", "word": "organ"},
    {"classification": "Verb", "word": "organ"},
    {"classification": "Adjective", "word": "organic"},
    {"classification": "Verb", "word": "organize"},
    {"classification": "Verb", "word": "orientate"},
    {"classification": "Noun", "word": "origin"},
    {"classification": "Adjective", "word": "original"},
    {"classification": "Adverb", "word": "originally"},
    {"classification": "Noun", "word": "orleans"},
    {"classification": "Noun", "word": "ornament"},
    {"classification": "Verb", "word": "ornament"},
    {"classification": "Verb", "word": "oscillate"},
    {"classification": "Adverb", "word": "other"},
    {"classification": "Adverb", "word": "otherwise"},
    {"classification": "Verb", "word": "ought"},
    {"classification": "Noun", "word": "ounce"},
    {"classification": "Pronoun", "word": "our"},
    {"classification": "Noun", "word": "our"},
    {"classification": "Pronoun", "word": "ours"},
    {"classification": "Noun", "word": "ours"},
    {"classification": "Noun", "word": "ourselves"},
    {"classification": "Noun", "word": "out"},
    {"classification": "Adjective", "word": "out"},
    {"classification": "Verb", "word": "out"},
    {"classification": "Noun", "word": "outcome"},
    {"classification": "Adjective", "word": "outdoor"},
    {"classification": "Noun", "word": "outer"},
    {"classification": "Adjective", "word": "outer"},
    {"classification": "Verb", "word": "outer"},
    {"classification": "Noun", "word": "outline"},
    {"classification": "Verb", "word": "outline"},
    {"classification": "Noun", "word": "outlook"},
    {"classification": "Verb", "word": "outlook"},
    {"classification": "Noun", "word": "output"},
    {"classification": "Noun", "word": "outside"},
    {"classification": "Adverb", "word": "outside"},
    {"classification": "Adjective", "word": "outside"},
    {"classification": "Adjective", "word": "outstanding"},
    {"classification": "Noun", "word": "outward"},
    {"classification": "Adjective", "word": "outward"},
    {"classification": "Adverb", "word": "outward"},
    {"classification": "Preposition", "word": "over"},
    {"classification": "Noun", "word": "over"},
    {"classification": "Adjective", "word": "over"},
    {"classification": "Adverb", "word": "over"},
    {"classification": "Verb", "word": "overcome"},
    {"classification": "Noun", "word": "overflow"},
    {"classification": "Verb", "word": "overflow"},
    {"classification": "Adverb", "word": "overseas"},
    {"classification": "Adjective", "word": "overwhelming"},
    {"classification": "Verb", "word": "owe"},
    {"classification": "Adjective", "word": "owen"},
    {"classification": "Adjective", "word": "own"},
    {"classification": "Verb", "word": "own"},
    {"classification": "Noun", "word": "owner"},
    {"classification": "Noun", "word": "ownership"},
    {"classification": "Noun", "word": "oxidation"},
    {"classification": "Noun", "word": "oxygen"},
    {"classification": "Noun", "word": "pa"},
    {"classification": "Noun", "word": "pace"},
    {"classification": "Verb", "word": "pace"},
    {"classification": "Adjective", "word": "pacific"},
    {"classification": "Noun", "word": "pack"},
    {"classification": "Verb", "word": "pack"},
    {"classification": "Noun", "word": "package"},
    {"classification": "Noun", "word": "pad"},
    {"classification": "Verb", "word": "pad"},
    {"classification": "Noun", "word": "page"},
    {"classification": "Verb", "word": "page"},
    {"classification": "Noun", "word": "pain"},
    {"classification": "Adjective", "word": "painful"},
    {"classification": "Noun", "word": "paint"},
    {"classification": "Verb", "word": "paint"},
    {"classification": "Adjective", "word": "painted"},
    {"classification": "Noun", "word": "painter"},
    {"classification": "Noun", "word": "painting"},
    {"classification": "Noun", "word": "pair"},
    {"classification": "Verb", "word": "pair"},
    {"classification": "Noun", "word": "palace"},
    {"classification": "Noun", "word": "pale"},
    {"classification": "Verb", "word": "pale"},
    {"classification": "Noun", "word": "palfrey"},
    {"classification": "Verb", "word": "palm"},
    {"classification": "Noun", "word": "palm"},
    {"classification": "Noun", "word": "palmer"},
    {"classification": "Verb", "word": "palmer"},
    {"classification": "Verb", "word": "pan"},
    {"classification": "Noun", "word": "pan"},
    {"classification": "Verb", "word": "panel"},
    {"classification": "Noun", "word": "panel"},
    {"classification": "Noun", "word": "panic"},
    {"classification": "Adjective", "word": "panic"},
    {"classification": "Noun", "word": "papa"},
    {"classification": "Verb", "word": "paper"},
    {"classification": "Adjective", "word": "paper"},
    {"classification": "Noun", "word": "paper"},
    {"classification": "Verb", "word": "parade"},
    {"classification": "Adjective", "word": "parallel"},
    {"classification": "Verb", "word": "parallel"},
    {"classification": "Verb", "word": "parcel"},
    {"classification": "Noun", "word": "parcel"},
    {"classification": "Verb", "word": "pardon"},
    {"classification": "Noun", "word": "parent"},
    {"classification": "Noun", "word": "paris"},
    {"classification": "Noun", "word": "park"},
    {"classification": "Verb", "word": "park"},
    {"classification": "Noun", "word": "parker"},
    {"classification": "Noun", "word": "parliament"},
    {"classification": "Verb", "word": "part"},
    {"classification": "Adverb", "word": "part"},
    {"classification": "Noun", "word": "part"},
    {"classification": "Adverb", "word": "partially"},
    {"classification": "Verb", "word": "participate"},
    {"classification": "Adjective", "word": "participate"},
    {"classification": "Adjective", "word": "particular"},
    {"classification": "Adverb", "word": "particularly"},
    {"classification": "Noun", "word": "parties"},
    {"classification": "Adjective", "word": "partisan"},
    {"classification": "Noun", "word": "partisan"},
    {"classification": "Adverb", "word": "partly"},
    {"classification": "Verb", "word": "partner"},
    {"classification": "Noun", "word": "partner"},
    {"classification": "Adverb", "word": "party"},
    {"classification": "Verb", "word": "party"},
    {"classification": "Verb", "word": "pass"},
    {"classification": "Noun", "word": "pass"},
    {"classification": "Verb", "word": "passage"},
    {"classification": "Noun", "word": "passenger"},
    {"classification": "Adverb", "word": "passing"},
    {"classification": "Noun", "word": "passing"},
    {"classification": "Adjective", "word": "passing"},
    {"classification": "Verb", "word": "passion"},
    {"classification": "Noun", "word": "passion"},
    {"classification": "Adjective", "word": "passive"},
    {"classification": "Preposition", "word": "past"},
    {"classification": "Verb", "word": "past"},
    {"classification": "Adverb", "word": "past"},
    {"classification": "Noun", "word": "past"},
    {"classification": "Noun", "word": "paste"},
    {"classification": "Verb", "word": "paste"},
    {"classification": "Noun", "word": "pastry"},
    {"classification": "Adverb", "word": "pat"},
    {"classification": "Verb", "word": "pat"},
    {"classification": "Adjective", "word": "pat"},
    {"classification": "Noun", "word": "pat"},
    {"classification": "Adjective", "word": "patent"},
    {"classification": "Verb", "word": "patent"},
    {"classification": "Verb", "word": "path"},
    {"classification": "Noun", "word": "path"},
    {"classification": "Noun", "word": "patience"},
    {"classification": "Verb", "word": "patient"},
    {"classification": "Adjective", "word": "patient"},
    {"classification": "Adjective", "word": "patriotic"},
    {"classification": "Noun", "word": "patrol"},
    {"classification": "Verb", "word": "patrol"},
    {"classification": "Verb", "word": "pattern"},
    {"classification": "Noun", "word": "paul"},
    {"classification": "Verb", "word": "pause"},
    {"classification": "Noun", "word": "pause"},
    {"classification": "Verb", "word": "paw"},
    {"classification": "Noun", "word": "paw"},
    {"classification": "Noun", "word": "pay"},
    {"classification": "Verb", "word": "pay"},
    {"classification": "Noun", "word": "payment"},
    {"classification": "Verb", "word": "peace"},
    {"classification": "Adjective", "word": "peaceful"},
    {"classification": "Adjective", "word": "pearl"},
    {"classification": "Verb", "word": "pearl"},
    {"classification": "Noun", "word": "pearl"},
    {"classification": "Noun", "word": "peas"},
    {"classification": "Adjective", "word": "peasant"},
    {"classification": "Noun", "word": "peasant"},
    {"classification": "Noun", "word": "peculiar"},
    {"classification": "Adjective", "word": "peculiar"},
    {"classification": "Noun", "word": "pen"},
    {"classification": "Verb", "word": "pen"},
    {"classification": "Verb", "word": "pencil"},
    {"classification": "Noun", "word": "pencil"},
    {"classification": "Adjective", "word": "penny"},
    {"classification": "Noun", "word": "penny"},
    {"classification": "Verb", "word": "people"},
    {"classification": "Noun", "word": "people"},
    {"classification": "Preposition", "word": "per"},
    {"classification": "Noun", "word": "percentage"},
    {"classification": "Noun", "word": "perfect"},
    {"classification": "Adjective", "word": "perfect"},
    {"classification": "Verb", "word": "perfection"},
    {"classification": "Adverb", "word": "perfectly"},
    {"classification": "Verb", "word": "perform"},
    {"classification": "Adverb", "word": "perhaps"},
    {"classification": "Verb", "word": "period"},
    {"classification": "Noun", "word": "period"},
    {"classification": "Adjective", "word": "permanent"},
    {"classification": "Verb", "word": "permit"},
    {"classification": "Noun", "word": "permit"},
    {"classification": "Adjective", "word": "perpendicular"},
    {"classification": "Verb", "word": "perpetrate"},
    {"classification": "Adjective", "word": "perpetual"},
    {"classification": "Verb", "word": "persist"},
    {"classification": "Noun", "word": "person"},
    {"classification": "Verb", "word": "person"},
    {"classification": "Adjective", "word": "personal"},
    {"classification": "Adverb", "word": "personally"},
    {"classification": "Adjective", "word": "perspective"},
    {"classification": "Noun", "word": "perspective"},
    {"classification": "Verb", "word": "persuade"},
    {"classification": "Noun", "word": "persuade"},
    {"classification": "Adjective", "word": "pertinent"},
    {"classification": "Verb", "word": "pervade"},
    {"classification": "Noun", "word": "pest"},
    {"classification": "Noun", "word": "pet"},
    {"classification": "Adjective", "word": "pet"},
    {"classification": "Verb", "word": "pet"},
    {"classification": "Noun", "word": "peter"},
    {"classification": "Verb", "word": "peter"},
    {"classification": "Noun", "word": "phase"},
    {"classification": "Verb", "word": "phase"},
    {"classification": "Noun", "word": "phases"},
    {"classification": "Noun", "word": "phenomena"},
    {"classification": "Noun", "word": "philip"},
    {"classification": "Adjective", "word": "philosophical"},
    {"classification": "Verb", "word": "photograph"},
    {"classification": "Noun", "word": "phrase"},
    {"classification": "Verb", "word": "phrase"},
    {"classification": "Adjective", "word": "physical"},
    {"classification": "Adverb", "word": "physically"},
    {"classification": "Adjective", "word": "physiological"},
    {"classification": "Adjective", "word": "piano"},
    {"classification": "Noun", "word": "pick"},
    {"classification": "Verb", "word": "pick"},
    {"classification": "Adjective", "word": "picked"},
    {"classification": "Verb", "word": "picture"},
    {"classification": "Noun", "word": "piece"},
    {"classification": "Verb", "word": "piece"},
    {"classification": "Noun", "word": "pig"},
    {"classification": "Noun", "word": "pigeon"},
    {"classification": "Verb", "word": "pigeon"},
    {"classification": "Noun", "word": "pile"},
    {"classification": "Verb", "word": "pile"},
    {"classification": "Noun", "word": "pilot"},
    {"classification": "Verb", "word": "pilot"},
    {"classification": "Noun", "word": "pin"},
    {"classification": "Verb", "word": "pin"},
    {"classification": "Noun", "word": "pinch"},
    {"classification": "Verb", "word": "pinch"},
    {"classification": "Noun", "word": "pink"},
    {"classification": "Adjective", "word": "pink"},
    {"classification": "Verb", "word": "pink"},
    {"classification": "Noun", "word": "pint"},
    {"classification": "Noun", "word": "pioneer"},
    {"classification": "Noun", "word": "pip"},
    {"classification": "Verb", "word": "pip"},
    {"classification": "Noun", "word": "pipe"},
    {"classification": "Verb", "word": "pipe"},
    {"classification": "Noun", "word": "pistol"},
    {"classification": "Verb", "word": "pistol"},
    {"classification": "Noun", "word": "pitch"},
    {"classification": "Verb", "word": "pitch"},
    {"classification": "Noun", "word": "pitcher"},
    {"classification": "Noun", "word": "pity"},
    {"classification": "Verb", "word": "pity"},
    {"classification": "Noun", "word": "place"},
    {"classification": "Verb", "word": "place"},
    {"classification": "Verb", "word": "plain"},
    {"classification": "Adjective", "word": "plain"},
    {"classification": "Adverb", "word": "plain"},
    {"classification": "Verb", "word": "plan"},
    {"classification": "Adjective", "word": "plan"},
    {"classification": "Noun", "word": "plane"},
    {"classification": "Adjective", "word": "plane"},
    {"classification": "Verb", "word": "plane"},
    {"classification": "Noun", "word": "planet"},
    {"classification": "Adjective", "word": "planetary"},
    {"classification": "Noun", "word": "plant"},
    {"classification": "Verb", "word": "plant"},
    {"classification": "Noun", "word": "plaster"},
    {"classification": "Verb", "word": "plaster"},
    {"classification": "Noun", "word": "plastic"},
    {"classification": "Adjective", "word": "plastic"},
    {"classification": "Noun", "word": "plate"},
    {"classification": "Verb", "word": "plate"},
    {"classification": "Noun", "word": "platform"},
    {"classification": "Verb", "word": "platform"},
    {"classification": "Noun", "word": "play"},
    {"classification": "Verb", "word": "play"},
    {"classification": "Verb", "word": "resign"},
    {"classification": "Noun", "word": "resist"},
    {"classification": "Verb", "word": "resist"},
    {"classification": "Noun", "word": "resource"},
    {"classification": "Verb", "word": "respect"},
    {"classification": "Adjective", "word": "respectable"},
    {"classification": "Adjective", "word": "respective"},
    {"classification": "Adverb", "word": "respectively"},
    {"classification": "Noun", "word": "respond"},
    {"classification": "Verb", "word": "respond"},
    {"classification": "Adjective", "word": "responsible"},
    {"classification": "Noun", "word": "rest"},
    {"classification": "Verb", "word": "rest"},
    {"classification": "Noun", "word": "restaurant"},
    {"classification": "Verb", "word": "restore"},
    {"classification": "Verb", "word": "restrict"},
    {"classification": "Adjective", "word": "restrict"},
    {"classification": "Noun", "word": "result"},
    {"classification": "Verb", "word": "result"},
    {"classification": "Noun", "word": "retail"},
    {"classification": "Adjective", "word": "retail"},
    {"classification": "Verb", "word": "retail"},
    {"classification": "Verb", "word": "retain"},
    {"classification": "Noun", "word": "retard"},
    {"classification": "Verb", "word": "retard"},
    {"classification": "Noun", "word": "retire"},
    {"classification": "Verb", "word": "retire"},
    {"classification": "Adjective", "word": "retired"},
    {"classification": "Noun", "word": "return"},
    {"classification": "Verb", "word": "return"},
    {"classification": "Noun", "word": "reveal"},
    {"classification": "Verb", "word": "reveal"},
    {"classification": "Noun", "word": "revenge"},
    {"classification": "Verb", "word": "revenge"},
    {"classification": "Noun", "word": "revenue"},
    {"classification": "Adjective", "word": "reverberate"},
    {"classification": "Verb", "word": "reverberate"},
    {"classification": "Adjective", "word": "reverend"},
    {"classification": "Adjective", "word": "reverse"},
    {"classification": "Verb", "word": "reverse"},
    {"classification": "Noun", "word": "review"},
    {"classification": "Verb", "word": "review"},
    {"classification": "Noun", "word": "revise"},
    {"classification": "Verb", "word": "revise"},
    {"classification": "Verb", "word": "revive"},
    {"classification": "Noun", "word": "revolt"},
    {"classification": "Verb", "word": "revolt"},
    {"classification": "Noun", "word": "revolution"},
    {"classification": "Adjective", "word": "revolutionary"},
    {"classification": "Verb", "word": "revolve"},
    {"classification": "Noun", "word": "reward"},
    {"classification": "Verb", "word": "reward"},
    {"classification": "Noun", "word": "rhythm"},
    {"classification": "Noun", "word": "ribbon"},
    {"classification": "Verb", "word": "ribbon"},
    {"classification": "Noun", "word": "rice"},
    {"classification": "Adjective", "word": "rich"},
    {"classification": "Verb", "word": "rich"},
    {"classification": "Verb", "word": "rid"},
    {"classification": "Noun", "word": "ride"},
    {"classification": "Verb", "word": "ride"},
    {"classification": "Noun", "word": "riding"},
    {"classification": "Adjective", "word": "riding"},
    {"classification": "Noun", "word": "rifle"},
    {"classification": "Verb", "word": "rifle"},
    {"classification": "Adjective", "word": "right"},
    {"classification": "Adverb", "word": "right"},
    {"classification": "Verb", "word": "right"},
    {"classification": "Adjective", "word": "rigid"},
    {"classification": "Noun", "word": "rigor"},
    {"classification": "Noun", "word": "ring"},
    {"classification": "Verb", "word": "ring"},
    {"classification": "Noun", "word": "ripe"},
    {"classification": "Adjective", "word": "ripe"},
    {"classification": "Verb", "word": "ripe"},
    {"classification": "Verb", "word": "ripen"},
    {"classification": "Noun", "word": "rise"},
    {"classification": "Verb", "word": "rise"},
    {"classification": "Noun", "word": "rising"},
    {"classification": "Adjective", "word": "rising"},
    {"classification": "Noun", "word": "risk"},
    {"classification": "Noun", "word": "ritual"},
    {"classification": "Adjective", "word": "ritual"},
    {"classification": "Noun", "word": "rival"},
    {"classification": "Verb", "word": "rival"},
    {"classification": "Adjective", "word": "rival"},
    {"classification": "Noun", "word": "river"},
    {"classification": "Verb", "word": "river"},
    {"classification": "Noun", "word": "road"},
    {"classification": "Noun", "word": "roar"},
    {"classification": "Verb", "word": "roar"},
    {"classification": "Noun", "word": "roast"},
    {"classification": "Verb", "word": "roast"},
    {"classification": "Adjective", "word": "roast"},
    {"classification": "Noun", "word": "rob"},
    {"classification": "Verb", "word": "rob"},
    {"classification": "Noun", "word": "robert"},
    {"classification": "Verb", "word": "rock"},
    {"classification": "Noun", "word": "rock"},
    {"classification": "Noun", "word": "rod"},
    {"classification": "Verb", "word": "rode"},
    {"classification": "Noun", "word": "rode"},
    {"classification": "Noun", "word": "role"},
    {"classification": "Verb", "word": "roll"},
    {"classification": "Noun", "word": "roll"},
    {"classification": "Adjective", "word": "roman"},
    {"classification": "Noun", "word": "roman"},
    {"classification": "Adjective", "word": "romantic"},
    {"classification": "Verb", "word": "roof"},
    {"classification": "Noun", "word": "roof"},
    {"classification": "Adjective", "word": "room"},
    {"classification": "Verb", "word": "room"},
    {"classification": "Noun", "word": "room"},
    {"classification": "Verb", "word": "root"},
    {"classification": "Noun", "word": "root"},
    {"classification": "Verb", "word": "rope"},
    {"classification": "Noun", "word": "rope"},
    {"classification": "Verb", "word": "rose"},
    {"classification": "Noun", "word": "rose"},
    {"classification": "Verb", "word": "rot"},
    {"classification": "Noun", "word": "rot"},
    {"classification": "Verb", "word": "rotate"},
    {"classification": "Adjective", "word": "rotate"},
    {"classification": "Adjective", "word": "rotten"},
    {"classification": "Adverb", "word": "rough"},
    {"classification": "Verb", "word": "rough"},
    {"classification": "Noun", "word": "rough"},
    {"classification": "Adverb", "word": "roughly"},
    {"classification": "Adverb", "word": "round"},
    {"classification": "Verb", "word": "round"},
    {"classification": "Adjective", "word": "round"},
    {"classification": "Preposition", "word": "round"},
    {"classification": "Noun", "word": "round"},
    {"classification": "Noun", "word": "route"},
    {"classification": "Noun", "word": "routine"},
    {"classification": "Verb", "word": "row"},
    {"classification": "Noun", "word": "row"},
    {"classification": "Adjective", "word": "roy"},
    {"classification": "Noun", "word": "roy"},
    {"classification": "Adjective", "word": "royal"},
    {"classification": "Noun", "word": "royal"},
    {"classification": "Verb", "word": "rub"},
    {"classification": "Noun", "word": "rub"},
    {"classification": "Noun", "word": "rubber"},
    {"classification": "Adjective", "word": "rubbish"},
    {"classification": "Noun", "word": "rubbish"},
    {"classification": "Adjective", "word": "rude"},
    {"classification": "Adjective", "word": "rudimentary"},
    {"classification": "Adjective", "word": "rug"},
    {"classification": "Verb", "word": "rug"},
    {"classification": "Verb", "word": "ruin"},
    {"classification": "Noun", "word": "ruin"},
    {"classification": "Adjective", "word": "rule"},
    {"classification": "Verb", "word": "rule"},
    {"classification": "Noun", "word": "rule"},
    {"classification": "Adjective", "word": "ruling"},
    {"classification": "Noun", "word": "ruling"},
    {"classification": "Adjective", "word": "run"},
    {"classification": "Verb", "word": "run"},
    {"classification": "Noun", "word": "run"},
    {"classification": "Adjective", "word": "running"},
    {"classification": "Noun", "word": "running"},
    {"classification": "Adjective", "word": "rural"},
    {"classification": "Verb", "word": "rush"},
    {"classification": "Noun", "word": "rush"},
    {"classification": "Adjective", "word": "rushed"},
    {"classification": "Adjective", "word": "russ"},
    {"classification": "Noun", "word": "russia"},
    {"classification": "Adjective", "word": "russian"},
    {"classification": "Verb", "word": "rust"},
    {"classification": "Noun", "word": "rust"},
    {"classification": "Verb", "word": "ruth"},
    {"classification": "Noun", "word": "ruth"},
    {"classification": "Adjective", "word": "sacred"},
    {"classification": "Verb", "word": "sacrifice"},
    {"classification": "Verb", "word": "sad"},
    {"classification": "Verb", "word": "sadden"},
    {"classification": "Verb", "word": "saddle"},
    {"classification": "Noun", "word": "saddle"},
    {"classification": "Adjective", "word": "safe"},
    {"classification": "Verb", "word": "safe"},
    {"classification": "Noun", "word": "safe"},
    {"classification": "Noun", "word": "safety"},
    {"classification": "Adjective", "word": "said"},
    {"classification": "Verb", "word": "sail"},
    {"classification": "Noun", "word": "sail"},
    {"classification": "Noun", "word": "sailing"},
    {"classification": "Noun", "word": "sailor"},
    {"classification": "Verb", "word": "saint"},
    {"classification": "Noun", "word": "saint"},
    {"classification": "Noun", "word": "sake"},
    {"classification": "Adjective", "word": "salary"},
    {"classification": "Verb", "word": "salary"},
    {"classification": "Noun", "word": "salary"},
    {"classification": "Verb", "word": "sale"},
    {"classification": "Noun", "word": "sale"},
    {"classification": "Noun", "word": "salesman"},
    {"classification": "Adjective", "word": "saline"},
    {"classification": "Noun", "word": "saline"},
    {"classification": "Verb", "word": "salt"},
    {"classification": "Noun", "word": "salt"},
    {"classification": "Noun", "word": "salvation"},
    {"classification": "Adjective", "word": "sam"},
    {"classification": "Verb", "word": "same"},
    {"classification": "Verb", "word": "sample"},
    {"classification": "Noun", "word": "sample"},
    {"classification": "Verb", "word": "sanction"},
    {"classification": "Verb", "word": "sand"},
    {"classification": "Noun", "word": "sand"},
    {"classification": "Verb", "word": "sat"},
    {"classification": "Adjective", "word": "satellite"},
    {"classification": "Noun", "word": "satellite"},
    {"classification": "Noun", "word": "satisfaction"},
    {"classification": "Adjective", "word": "satisfactory"},
    {"classification": "Verb", "word": "satisfy"},
    {"classification": "Adjective", "word": "satisfy"},
    {"classification": "Verb", "word": "saturate"},
    {"classification": "Noun", "word": "saturday"},
    {"classification": "Verb", "word": "sauce"},
    {"classification": "Noun", "word": "sauce"},
    {"classification": "Noun", "word": "saucer"},
    {"classification": "Adjective", "word": "savage"},
    {"classification": "Verb", "word": "savage"},
    {"classification": "Noun", "word": "savage"},
    {"classification": "Verb", "word": "save"},
    {"classification": "Adjective", "word": "save"},
    {"classification": "Noun", "word": "save"},
    {"classification": "Adjective", "word": "saving"},
    {"classification": "Noun", "word": "saving"},
    {"classification": "Verb", "word": "saw"},
    {"classification": "Noun", "word": "saw"},
    {"classification": "Verb", "word": "say"},
    {"classification": "Noun", "word": "say"},
    {"classification": "Noun", "word": "saying"},
    {"classification": "Noun", "word": "scalar"},
    {"classification": "Verb", "word": "scale"},
    {"classification": "Noun", "word": "scale"},
    {"classification": "Adjective", "word": "scarce"},
    {"classification": "Adverb", "word": "scarce"},
    {"classification": "Adverb", "word": "scarcely"},
    {"classification": "Verb", "word": "scatter"},
    {"classification": "Adjective", "word": "scattered"},
    {"classification": "Verb", "word": "scene"},
    {"classification": "Noun", "word": "scene"},
    {"classification": "Noun", "word": "scenery"},
    {"classification": "Verb", "word": "scent"},
    {"classification": "Noun", "word": "scent"},
    {"classification": "Verb", "word": "schedule"},
    {"classification": "Noun", "word": "schedule"},
    {"classification": "Verb", "word": "scheme"},
    {"classification": "Noun", "word": "scheme"},
    {"classification": "Verb", "word": "school"},
    {"classification": "Noun", "word": "school"},
    {"classification": "Verb", "word": "science"},
    {"classification": "Noun", "word": "science"},
    {"classification": "Adjective", "word": "scientific"},
    {"classification": "Noun", "word": "scientist"},
    {"classification": "Noun", "word": "scissors"},
    {"classification": "Verb", "word": "scold"},
    {"classification": "Noun", "word": "scold"},
    {"classification": "Verb", "word": "scope"},
    {"classification": "Noun", "word": "scope"},
    {"classification": "Verb", "word": "score"},
    {"classification": "Noun", "word": "score"},
    {"classification": "Verb", "word": "scorn"},
    {"classification": "Noun", "word": "scorn"},
    {"classification": "Verb", "word": "scrape"},
    {"classification": "Noun", "word": "scrape"},
    {"classification": "Adjective", "word": "scratch"},
    {"classification": "Verb", "word": "scratch"},
    {"classification": "Noun", "word": "scratch"},
    {"classification": "Verb", "word": "screen"},
    {"classification": "Noun", "word": "screen"},
    {"classification": "Verb", "word": "screw"},
    {"classification": "Noun", "word": "screw"},
    {"classification": "Noun", "word": "sea"},
    {"classification": "Verb", "word": "search"},
    {"classification": "Adjective", "word": "searching"},
    {"classification": "Verb", "word": "season"},
    {"classification": "Noun", "word": "season"},
    {"classification": "Verb", "word": "seat"},
    {"classification": "Noun", "word": "seat"},
    {"classification": "Adjective", "word": "second"},
    {"classification": "Noun", "word": "second"},
    {"classification": "Adjective", "word": "secondary"},
    {"classification": "Verb", "word": "secret"},
    {"classification": "Adjective", "word": "secret"},
    {"classification": "Verb", "word": "secrete"},
    {"classification": "Noun", "word": "section"},
    {"classification": "Adjective", "word": "secure"},
    {"classification": "Verb", "word": "secure"},
    {"classification": "Verb", "word": "see"},
    {"classification": "Noun", "word": "see"},
    {"classification": "Verb", "word": "seed"},
    {"classification": "Noun", "word": "seed"},
    {"classification": "Noun", "word": "seeds"},
    {"classification": "Adjective", "word": "seek"},
    {"classification": "Verb", "word": "seek"},
    {"classification": "Adjective", "word": "seem"},
    {"classification": "Verb", "word": "seem"},
    {"classification": "Adjective", "word": "seen"},
    {"classification": "Verb", "word": "segment"},
    {"classification": "Noun", "word": "segment"},
    {"classification": "Verb", "word": "seize"},
    {"classification": "Adjective", "word": "seldom"},
    {"classification": "Verb", "word": "select"},
    {"classification": "Adjective", "word": "select"},
    {"classification": "Noun", "word": "selection"},
    {"classification": "Adjective", "word": "self"},
    {"classification": "Noun", "word": "self"},
    {"classification": "Adjective", "word": "selfish"},
    {"classification": "Verb", "word": "sell"},
    {"classification": "Noun", "word": "sell"},
    {"classification": "Noun", "word": "sen"},
    {"classification": "Noun", "word": "senate"},
    {"classification": "Noun", "word": "senator"},
    {"classification": "Verb", "word": "send"},
    {"classification": "Noun", "word": "send"},
    {"classification": "Adjective", "word": "senior"},
    {"classification": "Noun", "word": "senior"},
    {"classification": "Verb", "word": "sense"},
    {"classification": "Noun", "word": "sense"},
    {"classification": "Adjective", "word": "sensitive"},
    {"classification": "Noun", "word": "sensitivity"},
    {"classification": "Verb", "word": "sentence"},
    {"classification": "Noun", "word": "sentence"},
    {"classification": "Adjective", "word": "sentiment"},
    {"classification": "Verb", "word": "separate"},
    {"classification": "Noun", "word": "sequence"},
    {"classification": "Noun", "word": "series"},
    {"classification": "Adjective", "word": "serious"},
    {"classification": "Verb", "word": "servant"},
    {"classification": "Noun", "word": "servant"},
    {"classification": "Verb", "word": "serve"},
    {"classification": "Noun", "word": "service"},
    {"classification": "Noun", "word": "session"},
    {"classification": "Adjective", "word": "set"},
    {"classification": "Verb", "word": "set"},
    {"classification": "Noun", "word": "set"},
    {"classification": "Noun", "word": "setting"},
    {"classification": "Verb", "word": "settle"},
    {"classification": "Noun", "word": "settle"},
    {"classification": "Adjective", "word": "seven"},
    {"classification": "Noun", "word": "seven"},
    {"classification": "Adjective", "word": "seventeen"},
    {"classification": "Noun", "word": "seventeen"},
    {"classification": "Adjective", "word": "seventh"},
    {"classification": "Adverb", "word": "several"},
    {"classification": "Pronoun", "word": "several"},
    {"classification": "Adjective", "word": "several"},
    {"classification": "Noun", "word": "several"},
    {"classification": "Adjective", "word": "severe"},
    {"classification": "Verb", "word": "sew"},
    {"classification": "Noun", "word": "sew"},
    {"classification": "Noun", "word": "sewage"},
    {"classification": "Noun", "word": "sex"},
    {"classification": "Adjective", "word": "sexual"},
    {"classification": "Verb", "word": "shade"},
    {"classification": "Noun", "word": "shade"},
    {"classification": "Noun", "word": "shadow"},
    {"classification": "Verb", "word": "shake"},
    {"classification": "Noun", "word": "shake"},
    {"classification": "Verb", "word": "shallow"},
    {"classification": "Adjective", "word": "shallow"},
    {"classification": "Verb", "word": "shame"},
    {"classification": "Noun", "word": "shame"},
    {"classification": "Verb", "word": "shape"},
    {"classification": "Noun", "word": "shape"},
    {"classification": "Verb", "word": "share"},
    {"classification": "Noun", "word": "share"},
    {"classification": "Adjective", "word": "sharp"},
    {"classification": "Verb", "word": "sharp"},
    {"classification": "Adverb", "word": "sharp"},
    {"classification": "Noun", "word": "sharp"},
    {"classification": "Adjective", "word": "sharpen"},
    {"classification": "Verb", "word": "sharpen"},
    {"classification": "Adverb", "word": "sharply"},
    {"classification": "Verb", "word": "shave"},
    {"classification": "Pronoun", "word": "she"},
    {"classification": "Verb", "word": "shear"},
    {"classification": "Verb", "word": "sheet"},
    {"classification": "Verb", "word": "shelf"},
    {"classification": "Verb", "word": "shell"},
    {"classification": "Noun", "word": "shell"},
    {"classification": "Verb", "word": "shelter"},
    {"classification": "Noun", "word": "shelter"},
    {"classification": "Noun", "word": "shield"},
    {"classification": "Verb", "word": "shift"},
    {"classification": "Noun", "word": "shilling"},
    {"classification": "Verb", "word": "shine"},
    {"classification": "Noun", "word": "shine"},
    {"classification": "Adjective", "word": "shining"},
    {"classification": "Noun", "word": "shining"},
    {"classification": "Verb", "word": "ship"},
    {"classification": "Noun", "word": "ship"},
    {"classification": "Adjective", "word": "shipping"},
    {"classification": "Noun", "word": "shipping"},
    {"classification": "Noun", "word": "shirt"},
    {"classification": "Adjective", "word": "shock"},
    {"classification": "Verb", "word": "shock"},
    {"classification": "Noun", "word": "shock"},
    {"classification": "Noun", "word": "shoe"},
    {"classification": "Noun", "word": "shoes"},
    {"classification": "Verb", "word": "shook"},
    {"classification": "Noun", "word": "shook"},
    {"classification": "Verb", "word": "shoot"},
    {"classification": "Noun", "word": "shoot"},
    {"classification": "Adjective", "word": "shooting"},
    {"classification": "Noun", "word": "shooting"},
    {"classification": "Verb", "word": "shop"},
    {"classification": "Noun", "word": "shop"},
    {"classification": "Verb", "word": "shore"},
    {"classification": "Noun", "word": "shore"},
    {"classification": "Verb", "word": "short"},
    {"classification": "Adverb", "word": "short"},
    {"classification": "Adjective", "word": "short"},
    {"classification": "Noun", "word": "short"},
    {"classification": "Verb", "word": "shorten"},
    {"classification": "Adjective", "word": "shorten"},
    {"classification": "Adverb", "word": "shortly"},
    {"classification": "Adjective", "word": "shot"},
    {"classification": "Verb", "word": "shot"},
    {"classification": "Noun", "word": "shot"},
    {"classification": "Noun", "word": "shots"},
    {"classification": "Verb", "word": "should"},
    {"classification": "Verb", "word": "shoulder"},
    {"classification": "Noun", "word": "shoulder"},
    {"classification": "Verb", "word": "shout"},
    {"classification": "Noun", "word": "shout"},
    {"classification": "Verb", "word": "show"},
    {"classification": "Noun", "word": "show"},
    {"classification": "Verb", "word": "showed"},
    {"classification": "Verb", "word": "shower"},
    {"classification": "Noun", "word": "shower"},
    {"classification": "Verb", "word": "shrink"},
    {"classification": "Noun", "word": "shrink"},
    {"classification": "Adjective", "word": "shut"},
    {"classification": "Verb", "word": "shut"},
    {"classification": "Noun", "word": "shut"},
    {"classification": "Adjective", "word": "sick"},
    {"classification": "Verb", "word": "sick"},
    {"classification": "Noun", "word": "sick"},
    {"classification": "Adjective", "word": "side"},
    {"classification": "Verb", "word": "side"},
    {"classification": "Noun", "word": "side"},
    {"classification": "Noun", "word": "sidewalk"},
    {"classification": "Verb", "word": "sight"},
    {"classification": "Verb", "word": "sign"},
    {"classification": "Noun", "word": "sign"},
    {"classification": "Verb", "word": "signal"},
    {"classification": "Adjective", "word": "signal"},
    {"classification": "Noun", "word": "signal"},
    {"classification": "Verb", "word": "signature"},
    {"classification": "Noun", "word": "significance"},
    {"classification": "Adjective", "word": "significant"},
    {"classification": "Verb", "word": "silence"},
    {"classification": "Noun", "word": "silence"},
    {"classification": "Adjective", "word": "silent"},
    {"classification": "Noun", "word": "silent"},
    {"classification": "Noun", "word": "silk"},
    {"classification": "Adjective", "word": "silver"},
    {"classification": "Verb", "word": "silver"},
    {"classification": "Noun", "word": "silver"},
    {"classification": "Adjective", "word": "similar"},
    {"classification": "Noun", "word": "similar"},
    {"classification": "Adverb", "word": "similarly"},
    {"classification": "Adjective", "word": "simple"},
    {"classification": "Verb", "word": "simple"},
    {"classification": "Adverb", "word": "simply"},
    {"classification": "Adjective", "word": "simultaneous"},
    {"classification": "Noun", "word": "sin"},
    {"classification": "Adverb", "word": "since"},
    {"classification": "Preposition", "word": "since"},
    {"classification": "SubordConjunction", "word": "since"},
    {"classification": "Adjective", "word": "sincere"},
    {"classification": "Verb", "word": "sing"},
    {"classification": "Adjective", "word": "single"},
    {"classification": "Verb", "word": "single"},
    {"classification": "Noun", "word": "single"},
    {"classification": "Verb", "word": "sink"},
    {"classification": "Noun", "word": "sink"},
    {"classification": "Noun", "word": "sir"},
    {"classification": "Verb", "word": "sister"},
    {"classification": "Noun", "word": "sister"},
    {"classification": "Verb", "word": "sit"},
    {"classification": "Noun", "word": "site"},
    {"classification": "Noun", "word": "sitter"},
    {"classification": "Adjective", "word": "sitting"},
    {"classification": "Noun", "word": "sitting"},
    {"classification": "Noun", "word": "situation"},
    {"classification": "Adjective", "word": "six"},
    {"classification": "Noun", "word": "six"},
    {"classification": "Adjective", "word": "sixteen"},
    {"classification": "Noun", "word": "sixteen"},
    {"classification": "Adjective", "word": "sixth"},
    {"classification": "Noun", "word": "sixth"},
    {"classification": "Noun", "word": "sixties"},
    {"classification": "Adjective", "word": "sixty"},
    {"classification": "Noun", "word": "sixty"},
    {"classification": "Verb", "word": "size"},
    {"classification": "Noun", "word": "size"},
    {"classification": "Adjective", "word": "skeleton"},
    {"classification": "Verb", "word": "sketch"},
    {"classification": "Noun", "word": "sketch"},
    {"classification": "Verb", "word": "skill"},
    {"classification": "Noun", "word": "skill"},
    {"classification": "Adjective", "word": "skilled"},
    {"classification": "Verb", "word": "skin"},
    {"classification": "Noun", "word": "skin"},
    {"classification": "Verb", "word": "skirt"},
    {"classification": "Noun", "word": "skirt"},
    {"classification": "Verb", "word": "sky"},
    {"classification": "Noun", "word": "sky"},
    {"classification": "Verb", "word": "slave"},
    {"classification": "Noun", "word": "slave"},
    {"classification": "Verb", "word": "sleep"},
    {"classification": "Adjective", "word": "slender"},
    {"classification": "Verb", "word": "slid"},
    {"classification": "Verb", "word": "slide"},
    {"classification": "Noun", "word": "slide"},
    {"classification": "Adjective", "word": "slight"},
    {"classification": "Adverb", "word": "slight"},
    {"classification": "Verb", "word": "slight"},
    {"classification": "Noun", "word": "slight"},
    {"classification": "Adverb", "word": "slightly"},
    {"classification": "Adjective", "word": "slim"},
    {"classification": "Verb", "word": "slip"},
    {"classification": "Noun", "word": "slip"},
    {"classification": "Adjective", "word": "slippery"},
    {"classification": "Adjective", "word": "slope"},
    {"classification": "Verb", "word": "slope"},
    {"classification": "Adverb", "word": "slope"},
    {"classification": "Noun", "word": "slope"},
    {"classification": "Adjective", "word": "slow"},
    {"classification": "Verb", "word": "slow"},
    {"classification": "Adverb", "word": "slow"},
    {"classification": "Noun", "word": "slow"},
    {"classification": "Adverb", "word": "slowly"},
    {"classification": "Adjective", "word": "small"},
    {"classification": "Adverb", "word": "small"},
    {"classification": "Verb", "word": "small"},
    {"classification": "Noun", "word": "small"},
    {"classification": "Verb", "word": "smart"},
    {"classification": "Verb", "word": "smell"},
    {"classification": "Noun", "word": "smell"},
    {"classification": "Verb", "word": "smile"},
    {"classification": "Noun", "word": "smith"},
    {"classification": "Verb", "word": "smoke"},
    {"classification": "Noun", "word": "smoke"},
    {"classification": "Adjective", "word": "smooth"},
    {"classification": "Adverb", "word": "smooth"},
    {"classification": "Verb", "word": "smooth"},
    {"classification": "Noun", "word": "smooth"},
    {"classification": "Verb", "word": "snake"},
    {"classification": "Noun", "word": "snake"},
    {"classification": "Verb", "word": "snow"},
    {"classification": "Noun", "word": "snow"},
    {"classification": "CoordConjunction", "word": "so"},
    {"classification": "Adverb", "word": "so"},
    {"classification": "Verb", "word": "soap"},
    {"classification": "Noun", "word": "soap"},
    {"classification": "Adjective", "word": "so-called"},
    {"classification": "Adjective", "word": "social"},
    {"classification": "Noun", "word": "socialism"},
    {"classification": "Adjective", "word": "socialist"},
    {"classification": "Noun", "word": "societies"},
    {"classification": "Verb", "word": "sock"},
    {"classification": "Noun", "word": "sock"},
    {"classification": "Adverb", "word": "soft"},
    {"classification": "Adjective", "word": "soft"},
    {"classification": "Noun", "word": "soft"},
    {"classification": "Verb", "word": "soften"},
    {"classification": "Adverb", "word": "softly"},
    {"classification": "Verb", "word": "soil"},
    {"classification": "Noun", "word": "soil"},
    {"classification": "Adjective", "word": "solar"},
    {"classification": "Noun", "word": "sold"},
    {"classification": "Verb", "word": "soldier"},
    {"classification": "Noun", "word": "soldier"},
    {"classification": "Adverb", "word": "solely"},
    {"classification": "Adjective", "word": "solemn"},
    {"classification": "Adjective", "word": "solid"},
    {"classification": "Noun", "word": "solid"},
    {"classification": "Noun", "word": "solution"},
    {"classification": "Verb", "word": "solve"},
    {"classification": "Noun", "word": "solve"},
    {"classification": "Adjective", "word": "some"},
    {"classification": "Pronoun", "word": "somebody"},
    {"classification": "Noun", "word": "somebody"},
    {"classification": "Adverb", "word": "somehow"},
    {"classification": "Pronoun", "word": "someone"},
    {"classification": "Adverb", "word": "something"},
    {"classification": "Noun", "word": "something"},
    {"classification": "Adverb", "word": "sometime"},
    {"classification": "Adjective", "word": "sometime"},
    {"classification": "Adverb", "word": "sometimes"},
    {"classification": "Adjective", "word": "sometimes"},
    {"classification": "Adverb", "word": "somewhat"},
    {"classification": "Noun", "word": "somewhat"},
    {"classification": "Adverb", "word": "somewhere"},
    {"classification": "Noun", "word": "son"},
    {"classification": "Noun", "word": "song"},
    {"classification": "Adjective", "word": "soon"},
    {"classification": "Adverb", "word": "soon"},
    {"classification": "Adjective", "word": "sophisticated"},
    {"classification": "Adjective", "word": "sore"},
    {"classification": "Noun", "word": "sore"},
    {"classification": "Noun", "word": "sorrow"},
    {"classification": "Adjective", "word": "sorry"},
    {"classification": "Verb", "word": "sort"},
    {"classification": "Noun", "word": "sort"},
    {"classification": "Verb", "word": "soul"},
    {"classification": "Adjective", "word": "soul"},
    {"classification": "Noun", "word": "soul"},
    {"classification": "Adverb", "word": "sound"},
    {"classification": "Verb", "word": "sound"},
    {"classification": "Adjective", "word": "sound"},
    {"classification": "Noun", "word": "sound"},
    {"classification": "Verb", "word": "soup"},
    {"classification": "Noun", "word": "soup"},
    {"classification": "Adjective", "word": "sour"},
    {"classification": "Verb", "word": "sour"},
    {"classification": "Noun", "word": "sour"},
    {"classification": "Noun", "word": "source"},
    {"classification": "Adjective", "word": "south"},
    {"classification": "Adverb", "word": "south"},
    {"classification": "Verb", "word": "south"},
    {"classification": "Noun", "word": "south"},
    {"classification": "Adjective", "word": "southeast"},
    {"classification": "Noun", "word": "southeast"},
    {"classification": "Adjective", "word": "southern"},
    {"classification": "Adjective", "word": "sovereign"},
    {"classification": "Noun", "word": "sovereign"},
    {"classification": "Verb", "word": "sow"},
    {"classification": "Noun", "word": "sow"},
    {"classification": "Noun", "word": "space"},
    {"classification": "Verb", "word": "spade"},
    {"classification": "Noun", "word": "spade"},
    {"classification": "Verb", "word": "span"},
    {"classification": "Adjective", "word": "spanish"},
    {"classification": "Noun", "word": "spanish"},
    {"classification": "Adjective", "word": "spare"},
    {"classification": "Verb", "word": "spare"},
    {"classification": "Noun", "word": "spare"},
    {"classification": "Adjective", "word": "spatial"},
    {"classification": "Verb", "word": "speak"},
    {"classification": "Noun", "word": "speaker"},
    {"classification": "Adjective", "word": "speaking"},
    {"classification": "Adjective", "word": "special"},
    {"classification": "Noun", "word": "special"},
    {"classification": "Adjective", "word": "specific"},
    {"classification": "Noun", "word": "specific"},
    {"classification": "Adverb", "word": "specifically"},
    {"classification": "Verb", "word": "specify"},
    {"classification": "Noun", "word": "specimen"},
    {"classification": "Adjective", "word": "spectacular"},
    {"classification": "Verb", "word": "speculate"},
    {"classification": "Noun", "word": "speech"},
    {"classification": "Verb", "word": "speed"},
    {"classification": "Noun", "word": "speed"},
    {"classification": "Verb", "word": "spell"},
    {"classification": "Noun", "word": "spell"},
    {"classification": "Verb", "word": "spend"},
    {"classification": "Noun", "word": "spending"},
    {"classification": "Adjective", "word": "spent"},
    {"classification": "Verb", "word": "sphere"},
    {"classification": "Noun", "word": "sphere"},
    {"classification": "Verb", "word": "spill"},
    {"classification": "Noun", "word": "spill"},
    {"classification": "Verb", "word": "spin"},
    {"classification": "Noun", "word": "spin"},
    {"classification": "Verb", "word": "spirit"},
    {"classification": "Noun", "word": "spirit"},
    {"classification": "Adjective", "word": "spiritual"},
    {"classification": "Verb", "word": "spit"},
    {"classification": "Noun", "word": "spit"},
    {"classification": "Verb", "word": "spite"},
    {"classification": "Noun", "word": "spite"},
    {"classification": "Adjective", "word": "splendid"},
    {"classification": "Adjective", "word": "split"},
    {"classification": "Verb", "word": "split"},
    {"classification": "Noun", "word": "split"},
    {"classification": "Verb", "word": "spoil"},
    {"classification": "Noun", "word": "spoil"},
    {"classification": "Verb", "word": "spoke"},
    {"classification": "Noun", "word": "spoke"},
    {"classification": "Adjective", "word": "spoken"},
    {"classification": "Adjective", "word": "spontaneous"},
    {"classification": "Verb", "word": "spoon"},
    {"classification": "Noun", "word": "spoon"},
    {"classification": "Verb", "word": "sport"},
    {"classification": "Noun", "word": "sport"},
    {"classification": "Adjective", "word": "spot"},
    {"classification": "Verb", "word": "spot"},
    {"classification": "Noun", "word": "spot"},
    {"classification": "Verb", "word": "spread"},
    {"classification": "Noun", "word": "spread"},
    {"classification": "Verb", "word": "spring"},
    {"classification": "Adjective", "word": "square"},
    {"classification": "Verb", "word": "square"},
    {"classification": "Noun", "word": "square"},
    {"classification": "Adjective", "word": "stable"},
    {"classification": "Verb", "word": "stable"},
    {"classification": "Noun", "word": "stadium"},
    {"classification": "Noun", "word": "staff"},
    {"classification": "Verb", "word": "stage"},
    {"classification": "Noun", "word": "stage"},
    {"classification": "Verb", "word": "stain"},
    {"classification": "Noun", "word": "stain"},
    {"classification": "Noun", "word": "stair"},
    {"classification": "Verb", "word": "stake"},
    {"classification": "Noun", "word": "stake"},
    {"classification": "Verb", "word": "stamp"},
    {"classification": "Noun", "word": "stamp"},
    {"classification": "Verb", "word": "stand"},
    {"classification": "Noun", "word": "stand"},
    {"classification": "Adjective", "word": "standard"},
    {"classification": "Adjective", "word": "standing"},
    {"classification": "Noun", "word": "standing"},
    {"classification": "Verb", "word": "star"},
    {"classification": "Noun", "word": "star"},
    {"classification": "Verb", "word": "start"},
    {"classification": "Noun", "word": "start"},
    {"classification": "Verb", "word": "starve"},
    {"classification": "Verb", "word": "state"},
    {"classification": "Adjective", "word": "state"},
    {"classification": "Noun", "word": "state"},
    {"classification": "Adjective", "word": "stated"},
    {"classification": "Noun", "word": "statement"},
    {"classification": "Verb", "word": "station"},
    {"classification": "Noun", "word": "station"},
    {"classification": "Adjective", "word": "stationary"},
    {"classification": "Adjective", "word": "statistic"},
    {"classification": "Noun", "word": "status"},
    {"classification": "Verb", "word": "stay"},
    {"classification": "Noun", "word": "stay"},
    {"classification": "Adjective", "word": "stayed"},
    {"classification": "Adverb", "word": "steadily"},
    {"classification": "Verb", "word": "steady"},
    {"classification": "Noun", "word": "steady"},
    {"classification": "Verb", "word": "steam"},
    {"classification": "Noun", "word": "steam"},
    {"classification": "Noun", "word": "steel"},
    {"classification": "Verb", "word": "steep"},
    {"classification": "Adjective", "word": "steep"},
    {"classification": "Noun", "word": "steep"},
    {"classification": "Adjective", "word": "steer"},
    {"classification": "Verb", "word": "steer"},
    {"classification": "Noun", "word": "steer"},
    {"classification": "Verb", "word": "stem"},
    {"classification": "Noun", "word": "stem"},
    {"classification": "Adjective", "word": "step"},
    {"classification": "Verb", "word": "step"},
    {"classification": "Noun", "word": "step"},
    {"classification": "Adjective", "word": "stepped"},
    {"classification": "Verb", "word": "stereotype"},
    {"classification": "Verb", "word": "stern"},
    {"classification": "Adjective", "word": "stern"},
    {"classification": "Noun", "word": "stern"},
    {"classification": "Verb", "word": "stick"},
    {"classification": "Noun", "word": "stick"},
    {"classification": "Adjective", "word": "stiff"},
    {"classification": "Verb", "word": "stiffen"},
    {"classification": "Adjective", "word": "still"},
    {"classification": "Adverb", "word": "still"},
    {"classification": "Verb", "word": "still"},
    {"classification": "Noun", "word": "still"},
    {"classification": "Verb", "word": "stimulate"},
    {"classification": "Verb", "word": "sting"},
    {"classification": "Adjective", "word": "stipulate"},
    {"classification": "Verb", "word": "stipulate"},
    {"classification": "Verb", "word": "stir"},
    {"classification": "Noun", "word": "stir"},
    {"classification": "Adjective", "word": "stock"},
    {"classification": "Verb", "word": "stock"},
    {"classification": "Noun", "word": "stock"},
    {"classification": "Verb", "word": "stocking"},
    {"classification": "Verb", "word": "stomach"},
    {"classification": "Noun", "word": "stomach"},
    {"classification": "Noun", "word": "stone"},
    {"classification": "Verb", "word": "stop"},
    {"classification": "Noun", "word": "stop"},
    {"classification": "Adjective", "word": "stopped"},
    {"classification": "Noun", "word": "storage"},
    {"classification": "Adjective", "word": "store"},
    {"classification": "Verb", "word": "store"},
    {"classification": "Adjective", "word": "stored"},
    {"classification": "Verb", "word": "storm"},
    {"classification": "Noun", "word": "storm"},
    {"classification": "Verb", "word": "story"},
    {"classification": "Noun", "word": "story"},
    {"classification": "Verb", "word": "stove"},
    {"classification": "Noun", "word": "stove"},
    {"classification": "Adjective", "word": "straight"},
    {"classification": "Adverb", "word": "straight"},
    {"classification": "Verb", "word": "straight"},
    {"classification": "Noun", "word": "straight"},
    {"classification": "Verb", "word": "straighten"},
    {"classification": "Verb", "word": "strain"},
    {"classification": "Adjective", "word": "strain"},
    {"classification": "Noun", "word": "strain"},
    {"classification": "Adjective", "word": "strange"},
    {"classification": "Adverb", "word": "strange"},
    {"classification": "Verb", "word": "strange"},
    {"classification": "Verb", "word": "stranger"},
    {"classification": "Verb", "word": "strap"},
    {"classification": "Noun", "word": "strap"},
    {"classification": "Noun", "word": "strata"},
    {"classification": "Adjective", "word": "strategic"},
    {"classification": "Verb", "word": "straw"},
    {"classification": "Noun", "word": "straw"},
    {"classification": "Verb", "word": "stream"},
    {"classification": "Noun", "word": "stream"},
    {"classification": "Adjective", "word": "street"},
    {"classification": "Verb", "word": "strength"},
    {"classification": "Noun", "word": "strength"},
    {"classification": "Verb", "word": "strengthen"},
    {"classification": "Verb", "word": "stress"},
    {"classification": "Noun", "word": "stress"},
    {"classification": "Verb", "word": "stretch"},
    {"classification": "Noun", "word": "stretch"},
    {"classification": "Adjective", "word": "strict"},
    {"classification": "Adverb", "word": "strictly"},
    {"classification": "Verb", "word": "strike"},
    {"classification": "Noun", "word": "strike"},
    {"classification": "Adjective", "word": "striking"},
    {"classification": "Verb", "word": "string"},
    {"classification": "Noun", "word": "string"},
    {"classification": "Verb", "word": "strip"},
    {"classification": "Noun", "word": "strip"},
    {"classification": "Verb", "word": "stripe"},
    {"classification": "Noun", "word": "stripe"},
    {"classification": "Verb", "word": "stroke"},
    {"classification": "Adjective", "word": "strong"},
    {"classification": "Adverb", "word": "strongly"},
    {"classification": "Verb", "word": "struck"},
    {"classification": "Adjective", "word": "structural"},
    {"classification": "Noun", "word": "structure"},
    {"classification": "Verb", "word": "struggle"},
    {"classification": "Noun", "word": "struggle"},
    {"classification": "Noun", "word": "stuck"},
    {"classification": "Noun", "word": "student"},
    {"classification": "Adjective", "word": "studied"},
    {"classification": "Noun", "word": "studio"},
    {"classification": "Verb", "word": "study"},
    {"classification": "Noun", "word": "study"},
    {"classification": "Verb", "word": "stuff"},
    {"classification": "Noun", "word": "stuff"},
    {"classification": "Adjective", "word": "stupid"},
    {"classification": "Verb", "word": "style"},
    {"classification": "Verb", "word": "subdivide"},
    {"classification": "Adjective", "word": "subject"},
    {"classification": "Verb", "word": "subject"},
    {"classification": "Noun", "word": "subject"},
    {"classification": "Adjective", "word": "subjected"},
    {"classification": "Adjective", "word": "subjective"},
    {"classification": "Adjective", "word": "submarine"},
    {"classification": "Noun", "word": "submarine"},
    {"classification": "Verb", "word": "subordinate"},
    {"classification": "Adjective", "word": "subordinate"},
    {"classification": "Adjective", "word": "subsequent"},
    {"classification": "Verb", "word": "subside"},
    {"classification": "Verb", "word": "subsidize"},
    {"classification": "Verb", "word": "substance"},
    {"classification": "Noun", "word": "substance"},
    {"classification": "Adjective", "word": "substantial"},
    {"classification": "Adverb", "word": "substantially"},
    {"classification": "Adjective", "word": "substrate"},
    {"classification": "Verb", "word": "substrate"},
    {"classification": "Adjective", "word": "subtle"},
    {"classification": "Adjective", "word": "suburban"},
    {"classification": "Verb", "word": "succeed"},
    {"classification": "Noun", "word": "success"},
    {"classification": "Adjective", "word": "successful"},
    {"classification": "Adjective", "word": "such"},
    {"classification": "Verb", "word": "suck"},
    {"classification": "Noun", "word": "suck"},
    {"classification": "Adverb", "word": "sudden"},
    {"classification": "Adjective", "word": "sudden"},
    {"classification": "Noun", "word": "sudden"},
    {"classification": "Verb", "word": "suffer"},
    {"classification": "Adjective", "word": "suffering"},
    {"classification": "Verb", "word": "suffice"},
    {"classification": "Adjective", "word": "sufficient"},
    {"classification": "Adverb", "word": "sufficiently"},
    {"classification": "Verb", "word": "sugar"},
    {"classification": "Noun", "word": "sugar"},
    {"classification": "Verb", "word": "suggest"},
    {"classification": "Verb", "word": "suit"},
    {"classification": "Noun", "word": "suit"},
    {"classification": "Adjective", "word": "suitable"},
    {"classification": "Noun", "word": "suite"},
    {"classification": "Verb", "word": "sum"},
    {"classification": "Noun", "word": "sum"},
    {"classification": "Adjective", "word": "summary"},
    {"classification": "Verb", "word": "summer"},
    {"classification": "Noun", "word": "summer"},
    {"classification": "Verb", "word": "sun"},
    {"classification": "Noun", "word": "sun"},
    {"classification": "Adjective", "word": "sunday"},
    {"classification": "Noun", "word": "sunday"},
    {"classification": "Adjective", "word": "superficial"},
    {"classification": "Verb", "word": "superimpose"},
    {"classification": "Adjective", "word": "superior"},
    {"classification": "Verb", "word": "supper"},
    {"classification": "Noun", "word": "supper"},
    {"classification": "Verb", "word": "supplement"},
    {"classification": "Verb", "word": "supply"},
    {"classification": "Adjective", "word": "supply"},
    {"classification": "Noun", "word": "supply"},
    {"classification": "Verb", "word": "support"},
    {"classification": "Noun", "word": "support"},
    {"classification": "Verb", "word": "suppose"},
    {"classification": "Verb", "word": "suppress"},
    {"classification": "Adjective", "word": "supreme"},
    {"classification": "Adjective", "word": "sure"},
    {"classification": "Adverb", "word": "sure"},
    {"classification": "Adverb", "word": "surely"},
    {"classification": "Verb", "word": "surface"},
    {"classification": "Noun", "word": "surface"},
    {"classification": "Adjective", "word": "surplus"},
    {"classification": "Noun", "word": "surplus"},
    {"classification": "Adjective", "word": "surprising"},
    {"classification": "Verb", "word": "surrender"},
    {"classification": "Noun", "word": "surrender"},
    {"classification": "Verb", "word": "surround"},
    {"classification": "Noun", "word": "surround"},
    {"classification": "Adjective", "word": "surrounding"},
    {"classification": "Verb", "word": "survey"},
    {"classification": "Noun", "word": "survey"},
    {"classification": "Noun", "word": "survival"},
    {"classification": "Verb", "word": "survive"},
    {"classification": "Adjective", "word": "suspect"},
    {"classification": "Verb", "word": "suspect"},
    {"classification": "Adjective", "word": "suspected"},
    {"classification": "Verb", "word": "suspend"},
    {"classification": "Noun", "word": "suspend"},
    {"classification": "Verb", "word": "suspicion"},
    {"classification": "Noun", "word": "suspicion"},
    {"classification": "Adjective", "word": "suspicious"},
    {"classification": "Verb", "word": "sustain"},
    {"classification": "Noun", "word": "sustain"},
    {"classification": "Verb", "word": "swallow"},
    {"classification": "Noun", "word": "swallow"},
    {"classification": "Verb", "word": "swear"},
    {"classification": "Verb", "word": "sweat"},
    {"classification": "Verb", "word": "sweep"},
    {"classification": "Noun", "word": "sweep"},
    {"classification": "Adjective", "word": "sweet"},
    {"classification": "Adverb", "word": "sweet"},
    {"classification": "Verb", "word": "sweet"},
    {"classification": "Noun", "word": "sweet"},
    {"classification": "Verb", "word": "sweeten"},
    {"classification": "Adjective", "word": "sweeten"},
    {"classification": "Adjective", "word": "swell"},
    {"classification": "Verb", "word": "swell"},
    {"classification": "Noun", "word": "swell"},
    {"classification": "Adverb", "word": "swift"},
    {"classification": "Verb", "word": "swift"},
    {"classification": "Noun", "word": "swift"},
    {"classification": "Verb", "word": "swim"},
    {"classification": "Noun", "word": "swim"},
    {"classification": "Adjective", "word": "swimming"},
    {"classification": "Noun", "word": "swimming"},
    {"classification": "Verb", "word": "swing"},
    {"classification": "Noun", "word": "swing"},
    {"classification": "Verb", "word": "switch"},
    {"classification": "Noun", "word": "switch"},
    {"classification": "Noun", "word": "sword"},
    {"classification": "Verb", "word": "symbol"},
    {"classification": "Noun", "word": "symbol"},
    {"classification": "Adjective", "word": "symbolic"},
    {"classification": "Adjective", "word": "sympathetic"},
    {"classification": "Noun", "word": "symptom"},
    {"classification": "Adjective", "word": "synthetic"},
    {"classification": "Noun", "word": "system"},
    {"classification": "Verb", "word": "table"},
    {"classification": "Noun", "word": "table"},
    {"classification": "Adjective", "word": "tail"},
    {"classification": "Verb", "word": "tail"},
    {"classification": "Noun", "word": "tail"},
    {"classification": "Verb", "word": "tailor"},
    {"classification": "Noun", "word": "tailor"},
    {"classification": "Verb", "word": "take"},
    {"classification": "Noun", "word": "take"},
    {"classification": "Adjective", "word": "taking"},
    {"classification": "Noun", "word": "taking"},
    {"classification": "Verb", "word": "tale"},
    {"classification": "Noun", "word": "tale"},
    {"classification": "Verb", "word": "talent"},
    {"classification": "Noun", "word": "tales"},
    {"classification": "Verb", "word": "talk"},
    {"classification": "Noun", "word": "talk"},
    {"classification": "Adjective", "word": "talking"},
    {"classification": "Adjective", "word": "tall"},
    {"classification": "Adjective", "word": "tame"},
    {"classification": "Verb", "word": "tame"},
    {"classification": "Adjective", "word": "tangent"},
    {"classification": "Verb", "word": "tangent"},
    {"classification": "Adjective", "word": "tangible"},
    {"classification": "Verb", "word": "tap"},
    {"classification": "Noun", "word": "tap"},
    {"classification": "Verb", "word": "tape"},
    {"classification": "Noun", "word": "tape"},
    {"classification": "Noun", "word": "target"},
    {"classification": "Verb", "word": "task"},
    {"classification": "Verb", "word": "taste"},
    {"classification": "Noun", "word": "taste"},
    {"classification": "Adjective", "word": "taught"},
    {"classification": "Noun", "word": "tax"},
    {"classification": "Verb", "word": "tea"},
    {"classification": "Noun", "word": "tea"},
    {"classification": "Verb", "word": "teach"},
    {"classification": "Noun", "word": "teaching"},
    {"classification": "Verb", "word": "team"},
    {"classification": "Noun", "word": "team"},
    {"classification": "Verb", "word": "tear"},
    {"classification": "Noun", "word": "tear"},
    {"classification": "Adjective", "word": "technical"},
    {"classification": "Verb", "word": "teeth"},
    {"classification": "Noun", "word": "teeth"},
    {"classification": "Verb", "word": "telegraph"},
    {"classification": "Verb", "word": "telephone"},
    {"classification": "Noun", "word": "telescope"},
    {"classification": "Verb", "word": "telescope"},
    {"classification": "Adjective", "word": "telescope"},
    {"classification": "Noun", "word": "tell"},
    {"classification": "Verb", "word": "tell"},
    {"classification": "Adjective", "word": "telling"},
    {"classification": "Noun", "word": "temper"},
    {"classification": "Verb", "word": "temper"},
    {"classification": "Noun", "word": "temple"},
    {"classification": "Verb", "word": "temple"},
    {"classification": "Adverb", "word": "temporarily"},
    {"classification": "Adjective", "word": "temporary"},
    {"classification": "Verb", "word": "tempt"},
    {"classification": "Noun", "word": "ten"},
    {"classification": "Adjective", "word": "ten"},
    {"classification": "Verb", "word": "tend"},
    {"classification": "Adjective", "word": "tend"},
    {"classification": "Noun", "word": "tender"},
    {"classification": "Verb", "word": "tender"},
    {"classification": "Adjective", "word": "tender"},
    {"classification": "Noun", "word": "tense"},
    {"classification": "Adjective", "word": "tense"},
    {"classification": "Adjective", "word": "tension"},
    {"classification": "Noun", "word": "tent"},
    {"classification": "Verb", "word": "tent"},
    {"classification": "Adjective", "word": "tentative"},
    {"classification": "Noun", "word": "term"},
    {"classification": "Adjective", "word": "terrible"},
    {"classification": "Noun", "word": "terror"},
    {"classification": "Noun", "word": "test"},
    {"classification": "Verb", "word": "test"},
    {"classification": "Noun", "word": "testament"},
    {"classification": "Verb", "word": "testimony"},
    {"classification": "Noun", "word": "tests"},
    {"classification": "Noun", "word": "texas"},
    {"classification": "Noun", "word": "text"},
    {"classification": "Verb", "word": "text"},
    {"classification": "Noun", "word": "textile"},
    {"classification": "Adjective", "word": "textile"},
    {"classification": "Noun", "word": "texture"},
    {"classification": "Verb", "word": "texture"},
    {"classification": "SubordConjunction", "word": "than"},
    {"classification": "Adverb", "word": "than"},
    {"classification": "Noun", "word": "thank"},
    {"classification": "Noun", "word": "thanks"},
    {"classification": "Pronoun", "word": "that"},
    {"classification": "SubordConjunction", "word": "that"},
    {"classification": "Verb", "word": "the"},
    {"classification": "Adverb", "word": "the"},
    {"classification": "Noun", "word": "theater"},
    {"classification": "Noun", "word": "theatre"},
    {"classification": "Adjective", "word": "theatrical"},
    {"classification": "Noun", "word": "theft"},
    {"classification": "Pronoun", "word": "their"},
    {"classification": "Pronoun", "word": "theirs "},
    {"classification": "Pronoun", "word": "them"},
    {"classification": "Noun", "word": "theme"},
    {"classification": "Adverb", "word": "then"},
    {"classification": "Adjective", "word": "theological"},
    {"classification": "Noun", "word": "theorem"},
    {"classification": "Verb", "word": "theorem"},
    {"classification": "Adjective", "word": "theoretical"},
    {"classification": "Noun", "word": "theory"},
    {"classification": "Adverb", "word": "thereafter"},
    {"classification": "Adverb", "word": "thereby"},
    {"classification": "Adverb", "word": "therefore"},
    {"classification": "Adjective", "word": "thermal"},
    {"classification": "Noun", "word": "these"},
    {"classification": "Pronoun", "word": "these"},
    {"classification": "Pronoun", "word": "they"},
    {"classification": "Noun", "word": "thick"},
    {"classification": "Adverb", "word": "thick"},
    {"classification": "Adjective", "word": "thick"},
    {"classification": "Verb", "word": "thicken"},
    {"classification": "Noun", "word": "thickness"},
    {"classification": "Noun", "word": "thief"},
    {"classification": "Verb", "word": "thin"},
    {"classification": "Adjective", "word": "thin"},
    {"classification": "Adverb", "word": "thin"},
    {"classification": "Noun", "word": "thing"},
    {"classification": "Noun", "word": "think"},
    {"classification": "Verb", "word": "think"},
    {"classification": "Noun", "word": "thinking"},
    {"classification": "Adjective", "word": "thinking"},
    {"classification": "Noun", "word": "third"},
    {"classification": "Adjective", "word": "third"},
    {"classification": "Noun", "word": "thirst"},
    {"classification": "Verb", "word": "thirst"},
    {"classification": "Noun", "word": "thirty"},
    {"classification": "Adjective", "word": "thirty"},
    {"classification": "Pronoun", "word": "this"},
    {"classification": "Noun", "word": "thorn"},
    {"classification": "Verb", "word": "thorn"},
    {"classification": "Noun", "word": "thorough"},
    {"classification": "Preposition", "word": "thorough"},
    {"classification": "Adverb", "word": "thorough"},
    {"classification": "Adjective", "word": "thorough"},
    {"classification": "Adverb", "word": "thoroughly"},
    {"classification": "Pronoun", "word": "those "},
    {"classification": "SubordConjunction", "word": "though"},
    {"classification": "Adverb", "word": "though"},
    {"classification": "Noun", "word": "thought"},
    {"classification": "Noun", "word": "thousand"},
    {"classification": "Adjective", "word": "thousand"},
    {"classification": "Noun", "word": "thread"},
    {"classification": "Verb", "word": "thread"},
    {"classification": "Noun", "word": "threat"},
    {"classification": "Verb", "word": "threaten"},
    {"classification": "Noun", "word": "three"},
    {"classification": "Adjective", "word": "three"},
    {"classification": "Verb", "word": "threw"},
    {"classification": "Noun", "word": "throat"},
    {"classification": "Verb", "word": "throat"},
    {"classification": "Preposition", "word": "through"},
    {"classification": "Adjective", "word": "through"},
    {"classification": "Adverb", "word": "through"},
    {"classification": "Preposition", "word": "throughout"},
    {"classification": "Adverb", "word": "throughout"},
    {"classification": "Noun", "word": "throw"},
    {"classification": "Verb", "word": "throw"},
    {"classification": "Noun", "word": "thrust"},
    {"classification": "Verb", "word": "thrust"},
    {"classification": "Noun", "word": "thumb"},
    {"classification": "Verb", "word": "thumb"},
    {"classification": "Noun", "word": "thunder"},
    {"classification": "Verb", "word": "thunder"},
    {"classification": "Noun", "word": "thursday"},
    {"classification": "Noun", "word": "thus"},
    {"classification": "Adverb", "word": "thus"},
    {"classification": "Adjective", "word": "thyroid"},
    {"classification": "Verb", "word": "ticket"},
    {"classification": "Noun", "word": "tide"},
    {"classification": "Verb", "word": "tide"},
    {"classification": "Noun", "word": "tidy"},
    {"classification": "Verb", "word": "tidy"},
    {"classification": "Adjective", "word": "tidy"},
    {"classification": "Verb", "word": "tie"},
    {"classification": "Adjective", "word": "tight"},
    {"classification": "Verb", "word": "tight"},
    {"classification": "Verb", "word": "tighten"},
    {"classification": "Noun", "word": "till"},
    {"classification": "SubordConjunction", "word": "till"},
    {"classification": "Verb", "word": "till"},
    {"classification": "Noun", "word": "time"},
    {"classification": "Verb", "word": "time"},
    {"classification": "Noun", "word": "times"},
    {"classification": "Noun", "word": "tin"},
    {"classification": "Verb", "word": "tin"},
    {"classification": "Adjective", "word": "tiny"},
    {"classification": "Noun", "word": "tip"},
    {"classification": "Verb", "word": "tip"},
    {"classification": "Noun", "word": "tire"},
    {"classification": "Verb", "word": "tire"},
    {"classification": "Adjective", "word": "tired"},
    {"classification": "Noun", "word": "tissue"},
    {"classification": "Verb", "word": "tissue"},
    {"classification": "Noun", "word": "title"},
    {"classification": "Preposition", "word": "to"},
    {"classification": "Verb", "word": "toast"},
    {"classification": "Noun", "word": "tobacco"},
    {"classification": "Noun", "word": "toe"},
    {"classification": "Verb", "word": "toe"},
    {"classification": "Verb", "word": "tolerate"},
    {"classification": "Noun", "word": "tom"},
    {"classification": "Noun", "word": "tomorrow"},
    {"classification": "Adverb", "word": "tomorrow"},
    {"classification": "Noun", "word": "ton"},
    {"classification": "Noun", "word": "tone"},
    {"classification": "Verb", "word": "tone"},
    {"classification": "Noun", "word": "tongue"},
    {"classification": "Verb", "word": "tongue"},
    {"classification": "Noun", "word": "tonight"},
    {"classification": "Adverb", "word": "tonight"},
    {"classification": "Adverb", "word": "too"},
    {"classification": "Verb", "word": "took"},
    {"classification": "Noun", "word": "tool"},
    {"classification": "Verb", "word": "tool"},
    {"classification": "Noun", "word": "tooth"},
    {"classification": "Verb", "word": "tooth"},
    {"classification": "Noun", "word": "top"},
    {"classification": "Verb", "word": "top"},
    {"classification": "Noun", "word": "topic"},
    {"classification": "Adjective", "word": "topic"},
    {"classification": "Noun", "word": "total"},
    {"classification": "Verb", "word": "total"},
    {"classification": "Adjective", "word": "total"},
    {"classification": "Adverb", "word": "totally"},
    {"classification": "Noun", "word": "touch"},
    {"classification": "Verb", "word": "touch"},
    {"classification": "Adjective", "word": "touch"},
    {"classification": "Adjective", "word": "tough"},
    {"classification": "Noun", "word": "tour"},
    {"classification": "Verb", "word": "tour"},
    {"classification": "Noun", "word": "tournament"},
    {"classification": "Preposition", "word": "toward"},
    {"classification": "Adverb", "word": "toward"},
    {"classification": "Preposition", "word": "towards"},
    {"classification": "Adverb", "word": "towards"},
    {"classification": "Noun", "word": "towel"},
    {"classification": "Verb", "word": "towel"},
    {"classification": "Noun", "word": "tower"},
    {"classification": "Verb", "word": "tower"},
    {"classification": "Verb", "word": "toy"},
    {"classification": "Noun", "word": "trace"},
    {"classification": "Verb", "word": "trace"},
    {"classification": "Noun", "word": "track"},
    {"classification": "Verb", "word": "track"},
    {"classification": "Noun", "word": "tractor"},
    {"classification": "Verb", "word": "trade"},
    {"classification": "Adjective", "word": "trading"},
    {"classification": "Noun", "word": "tradition"},
    {"classification": "Verb", "word": "tradition"},
    {"classification": "Adjective", "word": "traditional"},
    {"classification": "Verb", "word": "traffic"},
    {"classification": "Noun", "word": "tragic"},
    {"classification": "Adjective", "word": "tragic"},
    {"classification": "Noun", "word": "trail"},
    {"classification": "Verb", "word": "trail"},
    {"classification": "Noun", "word": "train"},
    {"classification": "Verb", "word": "train"},
    {"classification": "Noun", "word": "training"},
    {"classification": "Noun", "word": "trait"},
    {"classification": "Verb", "word": "trait"},
    {"classification": "Verb", "word": "transact"},
    {"classification": "Noun", "word": "transfer"},
    {"classification": "Verb", "word": "transfer"},
    {"classification": "Verb", "word": "transform"},
    {"classification": "Verb", "word": "translate"},
    {"classification": "Noun", "word": "translation"},
    {"classification": "Verb", "word": "transmit"},
    {"classification": "Adjective", "word": "transparent"},
    {"classification": "Verb", "word": "transport"},
    {"classification": "Noun", "word": "trap"},
    {"classification": "Adjective", "word": "trap"},
    {"classification": "Verb", "word": "trap"},
    {"classification": "Noun", "word": "travel"},
    {"classification": "Verb", "word": "travel"},
    {"classification": "Adjective", "word": "traveled"},
    {"classification": "Noun", "word": "tray"},
    {"classification": "Verb", "word": "tray"},
    {"classification": "Noun", "word": "treasure"},
    {"classification": "Verb", "word": "treasure"},
    {"classification": "Noun", "word": "treat"},
    {"classification": "Verb", "word": "treat"},
    {"classification": "Noun", "word": "treatment"},
    {"classification": "Noun", "word": "treaty"},
    {"classification": "Noun", "word": "tree"},
    {"classification": "Verb", "word": "tree"},
    {"classification": "Noun", "word": "tremble"},
    {"classification": "Verb", "word": "tremble"},
    {"classification": "Adjective", "word": "trembling"},
    {"classification": "Adjective", "word": "tremendous"},
    {"classification": "Noun", "word": "trend"},
    {"classification": "Verb", "word": "trend"},
    {"classification": "Noun", "word": "trial"},
    {"classification": "Noun", "word": "triangle"},
    {"classification": "Noun", "word": "tribe"},
    {"classification": "Verb", "word": "tribe"},
    {"classification": "Verb", "word": "tribute"},
    {"classification": "Adjective", "word": "trick"},
    {"classification": "Verb", "word": "trick"},
    {"classification": "Noun", "word": "trim"},
    {"classification": "Verb", "word": "trim"},
    {"classification": "Noun", "word": "trip"},
    {"classification": "Verb", "word": "trip"},
    {"classification": "Noun", "word": "triumph"},
    {"classification": "Verb", "word": "triumph"},
    {"classification": "Noun", "word": "trivial"},
    {"classification": "Adjective", "word": "trivial"},
    {"classification": "Adjective", "word": "trouble"},
    {"classification": "Verb", "word": "trouble"},
    {"classification": "Noun", "word": "truck"},
    {"classification": "Verb", "word": "truck"},
    {"classification": "Noun", "word": "true"},
    {"classification": "Adjective", "word": "true"},
    {"classification": "Adverb", "word": "true"},
    {"classification": "Adverb", "word": "truly"},
    {"classification": "Noun", "word": "trunk"},
    {"classification": "Verb", "word": "trunk"},
    {"classification": "Noun", "word": "trust"},
    {"classification": "Adjective", "word": "trust"},
    {"classification": "Verb", "word": "trust"},
    {"classification": "Noun", "word": "truth"},
    {"classification": "Verb", "word": "truth"},
    {"classification": "Noun", "word": "try"},
    {"classification": "Verb", "word": "try"},
    {"classification": "Adjective", "word": "trying"},
    {"classification": "Noun", "word": "tube"},
    {"classification": "Verb", "word": "tube"},
    {"classification": "Noun", "word": "tuesday"},
    {"classification": "Noun", "word": "tune"},
    {"classification": "Verb", "word": "tune"},
    {"classification": "Noun", "word": "turn"},
    {"classification": "Verb", "word": "turn"},
    {"classification": "Noun", "word": "turning"},
    {"classification": "Noun", "word": "twelve"},
    {"classification": "Adjective", "word": "twelve"},
    {"classification": "Adjective", "word": "twentieth"},
    {"classification": "Noun", "word": "twenty"},
    {"classification": "Adjective", "word": "twenty"},
    {"classification": "Adverb", "word": "twice"},
    {"classification": "Noun", "word": "twist"},
    {"classification": "Verb", "word": "twist"},
    {"classification": "Noun", "word": "two"},
    {"classification": "Noun", "word": "type"},
    {"classification": "Verb", "word": "type"},
    {"classification": "Adjective", "word": "typical"},
    {"classification": "Noun", "word": "ugly"},
    {"classification": "Adjective", "word": "ugly"},
    {"classification": "Verb", "word": "ugly"},
    {"classification": "Adjective", "word": "ultimate"},
    {"classification": "Adverb", "word": "ultimately"},
    {"classification": "Adjective", "word": "unable"},
    {"classification": "Adjective", "word": "uncertain"},
    {"classification": "Noun", "word": "uncle"},
    {"classification": "Adjective", "word": "unconscious"},
    {"classification": "Preposition", "word": "under"},
    {"classification": "Adjective", "word": "under"},
    {"classification": "Adverb", "word": "under"},
    {"classification": "Verb", "word": "undergo"},
    {"classification": "Adjective", "word": "underground"},
    {"classification": "Adverb", "word": "underground"},
    {"classification": "Verb", "word": "underlie"},
    {"classification": "Adjective", "word": "underlying"},
    {"classification": "Preposition", "word": "underneath"},
    {"classification": "Adverb", "word": "underneath"},
    {"classification": "Verb", "word": "understand"},
    {"classification": "Adjective", "word": "understanding"},
    {"classification": "Verb", "word": "undertake"},
    {"classification": "Adverb", "word": "unduly"},
    {"classification": "Adjective", "word": "uneasy"},
    {"classification": "Adjective", "word": "unexpected"},
    {"classification": "Noun", "word": "unfortunate"},
    {"classification": "Adjective", "word": "unfortunate"},
    {"classification": "Adjective", "word": "unhappy"},
    {"classification": "Adjective", "word": "uniform"},
    {"classification": "Verb", "word": "uniform"},
    {"classification": "Noun", "word": "union"},
    {"classification": "Noun", "word": "unique"},
    {"classification": "Adjective", "word": "unique"},
    {"classification": "Noun", "word": "unit"},
    {"classification": "Verb", "word": "unite"},
    {"classification": "Adjective", "word": "united"},
    {"classification": "Noun", "word": "unity"},
    {"classification": "Noun", "word": "universal"},
    {"classification": "Adjective", "word": "universal"},
    {"classification": "Adjective", "word": "unknown"},
    {"classification": "Adjective", "word": "unlike"},
    {"classification": "Adjective", "word": "unlikely"},
    {"classification": "Adverb", "word": "unlikely"},
    {"classification": "SubordConjunction", "word": "until"},
    {"classification": "Preposition", "word": "until"},
    {"classification": "Adjective", "word": "unusual"},
    {"classification": "Noun", "word": "up"},
    {"classification": "Preposition", "word": "up"},
    {"classification": "Adverb", "word": "up"},
    {"classification": "Adjective", "word": "up"},
    {"classification": "Preposition", "word": "upon"},
    {"classification": "Noun", "word": "upper"},
    {"classification": "Adjective", "word": "uppermost"},
    {"classification": "Noun", "word": "upright"},
    {"classification": "Adjective", "word": "upright"},
    {"classification": "Noun", "word": "upset"},
    {"classification": "Verb", "word": "upset"},
    {"classification": "Adjective", "word": "upset"},
    {"classification": "Adjective", "word": "upstairs"},
    {"classification": "Adverb", "word": "upstairs"},
    {"classification": "Noun", "word": "upward"},
    {"classification": "Adjective", "word": "upward"},
    {"classification": "Adverb", "word": "upward"},
    {"classification": "Adjective", "word": "urban"},
    {"classification": "Noun", "word": "urethane"},
    {"classification": "Verb", "word": "urge"},
    {"classification": "Adjective", "word": "urgent"},
    {"classification": "Noun", "word": "us"},
    {"classification": "Pronoun", "word": "us"},
    {"classification": "Noun", "word": "usage"},
    {"classification": "Verb", "word": "use"},
    {"classification": "Adjective", "word": "useful"},
    {"classification": "Noun", "word": "usual"},
    {"classification": "Verb", "word": "utilize"},
    {"classification": "Noun", "word": "utopia"},
    {"classification": "Adjective", "word": "utopian"},
    {"classification": "Noun", "word": "utter"},
    {"classification": "Adjective", "word": "utter"},
    {"classification": "Adverb", "word": "utterly"},
    {"classification": "Noun", "word": "vacation"},
    {"classification": "Noun", "word": "vacuum"},
    {"classification": "Noun", "word": "vague"},
    {"classification": "Verb", "word": "vague"},
    {"classification": "Noun", "word": "vain"},
    {"classification": "Adjective", "word": "vain"},
    {"classification": "Adjective", "word": "valid"},
    {"classification": "Noun", "word": "valley"},
    {"classification": "Noun", "word": "valuable"},
    {"classification": "Adjective", "word": "valuable"},
    {"classification": "Noun", "word": "value"},
    {"classification": "Verb", "word": "value"},
    {"classification": "Noun", "word": "van"},
    {"classification": "Verb", "word": "van"},
    {"classification": "Adjective", "word": "variable"},
    {"classification": "Noun", "word": "variation"},
    {"classification": "Adjective", "word": "varied"},
    {"classification": "Adjective", "word": "various"},
    {"classification": "Noun", "word": "vary"},
    {"classification": "Verb", "word": "vary"},
    {"classification": "Noun", "word": "vast"},
    {"classification": "Adjective", "word": "vast"},
    {"classification": "Noun", "word": "vehicle"},
    {"classification": "Noun", "word": "veil"},
    {"classification": "Noun", "word": "vein"},
    {"classification": "Verb", "word": "vein"},
    {"classification": "Noun", "word": "venture"},
    {"classification": "Verb", "word": "venture"},
    {"classification": "Noun", "word": "verb"},
    {"classification": "Noun", "word": "verbal"},
    {"classification": "Adjective", "word": "verbal"},
    {"classification": "Verb", "word": "verify"},
    {"classification": "Noun", "word": "verse"},
    {"classification": "Verb", "word": "verse"},
    {"classification": "Noun", "word": "version"},
    {"classification": "Noun", "word": "vertical"},
    {"classification": "Adjective", "word": "vertical"},
    {"classification": "Adverb", "word": "very"},
    {"classification": "Verb", "word": "very"},
    {"classification": "Noun", "word": "vessel"},
    {"classification": "Verb", "word": "vessel"},
    {"classification": "Noun", "word": "veteran"},
    {"classification": "Adjective", "word": "veteran"},
    {"classification": "Noun", "word": "via"},
    {"classification": "Preposition", "word": "via"},
    {"classification": "Verb", "word": "vibrate"},
    {"classification": "Noun", "word": "vice"},
    {"classification": "Verb", "word": "vice"},
    {"classification": "Noun", "word": "victim"},
    {"classification": "Noun", "word": "victor"},
    {"classification": "Adjective", "word": "victor"},
    {"classification": "Noun", "word": "view"},
    {"classification": "Verb", "word": "view"},
    {"classification": "Adjective", "word": "vigorous"},
    {"classification": "Noun", "word": "village"},
    {"classification": "Verb", "word": "violate"},
    {"classification": "Noun", "word": "violence"},
    {"classification": "Verb", "word": "violence"},
    {"classification": "Verb", "word": "violent"},
    {"classification": "Adjective", "word": "violent"},
    {"classification": "Noun", "word": "virgin"},
    {"classification": "Adjective", "word": "virgin"},
    {"classification": "Verb", "word": "virgin"},
    {"classification": "Adjective", "word": "virginia"},
    {"classification": "Adjective", "word": "virtual"},
    {"classification": "Adverb", "word": "virtually"},
    {"classification": "Noun", "word": "virtue"},
    {"classification": "Adjective", "word": "visible"},
    {"classification": "Verb", "word": "vision"},
    {"classification": "Verb", "word": "visit"},
    {"classification": "Adjective", "word": "visual"},
    {"classification": "Noun", "word": "vital"},
    {"classification": "Adjective", "word": "vital"},
    {"classification": "Adjective", "word": "vivid"},
    {"classification": "Noun", "word": "voice"},
    {"classification": "Verb", "word": "voice"},
    {"classification": "Noun", "word": "volt"},
    {"classification": "Noun", "word": "volume"},
    {"classification": "Verb", "word": "voluntary"},
    {"classification": "Noun", "word": "vote"},
    {"classification": "Verb", "word": "vote"},
    {"classification": "Noun", "word": "vowel"},
    {"classification": "Adjective", "word": "vowel"},
    {"classification": "Noun", "word": "voyage"},
    {"classification": "Verb", "word": "voyage"},
    {"classification": "Verb", "word": "wage"},
    {"classification": "Noun", "word": "wages"},
    {"classification": "Noun", "word": "wagon"},
    {"classification": "Verb", "word": "wagon"},
    {"classification": "Noun", "word": "waist"},
    {"classification": "Verb", "word": "wait"},
    {"classification": "Noun", "word": "waiter"},
    {"classification": "Noun", "word": "wake"},
    {"classification": "Verb", "word": "wake"},
    {"classification": "Noun", "word": "walk"},
    {"classification": "Verb", "word": "walk"},
    {"classification": "Noun", "word": "wall"},
    {"classification": "Verb", "word": "wall"},
    {"classification": "Verb", "word": "walter"},
    {"classification": "Verb", "word": "wander"},
    {"classification": "Verb", "word": "want"},
    {"classification": "Noun", "word": "war"},
    {"classification": "Verb", "word": "war"},
    {"classification": "Adjective", "word": "war"},
    {"classification": "Noun", "word": "ward"},
    {"classification": "Adjective", "word": "ward"},
    {"classification": "Verb", "word": "ward"},
    {"classification": "Noun", "word": "warfare"},
    {"classification": "Verb", "word": "warfare"},
    {"classification": "Noun", "word": "warm"},
    {"classification": "Verb", "word": "warm"},
    {"classification": "Adjective", "word": "warm"},
    {"classification": "Noun", "word": "warmth"},
    {"classification": "Verb", "word": "warn"},
    {"classification": "Noun", "word": "warning"},
    {"classification": "Adjective", "word": "warning"},
    {"classification": "Noun", "word": "warren"},
    {"classification": "Verb", "word": "was"},
    {"classification": "Noun", "word": "wash"},
    {"classification": "Adjective", "word": "wash"},
    {"classification": "Verb", "word": "wash"},
    {"classification": "Adjective", "word": "washed"},
    {"classification": "Noun", "word": "waste"},
    {"classification": "Verb", "word": "waste"},
    {"classification": "Adjective", "word": "waste"},
    {"classification": "Noun", "word": "watch"},
    {"classification": "Verb", "word": "watch"},
    {"classification": "Noun", "word": "water"},
    {"classification": "Verb", "word": "water"},
    {"classification": "Noun", "word": "wave"},
    {"classification": "Verb", "word": "wave"},
    {"classification": "Noun", "word": "wax"},
    {"classification": "Verb", "word": "wax"},
    {"classification": "Noun", "word": "way"},
    {"classification": "Adverb", "word": "way"},
    {"classification": "Verb", "word": "way"},
    {"classification": "Noun", "word": "we"},
    {"classification": "Pronoun", "word": "we"},
    {"classification": "Adjective", "word": "weak"},
    {"classification": "Verb", "word": "weak"},
    {"classification": "Verb", "word": "weaken"},
    {"classification": "Noun", "word": "weakness"},
    {"classification": "Noun", "word": "wealth"},
    {"classification": "Noun", "word": "weapon"},
    {"classification": "Noun", "word": "wear"},
    {"classification": "Verb", "word": "wear"},
    {"classification": "Adjective", "word": "wearing"},
    {"classification": "Noun", "word": "weather"},
    {"classification": "Verb", "word": "weather"},
    {"classification": "Adjective", "word": "weather"},
    {"classification": "Noun", "word": "weave"},
    {"classification": "Verb", "word": "weave"},
    {"classification": "Noun", "word": "wedding"},
    {"classification": "Adjective", "word": "wednesday"},
    {"classification": "Noun", "word": "weed"},
    {"classification": "Verb", "word": "weed"},
    {"classification": "Noun", "word": "week"},
    {"classification": "Noun", "word": "weekly"},
    {"classification": "Adjective", "word": "weekly"},
    {"classification": "Adverb", "word": "weekly"},
    {"classification": "Noun", "word": "weigh"},
    {"classification": "Verb", "word": "weigh"},
    {"classification": "Verb", "word": "weight"},
    {"classification": "Noun", "word": "welcome"},
    {"classification": "Verb", "word": "welcome"},
    {"classification": "Noun", "word": "welfare"},
    {"classification": "Verb", "word": "well"},
    {"classification": "Adjective", "word": "well"},
    {"classification": "Noun", "word": "went"},
    {"classification": "Verb", "word": "went"},
    {"classification": "Noun", "word": "were"},
    {"classification": "Verb", "word": "were"},
    {"classification": "Noun", "word": "west"},
    {"classification": "Verb", "word": "west"},
    {"classification": "Adverb", "word": "west"},
    {"classification": "Adjective", "word": "west"},
    {"classification": "Adjective", "word": "western"},
    {"classification": "Adjective", "word": "wet"},
    {"classification": "Verb", "word": "wet"},
    {"classification": "Noun", "word": "what"},
    {"classification": "Pronoun", "word": "what"},
    {"classification": "Noun", "word": "wheat"},
    {"classification": "Noun", "word": "wheel"},
    {"classification": "Verb", "word": "wheel"},
    {"classification": "SubordConjunction", "word": "when"},
    {"classification": "Adverb", "word": "when"},
    {"classification": "Noun", "word": "where"},
    {"classification": "SubordConjunction", "word": "where"},
    {"classification": "Adverb", "word": "where"},
    {"classification": "Adverb", "word": "whereas"},
    {"classification": "Adverb", "word": "whereby"},
    {"classification": "Adverb", "word": "wherever"},
    {"classification": "SubordConjunction", "word": "whether"},
    {"classification": "Pronoun", "word": "which"},
    {"classification": "Adjective", "word": "which"},
    {"classification": "Noun", "word": "while"},
    {"classification": "SubordConjunction", "word": "while"},
    {"classification": "Preposition", "word": "while"},
    {"classification": "Verb", "word": "while"},
    {"classification": "Noun", "word": "whip"},
    {"classification": "Verb", "word": "whip"},
    {"classification": "Noun", "word": "whisky"},
    {"classification": "Noun", "word": "whisper"},
    {"classification": "Verb", "word": "whisper"},
    {"classification": "Verb", "word": "whistle"},
    {"classification": "Noun", "word": "white"},
    {"classification": "Adjective", "word": "white"},
    {"classification": "Verb", "word": "white"},
    {"classification": "Verb", "word": "whiten"},
    {"classification": "Pronoun", "word": "who"},
    {"classification": "Noun", "word": "whole"},
    {"classification": "Adjective", "word": "whole"},
    {"classification": "Adverb", "word": "wholly"},
    {"classification": "Pronoun", "word": "whom"},
    {"classification": "Pronoun", "word": "whose "},
    {"classification": "Noun", "word": "why"},
    {"classification": "Adverb", "word": "why"},
    {"classification": "Adjective", "word": "wicked"},
    {"classification": "Noun", "word": "wide"},
    {"classification": "Adverb", "word": "wide"},
    {"classification": "Adjective", "word": "wide"},
    {"classification": "Adverb", "word": "widely"},
    {"classification": "Verb", "word": "widen"},
    {"classification": "Adjective", "word": "widespread"},
    {"classification": "Noun", "word": "widow"},
    {"classification": "Adjective", "word": "widow"},
    {"classification": "Verb", "word": "widow"},
    {"classification": "Noun", "word": "widower"},
    {"classification": "Noun", "word": "width"},
    {"classification": "Noun", "word": "wife"},
    {"classification": "Noun", "word": "wild"},
    {"classification": "Adverb", "word": "wild"},
    {"classification": "Adjective", "word": "wild"},
    {"classification": "Adverb", "word": "wildly"},
    {"classification": "Noun", "word": "will"},
    {"classification": "Adverb", "word": "will"},
    {"classification": "Verb", "word": "will"},
    {"classification": "Verb", "word": "willing"},
    {"classification": "Adjective", "word": "win"},
    {"classification": "Verb", "word": "win"},
    {"classification": "Noun", "word": "wind"},
    {"classification": "Verb", "word": "wind"},
    {"classification": "Noun", "word": "window"},
    {"classification": "Verb", "word": "window"},
    {"classification": "Noun", "word": "wine"},
    {"classification": "Noun", "word": "wing"},
    {"classification": "Verb", "word": "wing"},
    {"classification": "Noun", "word": "winning"},
    {"classification": "Adjective", "word": "winning"},
    {"classification": "Noun", "word": "winter"},
    {"classification": "Verb", "word": "winter"},
    {"classification": "Noun", "word": "wipe"},
    {"classification": "Verb", "word": "wipe"},
    {"classification": "Noun", "word": "wire"},
    {"classification": "Verb", "word": "wire"},
    {"classification": "Adjective", "word": "wisdom"},
    {"classification": "Verb", "word": "wise"},
    {"classification": "Noun", "word": "wish"},
    {"classification": "Verb", "word": "wish"},
    {"classification": "Noun", "word": "wit"},
    {"classification": "Verb", "word": "wit"},
    {"classification": "Noun", "word": "with"},
    {"classification": "Preposition", "word": "with"},
    {"classification": "Verb", "word": "withdraw"},
    {"classification": "Preposition", "word": "within"},
    {"classification": "Adverb", "word": "within"},
    {"classification": "Preposition", "word": "without "},
    {"classification": "Adverb", "word": "without"},
    {"classification": "Verb", "word": "witness"},
    {"classification": "Noun", "word": "woman"},
    {"classification": "Verb", "word": "woman"},
    {"classification": "Noun", "word": "wonder"},
    {"classification": "Adjective", "word": "wonder"},
    {"classification": "Adverb", "word": "wonder"},
    {"classification": "Verb", "word": "wonder"},
    {"classification": "Adjective", "word": "wondered"},
    {"classification": "Adjective", "word": "wonderful"},
    {"classification": "Noun", "word": "wood"},
    {"classification": "Adjective", "word": "wood"},
    {"classification": "Verb", "word": "wood"},
    {"classification": "Adjective", "word": "wooden"},
    {"classification": "Noun", "word": "woodruff"},
    {"classification": "Noun", "word": "wool"},
    {"classification": "Noun", "word": "woolen"},
    {"classification": "Adjective", "word": "woolen"},
    {"classification": "Noun", "word": "word"},
    {"classification": "Verb", "word": "word"},
    {"classification": "Verb", "word": "wore"},
    {"classification": "Noun", "word": "work"},
    {"classification": "Verb", "word": "work"},
    {"classification": "Noun", "word": "worker"},
    {"classification": "Noun", "word": "worm"},
    {"classification": "Verb", "word": "worm"},
    {"classification": "Noun", "word": "worry"},
    {"classification": "Verb", "word": "worry"},
    {"classification": "Noun", "word": "worse"},
    {"classification": "Adjective", "word": "worse"},
    {"classification": "Verb", "word": "worse"},
    {"classification": "Adjective", "word": "worship"},
    {"classification": "Verb", "word": "worship"},
    {"classification": "Noun", "word": "worst"},
    {"classification": "Adjective", "word": "worst"},
    {"classification": "Verb", "word": "worst"},
    {"classification": "Adjective", "word": "worth"},
    {"classification": "Verb", "word": "worth"},
    {"classification": "Noun", "word": "worthy"},
    {"classification": "Verb", "word": "worthy"},
    {"classification": "Noun", "word": "would"},
    {"classification": "Verb", "word": "would"},
    {"classification": "Noun", "word": "wound"},
    {"classification": "Noun", "word": "wrap"},
    {"classification": "Verb", "word": "wrap"},
    {"classification": "Verb", "word": "wreck"},
    {"classification": "Noun", "word": "wright"},
    {"classification": "Noun", "word": "wrist"},
    {"classification": "Verb", "word": "write"},
    {"classification": "Noun", "word": "writer"},
    {"classification": "Noun", "word": "writing"},
    {"classification": "Adjective", "word": "wrong"},
    {"classification": "Adverb", "word": "wrong"},
    {"classification": "Verb", "word": "wrong"},
    {"classification": "Noun", "word": "yard"},
    {"classification": "Verb", "word": "yard"},
    {"classification": "Noun", "word": "year"},
    {"classification": "Noun", "word": "yell"},
    {"classification": "Verb", "word": "yell"},
    {"classification": "Noun", "word": "yellow"},
    {"classification": "Verb", "word": "yellow"},
    {"classification": "Adjective", "word": "yellow"},
    {"classification": "Adverb", "word": "yes"},
    {"classification": "Noun", "word": "yesterday"},
    {"classification": "Adverb", "word": "yesterday"},
    {"classification": "Noun", "word": "yet"},
    {"classification": "CoordConjunction", "word": "yet"},
    {"classification": "Adverb", "word": "yet"},
    {"classification": "Noun", "word": "yield"},
    {"classification": "Verb", "word": "yield"},
    {"classification": "Pronoun", "word": "you"},
    {"classification": "Noun", "word": "young"},
    {"classification": "Adjective", "word": "young"},
    {"classification": "Noun", "word": "youngster"},
    {"classification": "Pronoun", "word": "your"},
    {"classification": "Pronoun", "word": "yours"},
    {"classification": "Noun", "word": "youth"},
    {"classification": "Noun", "word": "zero"},
    {"classification": "Interjection", "word": "adieu!"},
    {"classification": "Interjection", "word": "ah!"},
    {"classification": "Interjection", "word": "aha!"},
    {"classification": "Interjection", "word": "ahem!"},
    {"classification": "Interjection", "word": "ahoy!"},
    {"classification": "Interjection", "word": "alas!"},
    {"classification": "Interjection", "word": "all right!"},
    {"classification": "Interjection", "word": "amen!"},
    {"classification": "Interjection", "word": "ay!"},
    {"classification": "Interjection", "word": "bah!"},
    {"classification": "Interjection", "word": "behold!"},
    {"classification": "Interjection", "word": "blast!"},
    {"classification": "Interjection", "word": "boo!"},
    {"classification": "Interjection", "word": "bravo!"},
    {"classification": "Interjection", "word": "damn!"},
    {"classification": "Interjection", "word": "dear me!"},
    {"classification": "Interjection", "word": "dear!"},
    {"classification": "Interjection", "word": "duh!"},
    {"classification": "Interjection", "word": "eh!"},
    {"classification": "Interjection", "word": "encore!"},
    {"classification": "Interjection", "word": "er!"},
    {"classification": "Interjection", "word": "fie!"},
    {"classification": "Interjection", "word": "flip!"},
    {"classification": "Interjection", "word": "gadzooks!"},
    {"classification": "Interjection", "word": "gee whiz!"},
    {"classification": "Interjection", "word": "good grief!"},
    {"classification": "Interjection", "word": "good!"},
    {"classification": "Interjection", "word": "goodness!"},
    {"classification": "Interjection", "word": "gosh!"},
    {"classification": "Interjection", "word": "great!"},
    {"classification": "Interjection", "word": "hah!"},
    {"classification": "Interjection", "word": "heck!"},
    {"classification": "Interjection", "word": "hell!"},
    {"classification": "Interjection", "word": "hello!"},
    {"classification": "Interjection", "word": "help!"},
    {"classification": "Interjection", "word": "here!"},
    {"classification": "Interjection", "word": "hey!"},
    {"classification": "Interjection", "word": "hi!"},
    {"classification": "Interjection", "word": "hmm!"},
    {"classification": "Interjection", "word": "ho!"},
    {"classification": "Interjection", "word": "hooray!"},
    {"classification": "Interjection", "word": "huh!"},
    {"classification": "Interjection", "word": "humph!"},
    {"classification": "Interjection", "word": "hurrah!"},
    {"classification": "Interjection", "word": "hush!"},
    {"classification": "Interjection", "word": "indeed!"},
    {"classification": "Interjection", "word": "lo!"},
    {"classification": "Interjection", "word": "my goodness!"},
    {"classification": "Interjection", "word": "now!"},
    {"classification": "Interjection", "word": "nuts!"},
    {"classification": "Interjection", "word": "oh no!"},
    {"classification": "Interjection", "word": "oh!"},
    {"classification": "Interjection", "word": "oooops!"},
    {"classification": "Interjection", "word": "oops!"},
    {"classification": "Interjection", "word": "ouch!"},
    {"classification": "Interjection", "word": "phew!"},
    {"classification": "Interjection", "word": "pshaw!"},
    {"classification": "Interjection", "word": "right on!"},
    {"classification": "Interjection", "word": "so!"},
    {"classification": "Interjection", "word": "super!"},
    {"classification": "Interjection", "word": "there!"},
    {"classification": "Interjection", "word": "tush!"},
    {"classification": "Interjection", "word": "tut!"},
    {"classification": "Interjection", "word": "ugh!"},
    {"classification": "Interjection", "word": "uh!"},
    {"classification": "Interjection", "word": "uh-huh!"},
    {"classification": "Interjection", "word": "um!"},
    {"classification": "Interjection", "word": "um, umm!"},
    {"classification": "Interjection", "word": "well!"},
    {"classification": "Interjection", "word": "what!"},
    {"classification": "Interjection", "word": "whoa!"},
    {"classification": "Interjection", "word": "whoopee!"},
    {"classification": "Interjection", "word": "whoops!"},
    {"classification": "Interjection", "word": "why!"},
    {"classification": "Interjection", "word": "wow!"},
    {"classification": "Interjection", "word": "yay!"},
    {"classification": "Interjection", "word": "yes!"},
    {"classification": "Interjection", "word": "yikes!"},
    {"classification": "Interjection", "word": "yippee!"},
    {"classification": "Interjection", "word": "yo!"},
    {"classification": "Interjection", "word": "yoo-hoo!"},
    {"classification": "Interjection", "word": "yuck!"},
]
